@@ -40,8 +40,8 @@ namespace ArrayCore {
     Stores the list of stations and log stream.
   */
 
-  AbstractArrayTool::AbstractArrayTool()
-    : _arraySelection(&_array)
+  AbstractArrayTool::AbstractArrayTool(QObject * parent)
+    : AbstractTool(parent), _arraySelection(&_array)
   {
     TRACE;
     _results=nullptr;
@@ -95,29 +95,25 @@ namespace ArrayCore {
     return nullptr;
   }
 
-  bool AbstractArrayTool::setParameters(const AbstractParameters& param)
+  bool AbstractArrayTool::selectStations()
   {
     TRACE;
-    const ArrayParameters * aParam=dynamic_cast<const ArrayParameters *>(&param);
-    if(!aParam) {
-      qDebug() << "Parameters are not ArrayParameters in AbstractArrayTool::setParameters.";
-      return false;
-    }
+    ArrayParameters * param=parameters();
+
     // Compute the definitive coordinates with corrections for 3C processing
-    _array.setRelativePos(aParam->magneticDeclination());
+    _array.setRelativePos(param->magneticDeclination());
 
     // Eventually restrict the original set of station (time and radius conditions)
     _arraySelection.clear();
-    aParam->selectStations(_arraySelection);
+    return param->selectStations(_arraySelection);
+  }
 
-    if(!AbstractTool::setParameters(param)) {
-      return false;
-    }
+  bool AbstractArrayTool::setFrequencySampling()
+  {
+    TRACE;
+    ArrayParameters * param=parameters();
 
-    _results->setParameters(parameters());
-
-    ArrayParameters * myParam=parameters();
-    SamplingParameters& samplingParam=myParam->frequencySampling();
+    SamplingParameters& samplingParam=param->frequencySampling();
     if(samplingParam.isValid()) {
       return true;
     }
@@ -126,7 +122,7 @@ namespace ArrayCore {
       // Minimum: at least 2 block sets
       // Maximum: up to Nyquist frequency
       if(samplingParam.minimum()<=0.0) {
-        samplingParam.setMinimum(minimumFrequency(2, myParam->windowing().periodCount()));
+        samplingParam.setMinimum(minimumFrequency(2, param->windowing().periodCount()));
       }
       if(samplingParam.maximum()<=0.0) {
         samplingParam.setMaximum(maximumFrequency());
@@ -177,7 +173,7 @@ namespace ArrayCore {
   {
     TRACE;
     if(!array()->isEmpty()) {
-      return 0.5*array()->at(0)->samplingFrequency();
+      return 0.5*array()->samplingFrequency();
     } else {
       return 0.0;
     }
@@ -186,12 +182,21 @@ namespace ArrayCore {
   bool AbstractArrayTool::setLoop()
   {
     TRACE;
-    ASSERT(_results);
+    if(parameters()->frequencySampling().count()==0) {
+      App::log(tr("Empty frequency sampling\n"));
+      return false;
+    }
     if(!AbstractTool::setLoop()) {
       return false;
     }
     ArrayTaskManager * loop=static_cast<ArrayTaskManager *>(AbstractTool::loop());
-    loop->setResults(_results);
+    if(_results) {
+      // Not a virtual function, in next loop->setParameters(),
+      // re-implemented classes init also parameters, see if
+      // it is worth to move to a virtual function (check FK, SPAC,...)
+      _results->setParameters(parameters());
+      loop->setResults(_results);
+    }
     if(loop->setParameters(parameters())) {
       loop->setTasks();
       return true;
@@ -200,11 +205,13 @@ namespace ArrayCore {
     }
   }
 
-  void AbstractArrayTool::start()
+  void AbstractArrayTool::start(int threadCount, bool forceParallel)
   {
     TRACE;
-    _results->clear();
-    AbstractTool::start();
+    if(_results) {
+      _results->clear();
+    }
+    AbstractTool::start(threadCount, forceParallel);
   }
 
   SparseTimeRange AbstractArrayTool::timeRange() const
