@@ -17,8 +17,8 @@
 **
 **  See http://www.geopsy.org for more information.
 **
-**  Created: 2018-10-04
-**  Copyright: 2018-2019
+**  Created: 2022-07-22
+**  Copyright: 2022
 **    Marc Wathelet (ISTerre, Grenoble, France)
 **
 ***************************************************************************/
@@ -26,34 +26,30 @@
 #ifndef ACTIVECONVFKRAYLEIGH_H
 #define ACTIVECONVFKRAYLEIGH_H
 
-#include "ActiveConvFKVertical.h"
+#include "AbstractFKRayleigh.h"
 #include "ArrayCoreDLLExport.h"
 
 namespace ArrayCore {
 
-  class ARRAYCORE_EXPORT ActiveConvFKRayleigh : public ActiveConvFKVertical
+  class ARRAYCORE_EXPORT ActiveConvFKRayleigh : public AbstractFKRayleigh
   {
   public:
-    ActiveConvFKRayleigh(FKCache * gridCache)
-    : ActiveConvFKVertical(gridCache) {_RoverN=0.0; _ellipticity=0.0;}
+    ActiveConvFKRayleigh(FKCache * cache);
+    ~ActiveConvFKRayleigh();
 
-    void setGrid(FKGridSearch * g, double step, double size);
-    bool isOnLimit(const Point& k, double frequency) const;
+    void initialize(const FKParameters& param);
+    FunctionSearch * createSearch(const FKParameters& param);
+    bool setSource(const VectorList<int>& blocks);
 
-    bool setSource(const QVector<int>& blocks);
+    void resetCrossSpectrum();
     void addCrossSpectrum();
+    void meanCrossSpectrum(int nBlocks);
+    void addIncoherentNoise(double horizontal, double vertical);
 
-    double value(const Point& kell) const;
+    void shareSteering(const ActiveConvFKRayleigh * s);
+    void clearSharedSteering();
 
-    Point2D waveNumber(const Point& k) const {return Point2D(k.x(), 0.0);}
-    bool hasEllipticity() const {return true;}
-    double ellipticity(const Point& kell, bool& ok);
-    double noise(const Point&) const;
-  protected:
-    double ellipticityHelper(double ellh, double ellz);
-
-    double _RoverN;
-    double _ellipticity;
+    FK_ACTIVE_STEERING
   };
 
 } // namespace ArrayCore
