@@ -25,6 +25,7 @@
 
 #include "ActiveFKTaskManager.h"
 #include "ActiveFKWorker.h"
+#include "ActiveFKTask.h"
 
 namespace ArrayCore {
 
@@ -86,5 +87,11 @@ namespace ArrayCore {
     }
   }
 
+  ParallelTask * ActiveFKTaskManager::createTask(int taskIndex)
+  {
+    TRACE;
+    return new ActiveFKTask(this, taskIndex, &_array, _keep, _parameters, _source);
+  }
+
 } // namespace ArrayCore
 
