@@ -35,14 +35,17 @@ namespace ArrayCore {
   class ARRAYCORE_EXPORT ActiveFKTool : public FKTool
   {
   public:
-    ActiveFKTool();
+    ActiveFKTool(QObject * parent);
     ~ActiveFKTool();
 
-    bool setParameters(const AbstractParameters &param);
+    inline const ActiveFKParameters * parameters() const;
+    inline ActiveFKParameters * parameters();
 
     void setSource(const SeismicEvent * e);
     const SeismicEvent * source() const {return _source;}
 
+    bool setLoop();
+
     virtual bool setWaveNumberGrid();
 
     const IrregularGrid2D * grid() const {return _grid;}
@@ -50,12 +53,22 @@ namespace ArrayCore {
     virtual QString toolName() {return tr("Active FK Array analysis");}
     virtual ParallelTaskManager * createLoop() {return new ActiveFKTaskManager(array(), _source, _grid);}
   private:
-    void setGrid(const ActiveFKParameters& param);
+    void setGrid();
 
     const SeismicEvent * _source;
     IrregularGrid2D * _grid;
   };
 
+  inline const ActiveFKParameters * ActiveFKTool::parameters() const
+  {
+    return static_cast<const ActiveFKParameters *>(AbstractArrayTool::parameters());
+  }
+
+  inline ActiveFKParameters * ActiveFKTool::parameters()
+  {
+    return static_cast<ActiveFKParameters *>(AbstractArrayTool::parameters());
+  }
+
 } // namespace ArrayCore
 
 #endif // ACTIVEFKTOOL_H
