@@ -36,21 +36,22 @@ namespace ArrayCore {
   class ARRAYCORE_EXPORT ActiveFKToolSet : public AbstractTool
   {
   public:
-    ActiveFKToolSet();
+    ActiveFKToolSet(QObject * parent);
     ~ActiveFKToolSet();
 
     bool setSubPool(SubSignalPool * subPool);
-    bool setParameters(const AbstractParameters& param);
+
     inline const ActiveFKParameters * parameters() const;
     inline ActiveFKParameters * parameters();
 
     const QList<ActiveFKTool *>& sources() const {return _subTools;}
 
-    const IrregularGrid2D * grid(int index);
+    const IrregularGrid2D * grid(int index, int threadCount);
+    ParallelTaskManager * loop(int index) const;
   protected:
     virtual QString toolName() {return tr("FK Array analysis for active sources");}
   public slots:
-    virtual void start();
+    void start(int threadCount, bool forceParallel);
   private:
     QList<ActiveFKTool *> _subTools;
   };
