@@ -24,9 +24,7 @@
 ***************************************************************************/
 
 #include "ActiveHRFKRayleigh.h"
-#include "FKGridSearch.h"
 #include "FKCrossSpectrum.h"
-#include "ActiveHRFKRayleighEllipticity.h"
 
 namespace ArrayCore {
 
@@ -37,51 +35,49 @@ namespace ArrayCore {
     Full description of class still missing
   */
 
-  void ActiveHRFKRayleigh::setGrid(FKGridSearch * g, double step, double size)
-  {
-    g->setGrid(0.0, size, step, -0.5*M_PI, 0.5*M_PI, M_PI/20);
-  }
-
   bool ActiveHRFKRayleigh::invertCrossSpectrum()
   {
     return _crossSpectrum->invert();
   }
 
-  double ActiveHRFKRayleigh::value(const Point& kell) const
+  inline void ActiveHRFKRayleigh::maximumEllipticity() const
   {
-    double k2=kell.x()*kell.x();
-    if(k2>minimumK2() && k2<maximumK2()) {
-      //ComplexMatrix e, eh;
-      //double ell=::tan(kell.y());
-      //_steeringGeometry.twoComponentRayleighRadial(kell.x(), ell, e, eh);
-      //double p=caponPower(eh, _crossSpectrum->matrix(), e);
-      //return p*p*ell*ell;
+    // We admit values ouside -pi/2 to p/2 to avoid been trapped right at +/- pi/2
+    // This happens if _xi is between the limits and the minimum
+    _ellOptimization.maximize(_xi, this, M_PI/8.0);
+  }
+
+  double ActiveHRFKRayleigh::value(Vector<double>& kell) const
+  {
+    kell[1]=0.0; // Only k[0] is modified by GridSearch
+    if(isInsideLimits(kell)) {
+      _steering->oneComponent(kell[0], powerEngine());
+      maximumEllipticity();
+      canonicalEllipticity(_xi.x);
+      kell[2]=_xi.x;
+      return _xi.value;
     } else {
       return -1.0;
     }
   }
 
-  double ActiveHRFKRayleigh::noise(const Point& kell) const
+  void ActiveHRFKRayleigh::setFunctionValue(Attributes& a) const
   {
-    const ComplexMatrix& covmat=_crossSpectrum->matrix();
-    FKGridSearch grid;
-    ActiveHRFKRayleighVerticalEllipticity * fz;
-    fz=new ActiveHRFKRayleighVerticalEllipticity(_gridCache);
-    grid.setFunction(fz);
-    fz->setK(kell.x());
-    fz->setCrossSpectrum(&covmat);
-    fz->setGrid(&grid, M_PI/20, 0.5*M_PI);
-    grid.globalMax(0.0);
-    double ez=::tan(grid.pos().x());
-    ActiveHRFKRayleighRadialEllipticity * fh;
-    fh=new ActiveHRFKRayleighRadialEllipticity(_gridCache);
-    grid.setFunction(fh);
-    fh->setK(kell.x());
-    fh->setCrossSpectrum(&covmat);
-    fh->setGrid(&grid, M_PI/20, 0.5*M_PI);
-    grid.globalMax(0.0);
-    double eh=::tan(grid.pos().x());
-    return _crossSpectrum->stationCount()*(::sqrt(ez/eh)-1);
+    a.ell.setUnitExp(a.x);
+    const Vector<Complex>& e=FKSteering::twoComponentRayleighCross(a.ell, powerEngine());
+    powerEngine()->setHighResolutionValue(e);
+    a.value=powerEngine()->value();
+  }
+
+  void ActiveHRFKRayleigh::setFunctionDerivatives(Attributes& a) const
+  {
+    double value2=a.value*a.value;
+    // Get first derivative
+    const Vector<Complex>& de=FKSteering::twoComponentRayleighCrossGradient(a.ell, powerEngine());
+    a.slope=-2.0*value2*powerEngine()->ellipticityGradient(de);
+    // Get second derivative
+    a.concavity=powerEngine()->xiSecondDerivative();
+    a.concavity=2.0*(a.slope*a.slope/a.value+a.value-value2*a.concavity);
   }
 
 } // namespace ArrayCore
