@@ -34,17 +34,17 @@ namespace ArrayCore {
   class ARRAYCORE_EXPORT ActiveHRFKRayleigh : public ActiveConvFKRayleigh
   {
   public:
-    ActiveHRFKRayleigh(FKCache * gridCache)
-      : ActiveConvFKRayleigh(gridCache) {}
-
-    void setGrid(FKGridSearch * g, double step, double size);
+    ActiveHRFKRayleigh(FKCache * cache)
+      : ActiveConvFKRayleigh(cache) {}
 
     bool invertCrossSpectrum();
 
-    virtual double value(const Point& kell) const;
+    double value(Vector<double>& kell) const;
 
-    virtual double ellipticity(const Point& kell, bool& ok) {ok=true; return ::tan(kell.y());}
-    virtual double noise(const Point& kell) const;
+    void setFunctionValue(Attributes& a) const;
+    void setFunctionDerivatives(Attributes& a) const;
+  private:
+    inline void maximumEllipticity() const;
   };
 
 } // namespace ArrayCore
