@@ -47,11 +47,7 @@ namespace ArrayCore {
   ArraySelection::ArraySelection(const ArraySelection * array)
   {
     _array=array->array();
-    if(array->_parent) {
-      _parent=array->_parent;
-    } else {
-      _parent=array;
-    }
+    _parent=array;
     clear();
   }
 
@@ -79,19 +75,19 @@ namespace ArrayCore {
     }
   }
 
-  void ArraySelection::select(QVector<int> sel)
+  void ArraySelection::select(VectorList<int> sel)
   {
     TRACE;
     std::sort(sel.begin(), sel.end());
     unique(sel);
-    int n=count();
-    for(QVector<int>::iterator it=sel.begin(); it!=sel.end(); it++) {
+    int n=_selected.count();
+    for(VectorList<int>::iterator it=sel.begin(); it!=sel.end(); it++) {
       if(*it<0 || *it>=n) {
         qDebug() << "Error in index in ArraySelection::setSelection()";
         return;
       }
     }
-    for(QVector<int>::iterator it=sel.begin(); it!=sel.end(); it++) {
+    for(VectorList<int>::iterator it=sel.begin(); it!=sel.end(); it++) {
       *it=_selected.at(*it);
     }
     _selected=sel;
@@ -112,7 +108,7 @@ namespace ArrayCore {
     }
   }
 
-  QString ArraySelection::toString(Coordinates coord, int precision, char format) const
+  QString ArraySelection::toString(Coordinates coord, char format, int precision) const
   {
     TRACE;
     QString s;
@@ -123,43 +119,50 @@ namespace ArrayCore {
       utm=_array->utmZone(ok);
     }
     for(int i=0; i<n; i++) {
-      const StationSignals& stat=*at(i);
       switch(coord) {
       case Relative:
-        s+=_relativePos[i].toString(precision, format);
+        s+=_relativePos[i].toString(format, precision);
         break;
       case Absolute:
         if(utm.isValid()) {
           s+=utm.toString();
           s+=" ";
         }
-        s+=stat.coordinates().toString(precision, format);
+        s+=position(i).toString(format, precision);
         break;
       }
       s+=" ";
-      s+=stat.name();
+      s+=name(i);
       s+="\n";
     }
     return s;
   }
 
-
-  const StationSignals * ArraySelection::at(int index) const
+  QString ArraySelection::name(int index) const
   {
-    TRACE;
-    return _array->at(_selected.at(index));
+    return _array->name(_selected.at(index));
+  }
+
+  Point2D ArraySelection::position(int index) const
+  {
+    return _array->position(_selected.at(index));
+  }
+
+  StationSignals * ArraySelection::stationSignals(int index) const
+  {
+    return _array->stationSignals(_selected.at(index));
   }
 
   /*!
     Select all stations that are located at a distance from \a src between
     \a minDistance and \a maxDistance.
+    Absolute coordinates re required for \a src.
   */
   void ArraySelection::select(const Point& src, double minDistance, double maxDistance)
   {
-    QVector<int> sel;
-    // Absolute coordinates are used in the comparison, the relative positions
+    VectorList<int> sel;
     for(int i=count()-1; i>=0; i--) {
-      double d=src.distanceTo(at(i)->coordinates());
+      double d=src.horizontalDistanceTo(position(i));
       if(d>=minDistance && d<=maxDistance) {
         sel.append(i);
       }
