@@ -37,13 +37,12 @@ namespace ArrayCore {
     Currently used only by linear arrays (near-field effect reduction)
   */
 
-// Uncomment to get a detailled timing report of the signal processing
+// Get a detailled timing report of the processing
 // Run with verbosity level to 3 to get the report.
 // Level 3 also activate pre-loading of signals in AbstractTool.
-#define PROCESS_TIMING
-
+// Configure with '-D PROCESS_TIMING'
 #ifdef PROCESS_TIMING
-  static double tts=0, ttt=0, ttft=0;
+  static double ttcp=0.0, ttsb=0.0, tttp=0.0, ttft=0.0;
   static Mutex globalTimeMutex;
 #endif
 
@@ -59,9 +58,16 @@ namespace ArrayCore {
   ArrayStationSignals::~ArrayStationSignals()
   {
     TRACE;
+  }
+
+  void ArrayStationSignals::showProcessingTime()
+  {
 #ifdef PROCESS_TIMING
-    App::log(3, tr("Spectrum computation (subtract %1 ms,  taper %2 ms, ft %3 ms)\n")
-              .arg(tts*1e-6).arg(ttt*1e-6).arg(ttft*1e-6));
+    App::log(3, tr("Spectrum computation: %1 %2 %3 %4 (ms; copy, subtract,  tapers, fft)\n")
+             .arg(ttcp*1e-6)
+             .arg(ttsb*1e-6)
+             .arg(tttp*1e-6)
+             .arg(ttft*1e-6));
 #endif
   }
 
@@ -74,7 +80,8 @@ namespace ArrayCore {
     const ArrayParameters * arrayParam=static_cast<const ArrayParameters *>(param);
 #ifdef PROCESS_TIMING
     QElapsedTimer chrono;
-    int ts, tt, tft;
+    qint64 tcp, tsb, ttp, tft;
+    chrono.start();
 #endif
     int nComp=nComponents();
     for(int iComp=0; iComp<nComp; iComp++) {
@@ -82,26 +89,26 @@ namespace ArrayCore {
         return false;
       }
 #ifdef PROCESS_TIMING
-      chrono.start();
+      tcp=chrono.nsecsElapsed();
 #endif
       DoubleSignal *& sig=processed(iComp);
       //printf("Effective number of samples in window %i\n", sig->nSamples());
       sig->subtractValue();
 #ifdef PROCESS_TIMING
-      ts=chrono.nsecsElapsed();
+      tsb=chrono.nsecsElapsed();
 #endif
       // By default, set a 10% taper in time domain
-      sig->taper(taper);
+      if(!sig->taper(taper)) {
+        App::log(tr("Error applying taper, skipped\n"));
+      }
 #ifdef PROCESS_TIMING
-        tt=chrono.nsecsElapsed();
+      ttp=chrono.nsecsElapsed();
 #endif
 
       // Enlarge signal for frequency oversampling
       if(arrayParam->oversamplingFactor()>1.0) {
-        DoubleSignal * sigLarge=new DoubleSignal(static_cast<int>(sig->nSamples()*arrayParam->oversamplingFactor()));
-        sigLarge->setSamplingPeriod(sig->samplingPeriod());
-        sigLarge->setValue(0.0);
-        sigLarge->copySamplesFrom(sig, 0.0, 0.0, sig->duration());
+        DoubleSignal * sigLarge=new DoubleSignal;
+        sigLarge->frequencyOverSample(arrayParam->oversamplingFactor(), sig);
         delete sig;
         sig=sigLarge;
       }
@@ -119,19 +126,12 @@ namespace ArrayCore {
 #ifdef PROCESS_TIMING
       tft=chrono.nsecsElapsed();
       globalTimeMutex.lock();
-      tts+=ts;
-      ttt+=tt-ts;
-      ttft+=tft-tt;
+      ttcp+=tcp;
+      ttsb+=tsb-tcp;
+      tttp+=ttp-tsb;
+      ttft+=tft-ttp;
       globalTimeMutex.unlock();
 #endif
-
-      /*int nSamples=sig->nSamples();
-      CONST_LOCK_SAMPLES(double, samples, sig)
-      for(int i=0; i<nSamples/2; i++) {
-        printf("%lg %lg\n",(double)i*sig->duration(),
-                sig->amplitude(samples, i));
-      }
-      UNLOCK_SAMPLES(this)*/
     }
     return true;
   }
