@@ -83,7 +83,9 @@ namespace ArrayCore {
     if(!setTimeLimits()) {
       return false;
     }
-    setGlobalKeep();
+    if(!setGlobalKeep()) {
+      return false;
+    }
     return true;
   }
 
@@ -99,7 +101,7 @@ namespace ArrayCore {
   bool ArrayTaskManager::setTimeLimits()
   {
     if(_array.count()>0) {
-      const StationSignals * stat=_array.at(0);
+      const StationSignals * stat=_array.stationSignals(0);
       TimeRange tw=_parameters->timeLimits().absoluteRange(stat);
       if(tw.lengthSeconds()<=0) {
         App::log(tr("Processing time length is null.\n") );
@@ -112,32 +114,37 @@ namespace ArrayCore {
     }
   }
 
-  void ArrayTaskManager::setGlobalKeep()
+  bool ArrayTaskManager::setGlobalKeep()
   {
     int n=_array.count();
     // If there is no station selected, this function is not called (see setParameters() and setTimeLimits())
     ASSERT(n>0);
     // Collect ranges for all stations
-    TimeRange r=_parameters->timeLimits().absoluteRange(_array.at(0));
+    TimeRange r=_parameters->timeLimits().absoluteRange(_array.stationSignals(0));
     SparseTimeRange sr(r);
     for(int i=0; i<n; i++) {
-      SparseTimeRange ssr=_array.at(i)->timeRange(r);
+      SparseTimeRange ssr=_array.stationSignals(i)->timeRange(r);
       if(!ssr.isNull()) {
         sr=sr.intersection(ssr);
       }
     }
     delete _keep;
-    // The availibility of stations in time is checked before during selection of stations.
-    // So null keep cannot occur if a station not available at all.
     _keep=new SparseKeepSignal(sr);
     // Adjust range taking sampling of all stations into account
     for(int i=0; i<n; i++) {
-      _array.at(i)->setSampling(_keep);
+      _array.stationSignals(i)->setSampling(_keep);
     }
     // Set values of keep
+    _keep->removeNullSignals();
     _keep->initValues(1);
     for(int i=0; i<n; i++) {
-      _array.at(i)->setKeep(_keep, _parameters->windowing(), i);
+      _array.stationSignals(i)->setKeep(_keep, _parameters->windowing(), i);
+    }
+    if(_keep->keeps().count()==0) {
+      App::log(tr("No signal available, check parameters.\n"));
+      return false;
+    } else {
+      return true;
     }
   }
 
