@@ -56,6 +56,7 @@ namespace ArrayCore {
     _list.setVerbosityLevel(7);
     _plan=nullptr;
     _frequencyIndex=-1;
+    _frequencyFilter=nullptr;
   }
 
   /*!
@@ -65,6 +66,7 @@ namespace ArrayCore {
   {
     TRACE;
     delete _plan;
+    delete _frequencyFilter;
   }
 
   double ArrayTimeWindows::timeRangeLength() const
@@ -75,23 +77,58 @@ namespace ArrayCore {
   }
 
   /*!
-    Calculate the list of time windows for the current frequency.
+    Calculates the list of time windows for the current frequency.
   */
   void ArrayTimeWindows::setWindows()
   {
     ASSERT(_keep);
-    double f=_frequency.center();
+    double frequency=_frequency.center();
     _list.clear();
-    _list.add(f, _parameters->windowing(), *_keep, _keep->timeRange().range(), _events);
+    if(_parameters->windowing().seismicEventTrigger()) {
+      QList<const SeismicEvent *> events=_events->events(_keep->timeRange().range());
+      _list.add(frequency, _parameters->windowing(), *_keep, events);
+    } else {
+      _list.add(frequency, _parameters->windowing(), *_keep, _keep->timeRange().range());
+    }
+    initPreprocessing();
+  }
+
+  /*!
+    Calculates the list of time windows for the current frequency for one particular
+    \a event (active FK).
+  */
+  void ArrayTimeWindows::setWindows(const SeismicEvent * event)
+  {
+    ASSERT(_keep);
+    _list.clear();
+    QList<const SeismicEvent *> events;
+    events.append(event);
+    _list.add(_frequency.center(), _parameters->windowing(), *_keep, events);
+    initPreprocessing();
+  }
+
+  /*!
+    Initialization of taper and frequency filter based on window length
+  */
+  void ArrayTimeWindows::initPreprocessing()
+  {
     if(!_list.isEmpty()) {
       double oversamplingFactor=_parameters->oversamplingFactor();
       double duration=_list.at(0).lengthSeconds();
-      _frequencyFilter.calculate(_frequency, oversamplingFactor*duration, _samplingFrequency);
-      _frequencyFilter.sqrt();
       if(_parameters->frequencyBandwidth()==0) {
         delete _plan;
         _plan=new FourierPlan(qRound(_list.at(0).lengthSamples(_samplingFrequency)*oversamplingFactor),
-                              _samplingPeriod, f);
+                              _samplingPeriod, _frequency.center());
+        if(_frequencyFilter) {
+          delete _frequencyFilter;
+          _frequencyFilter=nullptr;
+        }
+      } else {
+        if(!_frequencyFilter) {
+          _frequencyFilter=new GaussianFrequencyBand();
+        }
+        _frequencyFilter->calculate(_frequency, oversamplingFactor*duration, _samplingFrequency);
+        _frequencyFilter->sqrt();
       }
       // Store taper function that is the same for all time windows, for all stations and for
       // all components.
