@@ -61,7 +61,7 @@ namespace ArrayCore {
     _crossSpectrum->setTimeWindows(at->timeWindows());
     const TimeWindowList& winList=_crossSpectrum->timeWindows()->list();
     while(!terminated()) {
-      QVector<int> blocks=param.list(t->currentStep(), _crossSpectrum->stationCount(), winList);
+      VectorList<int> blocks=param.list(t->currentStep(), _crossSpectrum->stationCount(), winList);
       if(blocks.isEmpty()) {
         t->setFinishing();
         break;
