@@ -48,19 +48,6 @@ namespace ArrayCore {
     _statisticMaxOverlap=0.0;
   }
 
-  /*!
-    Description of destructor still missing
-  */
-  BlockAveragingParameters::BlockAveragingParameters(const BlockAveragingParameters& o)
-    : AbstractParameters(o)
-  {
-    _overlap=o._overlap;
-    _count=o._count;
-    _countFactor=o._countFactor;
-    _statisticCount=o._statisticCount;
-    _statisticMaxOverlap=o._statisticMaxOverlap;
-  }
-
   void BlockAveragingParameters::setStatisticMaxOverlap(double n)
   {
     if(n<0.0) {
@@ -89,7 +76,7 @@ namespace ArrayCore {
     There can be sometimes a little more process than STATISTIC_COUNT.
     STATISTIC_MAX_OVERLAP is also considered.
   */
-  int BlockAveragingParameters::increment(const TimeRangeList& winList, const QVector<int>& blocks) const
+  int BlockAveragingParameters::increment(const TimeRangeList& winList, const VectorList<int>& blocks) const
   {
     TRACE;
     // No window or no maximum expected window count specified
@@ -100,6 +87,9 @@ namespace ArrayCore {
     // In case of time window overlap, it can be larger than the actual block count
     int processCount=blocks.last()-blocks.first()+1;
     int minIncr=qCeil(processCount*(1.0-_statisticMaxOverlap));
+    if(minIncr<1) {
+      minIncr=1;
+    }
     if(_statisticCount<=0) {
       return minIncr;
     }
@@ -115,9 +105,6 @@ namespace ArrayCore {
     int winIncr=qRound(maxProcessCount/static_cast<double>(_statisticCount));
     // In case of gaps processLength may be larger than the average, maxProcessCount may be smaller
     // than the average, hence the local increment may be smaller which is the expected behavior.
-    if(winIncr<2) {
-      winIncr=1;
-    }
     if(winIncr<minIncr) {
       winIncr=minIncr;
     }
@@ -128,8 +115,8 @@ namespace ArrayCore {
   /*!
     Return a list of blocks (indexes to time windows).
   */
-  QVector<int> BlockAveragingParameters::list(int firstWindowIndex, int stationCount,
-                                              const TimeRangeList& winList) const
+  VectorList<int> BlockAveragingParameters::list(int firstWindowIndex, int stationCount,
+                                                 const TimeRangeList& winList) const
   {
     TRACE;
     // Number of blocks must be at least the number of stations
@@ -138,7 +125,7 @@ namespace ArrayCore {
     int nWin=winList.count();
     int nBlocks=count(stationCount);
     TimeRange currentWindow;
-    QVector<int> list;
+    VectorList<int> list;
     int windowIndex=firstWindowIndex;
 
     if(windowIndex>=nWin) { // No block available
@@ -163,7 +150,7 @@ namespace ArrayCore {
         }
       }
       if(windowIndex>=nWin) { // Not enough blocks available
-        if(_countFactor>0.0 || _count>0) {
+        if((_countFactor>0.0 || _count>0) && nBlocks<INT_MAX) {
           list.clear();
           if(firstWindowIndex==0) {
             App::log(tr("Not enough time windows available to have %1 non-overlapping blocks.\n")
@@ -198,15 +185,16 @@ namespace ArrayCore {
   {
     TRACE;
     QString log;
-    log+="# Overlap is controled by the WINDOWS parameters, by default non overlapping blocks are selected\n";
+    log+="# Overlap of blocks is controled by WINDOW_OVERLAP. If this option is set to 'y', overlapping \n"
+         "# blocks are skipped. Do not confuse block overlap and block set overlap (see STATISTIC_MAX_OVERLAP).\n";
     log+=prefix+"BLOCK_OVERLAP"+suffix+"(y/n)="+(_overlap ? "y\n" : "n\n");
     log+="# If BLOCK_COUNT is null, BLOCK_COUNT=BLOCK_COUNT_FACTOR*<number of stations>\n";
     log+=prefix+"BLOCK_COUNT"+suffix+"="+QString::number(_count)+"\n";
     log+=prefix+"BLOCK_COUNT_FACTOR"+suffix+"="+QString::number(_countFactor)+"\n";
     log+="# If STATISTIC_COUNT is not null, approx. STATISTIC_COUNT estimates par frequency\n";
     log+=prefix+"STATISTIC_COUNT"+suffix+"="+QString::number(_statisticCount)+"\n";
-    log+="# If STATISTIC_MAX_OVERLAP=100%, successive statistics can be computed on overlapping block sets\n";
-    log+="# If STATISTIC_MAX_OVERLAP=0%, successive statistics are computed on non-overlapping block sets\n";
+    log+="# If STATISTIC_MAX_OVERLAP=100%, successive statistics can be computed on overlapping block sets\n"
+         "# If STATISTIC_MAX_OVERLAP=0%, successive statistics are computed on non-overlapping block sets\n";
     log+=prefix+"STATISTIC_MAX_OVERLAP"+suffix+"(%)="+QString::number(_statisticMaxOverlap*100.0)+"\n";
     return log;
   }
@@ -214,22 +202,23 @@ namespace ArrayCore {
   bool BlockAveragingParameters::setValue(PARAMETERS_SETVALUE_ARGS)
   {
     TRACE;
+    bool ok=true;
     switch(index-AbstractParameters::keywordCount()) {
     case 0:
       _overlap=(value=="y");
       return true;
     case 1:
-      _count=value.toInt();
-      return true;
+      _count=value.toInt(&ok);
+      return ok;
     case 2:
-      _countFactor=value.toDouble();
-      return true;
+      _countFactor=value.toDouble(&ok);
+      return ok;
     case 3:
-      _statisticCount=value.toInt();
-      return true;
+      _statisticCount=value.toInt(&ok);
+      return ok;
     case 4:
-      setStatisticMaxOverlap(value.toDouble()*0.01);
-      return true;
+      setStatisticMaxOverlap(value.toDouble(&ok)*0.01);
+      return ok;
     default:
       break;
     }
