@@ -17,8 +17,8 @@
 **
 **  See http://www.geopsy.org for more information.
 **
-**  Created: 2018-02-02
-**  Copyright: 2018-2019
+**  Created: 2022-07-22
+**  Copyright: 2022
 **    Marc Wathelet (ISTerre, Grenoble, France)
 **
 ***************************************************************************/
@@ -26,28 +26,27 @@
 #ifndef CONVFKRAYLEIGH_H
 #define CONVFKRAYLEIGH_H
 
-#include "AbstractFKFunction.h"
+#include "AbstractFKRayleigh.h"
+#include "ArrayCoreDLLExport.h"
 
 namespace ArrayCore {
 
-  class ARRAYCORE_EXPORT ConvFKRayleigh : public AbstractFKFunction
+  class ARRAYCORE_EXPORT ConvFKRayleigh : public AbstractFKRayleigh
   {
   public:
-    ConvFKRayleigh(FKCache * gridCache);
+    ConvFKRayleigh(FKCache * cache);
 
-    virtual void resetCrossSpectrum();
-    virtual void addCrossSpectrum();
-    virtual void meanCrossSpectrum(int nBlocks);
+    void initialize(const FKParameters& param);
+    FunctionSearch * createSearch(const FKParameters& param);
 
-    virtual bool initGrid(int n);
-    virtual void setGrid(FKGridSearch * g, double step, double size);
-    virtual void initGrid(const Point& kell, int index);
+    void resetCrossSpectrum();
+    void addCrossSpectrum();
+    void meanCrossSpectrum(int nBlocks);
+    void addIncoherentNoise(double horizontal, double vertical);
 
-    virtual double value(const Point& kell, int index) const;
-    virtual double value(const Point& kell) const;
+    const ComplexMatrix * crossSpectrum() const;
 
-    virtual bool hasEllipticity() const {return true;}
-    virtual double ellipticity(const Point& kell, bool& ok) {ok=true; return ::tan(kell.z());}
+    FK_PASSIVE_STEERING
   };
 
 } // namespace ArrayCore
