@@ -30,9 +30,9 @@
 
 #include "ArraySelection.h"
 #include "FKSteering.h"
+#include "ActiveFKSteering.h"
 #include "ArrayCoreDLLExport.h"
-
-#define STEERING_CASE_COUNT 7
+#include "KNullSolver.h"
 
 namespace ArrayCore {
 
@@ -42,28 +42,23 @@ namespace ArrayCore {
     FKCache(const ArraySelection * array);
     ~FKCache();
 
-    enum SteeringType {OneComponent=0,
-                       TwoComponentRayleigh,
-                       ThreeComponentRayleigh,
-                       ThreeComponentRayleighFixedEll,
-                       TwoComponentRadial,
-                       TwoComponentTransverse,
-                       TwoComponentRayleighFixedEll
-                      };
-
     const ArraySelection * array() const {return _array;}
 
-    bool isEmpty(SteeringType st) {return !_steering[st];}
-    void resize(SteeringType st, int cacheItemCount);
-    void reportCacheVolume(SteeringType st, int count, int sizeFactor) const;
+    void setPassiveSteering();
+    FKSteering * passiveSteering() const {return _passiveSteering;}
 
-    const FKSteering& steering(SteeringType st, int index) const {return _steering[st][index];}
-    FKSteering& steering(SteeringType st, int index) {return _steering[st][index];}
+    inline double arrayPatternSecondDerivativeAtOrigin(const Vector<double>& k) const;
   private:
     const ArraySelection * _array;
-    FKSteering * _steering[STEERING_CASE_COUNT];
+    FKSteering * _passiveSteering;
+    TheoreticalFK * _beampattern;
   };
 
+  inline double FKCache::arrayPatternSecondDerivativeAtOrigin(const Vector<double>& k) const
+  {
+    return _beampattern->radialSecondDerivativeAtOrigin(k);
+  }
+
 } // namespace ArrayCore
 
 #endif // FKCACHE_H
