@@ -47,14 +47,9 @@ namespace ArrayCore {
     void setArray(const ArraySelection * array);
     virtual void clear();
 
-    double minimumSlowness() const {return _minimumSlowness;}
-    void setMinimumSlowness(double s) {_minimumSlowness=s;}
-
     const FKParameters * parameters() const {return static_cast<const FKParameters *>(_parameters);}
 
-    inline bool add(const Point2D &k, double ell, double noise, double power,
-                    const WaveNumberConverter& conv);
-    inline void add(const FKPeaks& peaks);
+    inline void add(FKPeaks& peaks);
 
     bool isEmpty() const {return _peaks.size()==0;}
 
@@ -140,19 +135,12 @@ private:
     void range(const QList<Curve<RealStatisticalPoint> >& curves, double& fMin, double& fMax, double& sMax) const;
 
     int _binCount;
-    double _minimumSlowness;
     FKPeaks _peaks;
     QList<Curve<RealStatisticalPoint> > _curves;
     QStringList _files;
   };
 
-  inline bool FKResults::add(const Point2D &k, double ell, double noise, double power,
-                             const WaveNumberConverter& conv)
-  {
-    return _peaks.add(k, ell, noise, power, conv, _minimumSlowness);
-  }
-
-  inline void FKResults::add(const FKPeaks& peaks)
+  inline void FKResults::add(FKPeaks& peaks)
   {
     return _peaks.add(peaks);
   }
