@@ -75,7 +75,10 @@ namespace ArrayCore {
     TRACE;
     FKWorker * w=new FKWorker(&_array, parameters());
     w->setTaskManager(this);
-    w->setGrid(_gridCache);
+    if(!w->setGrid(_gridCache)) {
+      delete w;
+      w=nullptr;
+    }
     return w;
   }
 
