@@ -38,7 +38,7 @@ namespace ArrayCore {
     FKTaskManager(const ArraySelection * array);
     ~FKTaskManager();
 
-    virtual bool setParameters(const ArrayParameters * param);
+    bool setParameters(const ArrayParameters * param);
     const FKParameters * parameters() const {return static_cast<const FKParameters *>(_parameters);}
   protected:
     LoopWorker * newWorker();
