@@ -27,7 +27,6 @@
 #define FKTOOL_H
 
 #include "AbstractArrayTool.h"
-#include "FKTaskManager.h"
 #include "FKResults.h"
 #include "ArrayCoreDLLExport.h"
 
@@ -39,24 +38,27 @@ namespace ArrayCore {
   {
     Q_OBJECT
   public:
-    FKTool();
+    FKTool(QObject * parent);
     ~FKTool();
 
     virtual bool setSubPool(SubSignalPool *subPool);
-    bool setParameters(const AbstractParameters& param);
+
     inline const FKParameters * parameters() const;
     inline FKParameters * parameters();
 
+    bool setLoop();
     virtual bool setWaveNumberGrid();
 
     FKResults * results() const {return static_cast<FKResults *>(AbstractArrayTool::results());}
-    virtual void waitFinished();
+    void waitFinished(int ms);
     bool isWaveNumberGridReady() const {return !_kmaxSolver;}
+
+    bool saveResults(const QString& fileName);
   protected:
     virtual QString toolName() {return tr("FK Array analysis");}
-    virtual ParallelTaskManager * createLoop() {return new FKTaskManager(array());}
+    ParallelTaskManager * createLoop();
   public slots:
-    void start();
+    void start(int threadCount, bool forceParallel);
   signals:
     void waveNumberGridReady();
   private slots:
