@@ -25,16 +25,24 @@
 
 #include "FKWorker.h"
 #include "FKTaskManager.h"
-#include "FKGridSearch.h"
 #include "ArrayStations.h"
 #include "WaveNumberConverter.h"
 #include "FKResults.h"
 
-//#define INSPECT_FREQUENCY 2.945
-//#define INSPECT_TIME "20170314115338"
+//#define INSPECT_FREQUENCY 5.9958019753561773157
+//#define INSPECT_TIME "20000101000000.000000"
+
+// Run with verbosity level to 3 to get the report.
+// Level 3 also activate pre-loading of signals in AbstractTool.
+// Configure with '-D PROCESS_TIMING'
 
 namespace ArrayCore {
 
+#ifdef PROCESS_TIMING
+  static double ttmg=0.0;
+  static Mutex globalTimeMutex;
+#endif
+
   /*!
     \class FKWorker FKWorker.h
     \brief Brief description of class still missing
@@ -51,7 +59,7 @@ namespace ArrayCore {
     TRACE;
     _crossSpectrum=new FKCrossSpectrum(array, param);
     _peaks.setTimeReference(array->array()->first()->minTime());
-    _grid=nullptr;
+    _search=nullptr;
   }
 
   /*!
@@ -60,50 +68,50 @@ namespace ArrayCore {
   FKWorker::~FKWorker()
   {
     TRACE;
+    delete _search;
+#ifdef PROCESS_TIMING
+    App::log(3, tr("Merging results: %1 (ms)\n")
+             .arg(ttmg*1e-6));
+#endif
   }
 
-  bool FKWorker::setGrid(FKCache * gridCache)
+  bool FKWorker::setGrid(FKCache * cache)
   {
     TRACE;
     AbstractFKFunction * f=AbstractFKFunction::create(taskManager()->array().array()->mode(),
-                                                      crossSpectrum()->parameters(), gridCache);
+                                                      crossSpectrum()->parameters(), cache);
     if(f) {
       f->setCrossSpectrum(crossSpectrum());
       const FKParameters * param=crossSpectrum()->parameters();
-      // Cross-spectrum depends upon k for RTBF, analytical gradient is not supported.
-      /*if(param->inversionMethod()==FKParameters::Gradient && param->processType()!=FKParameters::RTBF) {
-         g=new FKGradientSearch;
-         g->setFunction(f);
-         f->setGrid(static_cast<FKGradientSearch *>(g), param->cacheGridStep(), param->gridStep(), param->effectiveGridSize());
-      } else {*/
-         _grid=new FKGridSearch;
-         _grid->setFunction(f);
-         f->setGrid(_grid, param->gridStep(), param->effectiveGridSize());
-      //}
+      // Initialization that require the virtual mechanism (e.g. allocation of power engine)
+      f->initialize(*param);
+      // Limiting search to kmin speedup computation but may pick alias peaks
+      // Better to filter out after FK search
+      //f->setMinimumWavenumber(param->minimumWaveNumber());
+      // Reduce the gridded box to a circle of radius effective grid size
+      f->setMaximumWavenumber(param->effectiveGridSize());
+      f->setMaximumSlowness(param->maximumSlowness());
+      _search=f->createSearch(*param);
+      f->setGridStep(param->gridStep());
       return true;
     } else {
-      delete _grid;
-      _grid=nullptr;
+      delete _search;
+      _search=nullptr;
       return false;
     }
   }
 
-  void FKWorker::process(const QVector<int>& blocks)
+  void FKWorker::process(const VectorList<int>& blocks)
   {
-    // If the frequency band width is null, _crossSpectrum->frequency().center() is not exactly the
-    // frequency that is processed. Using DTFT exact frequency is required.
-    double freq;
-    if(_crossSpectrum->isSingleValueSpectrum()) {
-      freq=_crossSpectrum->timeWindows()->frequencyFilter().exactFrequency();
-    } else {
-      freq=_crossSpectrum->timeWindows()->frequency().center();
-    }
-    WaveNumberConverter conv(freq);
+    WaveNumberConverter conv(_crossSpectrum->timeWindows()->frequency().center());
     const TimeWindowList& winList=_crossSpectrum->timeWindows()->list();
     conv.setTime(winList.at(blocks.first()).start());
+    APP_LOG(3, tr("Process at time %1 and at %2 Hz\n")
+            .arg(conv.time().toString(DateTime::defaultFormat))
+            .arg(conv.frequency()))
 
 #ifdef INSPECT_FREQUENCY
-    if(fabs(conv.frequency()-INSPECT_FREQUENCY)<0.1) {
+    if(fabs(conv.frequency()-INSPECT_FREQUENCY)<0.001) {
       App::log(tr("Inspect selected frequency %1 Hz\n").arg(conv.frequency()));
     } else {
       return;
@@ -121,30 +129,81 @@ namespace ArrayCore {
     if(!setSlownessRange()) {
       return;
     }
-    AbstractFKFunction * function=static_cast<AbstractFKFunction *>(_grid->function());
+    const FKParameters * param=crossSpectrum()->parameters();
+    AbstractFKFunction * function=static_cast<AbstractFKFunction *>(_search->function());
     function->setTotalLimits(crossSpectrum()->timeWindows()->frequency().squaredOmega());
-    function->setAzimuthRange(crossSpectrum()->parameters()->minimumAzimuth(),
-                              crossSpectrum()->parameters()->maximumAzimuth());
+    function->setAzimuthRange(param->minimumAzimuth(),
+                              param->maximumAzimuth());
+
     if(crossSpectrum()->calculate(blocks, function)) {
-      localizeMax();
-      if(!addPeak(conv)) {
-        return;
+      if(param->brightSpots()<=0) {
+        localizeMax();
+        addPeaks(conv);
+      } else {
+        decompose(conv);
+      }
+    }
+  }
+
+  void FKWorker::decompose(const WaveNumberConverter& conv)
+  {
+    const FKParameters * param=crossSpectrum()->parameters();
+    AbstractFKFunction * function=static_cast<AbstractFKFunction *>(_search->function());
+    int brightSpots=0;
+    double power0=0.0;
+    while(true) {
+      _search->globalMax(param->absoluteThreshold());
+      if(_search->maximaCount()!=1) {
+        break;
+      }
+      const FunctionSearchMaximum& m=**_search->begin();
+      if(addPeak(m, conv, param, function)) {
+        FKPeaks::Value * value=_peaks.lastValue();
+        if(power0==0.0) {
+          power0=value->power;
+        } else {
+          if(value->power<power0*param->relativeThreshold()) {
+            _peaks.removeLast();
+            break;
+          }
+        }
+
+        if(brightSpots>=param->brightSpots()) {
+          break;
+        }
+        if(!function->remove(m.position(), *value)) {
+          // End of the story, the modified matrix cannot be inverted
+          return;
+        }
+        brightSpots++;
       }
     }
   }
 
   void FKWorker::mergeResults()
   {
+#ifdef PROCESS_TIMING
+    QElapsedTimer chrono;
+    qint64 tmg;
+    chrono.start();
+#endif
     FKResults * results=static_cast<FKResults *>(taskManager()->results());
     if(results) {
+      App::log(tr("Merging results for worker %1...\n").arg(objectName()));
       results->add(_peaks);
     }
+#ifdef PROCESS_TIMING
+      tmg=chrono.nsecsElapsed();
+      globalTimeMutex.lock();
+      ttmg+=tmg;
+      globalTimeMutex.unlock();
+#endif
   }
 
   AbstractFKFunction * FKWorker::function()
   {
     if(setSlownessRange()) {
-      AbstractFKFunction * f=static_cast<AbstractFKFunction *>(_grid->function());
+      AbstractFKFunction * f=static_cast<AbstractFKFunction *>(_search->function());
       f->setTotalLimits(crossSpectrum()->timeWindows()->frequency().squaredOmega());
       f->setAzimuthRange(crossSpectrum()->parameters()->minimumAzimuth(),
                          crossSpectrum()->parameters()->maximumAzimuth());
@@ -158,64 +217,67 @@ namespace ArrayCore {
   {
     TRACE;
     const FKParameters * param=crossSpectrum()->parameters();
-    if(param->maximumPeakCount()>1) {
-      AbstractFKFunction * function=static_cast<AbstractFKFunction *>(_grid->function());
-      if(function->hasEllipticity()) {
-        _grid->localMaxBest(param->maximumPeakCount(),
-                            param->absoluteThreshold(),
-                            param->relativeThreshold());
-      } else {
-        _grid->localMax(param->maximumPeakCount(),
+    int nMax=param->maximumPeakCount(crossSpectrum()->array().count());
+    if(nMax>1) {
+      _search->localMax(nMax,
                         param->absoluteThreshold(),
                         param->relativeThreshold());
-      }
     } else {
-      _grid->globalMax(param->absoluteThreshold());
+      _search->globalMax(param->absoluteThreshold());
     }
   }
 
-  bool FKWorker::addPeak(const WaveNumberConverter& conv)
+  bool FKWorker::addPeaks(const WaveNumberConverter& conv)
   {
     TRACE;
     const FKParameters * param=static_cast<const FKParameters *>(taskManager()->parameters());
-    //FKResults * results=static_cast<FKResults *>(_taskManager->results());
-    AbstractFKFunction * function=static_cast<AbstractFKFunction *>(_grid->function());
+    AbstractFKFunction * function=static_cast<AbstractFKFunction *>(_search->function());
     FunctionMaximaIterator it;
-    bool ok;
-    APP_LOG(4, tr("    Found %1 peaks\n").arg(_grid->maximaCount()))
-    for(it=_grid->begin(); it!=_grid->end(); ++it) {
-      const FunctionSearchMaximum& m=**it;
-      Point kell=m.pos();
-      APP_LOG(4, tr("    New peak at k=%1\n").arg(kell.toString()))
-      if(!function->isOnLimit(kell, conv.frequency())) {
-        double ell=function->ellipticity(kell, ok); // Ensure that ellipticity is computed before
-                                                    // everything else: noise,...
-        if(ok || param->saveUndefinedEllipticities()) {
-          if(!function->refine(kell, ell, &_peaks, conv)) {
-            if(!_peaks.add(function->waveNumber(kell),
-                           ell,
-                           function->noise(kell),
-                           function->power(m.value()),
-                           conv,
-                           param->minimumSlowness())) {
-              return false;
-            }
-          }
-        }
-      }
+    APP_LOG(4, tr("    Found %1 peaks\n").arg(_search->maximaCount()))
+    for(it=_search->begin(); it!=_search->end(); ++it) {
+      addPeak(**it, conv, param, function);
     }
     return true;
   }
 
+  bool FKWorker::addPeak(const FunctionSearchMaximum& m, const WaveNumberConverter& conv,
+                         const FKParameters * param, AbstractFKFunction * function)
+  {
+    const Vector<double>& k=m.position();
+    double slowness=conv.slowness(k);
+    if(slowness>param->minimumSlowness() &&
+       !function->isOnLimit(k, conv.frequency())) {
+      FKPeaks::Value * val=_peaks.add();
+      if(val) {
+        val->time=_peaks.time(conv.time());
+        val->frequency=conv.frequency();
+        val->slowness=slowness;
+        val->azimuth=conv.azimuth(k);
+        val->valid=true;
+        val->extraValues=nullptr;
+        function->setAssociatedResults(k, m.value(), *val);
+        APP_LOG(4, tr("%1 Hz: new peak at %2 m/s propagating towards %3 with ellippticity %4 deg\n")
+                            .arg(conv.frequency())
+                            .arg(1.0/slowness)
+                            .arg(conv.azimuth(k))
+                            .arg(Angle::radiansToDegrees(::atan(val->ellipticity))))
+      } else {
+        return false;
+      }
+      return true;
+    }
+    return false;
+  }
+
   bool FKWorker::setSlownessRange()
   {
     TRACE;
     const FKParameters * param=crossSpectrum()->parameters();
-    AbstractFKFunction * function=static_cast<AbstractFKFunction *>(_grid->function());
+    AbstractFKFunction * function=static_cast<AbstractFKFunction *>(_search->function());
     double f=crossSpectrum()->timeWindows()->frequency().center();
     if(param->isRefine()) {
       //App::log(tr("Looking for frequency %1 in refinement limits\n").arg(f)
-      //              << param->refineMinimumSlowness().toString() << endl;
+      //              << param->refineMinimumSlowness().toString() << Qt::endl;
       int index=param->refineMinimumSlowness().indexOf(f, 1e-4); // default frequency step is 2.5%
       if(index<0) {
         APP_LOG(1, tr("  Skipped frequency %1 Hz\n").arg(f))
