@@ -17,8 +17,8 @@
 **
 **  See http://www.geopsy.org for more information.
 **
-**  Created: 2018-07-12
-**  Copyright: 2018-2019
+**  Created: 2022-06-28
+**  Copyright: 2022
 **    Marc Wathelet (ISTerre, Grenoble, France)
 **
 ***************************************************************************/
@@ -34,13 +34,20 @@ namespace ArrayCore {
   class ARRAYCORE_EXPORT HRFKDirectRayleighRadial : public HRFKDirectRayleigh
   {
   public:
-    HRFKDirectRayleighRadial(FKCache * gridCache)
-      : HRFKDirectRayleigh(gridCache) {}
+    HRFKDirectRayleighRadial(FKCache * cache)
+      : HRFKDirectRayleigh(cache) {}
+    ~HRFKDirectRayleighRadial();
 
-    virtual double value(const Point& kell, int index) const;
-    virtual double value(const Point& kell) const;
+    double value(const Vector<int>& index) const;
+    double value(Vector<double>& k) const;
+    double concavity(const Vector<double>& kell, int axis) const;
 
-    virtual double ellipticity(const Point& kell, bool& ok);
+    void setFunctionValue(Attributes& a) const;
+    void setFunctionDerivatives(Attributes& a) const;
+
+    double wavenumberNormalizedConcavity(const Vector<double>& kell) const;
+  private:
+    inline void maximumEllipticity() const;
   };
 
 } // namespace ArrayCore
