@@ -17,8 +17,8 @@
 **
 **  See http://www.geopsy.org for more information.
 **
-**  Created: 2018-07-12
-**  Copyright: 2018-2019
+**  Created: 2022-06-28
+**  Copyright: 2022
 **    Marc Wathelet (ISTerre, Grenoble, France)
 **
 ***************************************************************************/
@@ -33,16 +33,20 @@ namespace ArrayCore {
 
   class ARRAYCORE_EXPORT HRFKDirectRayleighVertical : public HRFKDirectRayleigh
   {
-  public:
-    HRFKDirectRayleighVertical(FKCache * gridCache)
-      : HRFKDirectRayleigh(gridCache) {}
+  public:;
+    HRFKDirectRayleighVertical(FKCache * cache);
+    ~HRFKDirectRayleighVertical();
 
-    virtual void initGrid(const Point& kell, int index);
+    double value(const Vector<int>& index) const;
+    double value(Vector<double>& k) const;
+    double concavity(const Vector<double>& kell, int axis) const;
 
-    virtual double value(const Point& kell, int index) const;
-    virtual double value(const Point& kell) const;
+    void setFunctionValue(Attributes& a) const;
+    void setFunctionDerivatives(Attributes& a) const;
 
-    virtual double ellipticity(const Point& kell, bool& ok);
+    double wavenumberNormalizedConcavity(const Vector<double>& kell) const;
+  private:
+    inline void maximumEllipticity() const;
   };
 
 } // namespace ArrayCore
