@@ -33,13 +33,15 @@ namespace ArrayCore {
   class ARRAYCORE_EXPORT HRFKRadial : public ConvFKRadial
   {
   public:
-    HRFKRadial(FKCache * gridCache)
-      : ConvFKRadial(gridCache) {}
+    HRFKRadial(FKCache * cache)
+      : ConvFKRadial(cache) {}
 
-    virtual bool invertCrossSpectrum();
+    bool invertCrossSpectrum();
 
-    virtual double value(const Point& k) const;
-    virtual double value(const Point& k, int index) const;
+    double value(const Vector<int>& index) const;
+    double value(Vector<double>& k) const;
+
+    double wavenumberNormalizedConcavity(const Vector<double>& k) const;
   };
 
 } // namespace ArrayCore
