@@ -17,8 +17,8 @@
 **
 **  See http://www.geopsy.org for more information.
 **
-**  Created: 2017-11-17
-**  Copyright: 2017-2019
+**  Created: 2022-06-28
+**  Copyright: 2022
 **    Marc Wathelet (ISTerre, Grenoble, France)
 **
 ***************************************************************************/
@@ -27,38 +27,17 @@
 #define HRFKRAYLEIGH_H
 
 #include "ConvFKRayleigh.h"
+#include "ArrayCoreDLLExport.h"
 
 namespace ArrayCore {
 
-  class ARRAYCORE_EXPORT HRFKRayleigh : public AbstractFKFunction
+  class ARRAYCORE_EXPORT HRFKRayleigh : public ConvFKRayleigh
   {
   public:
-    HRFKRayleigh(FKCache * gridCache);
+    HRFKRayleigh(FKCache * cache)
+     : ConvFKRayleigh(cache) {}
 
-    void resetCrossSpectrum();
-    void addCrossSpectrum();
-    void meanCrossSpectrum(int nBlocks);
     bool invertCrossSpectrum();
-
-    virtual void setGrid(FKGridSearch * g, double step, double size);
-
-    virtual double value(const Point& kell, int index) const;
-    virtual double value(const Point& kell) const;
-
-    virtual bool hasEllipticity() const {return true;}
-    virtual double ellipticity(const Point& kell, bool& ok);
-    virtual double noise(const Point& kell) const;
-    virtual double power(double optimumPower) const;
-
-    virtual double thirdMinimum() const {return -0.5*M_PI;}
-    virtual double thirdMaximum() const {return 0.5*M_PI;}
-    virtual double thirdStep() const {return M_PI/90;}
-  protected:
-    void printEllipticityCurve(const FKGridSearch& grid, double ell) const;
-
-    double _RoverN;
-    double _ellipticity;
-    int _kxkyCacheCount;
   };
 
 } // namespace ArrayCore
