@@ -37,33 +37,9 @@ namespace ArrayCore {
     The cross-spectrum is already projected on the transverse direction.
   */
 
-  bool HRFKTransverse::invertCrossSpectrum()
+  void HRFKTransverse::addCrossSpectrum()
   {
-    return _crossSpectrum->invertRotatedMatrices();
-  }
-
-  double HRFKTransverse::value(const Point& k, int index) const
-  {
-    if(isInsideLimits(k)) {
-      FKPower p(&FKSteeringOneComponent::cache(_gridCache, index));
-      p.setCaponValue(_crossSpectrum->rotatedMatrix(k));
-      return p.value();
-     } else {
-      return -1.0;
-    }
-  }
-
-  double HRFKTransverse::value(const Point& k) const
-  {
-    if(isInsideLimits(k)) {
-      FKSteeringOneComponent * s=static_cast<FKSteeringOneComponent *>(_steering);
-      s->initValue(k);
-      FKPower p(s);
-      p.setCaponValue(_crossSpectrum->rotatedMatrix(k));
-      return p.value();
-    } else {
-      return -1.0;
-    }
+    _crossSpectrum->addRotatedTransverse(steering()->sensorOrientationErrors());
   }
 
 } // namespace ArrayCore
