@@ -39,20 +39,26 @@ namespace ArrayCore {
     HRFKVertical(FKCache * cache);
     ~HRFKVertical();
 
-    virtual bool invertCrossSpectrum();
+    bool invertCrossSpectrum();
 
-    bool initGrid(int ) {return false;}
+    double value(const Vector<int>& index) const;
+    double value(Vector<double>& k) const;
+    void gradient(const Vector<double>&, Vector<double>& grad) const;
 
-    virtual double value(const Point& k, int index) const;
-    virtual double value(const Point& k) const;
+    bool remove(const Vector<double>& k, FKPeaks::Value& val);
 
     //virtual void setGradient(FKPower& p) const;
     //virtual void setHessian(FKPower& p) const;
 
     //virtual void setGradient(const Point& k, FKPower& p) const;
     //virtual void setHessian(const Point& k, FKPower& p) const;
+
+    double wavenumberNormalizedConcavity(const Vector<double>& k) const;
+  protected:
+    ComplexMatrix _originalCrossSpectrum;
   private:
-    mutable qint64 _countGrid, _countFree;
+    //mutable qint64 _countGrid, _countFree;
+    void testKDerivatives(const Vector<double>& k) const;
   };
 
 } // namespace ArrayCore
