@@ -37,11 +37,34 @@ namespace ArrayCore {
     Ellipticity is computed according Poggi et al. (2010) in GJI.
   */
 
-  double PoggiFKRadial::ellipticity(const Point& k, bool& ok)
+  void PoggiFKRadial::resetCrossSpectrum()
   {
-    HRFKVertical vertical(_gridCache);
-    ok=true;
-    return ::sqrt(value(k)/vertical.value(k));
+    _crossSpectrum->resetMatrix();
+    _crossSpectrum->resetRotatedMatrices();
+  }
+
+  void PoggiFKRadial::addCrossSpectrum()
+  {
+    _crossSpectrum->addVertical();
+    _crossSpectrum->addRotatedRadial(steering()->sensorOrientationErrors());
+  }
+
+  void PoggiFKRadial::meanCrossSpectrum(int nBlocks)
+  {
+    _crossSpectrum->meanMatrix(nBlocks);
+    _crossSpectrum->meanRotatedMatrices(nBlocks);
+  }
+
+  bool PoggiFKRadial::invertCrossSpectrum()
+  {
+    return _crossSpectrum->invert() && _crossSpectrum->invertRotatedMatrices();
+  }
+
+  double PoggiFKRadial::ellipticity(const Vector<double>& k)
+  {
+    HRFKVertical vertical(cache());
+    PrivateVector<double> nck(k);
+    return ::sqrt(value(nck)/vertical.value(nck));
   }
 
 } // namespace ArrayCore
