@@ -33,10 +33,15 @@ namespace ArrayCore {
   class ARRAYCORE_EXPORT PoggiFKVertical : public HRFKVertical
   {
   public:
-    PoggiFKVertical(FKCache * gridCache)
-      : HRFKVertical(gridCache) {}
+    PoggiFKVertical(FKCache * cache)
+      : HRFKVertical(cache) {}
 
-    virtual double ellipticity(const Point& k, bool& ok);
+    void resetCrossSpectrum();
+    void addCrossSpectrum();
+    void meanCrossSpectrum(int nBlocks);
+    bool invertCrossSpectrum();
+
+    double ellipticity(const Vector<double>& k);
   };
 
 } // namespace ArrayCore
