@@ -44,42 +44,45 @@ namespace ArrayCore {
                                        const SPACParameters * param)
       : ArrayCrossSpectrum(array, param), _stationPairs(array)
   {
-    setStations(array);
+    _horizontalMatrix=nullptr;
     _rings=_stationPairs.rings(parameters());
     resize();
   }
 
   SPACCrossSpectrum::~SPACCrossSpectrum()
   {
-    TRACE;
+    delete _horizontalMatrix;
   }
 
   void SPACCrossSpectrum::resize()
   {
+    delete _horizontalMatrix;
+    _horizontalMatrix=nullptr;
     switch (_mode) {
     case ArrayStations::ThreeComponents:
-      _horizontalMatrix.resize(2*_stations.count());
+      _horizontalMatrix=new ComplexMatrix(2*_array.count());
       break;
     case ArrayStations::Horizontal:
       ASSERT(false);
     case ArrayStations::Vertical:
       break;
     }
-    _matrix.resize(_stations.count());
+    delete _matrix;
+    _matrix=new ComplexMatrix(_array.count());
   }
 
-  bool SPACCrossSpectrum::calculate(const QVector<int>& blocks)
+  bool SPACCrossSpectrum::calculate(const VectorList<int>& blocks)
   {
     TRACE;
     if(_mode==ArrayStations::ThreeComponents) {
-      _horizontalMatrix.zero(0.0);
+      _horizontalMatrix->zero();
     }
     resetMatrix();
 
-    for(QVector<int>::const_iterator it=blocks.begin(); it!=blocks.end(); it++) {
+    for(VectorList<int>::const_iterator it=blocks.begin(); it!=blocks.end(); it++) {
       if(lockTimeWindow(_timeWindows->list().at(*it))) {
         if(_mode==ArrayStations::ThreeComponents) {
-          addHorizontal(_horizontalMatrix);
+          addHorizontal(*_horizontalMatrix);
         }
         addVertical();
         unlockTimeWindow();
@@ -87,12 +90,12 @@ namespace ArrayCore {
     }
 
     if(_mode==ArrayStations::ThreeComponents) {
-      _horizontalMatrix*=1.0/static_cast<double>(blocks.count());
+      (*_horizontalMatrix)*=1.0/static_cast<double>(blocks.count());
       // Normalization is more complex than for vertical
       // TODO??
     }
     meanMatrix(blocks.count());
-    normalize(_matrix);
+    normalize(*_matrix);
 
     return true;
   }
@@ -120,6 +123,58 @@ namespace ArrayCore {
     delete [] diag;
   }
 
+  Complex SPACCrossSpectrum::radialAutocorr(int station1, int station2, const Angle& azimuth) const
+  {
+    int n=_stations.count();
+    int iE1=station1;
+    int iN1=n+station1;
+    int iE2=station2;
+    int iN2=n+station2;
+    double sin2=azimuth.sin()*azimuth.sin();
+    double cos2=azimuth.cos()*azimuth.cos();
+    double sincos=azimuth.sin()*azimuth.cos();
+    Complex c;
+    c+=_horizontalMatrix->at(iN1, iN2)*sin2;
+    c+=_horizontalMatrix->at(iN1, iE2)*sincos;
+    c+=_horizontalMatrix->at(iE1, iN2)*sincos;
+    c+=_horizontalMatrix->at(iE1, iE2)*cos2;
+    Complex pow1;
+    pow1+=_horizontalMatrix->at(iN1, iN1)*sin2;
+    pow1+=(_horizontalMatrix->at(iN1, iE1)+_horizontalMatrix->at(iE1, iN1))*sincos;
+    pow1+=_horizontalMatrix->at(iE1, iE1)*cos2;
+    Complex pow2;
+    pow2+=_horizontalMatrix->at(iN2, iN2)*sin2;
+    pow2+=(_horizontalMatrix->at(iN2, iE2)+_horizontalMatrix->at(iE2, iN2))*sincos;
+    pow2+=_horizontalMatrix->at(iE2, iE2)*cos2;
+    c/=::sqrt(pow1.re()*pow2.re());
+    return c;
+  }
 
+  Complex SPACCrossSpectrum::transverseAutocorr(int station1, int station2, const Angle& azimuth) const
+  {
+    int n=_stations.count();
+    int iE1=station1;
+    int iN1=n+station1;
+    int iE2=station2;
+    int iN2=n+station2;
+    double sin2=azimuth.sin()*azimuth.sin();
+    double cos2=azimuth.cos()*azimuth.cos();
+    double sincos=azimuth.sin()*azimuth.cos();
+    Complex c;
+    c+=_horizontalMatrix->at(iN1, iN2)*cos2;
+    c-=_horizontalMatrix->at(iN1, iE2)*sincos;
+    c-=_horizontalMatrix->at(iE1, iN2)*sincos;
+    c+=_horizontalMatrix->at(iE1, iE2)*sin2;
+    Complex pow1;
+    pow1+=_horizontalMatrix->at(iN1, iN1)*cos2;
+    pow1-=(_horizontalMatrix->at(iN1, iE1)+_horizontalMatrix->at(iE1, iN1))*sincos;
+    pow1+=_horizontalMatrix->at(iE1, iE1)*sin2;
+    Complex pow2;
+    pow2+=_horizontalMatrix->at(iN2, iN2)*cos2;
+    pow2-=(_horizontalMatrix->at(iN2, iE2)+_horizontalMatrix->at(iE2, iN2))*sincos;
+    pow2+=_horizontalMatrix->at(iE2, iE2)*sin2;
+    c/=::sqrt(pow1.re()*pow2.re());
+    return c;
+  }
 
 } // namespace ArrayCore
