@@ -45,15 +45,16 @@ namespace ArrayCore {
 
     int stationPairCount() const {return _stationPairs.count();}
     const StationPair& stationPair(int index) const {return _stationPairs.at(index);}
-    const QVector<StationPair>& stationPairs() const {return _stationPairs;}
+    const VectorList<StationPair>& stationPairs() const {return _stationPairs;}
 
     int ringCount() const {return _rings.count();}
     const RingPairs& ring(int index) {return _rings.at(index);}
 
-    bool calculate(const QVector<int>& blocks);
+    bool calculate(const VectorList<int>& blocks);
 
-    inline const ComplexMatrix& verticalCrossSpectrum() const;
-    inline const ComplexMatrix& horizontalCrossSpectrum() const;
+    inline Complex verticalAutocorr(int station1, int station2) const;
+    Complex radialAutocorr(int station1, int station2, const Angle& azimuth) const;
+    Complex transverseAutocorr(int station1, int station2, const Angle& azimuth) const;
   private:
     void setStationPairs(const ArraySelection * array);
     void setRings();
@@ -61,18 +62,13 @@ namespace ArrayCore {
     void resize();
 
     StationPairs _stationPairs;
-    QVector<RingPairs> _rings;
-    ComplexMatrix _horizontalMatrix;
+    VectorList<RingPairs> _rings;
+    ComplexMatrix * _horizontalMatrix;
   };
 
-  inline const ComplexMatrix& SPACCrossSpectrum::verticalCrossSpectrum() const
+  inline Complex SPACCrossSpectrum::verticalAutocorr(int station1, int station2) const
   {
-    return ArrayCrossSpectrum::matrix();
-  }
-
-  inline const ComplexMatrix& SPACCrossSpectrum::horizontalCrossSpectrum() const
-  {
-    return _horizontalMatrix;
+    return ArrayCrossSpectrum::matrix()->at(station1, station2);
   }
 
 } // namespace ArrayCore
