@@ -44,16 +44,14 @@ namespace ArrayCore {
     setOversamplingFactor(1.0);
     windowing().setSeismicEventTrigger(false);
 
+    _method=MSPAC;
     _maximumImaginary=1.0;
     _dotMaxOutput=false;
   }
 
-  SPACParameters::SPACParameters(const SPACParameters& o)
-    : ArrayParameters(o)
+  void SPACParameters::clearRings()
   {
-    _rings=o._rings;
-    _maximumImaginary=o._maximumImaginary;
-    _dotMaxOutput=o._dotMaxOutput;
+    _rings.clear();
   }
 
   void SPACParameters::addRing(double minRadius, double maxRadius)
@@ -63,7 +61,7 @@ namespace ArrayCore {
 
   int SPACParameters::keywordCount(PARAMETERS_KEYWORDCOUNT_ARGS) const
   {
-    return 7+ArrayParameters::keywordCount();
+    return 8+ArrayParameters::keywordCount();
   }
 
   void SPACParameters::collectKeywords(PARAMETERS_COLLECTKEYWORDS_ARGS)
@@ -78,6 +76,7 @@ namespace ArrayCore {
     keywords.add(prefix+"RINGS"+suffix, this, baseIndex+4);
     keywords.add(prefix+"MAXIMUM_IMAGINARY_PART"+suffix, this, baseIndex+5);
     keywords.add(prefix+"DOT_MAX_OUTPUT"+suffix, this, baseIndex+6);
+    keywords.add(prefix+"SPAC_METHOD"+suffix, this, baseIndex+7);
   }
 
   QString SPACParameters::toString(PARAMETERS_TOSTRING_ARGS_IMPL) const
@@ -89,6 +88,8 @@ namespace ArrayCore {
     // RING_MINIMUM_PAIR_COUNT=6
     QString log;
     log+=ArrayParameters::toString(prefix, suffix);
+    log+="# SPAC method: MSPAC or ESAC\n";
+    log+=prefix+"SPAC_METHOD"+suffix+"="+convertMethod(_method)+"\n";
     log+="# List of rings (distances in m): min_radius_1 max_radius_1 min_radius_2 max_radius_2 ...\n";
     log+=prefix+"RINGS"+suffix+"=";
     int n=_rings.count();
@@ -137,6 +138,9 @@ namespace ArrayCore {
     case 6:
       _dotMaxOutput=(value=="true");
       return ok;
+    case 7:
+      _method=convertMethod(value, ok);
+      return ok;
     default:
       break;
     }
@@ -162,4 +166,8 @@ namespace ArrayCore {
     }
   }
 
+  ENUM_AS_STRING_BEGIN(SPACParameters, Method)
+  ENUM_AS_STRING_DATA_2(ESAC, MSPAC);
+  ENUM_AS_STRING_END
+
 } // namespace ArrayCore
