@@ -28,7 +28,8 @@
 
 #include "AbstractArrayResults.h"
 #include "SPACParameters.h"
-#include "SPACStatistics.h"
+#include "MSPACStatistics.h"
+#include "ESACStatistics.h"
 #include "ArrayCoreDLLExport.h"
 
 namespace ArrayCore {
@@ -39,34 +40,38 @@ namespace ArrayCore {
   {
   public:
     SPACResults();
-    virtual ~SPACResults();
+    ~SPACResults();
 
     struct ValueInfo
     {
       DateTime time;
       int frequencyIndex;
       double frequency;
+      double distance;
+      int ringIndex;
     };
 
     const SPACParameters * parameters() const {return static_cast<const SPACParameters *>(_parameters);}
 
-    virtual void setArray(const ArraySelection * array);
+    void setArray(const ArraySelection * array);
 
     void setParameters(const SPACParameters& param);
-    virtual void clear();
+    void clear();
 
-    void addValue(Mode::Polarization polarization, const ValueInfo& info,
-                  int ring, double value);
+    void addValue(Mode::Polarization polarization, const ValueInfo& info, double value);
     void addRejected(int frequency, int * rejected);
 
     void commitStatistics();
-    void save(QString fileName, const QString& log);
+    bool save(QString fileName, const QString& log);
     void reportRejects();
   private:
+    ModalCurve esacDispersionCurve(int iComp);
+
     Mutex _addLock;
     int _nFrequencies, _nRings, _nComponents;
-    AutocorrCurves * _target;
-    SPACStatistics * _stats;
+    AutocorrCurves * _mspacTarget;
+    MSPACStatistics * _mspacStats;
+    ESACStatistics * _esacStats;
     int * _rejected[3];
     SPACPeaks * _peaks;
   };
