@@ -78,16 +78,18 @@ namespace ArrayCore {
   void SPACRing::add(const StationPair * p)
   {
     TRACE;
-    _pairs.append(p);
-    if(p->distance()>maxRadius()) {
-      setMaxRadius(p->distance());
-    }
-    if(minRadius()==0.0) {
+    if(_pairs.isEmpty()) {
       setMinRadius(p->distance());
+      setMaxRadius(p->distance());
+    } else {
+      if(p->distance()>maxRadius()) {
+        setMaxRadius(p->distance());
+      }
     }
+    _pairs.append(p);
   }
 
-  void SPACRing::setPairs(const QVector<StationPair>& stationPairs)
+  void SPACRing::setPairs(const VectorList<StationPair>& stationPairs)
   {
     TRACE;
     _pairs.clear();
@@ -107,7 +109,8 @@ namespace ArrayCore {
   {
     _pairs.removeFirst();
     if(_pairs.isEmpty()) {
-      setMinRadius(0.0);
+      setMinRadius(maxRadius());  // Radii are fully set when adding
+                                  // the first station.
     } else {
       setMinRadius(_pairs.first()->distance());
     }
@@ -184,7 +187,7 @@ namespace ArrayCore {
     Pairs are ordered by increasing distance.
     They are added one by one checking the angle step.
   */
-  QVector<SPACRing> SPACRing::autoRings(const QVector<StationPair>& pairs,
+  VectorList<SPACRing> SPACRing::autoRings(const VectorList<StationPair>& pairs,
                                         double maxAngleStep,
                                         double maxRelThickness,
                                         int minPairCount,
@@ -193,7 +196,7 @@ namespace ArrayCore {
     TRACE;
     ASSERT(minPairCount>=1);
     bool line=isLinear(pairs);
-    QVector<SPACRing> rings;
+    VectorList<SPACRing> rings;
     int n=pairs.count();
     if(n>=2) {
       SPACRing ring;
@@ -202,19 +205,24 @@ namespace ArrayCore {
       ring.setMaxRadius(ring.minRadius());
       for(int i=1; i<n; i++) {
         const StationPair& p=pairs.at(i);
+        App::log(1, tr("New pair at radius %1 azimuth %2 deg\n")
+                 .arg(p.distance()).arg(p.azimuth().degrees()));
         if(p.distance()==ring.maxRadius()) {
           ring.add(&p);
         } else {
+          ring.add(&p);
+          App::log(1, tr("Enlarging ring...\n"));
           double ringMaxAngleStep=ring.maximumAngleStep();
+          App::log(1, tr("  Max angle step %1\n").arg(ringMaxAngleStep));
           if(line || ringMaxAngleStep<=maxAngleStep) { // Yeah, found at least a collection of pairs
-                                                              // satifying the maximum angle step condition
+                                                       // satifying the maximum angle step condition
             // Try to remove as many pairs as possible still satifying the angle step condition
             if(!line) {
               App::log(tr("Found a ring with angle step %1 (<=%2) %3\n")
                        .arg(ringMaxAngleStep)
                        .arg(maxAngleStep)
                        .arg(ring.toUserString()));
-              while(ring.maximumAngleStep(1)<=maxAngleStep) {
+              while(ring.maximumAngleStep(1)<=maxAngleStep && !ring._pairs.isEmpty()) {
                 App::log(tr("    remove first pair, condition still satisfied\n"));
                 ring.removeFirst();
               }
@@ -236,7 +244,7 @@ namespace ArrayCore {
                 double min=ring.minRadius();
                 do {
                   ring.removeFirst();
-                } while(ring.minRadius()==min);
+                } while(ring.minRadius()==min && !ring._pairs.isEmpty());
               } else {
                 App::log(tr("Ring rejected\n"));
                 /* To satisfy the maximum relative thickness condition, the minimum
@@ -249,13 +257,12 @@ namespace ArrayCore {
                 do {
                   App::log(tr("  Remove first pair\n"));
                   ring.removeFirst();
-                } while(ring.minRadius()<min);
+                } while(ring.minRadius()<min && !ring._pairs.isEmpty());
               }
               App::log(tr("Starting a new ring %1\n")
                        .arg(ring.toUserString()));
             }
           }
-          ring.add(&p);
         }
       }
     }
@@ -279,7 +286,7 @@ namespace ArrayCore {
   /*!
     Returns true if all pairs have the same azimuth
   */
-  bool SPACRing::isLinear(const QVector<StationPair>& pairs)
+  bool SPACRing::isLinear(const VectorList<StationPair>& pairs)
   {
     if(pairs.count()<2) {
       return true;
