@@ -41,8 +41,9 @@ namespace ArrayCore {
     ~SPACRing();
 
     void add(const StationPair * p);
-    void setPairs(const QVector<StationPair>& stationPairs);
+    void setPairs(const VectorList<StationPair>& stationPairs);
     void removeFirst();
+    const QList<const StationPair *>& pairs() const {return _pairs;}
 
     double maximumAngleStep(int startIndex=0) const;
     double overlap(const SPACRing& o) const;
@@ -52,12 +53,12 @@ namespace ArrayCore {
 
     int count() const {return _pairs.count();}
 
-    static QVector<SPACRing> autoRings(const QVector<StationPair>& pairs,
+    static VectorList<SPACRing> autoRings(const VectorList<StationPair>& pairs,
                                        double maxAngleStep=40.0,
                                        double maxRelThickness=0.2,
                                        int minPairCount=6,
                                        double maxOverlap=0.5);
-    static bool isLinear(const QVector<StationPair>& pairs);
+    static bool isLinear(const VectorList<StationPair>& pairs);
   private:
     static bool lessThanDistance(const StationPair * p1,
                                  const StationPair * p2);
