@@ -38,7 +38,7 @@ namespace ArrayCore {
     SPACTaskManager(const ArraySelection * array);
     ~SPACTaskManager();
 
-    virtual bool setParameters(const ArrayParameters * param);
+    bool setParameters(const ArrayParameters * param);
     const SPACParameters * parameters() const {return static_cast<const SPACParameters *>(_parameters);}
   protected:
     LoopWorker * newWorker();
