@@ -39,7 +39,7 @@ namespace ArrayCore {
     Description of constructor still missing
   */
   StationPairs::StationPairs(const ArraySelection * array)
-    : QVector<StationPair>()
+    : VectorList<StationPair>()
   {
     TRACE;
     int nStations=array->count();
@@ -62,10 +62,10 @@ namespace ArrayCore {
     TRACE;
   }
 
-  QVector<RingPairs> StationPairs::rings(const SPACParameters * param)
+  VectorList<RingPairs> StationPairs::rings(const SPACParameters * param)
   {
     TRACE;
-    QVector<RingPairs> list;
+    VectorList<RingPairs> list;
     int n=param->ringCount();
     for(int i=0; i<n; i++) {
       RingPairs r(param->rings().at(i));
@@ -76,11 +76,11 @@ namespace ArrayCore {
     return list;
   }
 
-  QVector<RingPairs> StationPairs::rings()
+  VectorList<RingPairs> StationPairs::rings()
   {
     TRACE;
-    QVector<RingPairs> list;
-    QVector<SPACRing> spacRings=SPACRing::autoRings(*this);
+    VectorList<RingPairs> list;
+    VectorList<SPACRing> spacRings=SPACRing::autoRings(*this);
     int n=spacRings.count();
     for(int i=0; i<n; i++) {
       RingPairs r(spacRings.at(i));
