@@ -33,14 +33,14 @@
 
 namespace ArrayCore {
 
-  class ARRAYCORE_EXPORT StationPairs : public QVector<StationPair>
+  class ARRAYCORE_EXPORT StationPairs : public VectorList<StationPair>
   {
   public:
     StationPairs(const ArraySelection * array);
     ~StationPairs();
 
-    QVector<RingPairs> rings(const SPACParameters * param);
-    QVector<RingPairs> rings();
+    VectorList<RingPairs> rings(const SPACParameters * param);
+    VectorList<RingPairs> rings();
   };
 
 } // namespace ArrayCore
