@@ -44,11 +44,5 @@ namespace ArrayCore {
     _waveNumberFactor=1.0/(2.0*M_PI*_frequency);
   }
 
-  double WaveNumberConverter::azimuth(const Point2D &k) const
-  {
-    double a=90.0-Angle::radiansToDegrees(k.azimuth());
-    return Angle::canonicalDegrees(a);
-  }
-
 } // namespace ArrayCore
 
