@@ -99,51 +99,15 @@ bool AbstractCondition::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(context)
   switch(memberID) {
   case 0:
-    _paramNameList.append(content.toString());
+    _paramNameList.append(content.toStringBuffer());
     return true;
   default:
     return false;
   }
 }
 
-QString AbstractCondition::toString(Type t)
-{
-  switch(t) {
-  case LessThan:
-    break;
-  case GreaterThan:
-    return "GreaterThan";
-  case NoCondition:
-    return "NoCondition";
-  }
-  return "LessThan";
-}
-
-AbstractCondition::Type AbstractCondition::fromString(QString t, bool& ok)
-{
-  if(!t.isEmpty()) {
-    switch(t[0].unicode()) {
-    case 'L':
-      if(t=="LessThan") {
-        return LessThan;
-      }
-      break;
-    case 'G':
-      if(t=="GreaterThan") {
-        return GreaterThan;
-      }
-      break;
-    case 'N':
-      if(t=="NoCondition") {
-        return NoCondition;
-      }
-      break;
-    default:
-      break;
-    }
-  }
-  ok=false;
-  return NoCondition;
-}
+ENUM_AS_STRING_BEGIN(AbstractCondition, Type)
+ENUM_AS_STRING_DATA_3(GreaterThan, LessThan, NoCondition);
+ENUM_AS_STRING_END
 
 } // namespace DinverCore
