@@ -80,10 +80,10 @@ namespace DinverCore {
     _allModels->print(m.index());
   }
 
-  void ActiveModels::addNavigatorHits(const QVector<ActiveIndex>& indexes)
+  void ActiveModels::addNavigatorHits(const VectorList<ActiveIndex>& indexes)
   {
-    int t=_allModels->count();
-    for(QVector<ActiveIndex>::const_iterator it=indexes.begin(); it!=indexes.end(); it++ ) {
+    int t=_allModels->size();
+    for(VectorList<ActiveIndex>::const_iterator it=indexes.begin(); it!=indexes.end(); it++ ) {
       ActiveModel& m=at(*it);
       m.addNavigatorHit();
       m.setNavigatorHitTime(t);
@@ -110,4 +110,19 @@ namespace DinverCore {
     }
   }
 
+  /*!
+    Get the Manhatan distance between two models.
+    Usually the number of bins is around 500, hence the risk of integer overflow is almost null.
+  */
+  int ActiveModels::distance(const ActiveIndex& i1, const ActiveIndex& i2) const
+  {
+    const int * m1=model(i1);
+    const int * m2=model(i2);
+    int d=0;
+    for(int i=parameterCount()-1; i>=0; i--) {
+      d+=abs(m1[i]-m2[i]);
+    }
+    return d;
+  }
+
 } // namespace DinverCore
