@@ -7,6 +7,7 @@
 #include "AbstractForward.h"
 #include "ActiveModel.h"
 #include "ActiveModels.h"
+#include "ArtificialBeeColony.h"
 #include "BatchRun.h"
 #include "BestModels.h"
 #include "DinverCoreDLLExport.h"
@@ -18,6 +19,7 @@
 #include "Index.h"
 #include "Model.h"
 #include "ModelRepository.h"
+#include "ModelSet.h"
 #include "NewModel.h"
 #include "ParamCondition.h"
 #include "ParamSpaceScript.h"
