@@ -129,10 +129,6 @@ namespace DinverCore {
 
     RealSpace& parameterSpace=_forward->parameterSpace();
     int ndVar=parameterSpace.variableParameterCount();
-    ASSERT(parameterSpace.isOkDebug());
-    int minp, maxp;
-    SAFE_UNINITIALIZED(minp, 0);
-    SAFE_UNINITIALIZED(maxp, 0);
 
     // Save current model is case of failure
     int * backupModel=new int[ndVar];
@@ -140,92 +136,21 @@ namespace DinverCore {
       backupModel[ip]=parameterSpace.variableParameter(ip)->gridValue();
     }
 
-    // Some parametrizations may need some updates before proceeding
-    _forward->valueChanged();
-
-//#define MONTECARLO_DEBUG
     forever {
-      // Makes a minimum number of random walks to provide a statistically
-      // independent model (from the current one)
-      for(int iw=0; iw<_walkCount; iw++) {
-        for(int i=0; i<ndVar; i++) {
-          Parameter * p=parameterSpace.variableParameter(i);
-#ifdef MONTECARLO_DEBUG
-          App::log(tr("randomWalk: parameter[%1]:%2\n").arg(i).arg(p->name()));
-          App::log(parameterSpace.toString()+"\n");
-#endif
-          p->getGridLimits(minp, maxp);
-#ifdef MONTECARLO_DEBUG
-          App::log(tr(" --> from %1 to %2\n").arg(minp).arg(maxp));
-#endif
-          if(maxp<minp) {
-            App::log(tr("Generating random model with random walk\n") );
-            App::log(tr("Parameter %1: bad parameter range [%2, %3]\n").arg(p->name())
-                .arg(p->realValue(minp)).arg(p->realValue(maxp)));
-            App::log(parameterSpace.toString()+"\n");
-            _repository->stop(); // force termination of inversion
-            delete [] backupModel;
-            return;
-          } else if(minp<maxp) {
-            if(p->isFussy()) {
-              int nTries;
-              // Allow for a maximum of 100 tries before giving up
-              // This is not really a good solution but in some cases it avoids the process to be blocked
-              for(nTries=0; nTries<100; nTries++) {
-                p->setGridValue(_randomNumbers->uniform(minp, maxp) );
-                // Some parametrizations may need some updates before proceeding
-                _forward->valueChanged(p);
-                if(_terminated.value()) {
-                  //App::log(tr("Aborting Monte Carlo.\n") );
-                  // Current model does not satisfy all conditions, we fix it
-                  for(int ip=0; ip<ndVar; ip++) {
-                    parameterSpace.variableParameter(ip)->setGridValue(backupModel[ip]);
-                  }
-                  _forward->valueChanged();
-                  delete [] backupModel;
-                  return;
-                }
-                if(_forward->isFussyOk(p)) {
-                  /*if(nTries>0) {
-                    App::log(tr("Fussy parameter accepted after %1 tries\n").arg(nTries) );
-                  }*/
-                  break;
-                }
-              }
-              if(nTries==100) {
-                App::log(tr("Fussy parameter rejected after %1 tries, trying another model.\n").arg(nTries) );
-                // Current model does not satisfy all conditions, we fix it
-                for(int ip=0; ip<ndVar; ip++) {
-                  parameterSpace.variableParameter(ip)->setGridValue(backupModel[ip]);
-                }
-                _forward->valueChanged();
-                delete [] backupModel;
-                return;
-              }
-            } else {
-              p->setGridValue(_randomNumbers->uniform(minp, maxp));
-              // Some parametrizations may need some updates before proceeding
-              _forward->valueChanged(p);
-            }
-          } else {
-            p->setGridValue(minp);
-            // Some parametrizations may need some updates before proceeding
-            _forward->valueChanged(p);
-          }
-#ifdef MONTECARLO_DEBUG
-          App::log(tr(" \t---> grid %1 real %2\n").arg(p->gridValue()).arg(p->realValue()));
-          ASSERT(_forward->isOk());
-          if(fabs(parameterSpace.variableParameter(1)->realValue()-234.5)<0.1 &&
-             fabs(parameterSpace.variableParameter(2)->realValue()-2.78677)<0.00001) {
-            printf("\n");
-          }
-          ASSERT(parameterSpace.isOkDebug());
-#endif
-        }
+      if(_forward->randomModel(*_randomNumbers, _walkCount)) {
         if(misfit(newModel, parameterSpace)) {
           delete [] backupModel;
           return;
         }
+      } else {
+        // Current model does not satisfy all conditions, we fix it
+        for(int ip=0; ip<ndVar; ip++) {
+          parameterSpace.variableParameter(ip)->setGridValue(backupModel[ip]);
+        }
+        _forward->valueChanged();
+        delete [] backupModel;
+        _repository->stop(); // force termination of inversion
+        return;
       }
     }
   }
@@ -266,7 +191,7 @@ namespace DinverCore {
     TRACE;
     RealSpace& parameterSpace=_forward->parameterSpace();
     const ParentIndex * parentIndex=newModel->parentIndex();
-    const ActiveIndex& activeIndex=parentIndex->index();
+    const ActiveIndex& activeIndex=parentIndex->activeIndex();
     int ndVar=parameterSpace.variableParameterCount();
     int nSteps=ndVar*_walkCount;
 
@@ -363,10 +288,10 @@ namespace DinverCore {
         //printf("  --- ACCEPT new model ---\n" );
         //nav.currentPoint().print();
         // Check that generated model belongs to the right cell
-        /*QVector<int> iGenModel=nav.cellAt(nav.currentPoint());
+        /*VectorList<int> iGenModel=nav.cellAt(nav.currentPoint());
         if( ! iGenModel.contains(nav.currentCell()) ) {
           printf("Model effectively NOT generated in cell %i but:\n", nav.currentCell());
-          for(QVector<int>::iterator it=iGenModel.begin(); it!=iGenModel.end(); it++) {
+          for(VectorList<int>::iterator it=iGenModel.begin(); it!=iGenModel.end(); it++) {
             printf("%i ", *it);
           }
           printf("\n" );
@@ -422,7 +347,7 @@ namespace DinverCore {
     TRACE;
     RealSpace& parameterSpace=_forward->parameterSpace();
     const ParentIndex * parentIndex=newModel->parentIndex();
-    const ActiveIndex& activeIndex=parentIndex->index();
+    const ActiveIndex& activeIndex=parentIndex->activeIndex();
     int ndVar=parameterSpace.variableParameterCount();
     int nSteps=ndVar*_walkCount;
 
@@ -436,6 +361,8 @@ namespace DinverCore {
     // all others generated so far), the cell is considered as atomic (only one point inside).
     int iStep, iTries;
     int xMin, xMax;
+    SAFE_UNINITIALIZED(xMin, 0);
+    SAFE_UNINITIALIZED(xMax, 0);
     ActiveIndex cellIndex;
     PdfCurve pdf;
     for(iTries=0; iTries<10; iTries++) {
@@ -552,8 +479,8 @@ namespace DinverCore {
       // We put a threshold at 80% coverage to abort the inversion process.
       double nPossibleModels=parameterSpace.possibleCount();
       ASSERT(!newModel->isValidMisfit());
-      _repository->allModels()->lock();
-      if(_repository->allModels()->count()>0.8*nPossibleModels) {
+      _repository->allModels()->lockForRead();
+      if(_repository->allModels()->size()>0.8*nPossibleModels) {
         _repository->allModels()->unlock();
         _repository->stop(); // force termination of inversion
         return true;
