@@ -47,8 +47,8 @@ ModelSet::ModelSet(int parameterCount, int targetCount, int defaultCapacity)
   ASSERT(parameterCount>0);
   _parameterCount=parameterCount;
   _targetCount=targetCount;
-  _parameters=(int*)allocateVector(sizeof(int)*_parameterCount);
-  _misfits=(double*)allocateVector(sizeof(double)*_targetCount);
+  _parameters=static_cast<int*>(allocateVector(sizeof(int)*_parameterCount));
+  _misfits=static_cast<double*>(allocateVector(sizeof(double)*_targetCount));
 }
 
 ModelSet::~ModelSet()
@@ -60,8 +60,8 @@ ModelSet::~ModelSet()
 void ModelSet::reallocate()
 {
   _modelLock.lockForWrite();
-  _parameters=(int*)reallocateVector((uchar *) _parameters, sizeof(int)*_parameterCount);
-  _misfits=(double*)reallocateVector((uchar *) _misfits, sizeof(double)*_targetCount);
+  _parameters=static_cast<int*>(reallocateVector(_parameters, sizeof(int)*_parameterCount));
+  _misfits=static_cast<double*>(reallocateVector(_misfits, sizeof(double)*_targetCount));
   _modelLock.unlock();
 }
 
@@ -72,8 +72,13 @@ void ModelSet::clear()
   free(_misfits);
   QSet<Model>::clear();
   IncreaseStorage::clear();
-  _parameters=(int*)allocateVector(sizeof(int)*_parameterCount);
-  _misfits=(double*)allocateVector(sizeof(double)*_targetCount);
+  _parameters=static_cast<int*>(allocateVector(sizeof(int)*_parameterCount));
+  _misfits=static_cast<double*>(allocateVector(sizeof(double)*_targetCount));
+}
+
+int ModelSet::size() const
+{
+  return QSet<Model>::size();
 }
 
 /*!
@@ -235,6 +240,7 @@ bool ModelSet::importModels(RealSpace& parameterSpace, QString fileName, bool st
 bool ModelSet::importModelsFromAscii(RealSpace& parameterSpace, QString fileName)
 {
   TRACE;
+  bool ok=true;
   ASSERT(parameterSpace.variableParameterCount()==_parameterCount);
   QFile f(fileName);
   if( !f.open(QIODevice::ReadOnly) ) {
@@ -243,7 +249,7 @@ bool ModelSet::importModelsFromAscii(RealSpace& parameterSpace, QString fileName
   }
   QTextStream s(&f);
   QString line;
-  StringSection val, content(line);
+  StringSection val;
   const QChar * ptr;
   int i;
   int iLine=0;
@@ -256,13 +262,21 @@ bool ModelSet::importModelsFromAscii(RealSpace& parameterSpace, QString fileName
       ptr=0;
       for(i=0; i<nParams; i++) {
         val=content.nextField(ptr);
-        if(val.isValid()) parameterSpace.parameter(i)->setRealValue(val.toDouble()); else break;
+        if(val.isValid()) {
+          parameterSpace.parameter(i)->setRealValue(val.toDouble(ok));
+        } else {
+          break;
+        }
       }
       if(i==nParams) {
         double misfits[_targetCount];
         for(i=0; i<_targetCount; i++) {
           val=content.nextField(ptr);
-          if(val.isValid()) misfits[i]=val.toDouble(); else break;
+          if(val.isValid()) {
+            misfits[i]=val.toDouble(ok);
+          } else {
+            break;
+          }
         }
         // All parameter values were correctly retreived and also misfit (last one), then add a new model
         if(i==_targetCount) {
@@ -277,7 +291,7 @@ bool ModelSet::importModelsFromAscii(RealSpace& parameterSpace, QString fileName
       }
     }
   }
-  return true;
+  return ok;
 }
 
 /*!
