@@ -27,7 +27,8 @@
 #ifndef MODELSET_H
 #define MODELSET_H
 
-#include <QGpCoreTools.h>
+#include <QtCore>
+#include <QGpCoreMath.h>
 
 #include "Index.h"
 
@@ -37,7 +38,7 @@ namespace DinverCore {
   class RealSpace;
   class ReportReader;
 
-  class ModelSet : private QSet<Model>, private IncreaseStorage
+  class DINVERCORE_EXPORT ModelSet : private QSet<Model>, private IncreaseStorage
   {
     TRANSLATIONS("ModelSet")
   public:
@@ -54,7 +55,7 @@ namespace DinverCore {
     void clear();
 
     void reserve(int n) {IncreaseStorage::reserve(n);}
-    int count() const {return QSet<Model>::count();}
+    int size() const;
     int parameterCount() const {return _parameterCount;}
     int targetCount() const {return _targetCount;}
 
@@ -62,14 +63,15 @@ namespace DinverCore {
     const int * firstModel() const {return _parameters;}
     inline double misfit(const SetIndex& i, const TargetIndex& t) const;
 
-    void lock() {_modelLock.lockForRead();}
+    void lockForRead() {_modelLock.lockForRead();}
+    void lockForWrite() {_modelLock.lockForWrite();}
     void unlock() {_modelLock.unlock();}
 
     void print(const int * model) const;
     void print(const SetIndex& i) const;
     SetIndex bestModel() const;
   private:
-    virtual void reallocate();
+    void reallocate();
 
     int _parameterCount;
     int _targetCount;
