@@ -53,7 +53,7 @@ namespace DinverCore {
 
     bool isValidMisfit() const {return _validMisfit;}
     double misfit() const {return _misfit;}
-    const QVector<ActiveIndex>& navigatorHits() const {return _navigatorHits;}
+    const VectorList<ActiveIndex>& navigatorHits() const {return _navigatorHits;}
   private:
     SetIndex _index;
     bool _validMisfit;
@@ -61,7 +61,7 @@ namespace DinverCore {
     bool _validParent;
     ParentIndex * _parentIndex;
     double _parentVolume;
-    QVector<ActiveIndex> _navigatorHits;
+    VectorList<ActiveIndex> _navigatorHits;
   };
 
   inline NewModel::NewModel()
