@@ -88,7 +88,7 @@ namespace DinverCore {
     uint sum=0;
     sum += qHash(_name);
     sum += qHash(_unit);
-    for(QVector<ParamCondition>::const_iterator it=_conditions.begin(); it!=_conditions.end(); ++it) {
+    for(VectorList<ParamCondition>::const_iterator it=_conditions.begin(); it!=_conditions.end(); ++it) {
       sum+=it->checksum();
     }
     return sum;
@@ -159,7 +159,7 @@ namespace DinverCore {
       App::log(" "+QString::number(minimum())+" <= "+_name+" <= "+QString::number(maximum())+" "+_unit+" ("+_grid.humanInfo()+")\n");
     }
 
-    for(QVector<ParamCondition>::const_iterator it=_conditions.begin(); it!=_conditions.end(); ++it) {
+    for(VectorList<ParamCondition>::const_iterator it=_conditions.begin(); it!=_conditions.end(); ++it) {
       it->humanInfo();
     }
   }
@@ -203,18 +203,19 @@ namespace DinverCore {
     Q_UNUSED(tag)
     Q_UNUSED(attributes)
     Q_UNUSED(context)
+    bool ok=true;
     switch(memberID) {
     case 0:
-      setMinimum(content.toDouble());
-      return true;
+      setMinimum(content.toDouble(ok));
+      return ok;
     case 1:
-      setMaximum(content.toDouble());
-      return true;
+      setMaximum(content.toDouble(ok));
+      return ok;
     case 2:
-      _name=content.toString();
+      _name=content.toStringBuffer();
       return true;
     case 3:
-      _unit=content.toString();
+      _unit=content.toStringBuffer();
       return true;
     default:
       return false;
