@@ -88,7 +88,7 @@ private:
   QString _name;
   QString _unit;
   bool _fussy;
-  QVector<ParamCondition> _conditions;
+  VectorList<ParamCondition> _conditions;
   ParameterGrid _grid;
   double _value;
 protected:
@@ -107,7 +107,7 @@ inline void Parameter::getRectangularLimits(double& min, double& max) const
 
 inline void Parameter::getLimits(double& min, double& max) const
 {
-  for(QVector<ParamCondition>::const_iterator it=_conditions.begin(); it!=_conditions.end(); ++it) {
+  for(VectorList<ParamCondition>::const_iterator it=_conditions.begin(); it!=_conditions.end(); ++it) {
     it->getLimits(min, max);
   }
 }
