@@ -77,11 +77,11 @@ public:
   QString gridToString() const;
 private:
   // List of all parameters including the fixed ones
-  QVector<Parameter *> _allParameters;
+  VectorList<Parameter *> _allParameters;
   // List of not fixed parameters
-  QVector<Parameter *> _variableParameters;
+  VectorList<Parameter *> _variableParameters;
   // Kept here only for clean delete
-  QVector<AbstractCondition *> _conditions;
+  VectorList<AbstractCondition *> _conditions;
   QString _parameterNamePrefix;
 protected:
   virtual void xml_writeChildren(XML_WRITECHILDREN_ARGS) const;
