@@ -157,7 +157,7 @@ void SimpleCondition::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
 {
   TRACE;
   Q_UNUSED(context)
-  writeProperty(s, "type", toString(_type));
+  writeProperty(s, "type", convertType(_type));
   writeProperty(s, "factor", _factor);
   writeProperty(s, "constant", _constant);
 }
@@ -178,16 +178,17 @@ XMLMember SimpleCondition::xml_member(XML_MEMBER_ARGS)
 bool SimpleCondition::xml_setProperty(XML_SETPROPERTY_ARGS)
 {
   TRACE;
+  bool ok=true;
   switch(memberID) {
   case 0:
-    _factor=content.toDouble();
+    _factor=content.toDouble(ok);
     return true;
   case 1:
-    _constant=content.toDouble();
+    _constant=content.toDouble(ok);
     return true;
   case 2: {
       bool ok=true;
-      _type=fromString(content.toString(), ok);
+      _type=convertType(content.toStringView(), ok);
       return ok;
     }
   default:
