@@ -61,7 +61,7 @@ namespace DinverCore {
   void SumCondition::setFactor(int index, double value)
   {
     TRACE;
-    if(index<count()) {
+    if(index>=0 && index<count()) {
       if(value==1.0) {
         if(_factors) {
           _factors[index]=1.0;
@@ -210,7 +210,7 @@ namespace DinverCore {
   {
     TRACE;
     Q_UNUSED(context)
-    writeProperty(s, "type", toString(_type));
+    writeProperty(s, "type", convertType(_type));
     writeProperty(s, "constant", _constant);
     XMLSaveAttributes att;
     att.add(indexKey);
@@ -240,21 +240,21 @@ namespace DinverCore {
   bool SumCondition::xml_setProperty(XML_SETPROPERTY_ARGS)
   {
     TRACE;
+    bool ok=true;
     switch(memberID) {
     case 0: {
         XMLRestoreAttributeIterator it=attributes.find(indexKey);
         if(it!=attributes.end()) {
-          int i=it.value().toInt();
-          setFactor(i, content.toDouble());
+          int i=it.value().toInt(ok);
+          setFactor(i, content.toDouble(ok));
         }
       }
-      return true;
+      return ok;
     case 1:
-      _constant=content.toDouble();
-      return true;
+      _constant=content.toDouble(ok);
+      return ok;
     case 2: {
-        bool ok=true;
-        _type=fromString(content.toString(), ok);
+        _type=convertType(content.toStringView(), ok);
         return ok;
       }
     default:
