@@ -296,7 +296,7 @@ namespace DinverCore {
       if(pk==xMin-1) {
         xMin=pk;
         //App::log(tr("Adjust xMin limit to Pk(%1), dxMin=%2")
-        //         .arg(pk).arg(dxMin, 0, 'g', 20) << endl;
+        //         .arg(pk).arg(dxMin, 0, 'g', 20) << Qt::endl;
       }
     }
     if(iMax.isValid()) {
@@ -305,7 +305,7 @@ namespace DinverCore {
       if(pk==xMax+1) {
         xMax=pk;
         //App::log(tr("Adjust xMax limit to Pk(%1), dxMax=%2")
-        //         .arg(pk).arg(dxMax, 0, 'g', 20) << endl;
+        //         .arg(pk).arg(dxMax, 0, 'g', 20) << Qt::endl;
       }
     }
   }
@@ -315,10 +315,10 @@ namespace DinverCore {
     Usually there is only one index in the returned vector, except
     if \a p is right on the limit between 2 or more cells.
   */
-  QVector<ActiveIndex> VoronoiNavigator::cellAt(const int * p) const
+  VectorList<ActiveIndex> VoronoiNavigator::cellAt(const int * p) const
   {
     TRACE;
-    QVector<ActiveIndex> belongs;
+    VectorList<ActiveIndex> belongs;
     double minDistance=std::numeric_limits<double>::infinity();
     int nd=_cells->parameterCount();
     ActiveIndex end;
@@ -347,10 +347,10 @@ namespace DinverCore {
     Usually there is only one index in the returned vector, except
     if \a p is right on the limit between 2 or more cells.
   */
-  QVector<ActiveIndex> VoronoiNavigator::cellAt(const double * p) const
+  VectorList<ActiveIndex> VoronoiNavigator::cellAt(const double * p) const
   {
     TRACE;
-    QVector<ActiveIndex> belongs;
+    VectorList<ActiveIndex> belongs;
     double minDistance=std::numeric_limits<double>::infinity();
     int nd=_cells->parameterCount();
     ActiveIndex end;
@@ -422,12 +422,12 @@ namespace DinverCore {
   */
   bool VoronoiNavigator::checkCurrentPoint(const RealSpace& parameterSpace) const
   {
-    QVector<ActiveIndex> iGenModel=cellAt(_currentPoint);
+    VectorList<ActiveIndex> iGenModel=cellAt(_currentPoint);
     if(!iGenModel.contains(_currentCell)) {
       printCurrentPoint(parameterSpace);
       printPoint(_currentCell.value(), parameterSpace);
       printf("Model effectively NOT generated in cell %i but:\n", _currentCell.value());
-      for(QVector<ActiveIndex>::iterator it=iGenModel.begin(); it!=iGenModel.end(); it++) {
+      for(VectorList<ActiveIndex>::iterator it=iGenModel.begin(); it!=iGenModel.end(); it++) {
         int im=it->value();
         printf("%i:\n", im);
         printPoint(im, parameterSpace);
