@@ -28,11 +28,20 @@
 
 namespace DinverCore {
 
-/*!
-  \class XMLDinverContext XMLDinverContext.h
-  \brief Brief description of class still missing
+  /*!
+    \class XMLDinverContext XMLDinverContext.h
+    \brief Brief description of class still missing
 
-  Full description of class still missing
-*/
+    Full description of class still missing
+  */
+
+  /*!
+    Never allocated with new
+  */
+  XMLDinverContext::XMLDinverContext(FileType ft)
+    : XMLContext(false)
+   {
+     _fileType=ft;
+   }
 
 } // namespace DinverCore
