@@ -9,6 +9,7 @@
 #include "DCReportBlock.h"
 #include "DinverDCCoreDLLExport.h"
 #include "DispersionTarget.h"
+#include "EllipticityPeakTarget.h"
 #include "Forward.h"
 #include "GradientProfile.h"
 #include "GroundParameter.h"
@@ -27,7 +28,6 @@
 #include "TargetList.h"
 #include "TargetList2D.h"
 #include "UniformProfile.h"
-#include "ValueTarget.h"
 
 #ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
 using namespace DinverDCCore;
