@@ -257,7 +257,7 @@ void ParamGroundModel::resampleProfiles()
   TRACE;
   // At this stage all profiles are ok and sorted
   // resample profiles to get a unique discretization
-  QVector<double> depths;
+  VectorList<double> depths;
   ProfileList::iterator it;
   for(it=_profiles.begin();it!=_profiles.end();++it) {
     (*it)->collectDepths(depths);
@@ -280,7 +280,7 @@ void ParamGroundModel::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
 {
   TRACE;
   Q_UNUSED(context)
-  writeProperty(s, "position", _position.toString(20));
+  writeProperty(s, "position", _position.toString('g', 20));
 }
 
 void ParamGroundModel::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
@@ -316,7 +316,7 @@ bool ParamGroundModel::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
   switch(memberID) {
-  case 0: _position.fromString(content.toString()); return true;
+  case 0: return _position.fromString(content.toStringView());
   default: return false;
   }
 }
