@@ -397,6 +397,10 @@ void ParamProfile::pMaxResampled() const
   _maxResampled.print();
 }
 
+ENUM_AS_STRING_BEGIN(ParamProfile, Type)
+ENUM_AS_STRING_DATA_2(Condition, Param);
+ENUM_AS_STRING_END
+
 void ParamProfile::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
 {
   TRACE;
@@ -405,8 +409,8 @@ void ParamProfile::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
   XMLSaveAttributes att;
   QString& value=att.add(key);
   for(it=_layers.begin();it!=_layers.end();++it) {
-    value=( *it) ->name();
-    ( *it) ->xml_save(s, context, att);
+    value=(*it)->name();
+    (*it)->xml_save(s, context, att);
   }
 }
 
@@ -414,13 +418,13 @@ void ParamProfile::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
 {
   TRACE;
   Q_UNUSED(context)
-  writeProperty(s, "type", _type==Param ? "Param" : "Condition" );
+  writeProperty(s, "type", convertType(_type));
   writeProperty(s, "longName", _longName);
   writeProperty(s, "shortName", _shortName);
   writeProperty(s, "unit", _unit);
   writeProperty(s, "defaultMinimum", _defaultMinimum);
   writeProperty(s, "defaultMaximum", _defaultMaximum);
-  writeProperty(s, "defaultCondition", SimpleCondition::toString(_defaultCondition));
+  writeProperty(s, "defaultCondition", SimpleCondition::convertType(_defaultCondition));
 }
 
 XMLMember ParamProfile::xml_member(XML_MEMBER_ARGS)
@@ -450,23 +454,19 @@ bool ParamProfile::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(context)
   Q_UNUSED(attributes)
+  bool ok=true;
   switch(memberID) {
-  case 0: _longName=content.toString(); return true;
-  case 1: _shortName=content.toString(); return true;
-  case 2: _unit=content.toString(); return true;
-  case 3: _defaultMinimum=content.toDouble(); return true;
-  case 4: _defaultMaximum=content.toDouble(); return true;
-  case 5: {
-      bool ok=true;
-      _defaultCondition=SimpleCondition::fromString(content.toString(), ok);
-      return ok;
-    }
+  case 0: _longName=content.toStringBuffer(); return true;
+  case 1: _shortName=content.toStringBuffer(); return true;
+  case 2: _unit=content.toStringBuffer(); return true;
+  case 3: _defaultMinimum=content.toDouble(ok); return ok;
+  case 4: _defaultMaximum=content.toDouble(ok); return ok;
+  case 5:
+    _defaultCondition=SimpleCondition::convertType(content.toStringView(), ok);
+    return ok;
   case 6:
-    if(content=="Condition" )
-      _type=Condition;
-    else
-      _type=Param;
-    return true;
+    _type=convertType(content.toStringView(), ok);
+    return ok;
   default: return false;
   }
 }
