@@ -47,9 +47,9 @@ DCModelViewer::DCModelViewer(QWidget * parent)
   TRACE;
   _sheet.setObjectName("sheet");
   _childLayout=new QVBoxLayout(this);
-  _childLayout->setMargin(0);
+  _childLayout->setContentsMargins(0, 0, 0, 0);
   _childLayout->setSpacing(0);
-#ifndef Q_OS_MAC
+#ifndef Q_OS_DARWIN
   _menuBar=new QMenuBar(this);
   _childLayout->addWidget(_menuBar);
 #endif
@@ -59,10 +59,11 @@ DCModelViewer::DCModelViewer(QWidget * parent)
   _colorMap=new ColorMapWidget(nullptr);
   _colorMap->setObjectName("Palette");
   ColorMap map;
-  map.setPalette(ColorPalette::preference("DCModelViewer", 20, ColorPalette::Hobi));
+  map.setPalette(ColorPalette::preference("DCModelViewer", 20,
+                                          ColorPalette::defaultSequential,
+                                          ColorPalette::Reversed));
   map.setValues(0, 1, SamplingParameters::Linear);
   _colorMap->setColorMap(map);
-  //_colorMap->setNumberPrecision(2);
   _colorMap->setTitle("Misfit value");
   _colorMap->setPrintXAnchor(6);
   _colorMap->setPrintYAnchor(9);
@@ -108,7 +109,7 @@ QMenu * DCModelViewer::addMenu(QString title)
   TRACE;
   QMenu * m=new QMenu(this);
   m->setTitle(title);
-#ifndef Q_OS_MAC
+#ifndef Q_OS_DARWIN
   _menuBar->addMenu(m);
 #endif
   _sheet.addMenu(m);
@@ -179,7 +180,13 @@ void DCModelViewer::initGraphs(int nGraphs)
     _curveLayers[i]->setColorMap(_colorMap->colorMap());
     _curveLayers[i]->addTrackingAction(tr("Select models"), 0, tr("Select models to create a new plot."));
     _curveLayers[i]->addTrackingAction(tr("Discard models"), 1, tr("Discard models to create a new plot."));
-    connect(_curveLayers[i], SIGNAL(dataSelected( int, const QVector<int>* )), this, SLOT(showSelectedModels( int, const QVector<int>* )) );
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    connect(_curveLayers[i], SIGNAL(dataSelected(int, const QList<int>*)),
+            this, SLOT(showSelectedModels(int, const QList<int>*)));
+#else
+    connect(_curveLayers[i], SIGNAL(dataSelected(int, const QVector<int>*)),
+            this, SLOT(showSelectedModels(int, const QVector<int>* )));
+#endif
     setTitles(i);
     // Connect palettes in both ways
     connect(_curveLayers[i], SIGNAL(colorMapChanged(ColorMap)), _colorMap, SLOT(setColorMap(const ColorMap&)));
@@ -275,7 +282,7 @@ void DCModelViewer::selectModels(QString reportFileName, double maxMisfit, int m
   }
 }
 
-void DCModelViewer::selectModels(DCModelViewer * w, const QVector<int> * indexes)
+void DCModelViewer::selectModels(DCModelViewer * w, const VectorList<int> * indexes)
 {
   TRACE;
   // Make sure models are properly ordered (plotting index)
@@ -298,7 +305,7 @@ void DCModelViewer::selectModels(DCModelViewer * w, const QVector<int> * indexes
   }
 }
 
-void DCModelViewer::rejectModels(DCModelViewer * w, const QVector<int> * indexes)
+void DCModelViewer::rejectModels(DCModelViewer * w, const VectorList<int> * indexes)
 {
   TRACE;
   QSet<int> rejectLookup;
@@ -435,14 +442,33 @@ void DCModelViewer::setDefaultPalette()
   ColorPalette::setPreference("DCModelViewer", _colorMap->colorMap().palette());
 }
 
+void DCModelViewer::setColorMap(const ColorMap& m)
+{
+  _colorMap->setColorMap(m);
+}
+
 void DCModelViewer::setTarget(const TargetList *)
 {
 }
 
+void DCModelViewer::exportPlot(const ExportOptions& o)
+{
+  TRACE;
+  o.selectObjects(&_sheet);
+  o.setLegend(&_sheet);
+  o.setColorMap(&_sheet);
+  o.addLayers(&_sheet);
+  o.restoreMakeUp(&_sheet);
+  if(!o.preserveScales()) {
+    setLimits();
+  }
+  o.exportObjects(&_sheet);
+}
+
 /*!
   indexes refers to the curve index
 */
-void DCModelViewer::showSelectedModels(int id, const QVector<int>* indexes)
+void DCModelViewer::showSelectedModels(int id, const VectorList<int>* indexes)
 {
   TRACE;
   ViewerParam * d=new ViewerParam(QApplication::activeWindow());
