@@ -85,6 +85,7 @@ void EllipticityViewer::setTitles(int i)
   w->yAxis()->setTitle("Ellipticity angle (deg)");
   w->yAxis()->setScaleType(Scale::Linear);
   w->xAxis()->setFrequency();
+  w->setObjectName(QString("ell_%1").arg(i));
   _curveLayers[i]->setSignChangeThreshold(70.0);
 }
 
@@ -158,8 +159,14 @@ void EllipticityViewer::setTarget(const TargetList * tl)
   for(int i=0; i<_nGraphs; i++) {
     _mode.setIndex(i);
     for(auto it=curves.begin(); it!=curves.end(); it++) {
-      if(it->hasMode(_mode) && it->isEnabled()) {
-        static_cast<ModalLine *>(_targetLayers[i]->addLine())->setCurve(*it);
+      if(it->isEnabled()) {
+        if(it->hasMode(_mode)) {
+          static_cast<ModalLine *>(_targetLayers[i]->addLine())->setCurve(*it);
+        } else {
+          App::log(tr("Curve '%1' does not have mode '%2'\n")
+                   .arg(it->name())
+                   .arg(_mode.toString(Mode::Ellipticity)));
+        }
       }
     }
     if(i==0)
