@@ -87,33 +87,33 @@ void GroundModelViewer::setTitles(int i)
 {
   TRACE;
   AxisWindow * w=_graphs[i];
-  w->yAxis()->setTitle( "Depth (m)" );
-  w->yAxis()->setTitleInversedScale( "1/Depth (1/m)" );
+  w->yAxis()->setTitle("Depth (m)");
+  w->yAxis()->setTitleInverseScale("1/Depth (1/m)");
   w->yAxis()->setReversedScale(true);
   switch (i) {
   case 0:
-    w->xAxis()->setTitle( "Vp (m/s)" );
-    w->xAxis()->setTitleInversedScale( "Slowness P (s/m)" );
+    w->xAxis()->setTitle("Vp (m/s)");
+    w->xAxis()->setTitleInverseScale( "Slowness P (s/m)");
     w->setObjectName("vp");
     break;
   case 1:
-    w->xAxis()->setTitle( "Vs (m/s)" );
-    w->xAxis()->setTitleInversedScale( "Slowness S (s/m)" );
+    w->xAxis()->setTitle("Vs (m/s)");
+    w->xAxis()->setTitleInverseScale( "Slowness S (s/m)");
     w->setObjectName("vs");
     break;
   case 2:
-    w->xAxis()->setTitle( "Density (t/m3)" );
-    w->xAxis()->setTitleInversedScale( "1/Density (m3/t)" );
+    w->xAxis()->setTitle("Density (kg/m3)");
+    w->xAxis()->setTitleInverseScale("1/Density (m3/kg)");
     w->setObjectName("rho");
     break;
   case 3:
-    w->xAxis()->setTitle( "Pitch" );
-    w->xAxis()->setTitleInversedScale( "1/Pitch" );
+    w->xAxis()->setTitle("Pitch");
+    w->xAxis()->setTitleInverseScale("1/Pitch");
     w->setObjectName("pitch");
     break;
   default:
-    w->xAxis()->setTitle( "Resistivity (ohm m)" );
-    w->xAxis()->setTitleInversedScale( "Conductivity (S/m)" );
+    w->xAxis()->setTitle("Resistivity (ohm m)");
+    w->xAxis()->setTitleInverseScale("Conductivity (S/m)");
     w->xAxis()->setScaleType(Scale::Log);
     w->setObjectName("res");
     break;
@@ -162,8 +162,8 @@ void GroundModelViewer::setLimits(int i, const Rect& r)
   if(r.x1()>0.0) {
     switch(a->scaleType()) {
     case Scale::Log:
-    case Scale::InversedLog:
-    case Scale::Inversed:
+    case Scale::InverseLog:
+    case Scale::Inverse:
       a->setRange(r.x1() * 0.95, r.x2() * 1.05);
       break;
     case Scale::Linear:
@@ -215,7 +215,7 @@ void GroundModelViewer::exportModels()
         if(dcBlock.vs()) vs.readReport(dcBlock.stream()); else continue;
         if(dcBlock.rho()) rho.readReport(dcBlock.stream()); else continue;
         // These are raw profiles without the same depth sampling
-        QVector<double> depths;
+        VectorList<double> depths;
         depths << vp.depths();
         depths << vs.depths();
         depths << rho.depths();
@@ -339,7 +339,7 @@ void GroundModelViewer::minMaxProfiles()
     LineLayer * plot=new LineLayer(_graphs[i] );
     plot->setObjectName("limits");
     PlotLine2D * line=new PlotLine2D;
-    line->setPen(Pen(Qt::black, 0.60, Qt::DashLine));
+    line->setPen(Pen(Qt::black, 0.60, Pen::DashLine));
     line->setSymbol(Symbol(Symbol::NoSymbol));
     plot->setReferenceLine(line);
     static_cast<PlotLine2D *>(plot->addLine())->setCurve(minCurves[i]);
