@@ -43,7 +43,7 @@ ViewerParam::ViewerParam(QWidget * parent)
   setupUi(this);
 }
 
-void ViewerParam::select(DCModelViewer * refW, const QVector<int> * indexes)
+void ViewerParam::select(DCModelViewer * refW, const VectorList<int> * indexes)
 {
   TRACE;
   setWindowTitle(tr("Viewer for selected models"));
@@ -56,7 +56,7 @@ void ViewerParam::select(DCModelViewer * refW, const QVector<int> * indexes)
   }
 }
 
-void ViewerParam::reject(DCModelViewer * refW, const QVector<int> * indexes)
+void ViewerParam::reject(DCModelViewer * refW, const VectorList<int> * indexes)
 {
   TRACE;
   setWindowTitle(tr("Viewer for non-discarded models"));
