@@ -135,23 +135,24 @@ namespace GeopsyCore {
   void AbstractFileFormat::setName(QString n)
   {
     TRACE;
-    QRegExp reg;
+    QRegularExpression reg;
     reg.setPattern("\t\'\"");
     n.replace(reg, " ");
     QString standardName;
     reg.setPattern(" *([a-zA-Z])");
-    int index=reg.indexIn(n, 0);
-    standardName=reg.cap(0).toUpper();
-    index+=reg.matchedLength();
+    QRegularExpressionMatch match;
+    int index=n.indexOf(reg, 0, &match);
+    standardName=match.captured(0).toUpper();
+    index+=match.capturedLength(0);
     int lastIndex=index;
     reg.setPattern(" +\\b([a-zA-Z]?)");
-    index=reg.indexIn(n, lastIndex);
+    index=n.indexOf(reg, lastIndex, &match);
     while(index>=0) {
       standardName+=n.mid(lastIndex, index-lastIndex);
-      standardName+=reg.cap(1).toUpper();
-      index+=reg.matchedLength();
+      standardName+=match.captured(1).toUpper();
+      index+=match.capturedLength(0);
       lastIndex=index;
-      index=reg.indexIn(n, lastIndex);
+      index=n.indexOf(reg, lastIndex, &match);
     }
     standardName+=n.mid(lastIndex);
     _name=standardName;
@@ -184,9 +185,9 @@ namespace GeopsyCore {
     Q_UNUSED(attributes)
     Q_UNUSED(context)
     switch(memberID) {
-    case 0: _name=content.toString(); return true;
+    case 0: _name=content.toStringBuffer(); return true;
     case 1: {
-        QString e=content.toString();
+        QString e=content.toStringBuffer();
         if(!e.isEmpty()) {
           _suffixList=e.split(",");
         } else {
@@ -194,7 +195,7 @@ namespace GeopsyCore {
         }
       }
       return true;
-    case 2: _caption=content.toString(); return true;
+    case 2: _caption=content.toStringBuffer(); return true;
     default:
       break;
     }
