@@ -46,7 +46,10 @@ namespace GeopsyCore {
     AbstractSignalGroup(AbstractSignalGroup * parent=nullptr);
     virtual ~AbstractSignalGroup() {}
 
-    virtual void setParent(AbstractSignalGroup * p);
+    const QString& xml_tagName() const {return xmlAbstractSignalGroupTag;}
+    static const QString xmlAbstractSignalGroupTag;
+
+    void setParent(TreeContainer * p);
 
     virtual QString name() const {return _name;}
     virtual void setName(const QString& n);
@@ -69,10 +72,10 @@ namespace GeopsyCore {
 
     const AbstractSignalGroup * find(QString name) const;
     const AbstractSignalGroup * find(int id) const;
-    QList<const AbstractSignalGroup *> find(const QRegExp& name) const;
+    QList<const AbstractSignalGroup *> find(const QRegularExpression& name) const;
     AbstractSignalGroup * find(QString name);
     AbstractSignalGroup * find(int id);
-    QList<AbstractSignalGroup *> find(const QRegExp& name);
+    QList<AbstractSignalGroup *> find(const QRegularExpression& name);
 
     QList<const AbstractSignalGroup *> find(const Signal * sig) const;
     QList<const AbstractSignalGroup *> list() const;
@@ -101,6 +104,8 @@ namespace GeopsyCore {
     AbstractSignalGroup * parent() {return static_cast<AbstractSignalGroup *>(TreeContainer::parent());}
     const AbstractSignalGroup * parent() const {return static_cast<const AbstractSignalGroup *>(TreeContainer::parent());}
     AbstractSignalGroup * childAt(int index) {return static_cast<AbstractSignalGroup *>(TreeContainer::childAt(index));}
+
+    bool xml_inherits(const QString& tagName) const;
   protected:
     virtual void xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const;
     void xml_writeChildren(XML_WRITECHILDREN_ARGS) const;
