@@ -41,26 +41,29 @@ namespace GeopsyCore {
     virtual bool setSubPool(SubSignalPool * subPool);
     SubSignalPool * subPool() const {return _subPool;}
 
-    virtual bool setParameters(const AbstractParameters& param);
     const AbstractParameters * parameters() const {return _param;}
     AbstractParameters * parameters() {return _param;}
 
-    bool setLoop();
+    virtual bool setLoop();
     ParallelTaskManager * loop() const {return _loop;}
 
     SignalDatabase * database() const {return _subPool->database();}
 
-    virtual void waitFinished();
+    virtual void waitFinished(int ms);
+    bool isFinished() const {return !_loop || _loop->isFinished();}
+
     void showProgress();
     const QString& log() const {return _log;}
+    virtual bool saveResults(const QString& /*fileName*/) {return false;}
   public slots:
-    virtual void start();
+    virtual void start(int threadCount, bool forceParallel);
     void stop();
   protected slots:
     void finish();
   signals:
     void finished();
   protected:
+    void setParameters(AbstractParameters * param);
     virtual ParallelTaskManager * createLoop() {return nullptr;}
   private:
     SubSignalPool * _subPool;
