@@ -51,23 +51,6 @@ namespace GeopsyCore {
     _factor=1.0;
   }
 
-  /*!
-    Copy constructor
-  */
-  AsciiSignalFormatRule::AsciiSignalFormatRule(const AsciiSignalFormatRule& o)
-      : XMLClass()
-  {
-    _channel=o._channel;
-    _data=o._data;
-    _constant=o._constant;
-    _mandatory=o._mandatory;
-    _operation=o._operation;
-    _pattern=o._pattern;
-    _patternIndex=o._patternIndex;
-    _value=o._value;
-    _factor=o._factor;
-  }
-
   void AsciiSignalFormatRule::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
   {
     TRACE;
@@ -81,7 +64,7 @@ namespace GeopsyCore {
       writeProperty(s, "value", _value.toString());
     } else {
       writeProperty(s, "mandatory", (bool)_mandatory);
-      writeProperty(s, "operation", operationString());
+      writeProperty(s, "operation", convertOperation(_operation));
       writeProperty(s, "pattern", _pattern);
       writeProperty(s, "patternIndex", (int)_patternIndex);
     }
@@ -110,81 +93,32 @@ namespace GeopsyCore {
     TRACE;
     Q_UNUSED(tag)
     Q_UNUSED(context)
+    bool ok=true;
     switch(memberID) {
-    case 0: _channel=content.toInt(); return true;
+    case 0: _channel=content.toInt(ok); return ok;
     case 1: {
-        _data=MetaDataFactory::instance()->index(content.toString());
+        _data=MetaDataFactory::instance()->index(content.toStringBuffer());
         XMLRestoreAttributeIterator it=attributes.find(indexKey);
         if(it!=attributes.end()) {
-          _data.setIndex(it.value().toString());
+          _data.setIndex(it.value().toStringBuffer());
         }
         return true;
       }
-    case 2: _pattern=content.toString(); return true;
-    case 3: _patternIndex=content.toInt(); return true;
-    case 4: _constant=content.toBool(); return true;
-    case 5: _mandatory=content.toBool(); return true;
-    case 6: _value=content.toString(); return true;
-    case 7: _factor=content.toDouble(); return true;
-    case 8: setOperation(content.toString()); return true;
+    case 2: _pattern=content.toStringBuffer(); return true;
+    case 3: _patternIndex=content.toInt(ok); return ok;
+    case 4: _constant=content.toBool(ok); return ok;
+    case 5: _mandatory=content.toBool(ok); return ok;
+    case 6: _value=content.toStringBuffer(); return true;
+    case 7: _factor=content.toDouble(ok); return ok;
+    case 8: setOperation(convertOperation(content.toStringView(), ok)); return ok;
     default:
       break;
     }
     return false;
   }
 
-  QString AsciiSignalFormatRule::operationString() const
-  {
-    TRACE;
-    switch(_operation) {
-    case Assign:
-      break;
-    case Add:
-      return "Add";
-    case Subtract:
-      return "Subtract";
-    case Multiply:
-      return "Multiply";
-    case Divide:
-      return "Divide";
-    }
-    return "Assign";
-  }
-
-  void AsciiSignalFormatRule::setOperation(const QString& o)
-  {
-    TRACE;
-    if(o.count()>=3) {
-      switch(o[2].unicode()) {
-      case 'd':
-        if(o=="Add") {
-          _operation=Add;
-        }
-        break;
-      case 'b':
-        if(o=="Subtract") {
-          _operation=Subtract;
-        }
-        break;
-      case 'l':
-        if(o=="Multiply") {
-          _operation=Multiply;
-        }
-        break;
-      case 'v':
-        if(o=="Divide") {
-          _operation=Divide;
-        }
-        break;
-      case 's':
-        if(o=="Assign") {
-          _operation=Assign;
-        }
-        break;
-      default:
-        break;
-      }
-    }
-  }
+  ENUM_AS_STRING_BEGIN(AsciiSignalFormatRule, Operation)
+  ENUM_AS_STRING_DATA_5(Add, Assign, Divide, Multiply, Subtract);
+  ENUM_AS_STRING_END
 
 } // namespace GeopsyCore
