@@ -23,11 +23,17 @@
 **
 ***************************************************************************/
 
+#include <signal.h>
+
 #include "CoreToolInterface.h"
 #include "SignalDatabase.h"
+#include "SignalGroup.h"
+#include "AbstractTool.h"
 
 namespace GeopsyCore {
 
+   AbstractTool * CoreToolInterface::_tool=nullptr;
+
   /*!
     \class CoreToolInterface CoreToolInterface.h
     \brief Brief description of class still missing
@@ -44,6 +50,7 @@ namespace GeopsyCore {
   {
     TRACE;
     _param=nullptr;
+    _overwrite=true;
   }
 
   /*!
@@ -66,10 +73,18 @@ namespace GeopsyCore {
   {
     App::setPrefix(CoreApplication::applicationName()+": ");
     CoreApplication::instance()->debugUserInterrupts(false);
+#ifdef Q_OS_WIN
+    signal(30, showProgress);  // From the list available with 'kill -l'
+#else
+    signal(SIGUSR1, showProgress);
+    signal(SIGINT, stopAndSave);
+#endif
 
     QString databaseFileName;
     QStringList groupPaths;
     QStringList groupPatterns;
+    QString utmCoordinateFile;
+    QString saveDatabase;
     QList<int> groupIds;
     bool showGroups=false, showCoord=false, groupLeaves=false;
 
@@ -105,9 +120,19 @@ namespace GeopsyCore {
         } else if(arg=="-station-list") {
           CoreApplication::checkOptionArg(i, argc, argv);
           QString l(argv[i]);
-          _stationList=l.split(QRegExp("[, ]"), QString::SkipEmptyParts);
+#if(QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+          _stationList=l.split(QRegularExpression("[, ]"), Qt::SkipEmptyParts);
+#else
+          _stationList=l.split(QRegularExpression("[, ]"), QString::SkipEmptyParts);
+#endif
         } else if(arg=="-coord") {
           showCoord=true;
+        } else if(arg=="-utm") {
+          CoreApplication::checkOptionArg(i, argc, argv);
+          utmCoordinateFile.append(argv[i]);
+        } else if(arg=="-save-db") {
+          CoreApplication::checkOptionArg(i, argc, argv);
+          saveDatabase=argv[i];
         } else if(arg=="-param") {
           CoreApplication::checkOptionArg(i, argc, argv);
           QStringList beginPatterns, endPatterns;
@@ -130,6 +155,8 @@ namespace GeopsyCore {
             return false;
           }
           ::exit(fixDatabasePaths(databaseFileName) ? 0 : 2);
+        } else if(arg=="-no-overwrite") {
+          _overwrite=false;
         } else {
           argv[j++]=argv[i];
         }
@@ -187,7 +214,7 @@ namespace GeopsyCore {
     }
     if(!groupPatterns.isEmpty()) {
       for(QStringList::iterator it=groupPatterns.begin(); it!=groupPatterns.end(); it++) {
-        QList<const AbstractSignalGroup *> list=const_cast<const SignalDatabase *>(db)->findGroups(QRegExp(*it));
+        QList<const AbstractSignalGroup *> list=const_cast<const SignalDatabase *>(db)->findGroups(QRegularExpression(*it));
         if(list.isEmpty()) {
           App::log(tr("group pattern '%1' has no match\n").arg(*it) );
           return false;
@@ -210,6 +237,23 @@ namespace GeopsyCore {
       }
       _groups=db->masterGroup()->list();
     }
+    if(!utmCoordinateFile.isEmpty()) {
+      App::log(tr("Setting coordinates from '%1'...\n").arg(utmCoordinateFile));
+      if(!setUtmCoordinates(utmCoordinateFile)) {
+        return false;
+      }
+    }
+    if(!saveDatabase.isEmpty()) {
+      SignalGroup * g=new SignalGroup;
+      g->setSignals(db->subPool());
+      g->setName("all");
+      App::log(tr("Creating group 'all' with all loaded signals\n"));
+      g->setParent(db->masterGroup());
+      if(db->saveAs(saveDatabase)) {
+        App::log(tr("Database saved to '%1'\n").arg(saveDatabase));
+      }
+      ::exit(0);
+    }
     App::log(tr("Selected groups:\n"));
     for(QList<const AbstractSignalGroup *>::iterator it=_groups.begin(); it!=_groups.end(); it++) {
       App::log(tr("  '%1': %2 signals\n").arg((*it)->pathName()).arg((*it)->signalCount()) );
@@ -222,7 +266,7 @@ namespace GeopsyCore {
         QList<NamedPoint> l=p.stations();
         sOut << "# " << groupName(i) << Qt::endl;
         for(QList<NamedPoint>::iterator its=l.begin(); its!=l.end(); its++) {
-          sOut << its->toString(20, 'g') << Qt::endl;
+          sOut << its->toString('g', 20) << Qt::endl;
         }
       }
       ::exit(0);
@@ -230,6 +274,44 @@ namespace GeopsyCore {
     return true;
   }
 
+  bool CoreToolInterface::setUtmCoordinates(const QString& utmCoordinateFile)
+  {
+    CoordinateFile cf;
+    cf.setUtmXYNameParser();
+    if(!cf.setFile(utmCoordinateFile)) {
+      return false;
+    }
+    while(!cf.wait()) {}
+    QList<NamedPoint> coordinates=cf.points();
+    // Populate map for quick lookup.
+    QMap<QString, int> coordinateMap;
+    for(int i=coordinates.count()-1; i>=0; i--) {
+      coordinateMap.insert(coordinates.at(i).name(), i);
+    }
+    SignalDatabase * db=GeopsyCoreEngine::instance()->defaultDatabase();
+    QMap<QString, int>::iterator it;
+    for(int i=db->count()-1; i>=0; i--) {
+      Signal * sig=db->at(i);
+      it=coordinateMap.find(sig->name());
+      if(it!=coordinateMap.end()) {
+        const NamedPoint& p=coordinates.at(it.value());
+        App::log(tr("Set coordinates (%1) to signal %2 (ID=%3)\n")
+                 .arg(p.toString('f', 3))
+                 .arg(sig->nameComponent())
+                 .arg(sig->id()));
+        sig->setReceiver(p);
+        sig->setUtmZone(cf.utmZone());
+      }
+    }
+    return true;
+  }
+
+  void CoreToolInterface::showArguments()
+  {
+    App::log(CoreApplication::applicationFilePath()+" "+
+             CoreApplication::argumentList().join(' ')+"\n");
+  }
+
   int CoreToolInterface::subPoolCount() const
   {
     TRACE;
@@ -277,35 +359,80 @@ namespace GeopsyCore {
     return db->save();
   }
 
+  bool CoreToolInterface::overwrite(const QString& fileName) const
+  {
+    if(_overwrite || !QFile::exists(fileName)) {
+      return true;
+    } else {
+      App::log(tr("File '%1' already exists.\n").arg(fileName));
+      return false;
+    }
+  }
+
+  void CoreToolInterface::showProgress(int)
+  {
+    if(_tool) {
+      _tool->showProgress();
+    }
+  }
+
+  void CoreToolInterface::stopAndSave(int)
+  {
+    if(_tool) {
+      _tool->stop();  // If one of the worker is blocked, it will not necessarily respond to this stop
+                     // Hence we save what can be saved.
+      signal(SIGINT, nullptr);
+      App::log(tr("Waiting for the termination during 60 sec. maximum\n"
+                  "The collected results will be saved even if some tasks are blocked.\n"
+                  "Send another interrupt signal to skip saving results.\n"));
+      _tool->waitFinished(60000);
+      if(!_tool->isFinished()) {
+        // The process did not stop properly after 60 seconds.
+        QString fileName=File::uniqueName("backup.max", QDir());
+        _tool->saveResults(fileName);
+        App::log(tr("Some tasks are blocked. Aborting\n"));
+        std::exit(2);
+      }
+      App::log(tr("Clean termination of all tasks achieved\n"
+                  "Waiting 10 sec. before saving the results.\n"
+                  "Send another interrupt signal to skip saving results.\n"));
+      CoreApplication::sleep(10000);
+    }
+  }
+
   void CoreToolInterface::setHelp(ApplicationHelp * h)
   {
-    h->addOption("-db","Database file to process if no signal files are imported.");
-    h->addOption("-no-file-key","Skip file content key when loading database (only for old database before 2017-09).");
-    h->addOption("-interactive","Allows interactions through stdin/out.");
-    h->addOption("-groups","Lists the available groups and exits.");
-    h->addOption("-group-leaves","When a group is selected by one of the following options, \"leaves\" means: process "
-                                 "individualy all elementary children. By default, the selected folder groups are process "
-                                 "in one block. This option has no effect if the selected groups are already elementary groups "
-                                 " with no children.");
-    h->addOption("-group-id <ID>","Group ID to process. Several entries are allowed. "
-                                  "If no group is selected, all groups are processed. If group with ID contains several children, "
-                                  "the children are processed.");
-    h->addOption("-group <PATH>","Alias to -group-path.");
-    h->addOption("-group-path <PATH>","Group path to process. Several entries are allowed. "
-                                      "If no group is selected, all groups are processed. If group with PATH contains several children, "
-                                      "the children are processed.");
-    h->addOption("-group-pattern <REGEXP>","Select for processing all groups whose name matches REGEXP. Only one entry is allowed. "
-                                           "If no group is selected, all groups are processed.");
-    h->addOption("-station-list <STATIONS>","STATIONS is a coma separated list of station names to be processed. "
-                                            "'-group-*' options are still required but only a subset of the group "
-                                            "can be selected with option '-station-list'.");
-    h->addOption("-coord","Returns the list of selected stations and their coordinates.");
-    h->addOption("-o <FILE>","Ouput file name (default='a')");
-    h->addOption("-param <PARAM>","Load parameters in PARAM");
-    h->addOption("-set <PARAM>=<VALUE>","Set VALUE to parameter PARAM.");
-    h->addOption("-fix-signal-paths","Only '-db' option is required. Absolute paths stored in a '.gpy' can be changed "
-                                     "without opening a graphical user interface. Useful when moving a database to a "
-                                     "remote server without X display.");
+    h->addOption("-db", "Database file to process if no signal files are imported.");
+    h->addOption("-save-db <FILE.gpy>", "Creates database FILE.gpy from the loaded signals and exits.");
+    h->addOption("-no-file-key", "Skip file content key when loading database (only for old database before 2017-09).");
+    h->addOption("-interactive", "Allows interactions through stdin/out.");
+    h->addOption("-no-overwrite", "If output file already exists, does not process.");
+    h->addOption("-groups", "Lists the available groups and exits.");
+    h->addOption("-group-leaves", "When a group is selected by one of the following options, \"leaves\" means: process "
+                                  "individualy all elementary children. By default, the selected folder groups are process "
+                                  "in one block. This option has no effect if the selected groups are already elementary groups "
+                                  " with no children.");
+    h->addOption("-group-id <ID>", "Group ID to process. Several entries are allowed. "
+                                   "If no group is selected, all groups are processed. If group with ID contains several children, "
+                                   "the children are processed.");
+    h->addOption("-group <PATH>", "Alias to -group-path.");
+    h->addOption("-group-path <PATH>", "Group path to process. Several entries are allowed. "
+                                       "If no group is selected, all groups are processed. If group with PATH contains several children, "
+                                       "the children are processed.");
+    h->addOption("-group-pattern <REGEXP>", "Select for processing all groups whose name matches REGEXP. Only one entry is allowed. "
+                                            "If no group is selected, all groups are processed.");
+    h->addOption("-station-list <STATIONS>", "STATIONS is a coma separated list of station names to be processed. "
+                                             "'-group-*' options are still required but only a subset of the group "
+                                             "can be selected with option '-station-list'.");
+    h->addOption("-utm <FILE>", "If provided, the coordinates of stations are assigned from the UTM coordinates in file. "
+                                "File columns must be: UTM_ZONE X Y STATION_NAME.");
+    h->addOption("-coord", "Returns the list of selected stations and their coordinates.");
+    h->addOption("-o <FILE>", "Ouput file name (default='a')");
+    h->addOption("-param <PARAM>", "Load parameters in PARAM");
+    h->addOption("-set <PARAM>=<VALUE>", "Set VALUE to parameter PARAM.");
+    h->addOption("-fix-signal-paths", "Only '-db' option is required. Absolute paths stored in a '.gpy' can be changed "
+                                      "without opening a graphical user interface. Useful when moving a database to a "
+                                      "remote server without X display.");
   }
 
 } // namespace GeopsyCore
