@@ -266,7 +266,7 @@ void DoubleSignal::frecur(int la, double *a, double *xa, int lb, double *b, doub
    \li \a type=-1. for high-pass, +1. for low-pass 
    \li \a nfil=order and type of filtering:
 
-   \li abs(\a nfil)=order of Butterworth filtre
+   \li abs(\a nfil)=order of Butterworth filter
    \li if \a nfil is negative, the filter is done in both directions, and it is non-causal but non-outphasing
    \li if \a nfil is positive, ,the filter is done in only one direction, and it is causal but outphasing
 */
@@ -348,15 +348,13 @@ bool DoubleSignal::filter(const FilterParameters& param)
           filrec(param.minimumFrequency(), 1, 0, _nSamples-1, 1, thisSamples, thisSamples, param.order(), _samplingPeriod);
           break;
         case FilterParameters::HighPass:
-          filrec(param.maximumFrequency(), -1, 0, _nSamples-1, 1, thisSamples, thisSamples, param.order(), _samplingPeriod);
+          filrec(param.minimumFrequency(), -1, 0, _nSamples-1, 1, thisSamples, thisSamples, param.order(), _samplingPeriod);
           break;
         }
       UNLOCK_SAMPLES(this) else ret=false;
       restoreType(ost);
     }
     break;
-  case FilterParameters::ChebyshevTypeI:
-    break;
   case FilterParameters::FrequencyWindow: {
       SignalType st=saveType(Spectrum);
       double fac=_samplingPeriod*static_cast<double>(_nSamples);
@@ -369,7 +367,9 @@ bool DoubleSignal::filter(const FilterParameters& param)
                                 _nyquistIndex,
                                 qRound(fac*param.minimumFrequency()*(1.0-2.0*param.width())),
                                 qRound(fac*param.minimumFrequency()));
-          window.apply(samples);
+          if(window.isValid()) {
+            window.apply(samples);
+          }
           break;
         case FilterParameters::HighPass: {
             int i=qRound(fac*param.minimumFrequency()*(1.0+1.0*param.width()));
@@ -379,7 +379,9 @@ bool DoubleSignal::filter(const FilterParameters& param)
             window.createFunction(0, i,
                                   qRound(fac*param.minimumFrequency()),
                                   qRound(fac*param.minimumFrequency()*(1.0+2.0*param.width())));
-            window.apply(samples);
+            if(window.isValid()) {
+              window.apply(samples);
+            }
           }
           break;
         case FilterParameters::BandPass:
@@ -387,7 +389,9 @@ bool DoubleSignal::filter(const FilterParameters& param)
           window.createFunction(0, _nyquistIndex,
                                 qRound(fac*param.minimumFrequency()),
                                 qRound(fac*param.maximumFrequency()));
-          window.apply(samples);
+          if(window.isValid()) {
+            window.apply(samples);
+          }
           break;
         }
       UNLOCK_SAMPLES(this) else ret=false;
@@ -709,9 +713,11 @@ bool DoubleSignal::taper(double start, double end, const WindowFunctionParameter
     TaperDelegate window(&param);
     if(end-start>samplingPeriod()) {
       window.createFunction(start, end, samplingFrequency(), _nSamples);
-      window.apply(samples);
+      if(window.isValid()) {
+        window.apply(samples);
+        ret=true;
+      }
     }
-    ret=true;
   UNLOCK_SAMPLES(this)
   restoreType(st);
   return ret;
@@ -731,8 +737,10 @@ bool DoubleSignal::taper(const WindowFunctionParameters& param)
     TaperDelegate::RealSample samples(thisSamples);
     TaperDelegate window(&param);
     window.createFunction(0, _nSamples-1, 0, _nSamples-1);
-    window.apply(samples);
-    ret=true;
+    if(window.isValid()) {
+      window.apply(samples);
+      ret=true;
+    }
   UNLOCK_SAMPLES(this)
   restoreType(st);
   return ret;
@@ -750,8 +758,10 @@ bool DoubleSignal::taper(const TaperDelegate& window)
   SignalType st=saveType(Waveform);
   LOCK_SAMPLES(double, thisSamples, this)
     TaperDelegate::RealSample samples(thisSamples);
-    window.apply(samples);
-    ret=true;
+    if(window.isValid()) {
+      window.apply(samples);
+      ret=true;
+    }
   UNLOCK_SAMPLES(this)
   restoreType(st);
   return ret;
@@ -878,7 +888,7 @@ void DoubleSignal::fastFourierTransform(SignalType st)
           FFTWCache::end(cache);
           //FastFourierTransform::instance()->backward(_nSamples, thisSamples);
           // Factor according to McNamara
-          // Stable for various sampling frequencis
+          // Stable for various sampling frequencies
           // Stable for various signal durations
 #ifdef COMPATIBILITY_2_5_0
           double rn=_samplingPeriod;
@@ -945,6 +955,19 @@ Complex DoubleSignal::discreteFourierTransform(const FourierPlan& plan) const
   return c;
 }
 
+void DoubleSignal::testDiscreteFourierTransform() const
+{
+  Complex c;
+  QTextStream s(stdout);
+  CONST_LOCK_SAMPLES(double, thisSamples, this)
+    for(int i=0; i<0.5*nSamples(); i++) {
+      double f=i/duration();
+      FourierPlan p(nSamples(), samplingPeriod(), f);
+      s << f << " " << p.dtft(thisSamples).toString() << "\n";
+    }
+  UNLOCK_SAMPLES(this)
+}
+
 /*
    Discrete fourier transform calculed with the explicit technique
    Slow but correct. Mainly used to validate other faster techniques.
@@ -1011,7 +1034,7 @@ bool DoubleSignal::discreteFourierTransform()
   else
     _evenNyquistIndex=0; // Set as an odd number of samples
 
-  Its use to get the complex spectrum:
+  It's use to get the complex spectrum:
 
   if(i==0 || i==_evenNyquistIndex) return samples[ i ];
   else return Complex(samples[ i ], samples[ _nSamples - i ] );
@@ -1059,6 +1082,45 @@ bool DoubleSignal::overSample(double factor, const DoubleSignal * sig)
   return ret;
 }
 
+/*!
+  Divide the frequency sampling period by \a factor, equivalent to zero padding in time domain.
+  \a sig is the reference signal. The results are stored in this signal. This signal must not be allocated.
+  This object can be created with any constructor.
+*/
+bool DoubleSignal::frequencyOverSample(double factor, const DoubleSignal * sig)
+{
+  TRACE;
+  if(factor<=1.0) {
+    App::log(tr("DoubleSignal::frequencyOverSample: factor cannot be less than 1, aborting.\n") );
+    return false;
+  }
+  if(isAllocated()) {
+    App::log(tr("DoubleSignal::frequencyOverSample: samples of destination signal cannot be allocated, aborting.\n") );
+    return false;
+  }
+  int nOriginal=sig->_nSamples;
+  int nResampled=qRound(nOriginal*factor);
+  setNSamples(nResampled);
+  setSamplingPeriod(sig->samplingPeriod());
+
+  bool ret=false;
+  const DoubleSignal * sigtime=sig->saveType(Waveform);
+  CONST_LOCK_SAMPLES(double, sigSamples, sigtime)
+    LOCK_SAMPLES(double, thisSamples, this)
+      for(int i=0; i<nOriginal; i++) {
+        thisSamples[i]=sigSamples[i];
+      }
+      for(int i=nOriginal; i<_nSamples; i++) {
+        thisSamples[i]=0.0;
+      }
+      setType(Waveform);
+      ret=true;
+    UNLOCK_SAMPLES(this);
+  UNLOCK_SAMPLES(sigtime)
+  sig->restoreType(sigtime);
+  return ret;
+}
+
 /*!
   Decimate \a sig along time scale. The result is set to this. An adequat anti-aliasing filter is used
   before any processing. One sample over \a factor is kept.
@@ -1109,6 +1171,32 @@ bool DoubleSignal::decimateTime(int factor, const DoubleSignal * sig)
   return ret;
 }
 
+bool DoubleSignal::random(double maxAmplitude, Random * generator)
+{
+  TRACE;
+  if(maxAmplitude<=0.0) {
+    App::log(tr("DoubleSignal::random: maxAmplitude must be positive, aborting.\n") );
+    return false;
+  }
+  Random * myGenerator;
+  if(generator) {
+    myGenerator=nullptr;
+  } else {
+    myGenerator=new Random;
+    generator=myGenerator;
+  }
+  fastFourierTransform(Waveform);
+  bool ret=false;
+  LOCK_SAMPLES(double, thisSamples, this)
+    for(int i=0; i<_nSamples; i++) {
+      thisSamples[i]=generator->uniform(-maxAmplitude, maxAmplitude);
+    }
+    ret=true;
+  UNLOCK_SAMPLES (this)
+  delete myGenerator;
+  return ret;
+}
+
 bool DoubleSignal::correlationCheck(const DoubleSignal * s1, const DoubleSignal * s2, double& maxDelay)
 {
   TRACE;
@@ -1631,6 +1719,8 @@ int DoubleSignal::add(const DoubleSignal * sig)
 /*!
   Returns the amplitude of the signal at time or frequency \a abscissa (depends upon signal type).
   The index is rounded to the lowest sample. No interpolation is perfomed.
+
+  This is a high level interface function. Any signal type is accepted.
 */
 double DoubleSignal::amplitudeAt(double abscissa) const
 {
@@ -1676,33 +1766,79 @@ double DoubleSignal::amplitudeAt(double abscissa) const
 /*!
   Returns the amplitude of the signal at time or frequency \a abscissa (depends upon signal type).
   The returned amplitude is interpolated.
+
+  Samples must be lock outside.
+  Type is assumed to be waveform.
 */
-double DoubleSignal::interpoleAt(double abscissa) const
+double DoubleSignal::at(const double * samples, double abscissa) const
 {
   TRACE;
-  double val;
-  CONST_LOCK_SAMPLES(double, thisSamples, this)
-    switch (_type) {
-    case Waveform: {
-        double di=abscissa/_samplingPeriod;
-        int i=(int) ceil(di);
-        if(i < 0 || i >= _nSamples) val=0.0;
-        else {
-          if(i==0) i=1;
-          val=thisSamples[ i ] + (thisSamples[ i ] - thisSamples[ i - 1 ] ) * (di - (double) i);
-        }
+  double di=abscissa/_samplingPeriod;
+  int i=qCeil(di);
+  if(i<0 || i>=_nSamples) {
+    return 0.0;
+  } else {
+    if(i==0) i=1;
+    return samples[i]+(samples[i-1]-samples[i])*(di-i);
+  }
+}
+
+/*!
+  Sets \a min and \a max to the minimum and the maximum values encountered between \a minTime
+  and \a maxTime. The signal type is assumed to be Waveform.
+*/
+void DoubleSignal::valueRange(const double * samples, double minTime, double maxTime,
+                              double& min, double &max) const
+{
+  double di1=minTime/_samplingPeriod;
+  int i1=qCeil(di1);
+  double di2=maxTime/_samplingPeriod;
+  int i2=qFloor(di2);
+  if(i1>=_nSamples || i2<0) {
+    min=0.0;
+    max=0.0;
+  } else {
+    if(i2>=_nSamples) {
+      i2=_nSamples-1;
+    }
+    if(i1<0) {
+      i1=0;
+    }
+    int i=i1;
+    min=samples[i];
+    max=min;
+    double val;
+    for(i++; i<=i2; i++) {
+      val=samples[i];
+      if(val<min) {
+        min=val;
+      } else if(val>max) {
+        max=val;
       }
-      break;
-    default:
-      val=0.0;
-      break;
     }
-  UNLOCK_SAMPLES(this)
-  else {
-    App::log(3, tr("DoubleSignal::interpoleAt() cannot access to data vector\n"));
-    val=0.0;
+  }
+}
+
+/*!
+  Returns the amplitude of the signal at time or frequency \a abscissa (depends upon signal type).
+  The returned amplitude is interpolated.
+
+  Samples must be lock outside.
+  Type is assumed to be Spectrum (or Phase).
+*/
+Complex DoubleSignal::complexAt(const double * samples, double abscissa) const
+{
+  TRACE;
+  double di=abscissa*_samplingPeriod*static_cast<double>(_nSamples);
+  int i=qCeil(di);
+  if(i<0 || i>=_nSamples) {
+    return Complex();
+  } else {
+    if(i==0) i=1;
+    Complex s1=complex(samples, i-1);
+    Complex s2=complex(samples, i);
+    return s1+(s2-s1)*(di-i);
   }
-  return val;
 }
 
 bool DoubleSignal::unglitch(double threshold)
@@ -2064,63 +2200,14 @@ double DoubleSignal::correlation(const DoubleSignal * sig, double sigStart, doub
   return corr/(double)iLength;
 }
 
-/*!
-  Return signal type as string.
-*/
-QString DoubleSignal::typeString(SignalType st)
-{
-  TRACE;
-  switch (st) {
-  case Spectrum: return "Spectrum";
-  case Phase: return "Phase";
-  case Waveform: return "Waveform";
-  case UndefinedSignalType: break;
-  }
-  return "Waveform";
-}
+ENUM_AS_STRING_BEGIN(DoubleSignal, SignalType)
+ENUM_AS_STRING_DATA_4(Phase, Spectrum, UndefinedSignalType, Waveform);
+ENUM_AS_STRING_SYNONYM("RealSpectrum", Waveform);
+ENUM_AS_STRING_SYNONYM("CPhaseWaveform", Waveform);
+ENUM_AS_STRING_SYNONYM("CAmpWaveform", Waveform);
+ENUM_AS_STRING_DEFAULT_VALUE(UndefinedSignalType);
+ENUM_AS_STRING_END
 
-/*!
-  Set signal type from a string
-*/
-DoubleSignal::SignalType DoubleSignal::type(QString st, bool * ok)
-{
-  TRACE;
-  if(st.isEmpty()) {
-    if(ok) {
-      *ok=false;
-    }
-    return UndefinedSignalType;
-  }
-  st=st.toLower();
-  switch(st[0].unicode()) {
-  case 'c':                         // Kept for compatibility
-    if(st=="cphasewaveform") {
-      return Waveform;
-    } else if(st=="campwaveform"){
-      return Waveform;
-    }
-    break;
-  case 'p':
-    if(st=="phase") return Phase;
-    break;
-  case 'r':                         // Kept for compatibility
-    if(st=="realspectrum") return Waveform;
-    break;
-  case 's':
-    if(st=="spectrum") return Spectrum;
-    break;
-  case 'w':
-    if(st=="waveform") return Waveform;
-    break;
-  default:
-    break;
-  }
-  if(ok) {
-    *ok=false;
-  }
-  return UndefinedSignalType;
-
-}
 
 /*!
   Returns the maximum amplitude of the signal between \a itmin and \a itmax
