@@ -40,24 +40,25 @@ namespace GeopsyCore {
     See details at https://en.wikipedia.org/wiki/Discrete-time_Fourier_transform
   */
   FourierPlan::FourierPlan(int n, double samplingPeriod, double frequency)
+    : _base(n, ::sqrt(2.0*samplingPeriod/static_cast<double>(n)), frequency*samplingPeriod)
   {
     _n=n;
     _frequency=frequency; // Useless, for debug only
-    double omega=-2.0*M_PI*frequency*samplingPeriod; // omega must be in rad/sample
-    _base=new Complex[_n];
-    double rn=::sqrt(2.0*samplingPeriod/static_cast<double>(n)); // Not the same factor as for FFT
-                                                                 // Checked that it produces the same value as FFT
-    for(int i=0; i<_n; i++) {
-      _base[i].setExp(rn, static_cast<double>(i)*omega);
-    }
   }
 
-  /*!
-    Description of destructor still missing
-  */
-  FourierPlan::~FourierPlan()
+  bool FourierPlan::test(double samplingPeriod)
   {
-    delete [] _base;
+    double omega=-2.0*M_PI*_frequency*samplingPeriod; // omega must be in rad/sample
+    double rn=::sqrt(2.0*samplingPeriod/static_cast<double>(_n)); // Not the same factor as for FFT
+                                                                  // Checked that it produces the same value as FFT
+    Complex c;
+    for(int i=0; i<_n; i++) {
+      c.setExp(rn, static_cast<double>(i)*omega);
+      if(c!=_base.value(i)) {
+        return false;
+      }
+    }
+    return true;
   }
 
 } // namespace GeopsyCore
