@@ -38,11 +38,13 @@
 #include "SparseTimeRange.h"
 #include "MetaDataMap.h"
 #include "MetaDataFactory.h"
+#include "PickParameters.h"
 
 namespace GeopsyCore {
 
 class SubSignalPool;
 class SignalDatabase;
+class SeismicEvent;
 
 class GEOPSYCORE_EXPORT Signal: public DoubleSignal, public SharedObject, public XMLClass
 {
@@ -54,9 +56,9 @@ public:
 
   Signal(SignalDatabase * db);
   Signal(const Signal& sig, SignalDatabase * db=nullptr);
-  virtual ~Signal();
+  ~Signal();
 
-  virtual const QString& xml_tagName() const {return xmlSignalTag;}
+  const QString& xml_tagName() const {return xmlSignalTag;}
   static const QString xmlSignalTag;
 
   static Signal * newCopy(Signal * sig);
@@ -116,6 +118,7 @@ public:
   void setStartTime(const DateTime& t);
   DateTime endTime() const {return _startTime.shifted(samplingPeriod()*_nSamples);}
   const SparseTimeRange& timeRange() const {return _timeRange;}
+  void gapsFromNaN();
   void setTimeRange(const SparseTimeRange& r);
   DateTime roundTime(const DateTime& t) const;
   TIME t0AsTIME() const;
@@ -170,7 +173,7 @@ public:
   DateTime maximumAmplitudeAt(const TimeRange& r=TimeRange()) const;
   double averageAmplitude(int itmin=0, int itmax=0) const;
   inline double amplitudeAt(const DateTime& t) const;
-  inline double interpoleAt(const DateTime& t) const;
+  double at(const DateTime& t) const;
 
   // Funtion to perform signal processing
   inline bool taper(const TimeRange& tw, const WindowFunctionParameters& param);
@@ -182,12 +185,13 @@ public:
   double correlation(const Signal * sig, const TimeRange& tw);
   void correlation(const Signal * s1, const Signal * s2, double maxDelay);
   void normalizedCorrelation(const Signal * s1, const Signal * s2, double maxDelay);
+  VectorList<const SeismicEvent *> pickEvents(const PickParameters& param) const;
 
   // Function to restore old databases (compatibility)
   bool read(FILE *f, SignalDatabase * db);
 
-  virtual double * lockSamples();
-  virtual const double * constLockSamples() const;
+  double * lockSamples();
+  const double * constLockSamples() const;
 #ifdef LOCK_SAMPLES_DEBUG
   double * lockSamples(char * file, int line) {return DoubleSignal::lockSamples(file, line);}
   const double * constLockSamples(char * file, int line) const {return DoubleSignal::constLockSamples(file, line);}
@@ -204,11 +208,11 @@ public:
   bool setHeader(const MetaDataIndex& index, QVariant val);
 
   // XML serialization
-  virtual void xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const;
-  virtual void xml_writeChildren(XML_WRITECHILDREN_ARGS) const;
-  virtual bool xml_setProperty(XML_SETPROPERTY_ARGS);
-  virtual bool xml_polish(XML_POLISH_ARGS);
-  virtual XMLMember xml_member(XML_MEMBER_ARGS);
+  void xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const;
+  void xml_writeChildren(XML_WRITECHILDREN_ARGS) const;
+  bool xml_setProperty(XML_SETPROPERTY_ARGS);
+  bool xml_polish(XML_POLISH_ARGS);
+  XMLMember xml_member(XML_MEMBER_ARGS);
 protected:
   mutable double _maxAmplitude;
   mutable double _averageAmplitude;
@@ -242,7 +246,8 @@ private:
   bool readError(const char * buf);
 
   // Functions to load samples from specific file formats into memory
-  bool load(double * samples) const;
+  bool loadSamples(double * samples) const;
+
   bool loadGeopsySignal(double * samples) const;
   bool loadSeg2(double * samples) const;
   bool loadSegD(double * samples) const;
@@ -264,11 +269,12 @@ private:
   bool loadAsciiOneColumn(double * samples) const;
   bool loadFourier(double * samples) const;
   bool loadEfispec3D(double * samples) const;
-  static bool loadMultiChannelsWav(Signal * sig0, double * samples0);
-  static bool loadMultiChannelsAscii(Signal * sig0, double * samples0);
-  static bool loadMultiChannelsFourier(Signal * sig0, double * samples0);
+  static bool loadMultiChannelFebusHDF5(Signal * sig0, double * samples0);
+  static bool loadMultiChannelWav(Signal * sig0, double * samples0);
+  static bool loadMultiChannelAscii(Signal * sig0, double * samples0);
+  static bool loadMultiChannelFourier(Signal * sig0, double * samples0);
   static SubSignalPool beginMultiChannelLoad(Signal * sig0, double * samples0,
-                                                 int & nSig, double **& samplePtr);
+                                             int & nSig, double **& samplePtr);
   static void endMultiChannelLoad(Signal * sig0, const SubSignalPool& loadedSigs, SignalType typeInFile=DoubleSignal::Waveform);
   static void miniSeedRecordHandler (char *record, int reclen, void *f);
   bool writeSeg2Header(QFile& f, const QString& keyword,
@@ -294,11 +300,6 @@ inline double Signal::amplitudeAt(const DateTime& t) const
   return DoubleSignal::amplitudeAt(_startTime.secondsTo(t));
 }
 
-inline double Signal::interpoleAt(const DateTime& t) const
-{
-  return DoubleSignal::interpoleAt(_startTime.secondsTo(t));
-}
-
 inline bool Signal::taper(const TimeRange& tw, const WindowFunctionParameters& param)
 {
   return DoubleSignal::taper(_startTime.secondsTo(tw.start()),
