@@ -38,6 +38,7 @@
 #include "CustomFileFormats.h"
 #include "Comments.h"
 #include "FFTW.h"
+#include "TimeRange.h"
 
 namespace GeopsyCore {
 
@@ -69,10 +70,14 @@ namespace GeopsyCore {
     _cache=new Cache;
     _cache->setSize(_preferences->cacheSize());
     _cache->setSwapDir(_preferences->cacheSwapDir());
+    APP_LOG(1, tr("Signal cache size %1 Mb\n").arg(_cache->freeMegaBytes()));
 
     if(_plugins) {
       _plugins->polish(); // post initialization of plugins
     }
+
+    // Makes TimeRange available for queued connections
+    qRegisterMetaType<GeopsyCore::TimeRange>();
   }
 
   GeopsyCoreEngine::~GeopsyCoreEngine()
@@ -185,16 +190,16 @@ namespace GeopsyCore {
       mesg << tr("File Format\n");
       mesg << tr("Possible file formats:\n");
       for(int i=0; i<formats.count(); i++) {
-        mesg << QString("%1.  ").arg(i) << formats.at(i).first << endl;
+        mesg << QString("%1.  ").arg(i) << formats.at(i).first << Qt::endl;
       }
-      mesg << tr("File format (0...%1)? [default=%2] ").arg(formats.count()-1).arg(formatIndex) << flush;
+      mesg << tr("File format (0...%1)? [default=%2] ").arg(formats.count()-1).arg(formatIndex) << Qt::flush;
       bool ok;
       int formatIndex=rep.readLine().toInt(&ok);
       if(ok) {
         if(formatIndex>=formats.count() || formatIndex<0) formatIndex=0;
         reg.setValue("fileFormat", formatIndex);
         format=formats.at(formatIndex).second;
-        mesg << tr("Ask for file format next time? [y]/n ") << flush;
+        mesg << tr("Ask for file format next time? [y]/n ") << Qt::flush;
         if(rep.readLine().toLower()=="n") {
           reg.setValue("again", false);
         }
@@ -218,7 +223,7 @@ namespace GeopsyCore {
     bool ok;
 
     int defI=reg.value("numSamp", 1024).toInt();
-    mesg << tr("Number of samples ? [default=%1] ").arg(defI) << endl;
+    mesg << tr("Number of samples ? [default=%1] ").arg(defI) << Qt::endl;
     int repI=rep.readLine().toInt(&ok);
     if(ok) {
       nSamples=repI;
@@ -226,7 +231,7 @@ namespace GeopsyCore {
     }
 
     double defD=reg.value("sampFreq", 578).toDouble();
-    mesg << tr("Sampling frequency ? [default=%1] ").arg(defD) << endl;
+    mesg << tr("Sampling frequency ? [default=%1] ").arg(defD) << Qt::endl;
     double repD=rep.readLine().toDouble(&ok);
     if(ok) {
       sampFreq=repD;
@@ -234,7 +239,7 @@ namespace GeopsyCore {
     }
 
     defD=reg.value("t0", 1024).toInt();
-    mesg << tr("T0 ? [default=%1] ").arg(defD) << endl;
+    mesg << tr("T0 ? [default=%1] ").arg(defD) << Qt::endl;
     repD=rep.readLine().toDouble(&ok);
     if(ok) {
       t0=repD;
