@@ -44,6 +44,7 @@ namespace GeopsyCore {
   {
     TRACE;
     _type=Hammer;
+    _duration=0.001;
     _force=Point(0.0, 0.0, -1.0);
     _lock=0;
   }
@@ -54,6 +55,8 @@ namespace GeopsyCore {
     _position=o._position;
     _utmZone=o._utmZone;
     _time=o._time;
+    _duration=o._duration;
+    _name=o._name;
     _type=o._type;
     _force=o._force;
     _lock=0;
@@ -70,6 +73,8 @@ namespace GeopsyCore {
     _position=o._position;
     _utmZone=o._utmZone;
     _time=o._time;
+    _duration=o._duration;
+    _name=o._name;
     _type=o._type;
     _force=o._force;
   }
@@ -79,6 +84,8 @@ namespace GeopsyCore {
     return _position==o._position &&
            _utmZone==o._utmZone &&
            _time==o._time &&
+           _duration==o._duration &&
+           _name==o._name &&
            _type==o._type &&
            _force==o._force;
   }
@@ -91,10 +98,14 @@ namespace GeopsyCore {
 
   QString SeismicEvent::name(int posPrec, int timePrec) const
   {
-    static const QString format(tr("(%1) @ %2"));
-    return format
-        .arg(_position.toString(posPrec, 'f'))
-        .arg(_time.toString("hh:mm:ssz", timePrec));
+    if(_name.isEmpty()) {
+      static const QString format(tr("(%1) @ %2"));
+      return format
+          .arg(_position.toString('f', posPrec))
+          .arg(_time.toString("hh:mm:ssz", timePrec));
+    } else {
+      return _name;
+    }
   }
 
   QStringList SeismicEvent::userTypes()
@@ -146,94 +157,47 @@ namespace GeopsyCore {
     return Hammer;
   }
 
-  QString SeismicEvent::type(Type t)
-  {
-    TRACE;
-    switch(t) {
-    case Hammer:
-      break;
-    case Explosion:
-      return "Explosion";
-    case WeightDrop:
-      return "WeightDrop";
-    case Steps:
-      return "Steps";
-    case Earthquake:
-      return "Earthquake";
-    }
-    return "Hammer";
-  }
-
-  SeismicEvent::Type SeismicEvent::type(QString t, bool * ok)
-  {
-    TRACE;
-    if(t.count()>2) {
-      t=t.toLower();
-      switch(t.at(2).unicode()) {
-      case 'm':
-        if(t=="hammer") {
-          return Hammer;
-        }
-        break;
-      case 'p':
-        if(t=="explosion") {
-          return Explosion;
-        }
-        break;
-      case 'i':
-        if(t=="weightdrop") {
-          return WeightDrop;
-        }
-        break;
-      case 'e':
-        if(t=="steps") {
-          return Steps;
-        }
-        break;
-      case 'r':
-        if(t=="earthquake") {
-          return Earthquake;
-        }
-        break;
-      default:
-        break;
-      }
-    }
-    if(ok) {
-      *ok=false;
-    }
-    return Hammer;
-  }
+  ENUM_AS_STRING_BEGIN(SeismicEvent, Type)
+  ENUM_AS_STRING_DATA_5(Earthquake, Explosion, Hammer, Steps, WeightDrop);
+  ENUM_AS_STRING_END
 
   void SeismicEvent::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
   {
     TRACE;
     Q_UNUSED(context)
-    writeProperty(s, "Position", _position.toString(15));
+    writeProperty(s, "Position", _position.toString('g', 15));
     writeProperty(s, "UtmZone", _utmZone.toString());
     writeProperty(s, "Time", _time.toString(DateTime::defaultFormat, 15));
-    writeProperty(s, "Type", type(_type));
-    writeProperty(s, "Force", _force.toString(15));
+    writeProperty(s, "Duration", _duration);
+    writeProperty(s, "Name", _name);
+    writeProperty(s, "Type", convertType(_type));
+    writeProperty(s, "Force", _force.toString('g', 15));
   }
 
   XMLMember SeismicEvent::xml_member(XML_MEMBER_ARGS)
   {
     Q_UNUSED(attributes)
     Q_UNUSED(context)
-    if(tag.size()>2) {
-      switch (tag[2].unicode()) {
-      case 's':
+    if(tag.size()>0) {
+      switch (tag[0].unicode()) {
+      case 'F':
+        if(tag=="Force") return XMLMember(3);
+        break;
+      case 'N':
+        if(tag=="Name") return XMLMember(5);
+        break;
+      case 'P':
         if(tag=="Position") return XMLMember(0);
         break;
-      case 'm':
+      case 'T':
         if(tag=="Time") return XMLMember(1);
-        else if(tag=="UtmZone") return XMLMember(4);
+        else if(tag=="Type") return XMLMember(2);
         break;
-      case 'p':
-        if(tag=="Type") return XMLMember(2);
+      case 'D':
+        if(tag=="Duration") return XMLMember(6);
         break;
-      case 'r':
-        if(tag=="Force") return XMLMember(3);
+      case 'U':
+        if(tag=="UtmZone") return XMLMember(4);
         break;
       default:
         break;
@@ -247,14 +211,14 @@ namespace GeopsyCore {
     Q_UNUSED(context)
     Q_UNUSED(tag)
     Q_UNUSED(attributes)
+    bool ok=true;
     switch(memberID) {
     case 0:
-      return _position.fromString(content.toString());
+      return _position.fromString(content.toStringView());
     case 1:
-      return _time.fromString(content.toString(), DateTime::defaultFormat);
+      return _time.fromString(content.toStringBuffer(), DateTime::defaultFormat);
     case 2: {
-        bool ok=true;
-        Type t=type(content.toString(), &ok);
+        Type t=convertType(content.toStringView(), ok);
         if(ok) {
           _type=t;
           return true;
@@ -263,10 +227,16 @@ namespace GeopsyCore {
         }
       }
     case 3:
-      return _force.fromString(content.toString());
+      return _force.fromString(content.toStringView());
     case 4:
-      _utmZone.fromString(content.toString());
+      _utmZone.fromString(content.toStringBuffer());
       return true;
+    case 5:
+      _name=content.toStringBuffer();
+      return true;
+    case 6:
+      _duration=content.toDouble(ok);
+      return ok;
     default:
       return false;
     }
