@@ -42,7 +42,8 @@ namespace GeopsyCore {
 
   const QString SignalDatabase::xmlSignalDatabaseTag="SignalDatabase";
 
-  SignalDatabase::SignalDatabase() : _files(this)
+  SignalDatabase::SignalDatabase()
+      : XMLContext(false), _files(this)
   {
     TRACE;
     _version=SIGNAL_DATABASE_CURRENT_VERSION;
@@ -145,8 +146,8 @@ namespace GeopsyCore {
           for(QStringList::iterator it=groupList.begin();it!=groupList.end();++it) {
             QString gName=*it;
             int i=1;
-            while(findGroup( gName) ) {
-              gName=*it + "_" + i;
+            while(findGroup(gName)) {
+              gName=gName+"_"+QString::number(i);
               i++;
             }
             SignalGroup* g=new SignalGroup(_masterGroup);
@@ -255,12 +256,13 @@ namespace GeopsyCore {
         GeopsyCoreEngine::instance()->preferences()->load();
       }
 
-      while( !feof(f) ) {
+      while(!feof(f)) {
         _files.load(d.absoluteFilePath(buf) );
         File::readLine(buf, bufLen, f, true);
       }
-      if(strlen( buf) > 0)
-        _files.load(d.absoluteFilePath(buf) );
+      if(strlen( buf)>0) {
+        _files.load(d.absoluteFilePath(buf));
+      }
       ret=true;
       break;
     case 2:
@@ -275,11 +277,10 @@ namespace GeopsyCore {
         ret=false;
         break;
       }
-#if __clang__
-      [[clang::fallthrough]];
-#endif
+      ret=openDBFileV2(f);
+      break;
    default:
-      ret=openDBFileV2 (f); // Kept also for transitional version 3 (devel only)
+      ret=openDBFileV2(f); // Kept also for transitional version 3 (devel only)
       break;
     }
     delete [] buf;
@@ -483,7 +484,9 @@ namespace GeopsyCore {
   {
     TRACE;
     int i=QList<Signal *>::indexOf(sig);
-    QList<Signal *>::removeAt(i);
+    if(i>=0) {
+      QList<Signal *>::removeAt(i);
+    }
   }
 
   QString SignalDatabase::askSaveAs()
@@ -575,6 +578,8 @@ namespace GeopsyCore {
         return false;
       } else { // New database opened successfully, merge it with current one
         add(newDB);
+        // Avoid nullptr for signals after database destructor
+        newDB->removeAll();
         delete newDB;
         // Set name as empty to force saveAs()
         _name=QString();
@@ -943,14 +948,15 @@ namespace GeopsyCore {
         static QString indexAtt="index";
         XMLRestoreAttributeIterator it=attributes.find(indexAtt);
         if(it!=attributes.end()) { // It is a link to shared data
-          MetaData * d=resolveMetaData(it.value().toInt());
-          if(d) {
+        bool ok=true;
+          MetaData * d=resolveMetaData(it.value().toInt(ok));
+          if(ok && d) {
             if(tag==d->xml_tagName()) {
               _permanentSharedMetaData.add(d);
               return XMLMember(101);
             } else {
               App::log(tr("Mismatch resolving shared meta data index %1: expecting type %2, found %3.\n")
-                  .arg(it.value().toInt()).arg(tag.toString()).arg(d->xml_tagName()));
+                  .arg(it.value().toInt(ok)).arg(tag.toStringView()).arg(d->xml_tagName()));
             }
           }
         }
@@ -965,19 +971,20 @@ namespace GeopsyCore {
     Q_UNUSED(tag)
     Q_UNUSED(attributes)
     Q_UNUSED(context)
+    bool ok=true;
     switch(memberID) {
     case 0:
-      _version=content.toInt();
+      _version=content.toInt(ok);
       if(_version>SIGNAL_DATABASE_CURRENT_VERSION) {
         App::log(tr("Database saved with a more recent release, upgrade yours.\n") );
         return false;
       }
-      return true;
+      return ok;
     case 1: {
         GeopsyCoreEngine * eng=GeopsyCoreEngine::instance();
-        eng->setProgressMaximum(this, content.toInt()-1);
+        eng->setProgressMaximum(this, content.toInt(ok)-1);
       }
-      return true;
+      return ok;
     default:
       return false;
     }
