@@ -79,10 +79,10 @@ public:
 
   const AbstractSignalGroup * findGroup(QString name) const {return _masterGroup->find(name);}
   const AbstractSignalGroup * findGroup(int id) const {return _masterGroup->find(id);}
-  QList<const AbstractSignalGroup *> findGroups(const QRegExp& name) const {return const_cast<const MasterSignalGroup *>(_masterGroup)->find(name);}
+  QList<const AbstractSignalGroup *> findGroups(const QRegularExpression& name) const {return const_cast<const MasterSignalGroup *>(_masterGroup)->find(name);}
   AbstractSignalGroup * findGroup(QString name) {return _masterGroup->find(name);}
   AbstractSignalGroup * findGroup(int id) {return _masterGroup->find(id);}
-  QList<AbstractSignalGroup *> findGroups(const QRegExp& name) {return _masterGroup->find(name);}
+  QList<AbstractSignalGroup *> findGroups(const QRegularExpression& name) {return _masterGroup->find(name);}
 
   SeismicEventTable * seismicEvents() {return _seismicEvents;}
   const SeismicEventTable * seismicEvents() const {return _seismicEvents;}
