@@ -84,19 +84,22 @@ namespace GeopsyCore {
   {
     TRACE;
     // Save history to signal comments
-    if(_steps.isEmpty()) {
-      for(SubSignalPool::iterator it=_current->begin(); it!=_current->end(); it++) {
-        Signal * sig=*it;
+    if(!_steps.isEmpty()) {
+      for(int i=_current->count()-1; i>=0; i--) {
+        Signal * sig=_current->at(i);
         Comments& c=sig->beginModifyMetaData<Comments>();
-        if(sig->file()) {
-          c+="'"+sig->file()->name()+"' at index "+QString::number(sig->numberInFile())+"\n";
+        if(c.value().isEmpty()) { // may be lost by a process like 'cut'
+          if(_steps.last().count()==_current->count()) { // Trace back of signal is possible
+            if(_steps.count()==1) {
+              Signal * originalSig=_steps.last().at(i);
+              if(originalSig->file()) {
+                c="'"+originalSig->file()->name()+"' at index "+QString::number(originalSig->numberInFile())+"\n";
+              }
+            } else {
+              c=_steps.last().at(i)->metaData<Comments>();
+            }
+          }
         }
-        sig->endModifyMetaData(c);
-      }
-    } else {
-      for(SubSignalPool::iterator it=_current->begin(); it!=_current->end(); it++) {
-        Signal * sig=*it;
-        Comments& c=sig->beginModifyMetaData<Comments>();
         c+="  "+tag+"\n";
         sig->endModifyMetaData(c);
       }
@@ -139,7 +142,7 @@ namespace GeopsyCore {
     TRACE;
     fastFourierTransformCore(st);
     addToHistory(QString("fastFourierTransform(\"%1\");\n")
-                .arg(DoubleSignal::typeString(st) ));
+                .arg(DoubleSignal::convertSignalType(st)));
   }
 
   bool SignalProcess::exportFile(const QString& filePath, bool useOriginalBaseName,
@@ -148,11 +151,20 @@ namespace GeopsyCore {
   {
     TRACE;
     bool ret=exportFileCore(filePath, useOriginalBaseName, format, maximumSignalsPerFile, pickName);
-    addToHistory(QString("export(\"%1\", %2, \"%3\", %4);\n")
-                .arg(filePath)
-                .arg(useOriginalBaseName ? "true" : "false")
-                .arg(format.name())
-                .arg(pickName));
+    addToHistory(QString("exportFile(\"%1\", %2, \"%3\", %4);\n")
+                     .arg(filePath)
+                     .arg(useOriginalBaseName ? "true" : "false")
+                     .arg(format.name())
+                     .arg(pickName));
+    return ret;
+  }
+
+  bool SignalProcess::saveDatabase(const QString& filePath)
+  {
+    TRACE;
+    bool ret=saveDatabaseCore(filePath);
+    addToHistory(QString("saveDatabase(\"%1\");\n")
+                     .arg(filePath));
     return ret;
   }
 
@@ -187,6 +199,28 @@ namespace GeopsyCore {
     addToHistory(fun+";\n");
   }
 
+  void SignalProcess::addSignal(int index)
+  {
+    TRACE;
+    newStep();
+    addSignalCore(index);
+    static const QString funStruct("addSignal(%1)");
+    QString fun=funStruct.arg(index);
+    saveStep(fun);
+    addToHistory(fun+";\n");
+  }
+
+  void SignalProcess::addSignals(const QString& groupName)
+  {
+    TRACE;
+    newStep();
+    addSignalsCore(groupName);
+    static const QString funStruct("addSignals(\"%1\")");
+    QString fun=funStruct.arg(groupName);
+    saveStep(fun);
+    addToHistory(fun+";\n");
+  }
+
   void SignalProcess::subtractSignal(int index)
   {
     TRACE;
@@ -229,8 +263,8 @@ namespace GeopsyCore {
     newStep();
     filterCore(param);
     static const QString funStruct("filter(\"%1\", \"%2\", %3, %4, %5)");
-    QString fun=funStruct.arg(param.methodString())
-                         .arg(param.bandString())
+    QString fun=funStruct.arg(FilterParameters::convertMethod(param.method()))
+                         .arg(FilterParameters::convertBand(param.band()))
                          .arg(param.minimumFrequency())
                          .arg(param.maximumFrequency());
     switch(param.method()) {
@@ -380,6 +414,17 @@ namespace GeopsyCore {
     addToHistory(fun+";\n");
   }
 
+  void SignalProcess::random(double maxAmplitude)
+  {
+    TRACE;
+    newStep();
+    randomCore(maxAmplitude);
+    static const QString funStruct("random(%1)");
+    QString fun=funStruct.arg(maxAmplitude);
+    saveStep(fun);
+    addToHistory(fun+";\n");
+  }
+
   void SignalProcess::waveletTransform(const MorletParameters& param)
   {
     TRACE;
@@ -493,6 +538,11 @@ namespace GeopsyCore {
     return _current->save(filePath, useOriginalBaseName, format, maximumSignalsPerFile, pickName);
   }
 
+  bool SignalProcess::saveDatabaseCore(const QString& filePath)
+  {
+    return _current->database()->saveAs(filePath);
+  }
+
   QVariant SignalProcess::header(int signalIndex, const MetaDataIndex& dataIndex)
   {
     if(signalIndex<_current->count()) {
@@ -561,8 +611,16 @@ namespace GeopsyCore {
       g->setSignals(sigs);
       g->setName(name);
       SignalDatabase * db=_current->database();
-      AbstractSignalGroup * gp=db->findGroup(path);
-      g->setParent(gp);
+      if(path.isEmpty()) {
+        g->setParent(db->masterGroup());
+      } else {
+        AbstractSignalGroup * gp=db->findGroup(path);
+        if(gp) {
+          g->setParent(gp);
+        } else {
+          App::log(tr("Group path '%1' not found\n").arg(path));
+        }
+      }
     }
   }
 
@@ -576,9 +634,28 @@ namespace GeopsyCore {
     _current->subtractValue(val);
   }
 
+  void SignalProcess::addSignalCore(int index)
+  {
+    _current->signalOperationAdd(_current->at(index));
+  }
+
+  void SignalProcess::addSignalsCore(const QString& groupName)
+  {
+    // _current is never an empty SubSignalPool, hence db is always non null
+    SignalDatabase * db=_current->database();
+    const AbstractSignalGroup * g=db->findGroup(groupName);
+    if(!g) {
+      App::log(tr("Unknown group %1\n").arg(groupName) );
+      return;
+    }
+    SubSignalPool bySubPool;
+    bySubPool.addGroup(g);
+    _current->signalOperationAdd(&bySubPool);
+  }
+
   void SignalProcess::subtractSignalCore(int index)
   {
-    _current->subtractSignal(_current->at(index));
+    _current->signalOperationSubtract(_current->at(index));
   }
 
   void SignalProcess::subtractSignalsCore(const QString& groupName)
@@ -592,7 +669,7 @@ namespace GeopsyCore {
     }
     SubSignalPool bySubPool;
     bySubPool.addGroup(g);
-    _current->subtractSignals(&bySubPool);
+    _current->signalOperationSubtract(&bySubPool);
   }
 
   void SignalProcess::multiplyCore(double val)
@@ -660,6 +737,11 @@ namespace GeopsyCore {
     _current->decimateTime(factor);
   }
 
+  void SignalProcess::randomCore(double maxAmplitude)
+  {
+    _current->random(maxAmplitude);
+  }
+
   void SignalProcess::waveletTransformCore(const MorletParameters& param)
   {
     _current->waveletTransform(param);
