@@ -54,11 +54,13 @@ namespace GeopsyCore {
     int indexOfStep(const QString& tag) const;
     void saveStep(const QString& tag);
     void restoreStep(int index);
+    const SubSignalPool * step(int index) const {return &_steps.at(index);}
 
     void fastFourierTransform(DoubleSignal::SignalType st);
     bool exportFile(const QString& filePath, bool useOriginalBaseName=false,
                     const SignalFileFormat& format=SignalFileFormat::Unknown,
                     int maximumSignalsPerFile=0, const QString& pickName=QString());
+    bool saveDatabase(const QString& filePath);
     QVariant header(int signalIndex, const MetaDataIndex& dataIndex);
     void setHeader(int signalIndex, const MetaDataIndex& dataIndex, const QVariant& value);
     int signalCount();
@@ -67,6 +69,8 @@ namespace GeopsyCore {
 
     void removeTrend();
     void subtractValue(double val);
+    void addSignal(int index);
+    void addSignals(const QString& groupName);
     void subtractSignal(int index);
     void subtractSignals(const QString& groupName);
     void multiply(double val);
@@ -82,6 +86,7 @@ namespace GeopsyCore {
     bool mergeStations();
     void decimateAmplitude(int maxCount, double maxRef);
     void decimateTime(int factor);
+    void random(double maxAmplitude);
     void waveletTransform(const MorletParameters& param);
     void stalta(double tsta, double tlta);
     void discreteFourierTransform();
@@ -98,10 +103,13 @@ namespace GeopsyCore {
     bool exportFileCore(const QString& filePath, bool useOriginalBaseName,
                         const SignalFileFormat& format, int maximumSignalsPerFile,
                         const QString& pickName);
+    bool saveDatabaseCore(const QString& filePath);
     void setHeaderCore(int signalIndex, const MetaDataIndex& dataIndex, const QVariant& value);
 
     void removeTrendCore();
     void subtractValueCore(double val);
+    void addSignalCore(int index);
+    void addSignalsCore(const QString& groupName);
     void subtractSignalCore(int index);
     void subtractSignalsCore(const QString& groupName);
     void multiplyCore(double val);
@@ -117,6 +125,7 @@ namespace GeopsyCore {
     bool mergeStationsCore();
     void decimateAmplitudeCore(int maxCount, double maxRef);
     void decimateTimeCore(int factor);
+    void randomCore(double maxAmplitude);
     void waveletTransformCore(const MorletParameters& param);
     void staltaCore(double tsta, double tlta);
     void discreteFourierTransformCore();
@@ -128,7 +137,7 @@ namespace GeopsyCore {
 
     SubSignalPool * _current;
     SubSignalPool * _selected;
-    QVector<SubSignalPool> _steps;
+    VectorList<SubSignalPool> _steps;
     QString _history;
   };
 
