@@ -49,7 +49,7 @@ SparseKeepSignal::SparseKeepSignal(const SparseTimeRange& r)
     : SparseTimeRange(r)
 {
   TRACE;
-  const ::QVector<TimeRange>& rs=ranges();
+  const ::VectorList<TimeRange>& rs=ranges();
   int n=rs.count();
   _keeps.resize(n);
   for(int i=0; i<n; i++) {
@@ -103,7 +103,7 @@ bool SparseKeepSignal::setSampling(const TimeRange& sigRange, double samplingPer
   if(_keeps.isEmpty()) return true;
   int i=index(sigRange.start());
   double samplingFrequency=1.0/samplingPeriod;
-  const ::QVector<TimeRange>& keepRanges=ranges();
+  const ::VectorList<TimeRange>& keepRanges=ranges();
   for(;i<keepRanges.count();i++) {
     KeepSignal * k=_keeps[i];
     const TimeRange& keepRange=keepRanges.at(i);
@@ -120,9 +120,8 @@ bool SparseKeepSignal::setSampling(const TimeRange& sigRange, double samplingPer
         return false;
       }
     } else {
-      //printf("Arbitrary limits %lf to %lf\n",r.start(), r.end());
       DateTime startTime=sigRange.start();
-      startTime.addSeconds(-floor((keepRange.start().secondsTo(sigRange.start())*samplingFrequency)*samplingPeriod));
+      startTime.addSeconds(-floor(keepRange.start().secondsTo(sigRange.start())*samplingFrequency)*samplingPeriod);
       // +1 is there because the time end cuts the last time step which beginning
       // is still inside time range
       KeepSignal * k=new KeepSignal(qFloor(startTime.secondsTo(keepRange.end())*samplingFrequency)+1);
@@ -153,7 +152,7 @@ SparseKeepSignal * SparseKeepSignal::intersection(const TimeRange& r) const
     }
     const KeepSignal * kEnd=_keeps.at(iFirst+n-1);
     if(r.end()<kEnd->endTime()) {
-      res->_keeps[n-1]=cutEnd(kEnd, r.end());;
+      res->_keeps[n-1]=cutEnd(kEnd, r.end());
     } else {
       res->_keeps[n-1]=new KeepSignal(*kEnd);
     }
@@ -206,10 +205,30 @@ KeepSignal * SparseKeepSignal::cutEnd(const KeepSignal * keep, const DateTime& t
   return newKeep;
 }
 
+/*!
+  Remove null signal segments (not matching user and signal range).
+  Removing them here avoid systematic testing afterwards.
+*/
+void SparseKeepSignal::removeNullSignals()
+{
+  int n=_keeps.count();
+  ASSERT(n==ranges().count());
+  for(int i=0; i<n; i++) {
+    if(!_keeps.at(i)) {  // Null sections can exist if they do not match with
+                         // signal blocks.
+      SparseTimeRange::remove(i);
+      _keeps.remove(i);
+      i--;
+      n--;
+    }
+  }
+}
+
 void SparseKeepSignal::initValues(int value, const DateTime& start, const DateTime& end)
 {
   TRACE;
   int n=_keeps.count();
+  // Now that it is clean, let's go
   for(int i=0;i<n;i++) {
     KeepSignal * keep=_keeps[i];
     double invSamplingPeriod=1.0/keep->samplingPeriod();
@@ -233,13 +252,13 @@ void SparseKeepSignal::initValues(int value, const DateTime& start, const DateTi
 /*!
   Returns all keeps hit by \a r
 */
-QVector<KeepSignal *> SparseKeepSignal::keeps(const TimeRange& r) const
+VectorList<KeepSignal *> SparseKeepSignal::keeps(const TimeRange& r) const
 {
   TRACE;
-  ::QVector<KeepSignal *> res;
+  ::VectorList<KeepSignal *> res;
   if(isNull()) return res;
   int i=index(r.start());
-  const ::QVector<TimeRange>& rs=ranges();
+  const ::VectorList<TimeRange>& rs=ranges();
   int n=rs.count();
   for(;i<n && rs.at(i).end()<r.end();i++) {
     res.append(_keeps.at(i));
