@@ -33,12 +33,11 @@
 
 namespace GeopsyCore {
 
-class GEOPSYCORE_EXPORT SparseTimeRange : private QVector<TimeRange>
+class GEOPSYCORE_EXPORT SparseTimeRange : private VectorList<TimeRange>
 {
   TRANSLATIONS("SparseTimeRange")
 public:
   SparseTimeRange();
-  SparseTimeRange(const SparseTimeRange& r);
   SparseTimeRange(const TimeRange& r);
   ~SparseTimeRange();
 
@@ -62,10 +61,10 @@ public:
   inline bool intersects(const SparseTimeRange& r) const;
   inline bool intersects(const TimeRange& r) const;
   bool contains(const DateTime& t) const;
-  QVector<TimeRange> split(double minLength, double maxLength) const;
+  VectorList<TimeRange> split(double minLength, double maxLength) const;
 
-  bool isNull() const {return QVector<TimeRange>::isEmpty();}
-  const QVector<TimeRange>& ranges() const {return *this;}
+  bool isNull() const {return VectorList<TimeRange>::isEmpty();}
+  const VectorList<TimeRange>& ranges() const {return *this;}
   inline TimeRange range() const;
   double totalLength() const;
 
@@ -79,11 +78,11 @@ public:
 protected:
   int index(const DateTime& t) const;
   SparseTimeRange intersection(int index, const TimeRange& r) const;
+  void remove(int index);
   int remove(int& index, const TimeRange& r);
 private:
   void append(const TimeRange& r);
   void insert(int before, const TimeRange& r);
-  void remove(int index);
 
   int _n2;
   static const double _epsilon;
