@@ -160,7 +160,7 @@ bool StationSignals::addSignal(Signal * sig)
                 .arg(sig->id())
                 .arg(Signal::userName(sig->component()) )
                 .arg(name())
-                .arg(coordinates().toString(2, 'f')));
+                .arg(coordinates().toString('f', 2)));
   return true;
 }
 
@@ -368,8 +368,8 @@ void StationSignals::setKeep(SparseKeepSignal * keep, const WindowingParameters&
     const SubSignalPool& subPool=originals(iComp);
     for(SubSignalPool::const_iterator itSig=subPool.begin();itSig!=subPool.end(); ++itSig) {
       const Signal * sig=*itSig;
-      QVector<KeepSignal *> keeps=keep->keeps(sig->timeRange().range());
-      for(QVector<KeepSignal *>::iterator itKeep=keeps.begin(); itKeep!=keeps.end(); itKeep++) {
+      VectorList<KeepSignal *> keeps=keep->keeps(sig->timeRange().range());
+      for(VectorList<KeepSignal *>::iterator itKeep=keeps.begin(); itKeep!=keeps.end(); itKeep++) {
         KeepSignal * keepSig=*itKeep;
         double delay=keepSig->startTime().secondsTo(sig->startTime());
         if(param.rawSignalAntiTrigger().enabled &&
