@@ -38,8 +38,8 @@ namespace GeopsyCore {
 SyscomSVmrxHeader::SyscomSVmrxHeader()
 {
   TRACE;
-  ASSERT(sizeof( SyscomSVmrxHeader)==256);
-  memset(this, 0, 256);
+  ASSERT(sizeof(SyscomSVmrxHeader)==256);
+  memset(raw, 0, 256);
 }
 
 } // namespace GeopsyCore
