@@ -39,7 +39,7 @@ SyscomXmrHeader::SyscomXmrHeader()
 {
   TRACE;
   ASSERT(sizeof( SyscomXmrHeader)==256);
-  memset(this, 0, 256);
+  memset(raw, 0, 256);
 }
 
 } // namespace GeopsyCore
