@@ -59,7 +59,7 @@ public:
   virtual void beginSignalChange(Signal * ) {}
   virtual void endSignalChange(Signal * ) {}
   virtual void updateAllFields() {}
-  virtual void start() {}
+  virtual void start(int /*threadCount*/) {}
 
   void setLibSlot(GeopsyGuiInterface * lib, int slot) {_lib=lib; _libSlot=slot;}
   bool isLibSlot(GeopsyGuiInterface * lib, int slot) {return _lib==lib && _libSlot==slot;}
@@ -78,8 +78,8 @@ protected:
   void closeEvent(QCloseEvent * e);
   // Kept during transition to new core tool structure
   virtual bool initStations(SubSignalPool * subPool) {Q_UNUSED(subPool) return true;}
-  virtual AbstractParameters * parameters(AbstractParameters * param=0) const {return param;}
-  virtual void setParameters(const AbstractParameters * param) {Q_UNUSED(param)}
+  virtual void parametersToGui() {}
+  virtual void parametersFromGui() {}
 
   virtual void contextMenuEvent(QContextMenuEvent *e);
 
