@@ -155,12 +155,17 @@ bool CityLoader::mountUnmount(const char * cmd)
       }
       switch (p.error()) {
       case QProcess::Timedout:
-        if(Message::warning(MSG_ID, tr( "Unmounting/Mounting flash card" ), tr( "No responding after %1 seconds, do want to wait again?" ).arg(timeOut), Message::yes(), Message::no())==Message::Answer0) {
-          timeOut *= 2;
-        } else
+        if(Message::warning(MSG_ID, tr("Unmounting/Mounting flash card"),
+                            tr("Not responding after %1 seconds, do you want to wait again?").arg(timeOut),
+                            Message::yes(), Message::no())==Message::Answer0) {
+          timeOut*=2;
+        } else {
           return false;
+        }
+        break;
       default:
-        Message::critical(MSG_ID, tr( "Unmounting/Mounting flash card" ), QString(p.readAllStandardOutput ()) );
+        Message::critical(MSG_ID, tr("Unmounting/Mounting flash card"),
+                          QString(p.readAllStandardOutput()));
         return false;
       }
     }
