@@ -32,6 +32,7 @@
 #include "SignalLayer.h"
 #include "SignalsProperties.h"
 #include "GeopsyGuiEngine.h"
+#include "SubPoolWindow.h"
 
 namespace GeopsyGui {
 
@@ -50,18 +51,29 @@ const QString SignalLayer::indexTag="index";
 REGISTER_GRAPHCONTENTLAYER(SignalLayer, "SignalLayer")
 
 SignalLayer::SignalLayer (AxisWindow * parent) :
-    GridPlot(parent)
+    LiveGridLayer(parent)
 {
   TRACE;
   // Required for viewing the layer in figue (through geopsyfigs plugin)
   if(!GeopsyGuiEngine::instance()) {
     CoreApplication::addGlobalObject(new GeopsyGuiEngine);
   }
+  _subPoolWin=nullptr;
   _subPool=nullptr;
   _subPoolOwner=false;
   // Trace display options
   _wiggleTrace=true;
   _variableArea=true;
+  _coloredGrid=false;
+
+  // Do not use adjust color palette from LiveGridLayer
+  setAutoAdjust(false);
+  setSmooth(false);
+  ColorMap& map=beginColorMapChange();
+  map.generate(0, 48, ColorPalette::defaultDiverging, ColorPalette::Continuous);
+  map.setValues(-1.0, 1.0, SamplingParameters::Linear);
+  endColorMapChange();
+
   _offset=NoOffset;
   _normalize=NormalizeAll;
   _normalizeValue=1.0;
@@ -70,8 +82,6 @@ SignalLayer::SignalLayer (AxisWindow * parent) :
   _clipValue=1.0;
   _overlap=1.0;
   _gapHeight=0.375;
-  // Grid plotting options
-  _gridPlot=nullptr;
   // Y axis type options
   _yAxis=ViewerIndex;
   _timeScale=AbsoluteTime;
@@ -79,14 +89,11 @@ SignalLayer::SignalLayer (AxisWindow * parent) :
   _timeRange=AvailableRange;
   _beforePickDelay=0.02;
   _afterPickDelay=0.02;
-  // Palette options
-  setLinearColorMap(-_overlap*0.5, _overlap*0.5);
 }
 
 SignalLayer::~SignalLayer ()
 {
   TRACE;
-  delete _gridPlot;
   if(_subPoolOwner) {
     delete _subPool;
   }
@@ -113,7 +120,14 @@ int SignalLayer::baseLineCount() const
   }
 }
 
-void SignalLayer::subPoolUpdate (SubSignalPool * subPool)
+void SignalLayer::setSubPoolWindow(SubPoolWindow * subPoolWin)
+{
+  TRACE;
+  _subPoolWin=subPoolWin;
+  subPoolUpdate(&_subPoolWin->subPool());
+}
+
+void SignalLayer::subPoolUpdate(SubSignalPool * subPool)
 {
   TRACE;
   LayerLocker ll(this);
@@ -151,17 +165,12 @@ void SignalLayer::subPoolUpdate (SubSignalPool * subPool)
       break;
     }
   }
-  if(_gridPlot) updateGrid();
 }
 
 void SignalLayer::signalsUpdate ()
 {
   TRACE;
-  if(_gridPlot) {
-    LayerLocker ll(this);
-    updateGrid();
-  }
-  graphContent()->deepUpdate();
+  graphContents()->deepUpdate();
 }
 
 /*!
@@ -396,7 +405,7 @@ const DateTime& SignalLayer::timeReference(const Signal * sig) const
   \a x0 is the time or the frequency of the first sample
   \a dx is the frequency step or the time step between samples
 */
-bool SignalLayer::visibleSamples(const GraphContentOptions& gc, const Signal * sig,
+bool SignalLayer::visibleSamples(const GraphContentsOptions& gc, const Signal * sig,
                                  int& itmin, int& itmax, double& x0, double& dx) const
 {
   TRACE;
@@ -460,12 +469,12 @@ bool SignalLayer::visibleSamples(const GraphContentOptions& gc, const Signal * s
 }
 
 /*!
-  \fn void visibleSamples(const GraphContentOptions& gc, const Signal * sig, int& itmin, int& itmax) const
+  \fn void visibleSamples(const GraphContentsOptions& gc, const Signal * sig, int& itmin, int& itmax) const
 
   Overloaded function to simplify computation of \a itmin and \b itmax only
 */
 
-void SignalLayer::drawSignal(const GraphContentOptions& gc, QPainter& p, const Signal * sig, int iSig,
+void SignalLayer::drawSignal(const GraphContentsOptions& gc, QPainter& p, const Signal * sig, int iSig,
                              int itmin, int itmax, double x0, double dx,
                              bool allSamplesVisible, double affMax, int pixelWidth,
                              bool variableArea, bool wiggleTrace) const
@@ -475,7 +484,7 @@ void SignalLayer::drawSignal(const GraphContentOptions& gc, QPainter& p, const S
   // Introduction : preparing display options
   // ----------------------------------------
   double valClip;
-  if((_normalize & NormalizeAll) && sig->type()==Signal::Spectrum) {
+  if((_normalize==NormalizeAll) && sig->type()==Signal::Spectrum) {
     affMax*=2;
   }
   drawingAmplitude(sig, itmin, itmax, valClip, affMax);
@@ -494,8 +503,8 @@ void SignalLayer::drawSignal(const GraphContentOptions& gc, QPainter& p, const S
   } else {
     switch(_offset) {
     case NoOffset: y0=_signalY[ iSig ]; break;
-    case GlobalOffset: y0=_signalY[iSig]-sig->averageAmplitude()*affMax;; break;
-    case VisibleOffset: y0=_signalY[iSig]-sig->averageAmplitude(itmin, itmax)*affMax;; break;
+    case GlobalOffset: y0=_signalY[iSig]-sig->averageAmplitude()*affMax; break;
+    case VisibleOffset: y0=_signalY[iSig]-sig->averageAmplitude(itmin, itmax)*affMax; break;
     }
   }
   // For phase ploting max spectrum is required, not for other modes.
@@ -521,30 +530,30 @@ void SignalLayer::drawSignal(const GraphContentOptions& gc, QPainter& p, const S
       int iy1, iy2, iy1n, iy2n;
       switch (sig->type()) {
       case Signal::Waveform:
-        maxVal=samples[ i ];
-        if(maxVal > valClip) maxVal=valClip;
-        else if(maxVal < -valClip) maxVal=-valClip;
-        iy1=gc.yr2s(y0 + maxVal * affMax);
+        maxVal=samples[i];
+        if(maxVal>valClip) maxVal=valClip;
+        else if(maxVal<-valClip) maxVal=-valClip;
+        iy1=gc.yr2s(y0+maxVal*affMax);
         iy2=iy1;
-        for( ;ix < pixelWidth && i < itmax;ix++ ) {
+        for( ;ix<pixelWidth && i<itmax; ix++) {
           x_step=gc.xs2r(ix);
-          minVal=samples[ i ];
+          minVal=samples[i];
           maxVal=minVal;
-          while(x < x_step && i < itmax) {
-            val=samples[ i ];
-            if(val < minVal) minVal=val;
-            else if(val > maxVal) maxVal=val;
+          while(x<x_step && i<itmax) {
+            val=samples[i];
+            if(val<minVal) minVal=val;
+            else if(val>maxVal) maxVal=val;
             i++;
-            x += dx;
+            x+=dx;
           }
-          if(maxVal > valClip) maxVal=valClip;
-          else if(maxVal < -valClip) maxVal=-valClip;
-          if(minVal > valClip) minVal=valClip;
-          else if(minVal < -valClip) minVal=-valClip;
-          if(variableArea && minVal > 0.0) minVal=0;
-          iy1n=gc.yr2s(y0 + maxVal * affMax);
-          iy2n=gc.yr2s(y0 + minVal * affMax);
-          if(iy2<iy1n || iy1>iy2n) {
+          if(maxVal>valClip) maxVal=valClip;
+          else if(maxVal<-valClip) maxVal=-valClip;
+          if(minVal>valClip) minVal=valClip;
+          else if(minVal<-valClip) minVal=-valClip;
+          if(variableArea && minVal>0.0) minVal=0.0;
+          iy1n=gc.yr2s(y0+maxVal*affMax);
+          iy2n=gc.yr2s(y0+minVal*affMax);
+          if(iy2<iy1n || iy1>iy2n) { // Large amplitude variation
             p.drawLine(ix-1, iy2, ix, iy1n);
           }
           iy1=iy1n;
@@ -576,7 +585,7 @@ void SignalLayer::drawSignal(const GraphContentOptions& gc, QPainter& p, const S
             maxVal=valClip;
             if(minVal > valClip) minVal=valClip;
           }
-          if(variableArea && minVal > 0.0) minVal=0;
+          if(variableArea && minVal > 0.0) minVal=0.0;
           iy1n=gc.yr2s(y0 + maxVal * affMax);
           iy2n=gc.yr2s(y0 + minVal * affMax);
           if(iy2<iy1n || iy1>iy2n) {
@@ -825,53 +834,50 @@ void SignalLayer::drawSignal(const GraphContentOptions& gc, QPainter& p, const S
   UNLOCK_SAMPLES(sig);
 }
 
-void SignalLayer::paintData(const LayerPainterRequest& lp, QPainter& p, double) const
+void SignalLayer::paintData(const LayerPainterRequest& lp, QPainter& p, double dotpercm) const
 {
   TRACE;
   if(!_subPool) return ;
-  const GraphContentOptions& gc=lp.options();
-  int w=lp.size().width();
-  // Useful only for NormalizeAll and NormalizeVisibleAll
-  double affMax=0.5/maxAmplitude(gc);
-  int isigmin, isigmax;
-  SAFE_UNINITIALIZED(isigmin, 0);
-  SAFE_UNINITIALIZED(isigmax, 0);
-  visibleIndexRange(gc, isigmin, isigmax);
-  if(_gridPlot) {
-    if(smooth())
-      drawGrid2DYSmooth( *_gridPlot, colorMap(), lp, p);
-    else
-      drawGrid2DBlock( *_gridPlot, colorMap(), lp, p);
-    return ;
-  }
-  lp.graphContent()->setProgressMaximum (isigmax-isigmin-1);
-  int itmin, itmax;
-  double x0, dx;
-  CacheProcess cp;
-  for(int iSig=isigmin; iSig<isigmax; ++iSig) {
-    const Signal * sig=_subPool->at(iSig);
-    visibleSamples(gc, sig, itmin, itmax, x0, dx);
-    cp.add(_subPool->at(iSig));
-  }
-  // Really draw signals
-  for(int iSig=isigmin; iSig<isigmax; ++iSig) {
-    if(lp.terminated()) {
-      return;
+  if(_coloredGrid && _subPool->count()>1) {
+    LiveGridLayer::paintData(lp, p, dotpercm);
+  } else if(_variableArea || _wiggleTrace) {
+    const GraphContentsOptions& gc=lp.options();
+    int w=lp.size().width();
+    // Useful only for NormalizeAll and NormalizeVisibleAll
+    double affMax=0.5/maxAmplitude(gc);
+    int isigmin, isigmax;
+    SAFE_UNINITIALIZED(isigmin, 0);
+    SAFE_UNINITIALIZED(isigmax, 0);
+    visibleIndexRange(gc, isigmin, isigmax);
+    lp.graphContents()->setProgressMaximum (isigmax-isigmin-1);
+    int itmin, itmax;
+    double x0, dx;
+    CacheProcess cp;
+    for(int iSig=isigmin; iSig<isigmax; ++iSig) {
+      const Signal * sig=_subPool->at(iSig);
+      visibleSamples(gc, sig, itmin, itmax, x0, dx);
+      cp.add(_subPool->at(iSig));
+    }
+    // Really draw signals
+    for(int iSig=isigmin; iSig<isigmax; ++iSig) {
+      if(lp.terminated()) {
+        return;
+      }
+      const Signal * sig=_subPool->at(iSig);
+      lp.graphContents()->setProgressValue(iSig-isigmin);
+      bool allSamplesVisible=visibleSamples(gc, sig, itmin, itmax, x0, dx);
+      const QColor& c=signalColor(sig);
+      p.setPen(c);
+      p.setBrush(c);
+      drawSignal(gc, p, sig, iSig, itmin, itmax, x0, dx, allSamplesVisible, affMax, w, _variableArea, _wiggleTrace);
+      // Paint gaps if any
+      drawGaps(gc, p, sig, iSig);
+      cp.next();
     }
-    const Signal * sig=_subPool->at(iSig);
-    lp.graphContent()->setProgressValue(iSig-isigmin);
-    bool allSamplesVisible=visibleSamples(gc, sig, itmin, itmax, x0, dx);
-    const QColor& c=signalColor(sig);
-    p.setPen(c);
-    p.setBrush(c);
-    drawSignal(gc, p, sig, iSig, itmin, itmax, x0, dx, allSamplesVisible, affMax, w, _variableArea, _wiggleTrace);
-    // Paint gaps if any
-    drawGaps(gc, p, sig, iSig);
-    cp.next();
   }
 }
 
-void SignalLayer::timeWindowY(const GraphContentOptions& gc, int iSig, double rh, int& top, int& height) const
+void SignalLayer::timeWindowY(const GraphContentsOptions& gc, int iSig, double rh, int& top, int& height) const
 {
   if(_subPool->count()==1) {
     rh*=gc.yVisMax();
@@ -892,7 +898,7 @@ void SignalLayer::timeWindowY(const GraphContentOptions& gc, int iSig, double rh
   height=gc.yr2s(_signalY[iSig]+rh)-top;
 }
 
-void SignalLayer::drawGaps(const GraphContentOptions& gc, QPainter& p, const Signal * sig, int iSig) const
+void SignalLayer::drawGaps(const GraphContentsOptions& gc, QPainter& p, const Signal * sig, int iSig) const
 {
   const SparseTimeRange& signalRange=sig->timeRange();
   const DateTime& tref=timeReference(sig);
@@ -900,7 +906,7 @@ void SignalLayer::drawGaps(const GraphContentOptions& gc, QPainter& p, const Sig
   ::TimeRange sigLimits(sig->startTime(), sig->endTime());
   SparseTimeRange gaps=signalRange.invert(true); // Infinite ends to plot gaps at the start/end of signal
   gaps=gaps.intersection(gcLimits).intersection(sigLimits);
-  const QVector< ::TimeRange >& g=gaps.ranges();
+  const VectorList< ::TimeRange >& g=gaps.ranges();
   int n=g.count();
   if(n==0) return;
   p.save();
@@ -916,8 +922,8 @@ void SignalLayer::drawGaps(const GraphContentOptions& gc, QPainter& p, const Sig
     wwidth[ i ]=gc.xr2s(tref.secondsTo(tr.end())) - wleft[ i ];
     p.drawRect(wleft[ i ], wtop, wwidth[ i ], wheight);
   }
-  p.setPen(QPen( QColor(255, 75, 78), 1, Qt::SolidLine) );
-  p.setBrush(QBrush( Qt::NoBrush) );
+  p.setPen(QPen(QColor(255, 75, 78), 1, Qt::SolidLine));
+  p.setBrush(QBrush(Qt::NoBrush));
   for(int i=0; i<n; i++) {
     p.drawRect(wleft[ i ], wtop, wwidth[ i ], wheight);
   }
@@ -966,150 +972,23 @@ Rect SignalLayer::boundingRect() const
   return r;
 }
 
-void SignalLayer::setGrid(bool b)
-{
-  TRACE;
-  if(b) {
-    if(!_gridPlot) {
-      _gridPlot=new Grid2D<double>(10, 10);
-    }
-  } else {
-    delete _gridPlot;
-    _gridPlot=nullptr;
-  }
-}
-
-void SignalLayer::updateGrid()
-{
-  TRACE;
-  if(!_subPool || _subPool->isEmpty()) return;
-  // delete previously created grid
-  delete _gridPlot;
-  // Get time limits and sampling step
-  double t0, deltaT;
-  int n=-1, nSamples2;
-  DoubleSignal::SignalType sType;
-  SAFE_UNINITIALIZED(sType,DoubleSignal::UndefinedSignalType);
-  SAFE_UNINITIALIZED(deltaT,0);
-  SAFE_UNINITIALIZED(t0,0);
-  SAFE_UNINITIALIZED(nSamples2,0);
-  // Useful only for NormalizeAll and NormalizeVisibleAll
-  double affMax0=0.5/maxAmplitude(graphContent()->options());
-  SubSignalPool::iterator it;
-  // Check if uniform t0 and dt
-  for(it=_subPool->begin(); it!=_subPool->end(); ++it) {
-    Signal * sig=*it;
-    double it0, ideltaT;
-    int in=sig->nSamples();
-    DoubleSignal::SignalType isType=sig->type();
-    switch (sig->type()) {
-    case Signal::Waveform:
-      ideltaT=sig->samplingPeriod();
-      it0=timeReference(sig).secondsTo(sig->startTime());
-      break;
-    case Signal::Spectrum: {
-        double fNyquist=0.5/sig->samplingPeriod();
-        ideltaT=2.0*fNyquist/static_cast<double>(in);
-        it0=0;
-      }
-      break;
-    default:
-      Message::warning(MSG_ID, "Building signal grid",
-                           "Only Waveform and spectra can be used to build a colored grid",
-                           Message::cancel());
-      _gridPlot=nullptr;
-      return;
-    }
-    if(n==-1) {
-      sType=isType;
-      t0=it0;
-      n=in;
-      deltaT=ideltaT;
-      nSamples2=in/2;
-    } else if(it0!=t0 || in!=n || ideltaT!=deltaT) {
-      Message::warning(MSG_ID, "Building signal grid",
-                           "To build a colored grid all the signals must have the same deltaT and T0",
-                           Message::cancel());
-      _gridPlot=nullptr;
-      return ;
-    }
-  }
-  // Re-allocate a new grid
-  switch (sType) {
-  case Signal::Waveform:
-    _gridPlot=new Grid2D<double>(n, _subPool->count());
-    break;
-  case Signal::Spectrum:
-    _gridPlot=new Grid2D<double>(nSamples2 + 1, _subPool->count());
-    break;
-  default:
-    break;
-  }
-  _gridPlot->setOrigin(Point2D( t0, 1) );
-  _gridPlot->setDeltaX(deltaT);
-  // fill in the grid with signals
-  double * cells=_gridPlot->valuePointer(0, 0);
-  double valClip, affMax;
-  int imin, imax;
-  for(it=_subPool->begin(); it!=_subPool->end(); ++it) {
-    const Signal * sig=*it;
-    CONST_LOCK_SAMPLES(double, samples, sig)
-      visibleSamples(graphContent()->options(), sig, imin, imax);
-      switch (sig->type()) {
-      case Signal::Waveform: {
-          if(_normalize & NormalizeAll) affMax=affMax0;
-          drawingAmplitude(sig, imin, imax, valClip, affMax);
-          for(int i=0; i < n; i++, cells++ ) {
-            double val=samples[ i ];
-            if(val > valClip) val=valClip;
-            *cells=val * affMax;
-          }
-        }
-        break;
-      case Signal::Spectrum: {
-          if(_normalize & NormalizeAll) affMax=2 * affMax0;
-          drawingAmplitude(sig, imin, imax, valClip, affMax);
-          for(int i=0; i <= nSamples2; i++, cells++ ) {
-            double val=sig->amplitude(samples, i);
-            if(val > valClip) val=valClip;
-            *cells=val * affMax;
-          }
-        }
-        break;
-      case Signal::Phase: {
-          if(_normalize & NormalizeAll) affMax=affMax0;
-          drawingAmplitude(sig, imin, imax, valClip, affMax);
-          for(int i=0; i <= nSamples2; i++, cells++ ) {
-            double val=sig->phase(samples, i);
-            if(val > valClip) val=valClip;
-            *cells=val * affMax;
-          }
-        }
-        break;
-      case Signal::UndefinedSignalType:
-        break;
-      }
-    }
-  UNLOCK_SAMPLES(sig)
-}
-
 /*!
-  Return the index of signal at position Y \a yPos. Return -1 is subPool is empty.
-  \a baseDistance is set to the ditance between \a yPos and the base line of returned signal.
+  Return the index of signal at position Y \a yScreen. Return -1 is subPool is empty.
+  \a baseDistance is set to the ditance between \a yScreen and the base line of the returned signal.
 */
-int SignalLayer::signalAt (int yPos, double& baseDistance) const
+int SignalLayer::signalAt(int yScreen, double& baseDistance) const
 {
   TRACE;
   int n=_subPool->count();
-  if(n < 1) return -1;
-  double yd=graphContent()->options().ys2r(yPos);
+  if(n<1) return -1;
+  double yd=graphContents()->options().ys2r(yScreen);
   // Find which signal has the closest base line to yd
   int iSig=0;
-  double d=fabs(_signalY[ 0 ] - yd);
+  double d=fabs(_signalY[0]-yd);
   baseDistance=d;
-  for(int i=1;i < n;i++ ) {
-    d=fabs(_signalY[ i ] - yd);
-    if(d < baseDistance) {
+  for(int i=1; i<n; i++) {
+    d=fabs(_signalY[i]-yd);
+    if(d<baseDistance) {
       baseDistance=d;
       iSig=i;
     }
@@ -1121,7 +1000,7 @@ int SignalLayer::signalAt (int yPos, double& baseDistance) const
   Finds the maximum amplitude across all traces of current subpool.
   Returns 0 if normalize() is not NormalizeAll or NormalizeVisibleAll
 */
-double SignalLayer::maxAmplitude(const GraphContentOptions& gc) const
+double SignalLayer::maxAmplitude(const GraphContentsOptions& gc) const
 {
   TRACE;
   double vmax=0.0;
@@ -1161,233 +1040,117 @@ double SignalLayer::maxAmplitude(const GraphContentOptions& gc) const
 void SignalLayer::sigYBoundaries (int index, double overlap, QRect& bound) const
 {
   TRACE;
-  double h=0.5 * overlap;
-  bound.setTop(graphContent()->options().yr2s(_signalY[ index ] + h) );
-  bound.setBottom(graphContent()->options().yr2s(_signalY[ index ] - h) );
+  double h=0.5*overlap;
+  bound.setTop(graphContents()->options().yr2s(_signalY[index]+h));
+  bound.setBottom(graphContents()->options().yr2s(_signalY[index]-h));
 }
 
+ENUM_AS_STRING_BEGIN(SignalLayer, Normalize)
+ENUM_AS_STRING_DATA_5(NormalizeAll, NormalizeOne,
+                      NormalizeValue, NormalizeVisibleAll, NormalizeVisibleOne);
+ENUM_AS_STRING_END
+
+ENUM_AS_STRING_BEGIN(SignalLayer, Offset)
+ENUM_AS_STRING_DATA_3(GlobalOffset, NoOffset, VisibleOffset);
+ENUM_AS_STRING_END
+
+ENUM_AS_STRING_BEGIN(SignalLayer, Clip)
+ENUM_AS_STRING_DATA_4(ClipOverlap, ClipPercentage, ClipValue,NoClip);
+ENUM_AS_STRING_END
+
+ENUM_AS_STRING_BEGIN(SignalLayer, YAxis)
+ENUM_AS_STRING_DATA_4(Overlay, Receiver, SignalName, ViewerIndex);
+ENUM_AS_STRING_END
+
+ENUM_AS_STRING_BEGIN(SignalLayer, TimeRange)
+ENUM_AS_STRING_DATA_3(AroundPickRange, AvailableRange, CustomRange);
+ENUM_AS_STRING_END
+
+ENUM_AS_STRING_BEGIN(SignalLayer, TimeScale)
+ENUM_AS_STRING_DATA_2(AbsoluteTime, RelativeToStartTime);
+ENUM_AS_STRING_END
+
 QString SignalLayer::offsetString() const
 {
-  TRACE;
-  switch (offset()) {
-  case GlobalOffset:
-    return "GlobalOffset";
-  case VisibleOffset:
-    return "VisibleOffset";
-  default:
-    return "NoOffset";
-  };
+  return convertOffset(offset());
 }
 
-void SignalLayer::setOffset (QString o)
+void SignalLayer::setOffset(const QString& v)
 {
-  TRACE;
-  if(o.count()<5) return;
-  switch(o[0].unicode()) {
-  case 'N':
-    setOffset(NoOffset);
-    break;
-  case 'G':
-    setOffset(GlobalOffset);
-    break;
-  case 'V':
-    setOffset(VisibleOffset);
-    break;
-  default:
-    break;
+  bool ok=true;
+  Offset o=convertOffset(v, ok);
+  if(ok) {
+    setOffset(o);
   }
 }
 
 QString SignalLayer::normalizeString() const
 {
-  TRACE;
-  switch (normalize()) {
-  case NormalizeOne:
-    return "NormalizeOne";
-  case NormalizeVisibleAll:
-    return "NormalizeVisisibleAll";
-  case NormalizeVisibleOne:
-    return "NormalizeVisisibleOne";
-  case NormalizeValue:
-    return "NormalizeValue";
-  default:
-    return "NormalizeAll";
-  };
+  return convertNormalize(normalize());
 }
 
-void SignalLayer::setNormalize(QString n)
+void SignalLayer::setNormalize(const QString& v)
 {
-  TRACE;
-  if(n.count()>=11) {
-    switch (n[10].unicode()) {
-    case 'n':
-      if(n=="NormalizeOne" ) setNormalize(NormalizeOne);
-      break;
-    case 'l':
-      if(n=="NormalizeAll" ) setNormalize(NormalizeAll);
-      // Compatibility
-      else if(n=="NormAutoAll" ) setNormalize(NormalizeAll);
-      break;
-    case 'i':
-      if(n=="NormalizeVisibleAll" ) setNormalize(NormalizeVisibleAll);
-      else if(n=="NormalizeVisibleOne" ) setNormalize(NormalizeVisibleOne);
-      break;
-    case 'a':
-      if(n=="NormalizeValue" ) setNormalize(NormalizeValue);
-      break;
-    case 'e': // Compatibility
-      if(n=="NormAutoOne" ) setNormalize(NormalizeOne);
-      break;
-    case 'o': // Compatibility
-      if(n=="NormVisAutoAll" ) setNormalize(NormalizeVisibleOne);
-      else if(n=="NormVisAutoOne" ) setNormalize(NormalizeVisibleAll);
-      break;
-    default:
-      break;
-    }
-  // Compatibility
-  } else if(n=="NormValue" ) setNormalize(NormalizeValue);
+  bool ok=true;
+  Normalize n=convertNormalize(v, ok);
+  if(ok) {
+    setNormalize(n);
+  }
 }
 
 QString SignalLayer::clipString() const
 {
-  TRACE;
-  switch (clip()) {
-  case ClipOverlap:
-    return "ClipOverlap";
-  case ClipPercentage:
-    return "ClipPercentage";
-  case ClipValue:
-    return "ClipValue";
-  default:
-    return "NoClip";
-  };
+  return convertClip(clip());
 }
 
-void SignalLayer::setClip (QString c)
+void SignalLayer::setClip(const QString& v)
 {
-  TRACE;
-  if(c.count()<5) return;
-  switch(c[4].unicode()) {
-  case 'i':
-    setClip(NoClip);
-    break;
-  case 'O':
-    setClip(ClipOverlap);
-    break;
-  case 'V':
-    setClip(ClipValue);
-    break;
-  case 'P':
-    setClip(ClipPercentage);
-    break;
-  default:
-    break;
+  bool ok=true;
+  Clip c=convertClip(v, ok);
+  if(ok) {
+    setClip(c);
   }
 }
 
 QString SignalLayer::yAxisString() const
 {
-  TRACE;
-  switch (yAxis()) {
-  case ViewerIndex:
-    break;
-  case Receiver:
-    return "ReceiverCoordinate";
-  case SignalName:
-    return "SignalName";
-  case Overlay:
-    return "Overlay";
-  };
-  return "ViewerIndex";
+  return convertYAxis(yAxis());
 }
 
-void SignalLayer::setYAxis(QString a)
+void SignalLayer::setYAxis(const QString& v)
 {
-  TRACE;
-  if(a.isEmpty()) return;
-  switch(a[0].unicode()) {
-  case 'O':
-    setYAxis(Overlay);
-    break;
-  case 'R':
-    setYAxis(Receiver);
-    break;
-  case 'S':
-    setYAxis(SignalName);
-    break;
-  case 'V':
-    setYAxis(ViewerIndex);
-    break;
-  default:
-    break;
+  bool ok=true;
+  YAxis c=convertYAxis(v, ok);
+  if(ok) {
+    setYAxis(c);
   }
 }
 
 QString SignalLayer::timeRangeString() const
 {
-  TRACE;
-  switch (_timeRange) {
-  case CustomRange:
-    break;
-  case AroundPickRange:
-    return "AroundPickRange";
-  case AvailableRange:
-    return "AvailableRange";
-  };
-  return "CustomRange";
+  return convertTimeRange(_timeRange);
 }
 
-void SignalLayer::setTimeRange(QString tr)
+void SignalLayer::setTimeRange(const QString& v)
 {
-  TRACE;
-  if(tr.count()<2) return;
-  switch(tr[1].unicode()) {
-  case 'v':
-    setTimeRange(AvailableRange);
-    break;
-  case 'r':
-    setTimeRange(AroundPickRange);
-    break;
-  case 'u':
-    setTimeRange(CustomRange);
-    break;
-  default:
-    break;
+  bool ok=true;
+  TimeRange t=convertTimeRange(v, ok);
+  if(ok) {
+    setTimeRange(t);
   }
 }
 
 QString SignalLayer::timeScaleString() const
 {
-  TRACE;
-  switch (_timeScale) {
-  case AbsoluteTime:
-    break;
-  case RelativeToStartTime:
-    return "RelativeToStartTime";
-  };
-  return "AbsoluteTime";
+  return convertTimeScale(_timeScale);
 }
 
-void SignalLayer::setTimeScale(TimeScale s)
+void SignalLayer::setTimeScale(const QString& v)
 {
-  TRACE;
-  _timeScale=s;
-}
-
-void SignalLayer::setTimeScale(QString ts)
-{
-  TRACE;
-  if(ts.isEmpty()) return;
-  switch(ts[0].unicode()) {
-  case 'A':
-    setTimeScale(AbsoluteTime);
-    break;
-  case 'R':
-    setTimeScale(RelativeToStartTime);
-    break;
-  default:
-    break;
+  bool ok=true;
+  TimeScale t=convertTimeScale(v, ok);
+  if(ok) {
+    setTimeScale(t);
   }
 }
 
@@ -1450,15 +1213,16 @@ XMLMember SignalLayer::xml_member(XML_MEMBER_ARGS)
 bool SignalLayer::xml_setProperty(XML_SETPROPERTY_ARGS)
 {
   TRACE;
+  bool ok=true;
   switch(memberID) {
   case 0: {
       XMLRestoreAttributeIterator it=attributes.find(indexTag);
       if(it!=attributes.end()) {
-        int index=it.value().toInt();
-        if(index >= 0 && _subPool && index < _subPool->count()) {
-          setSignalColor(_subPool->at(index), QColor(content.toString()) );
+        int index=it.value().toInt(ok);
+        if(ok && index>=0 && _subPool && index<_subPool->count()) {
+          setSignalColor(_subPool->at(index), QColor(content.toStringView()));
         } else {
-          App::log(tr("Index '%1' out of range for 'signalColor' property.\n").arg(index) );
+          App::log(tr("Index '%1' out of range for 'signalColor' property.\n").arg(it.value().toStringView()));
         }
       } else {
         App::log(tr("No 'index' for 'signalColor' property.\n") );
@@ -1468,15 +1232,18 @@ bool SignalLayer::xml_setProperty(XML_SETPROPERTY_ARGS)
   case 1: {
       XMLRestoreAttributeIterator it=attributes.find(indexTag);
       if(it!=attributes.end()) {
-        int index=it.value().toInt();
-        if(index >= 0 && _subPool && index < _subPool->count()) {
+        int index=it.value().toInt(ok);
+        if(index>=0 && _subPool && index<_subPool->count()) {
           Signal * sig=_subPool->at(index);
-          _signalOverlaps.insert(sig, content.toDouble());
+          _signalOverlaps.insert(sig, content.toDouble(ok));
+          if(!ok) {
+          App::log(tr("Bad signal overlap value:'%1'.\n").arg(content.toStringView()));
+          }
         } else {
-          App::log(tr("Index '%1' out of range for 'signalOverlap' property.\n").arg(index) );
+          App::log(tr("Index '%1' out of range for 'signalOverlap' property.\n").arg(it.value().toStringView()));
         }
       } else {
-        App::log(tr("No 'index' for 'signalOverlap' property.\n") );
+        App::log(tr("No 'index' for 'signalOverlap' property.\n"));
       }
     }
     return true;
@@ -1514,7 +1281,7 @@ bool SignalLayer::xml_polish(XML_POLISH_ARGS)
   return true;
 }
 
-void SignalLayer::highlightSignal(const GraphContentOptions& gc, QPainter& p, int w, int iSig, int isigmin, int isigmax) const
+void SignalLayer::highlightSignal(const GraphContentsOptions& gc, QPainter& p, int w, int iSig, int isigmin, int isigmax) const
 {
   TRACE;
   if(iSig<isigmin) return ;
@@ -1537,7 +1304,11 @@ bool SignalLayer::wheelEvent (QWheelEvent * e)
   TRACE;
   if(e->modifiers() & Qt::ShiftModifier) {
     e->accept();
-    spinOverlap(e->delta()/120, e->modifiers() & Qt::ControlModifier, e->y());
+#if(QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+    spinOverlap(e->angleDelta().y()/120, e->modifiers() & Qt::ControlModifier, qRound(e->position().y()));
+#else
+    spinOverlap(e->angleDelta().y()/120, e->modifiers() & Qt::ControlModifier, e->y());
+#endif
     return false; // do not process this event for other layers
   }
   return true; // Continue scanning other layers with this event
@@ -1657,7 +1428,7 @@ void SignalLayer::setSignalLegend(const Legend& l)
   }
 }
 
-uint SignalLayer::_tab=PropertyProxy::uniqueId();
+uint SignalLayer::_tab=PropertyTab::uniqueId();
 
 /*!
   Setup property editor
@@ -1690,7 +1461,7 @@ void SignalLayer::properties(PropertyWidget * w) const
 {
   TRACE;
   if(w->id()==_tab) {
-    w->setValue(SignalsProperties::ColoredSection, static_cast<bool>(_gridPlot));
+    w->setValue(SignalsProperties::ColoredSection, _coloredGrid);
     if(_subPool && !_subPool->isEmpty())
       w->setValue(SignalsProperties::IsSpectrum, _subPool->first()->isSpectrum());
     w->setValue(SignalsProperties::Wiggle, _wiggleTrace);
@@ -1723,12 +1494,7 @@ void SignalLayer::setProperty(uint wid, int pid, QVariant val)
   if(wid==_tab) {
     switch(pid) {
     case SignalsProperties::ColoredSection:
-      if(val.toBool()) {
-        if( !_gridPlot) updateGrid();
-      } else {
-        delete _gridPlot;
-        _gridPlot=nullptr;
-      }
+      _coloredGrid=val.toBool();
       break;
     case SignalsProperties::Wiggle:
       _wiggleTrace=val.toBool();
@@ -1787,7 +1553,7 @@ void SignalLayer::setProperty(uint wid, int pid, QVariant val)
     GridPlot::setProperty(wid, pid, val);
   }
   emit propertiesChanged();
-  graphContent()->deepUpdate();
+  graphContents()->deepUpdate();
 }
 
 void SignalLayer::toggleTrackingAction(bool checked, int id)
@@ -1882,4 +1648,86 @@ bool SignalLayer::trackRectangle(int id, double rx1, double ry1, double rx2, dou
   return false;
 }
 
+IrregularGrid2D * SignalLayer::calculateGrid(const GridIterator& it,
+                                             const GraphContentsOptions& gc,
+                                             const LayerPainterRequest * lp) const
+{
+  TRACE;
+  IrregularGrid2D * grid=it.create(gc);
+
+  double y, d;
+  int ixGrid;
+  int iy=it._iStart;
+  int iyGrid=it._iyGrid;
+
+  double valClip, affMax;
+  double affMax0=0.5/maxAmplitude(graphContents()->options());
+  int imin, imax;
+  double val, minVal, maxVal;
+
+  for(; iyGrid!=it._iyEndGrid; iy+=it._di, iyGrid+=it._diyGrid) {
+    if(lp) {
+      if(lp->terminated()) {
+        grid->init(0.0);
+        return grid;
+      }
+      lp->graphContents()->setProgressValue(iy);
+    }
+    ixGrid=it._ixGrid;
+    y=grid->y(iyGrid);
+    int iSig=signalAt(gc.yr2s(y), d); // Far from optimum, could be optimized with a cache
+                                      // to translate y into signal index.
+    Signal * sig=_subPool->at(iSig);
+    double t0=timeReference(sig).secondsTo(sig->startTime());
+    visibleSamples(graphContents()->options(), sig, imin, imax);
+    CONST_LOCK_SAMPLES(double, samples, sig)
+      // If there are few signal, the same values can be transformed several times
+      // It does not matter, this is only for plotting a lot of signals.
+      switch(sig->type()) {
+      case Signal::Waveform:
+        if(_normalize==NormalizeAll) affMax=affMax0;
+        drawingAmplitude(sig, imin, imax, valClip, affMax);
+        for(ixGrid+=it._dixGrid; ixGrid!=it._ixEndGrid; ixGrid+=it._dixGrid) {
+          sig->valueRange(samples, grid->x(ixGrid-it._dixGrid)-t0, grid->x(ixGrid)-t0,
+                          minVal, maxVal);
+          if(minVal<0.0) {
+            if(maxVal>0.0) {
+              minVal=fabs(minVal);
+              val=minVal<maxVal ? maxVal : minVal;
+            } else {
+              val=minVal;
+            }
+          } else {
+            val=maxVal;
+          }
+          if(val>valClip) val=valClip;
+          grid->setValue(ixGrid, iyGrid, val*affMax);
+        }
+        break;
+      case Signal::Spectrum:
+        if(_normalize==NormalizeAll) affMax=2.0*affMax0;
+        drawingAmplitude(sig, imin, imax, valClip, affMax);
+        for(; ixGrid!=it._ixEndGrid; ixGrid+=it._dixGrid) {
+          val=sig->DoubleSignal::complexAt(samples, grid->x(ixGrid)-t0).abs();
+          if(val>valClip) val=valClip;
+          grid->setValue(ixGrid, iyGrid, val*affMax);
+        }
+        break;
+      case Signal::Phase:
+        if(_normalize==NormalizeAll) affMax=affMax0;
+        drawingAmplitude(sig, imin, imax, valClip, affMax);
+        for(; ixGrid!=it._ixEndGrid; ixGrid+=it._dixGrid) {
+          val=sig->DoubleSignal::complexAt(samples, grid->x(ixGrid)-t0).phase();
+          if(val>valClip) val=valClip;
+          grid->setValue(ixGrid, iyGrid, val*affMax);
+        }
+        break;
+      case Signal::UndefinedSignalType:
+        break;
+      }
+    UNLOCK_SAMPLES(sig)
+  }
+  return grid;
+}
+
 } // namespace GeopsyGui
