@@ -216,7 +216,7 @@ void SignalsProperties::on_setSignalColors_clicked()
   ASSERT(_signalColorEditor==nullptr);
   ASSERT(_currentLayer);
   _signalColorEditor=new LegendProperties;
-  _signalColorEditor->setPropertySections(LegendTable::Text | LegendTable::Pen);
+  _signalColorEditor->setPropertySections(LegendTable::TextSection | LegendTable::PenSection);
   d->setMainWidget(_signalColorEditor, Dialog::TitleClose);
   _signalColorEditor->setLegend(_currentLayer->signalLegend());
   _signalColorEditor->setReadOnlyText(true);
