@@ -43,25 +43,25 @@ WindowingParameterWidget::WindowingParameterWidget(QWidget *parent, Qt::WindowFl
   _nComponents=0;
 
   // signals and slots connections
-  connect(badSampleThreshold, SIGNAL(valueChanged( const QString& )), this, SIGNAL(parametersChanged()) );
-  connect(badSampleTol, SIGNAL(valueChanged( const QString& )), this, SIGNAL(parametersChanged()) );
-  connect(badSampleGap, SIGNAL(valueChanged( const QString& )), this, SIGNAL(parametersChanged()) );
-  connect(overlapValue, SIGNAL(valueChanged( const QString& )), this, SIGNAL(parametersChanged()) );
+  connect(badSampleThreshold, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
+  connect(badSampleTol, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
+  connect(badSampleGap, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
+  connect(overlapValue, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
 
-  connect(filtApplyList, SIGNAL(itemChanged( QListWidgetItem * )), this, SIGNAL(parametersChanged()) );
-  connect(filtStaLength, SIGNAL(valueChanged( const QString& )), this, SIGNAL(parametersChanged()) );
-  connect(filtLtaLength, SIGNAL(valueChanged( const QString& )), this, SIGNAL(parametersChanged()) );
-  connect(filtMinStaLta, SIGNAL(valueChanged( const QString& )), this, SIGNAL(parametersChanged()) );
-  connect(filtMaxStaLta, SIGNAL(valueChanged( const QString& )), this, SIGNAL(parametersChanged()) );
+  connect(filtApplyList, SIGNAL(itemChanged(QListWidgetItem *)), this, SIGNAL(parametersChanged()));
+  connect(filtStaLength, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
+  connect(filtLtaLength, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
+  connect(filtMinStaLta, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
+  connect(filtMaxStaLta, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
 
-  connect(rawApplyList, SIGNAL(itemChanged( QListWidgetItem * )), this, SIGNAL(parametersChanged()) );
-  connect(staLength, SIGNAL(valueChanged( const QString& )), this, SIGNAL(parametersChanged()) );
-  connect(ltaLength, SIGNAL(valueChanged( const QString& )), this, SIGNAL(parametersChanged()) );
-  connect(minStaLta, SIGNAL(valueChanged( const QString& )), this, SIGNAL(parametersChanged()) );
-  connect(maxStaLta, SIGNAL(valueChanged( const QString& )), this, SIGNAL(parametersChanged()) );
+  connect(rawApplyList, SIGNAL(itemChanged(QListWidgetItem *)), this, SIGNAL(parametersChanged()));
+  connect(staLength, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
+  connect(ltaLength, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
+  connect(minStaLta, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
+  connect(maxStaLta, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
 
-  connect(windowLength, SIGNAL(valueChanged( const QString& )), this, SIGNAL(parametersChanged()) );
-  connect(windowMaxLength, SIGNAL(valueChanged( const QString& )), this, SIGNAL(parametersChanged()) );
+  connect(windowLength, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
+  connect(windowMaxLength, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
   connect(filterWidget, SIGNAL(parametersChanged()), this, SIGNAL(parametersChanged()));
 
   windowLength->setRange(0.0, std::numeric_limits<double>::infinity());
@@ -70,7 +70,7 @@ WindowingParameterWidget::WindowingParameterWidget(QWidget *parent, Qt::WindowFl
   badSampleGap->setRange(0.0, std::numeric_limits<double>::infinity());
   badSampleThreshold->setRange(0.0, std::numeric_limits<double>::infinity());
 
-  connect(seismicEventDelay, SIGNAL(valueChanged(const QString&)), this, SIGNAL(parametersChanged()) );
+  connect(seismicEventDelay, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
 }
 
 void WindowingParameterWidget::createSelectMenu(QToolButton * select)
@@ -185,11 +185,11 @@ void WindowingParameterWidget::addStation(QString name)
   QListWidgetItem * item;
   if(_nComponents==rawApplyList->count()) {
     item=new QListWidgetItem( "---" );
-    item->setFlags(nullptr);
+    item->setFlags(Qt::NoItemFlags);
     rawApplyList->addItem(item);
     if(isFiltered) {
       item=new QListWidgetItem( "---" );
-      item->setFlags(nullptr);
+      item->setFlags(Qt::NoItemFlags);
       filtApplyList->addItem(item);
     }
   }
