@@ -286,8 +286,8 @@ void SeedLink::run()
     break;
   case Dns: {
       // Check if serverName is a numerical address or not
-      QRegExp ipExp("[0-9]*\\.[0-9]*\\.[0-9]*\\.[0-9]*");
-      if(ipExp.exactMatch(_serverName) ) {
+      QRegularExpression ipExp("[0-9]*\\.[0-9]*\\.[0-9]*\\.[0-9]*");
+      if(ipExp.globalMatch(_serverName).hasNext()) {
         _serverAddress=_serverName+":"+QString::number(_serverPort).toLatin1();
       } else {
         QHostInfo info=QHostInfo::fromName(_serverName);
@@ -339,7 +339,7 @@ void SeedLink::packetReceived()
     _xmlInfos+=QByteArray((char *) msr->msrecord + msr->fsdh.begin_data, msr->fsdh.num_samples);
     if(ptype==SLINFT) {
       XMLHeader hdr(&_serverInfo);
-      //App::log(_xmlInfos << endl;
+      //App::log(_xmlInfos << Qt::endl;
       if(hdr.xml_restoreString(_xmlInfos)==XMLClass::NoError) {
         App::log(tr("List of streams downloaded successfully: %1 stations\n").arg(_serverInfo.count()) );
         emit infoAvailable();
