@@ -44,7 +44,6 @@ namespace HVCore {
 
     bool setSubPool(SubSignalPool * subPool);
 
-    bool setParameters(const AbstractParameters& param);
     inline const HVParameters * parameters() const;
     inline HVParameters * parameters();
 
@@ -60,7 +59,7 @@ namespace HVCore {
     void setWindowColors();
     void setStatistics();
     void setPeaks();
-    virtual bool save(QDir outputDir);
+    bool saveResults(const QString& outputDir);
   protected:
     void setStations();
     virtual AbstractStation * createStation(StationSignals * sigs)=0;
