@@ -95,14 +95,14 @@ namespace HVCore {
 
     SignalDatabase * database() const;
   public slots:
-    void changeColors(const QVector<int>* selCurves, const Color &col);
+    void changeColors(const QList<int>* selCurves, const QGpCoreTools::Color &col);
   signals:
     void windowsChanged();
   protected:
     virtual AbstractResults * createResults()=0;
 
     StationProcessSignals * _signals;
-    QVector<AbstractResults *> _results;
+    VectorList<AbstractResults *> _results;
   private:
     SparseKeepSignal * _keep;
     TimeWindowList _timeWindows;
