@@ -48,7 +48,7 @@ namespace HVCore {
     int windowCount() const {return _windows->curveCount();}
     void setWindow(int winIndex, double winLength, const Curve<Point2D>& curve);
     void setWindowColor(int winIndex, const Color& col);
-    void setWindowColor(const QVector<int>* selCurves, const Color& col);
+    void setWindowColor(const QList<int>* selCurves, const Color& col);
     void setStatistics();
     void setPeaks();
     QString comments() const;
@@ -75,7 +75,7 @@ namespace HVCore {
     double averageWindowLength() const {return _averageWindowLength.mean();}
 
     double peak(int index, double minFreq, double maxFreq) const;
-    double averagePeak(const QVector<bool>& selection, double minFreq, double maxFreq) const;
+    double averagePeak(const VectorList<bool>& selection, double minFreq, double maxFreq) const;
 
     XUniqueYColorData * windows() const {return _windows;}
     const Curve<Point2D>& average() const {return _average;}
@@ -89,9 +89,9 @@ namespace HVCore {
     void derivate();
     void integrate();
   private slots:
-    void blackWindows(int, const QVector<int>* selCurves);
+    void blackWindows(int, const VectorList<int>* selCurves);
   signals:
-    void colorsToChange(const QVector<int>* selCurves, const Color& col);
+    void colorsToChange(const QList<int>* selCurves, const QGpCoreTools::Color& col);
     void showColors(bool);
     void peakChanged();
   private:
@@ -105,7 +105,7 @@ namespace HVCore {
 
     XUniqueYColorData * _windows;
     Curve<Point2D> _average, _stddevLow, _stddevHigh;
-    QVector<RealStatisticalValue> _peaks;
+    VectorList<RealStatisticalValue> _peaks;
     Statistics _averageWindowLength;
   };
 
