@@ -54,6 +54,7 @@ namespace HVCore {
 
     _commonTimeWindows=false;
 
+    _oversamplingFactor=1.0;
     _highPassFrequency=0;
     _horizontal=Squared;
     _horizontalAzimuth=0.0;
@@ -68,86 +69,13 @@ namespace HVCore {
     _rotationStep=Angle::degreesToRadians(10.0);
   }
 
-  /*!
-    Description of constructor still missing
-  */
-  HVParameters::HVParameters(const HVParameters& o)
-    : AbstractParameters(o),
-      _timeRange(o._timeRange),
-      _windowing(o._windowing),
-      _frequencySampling(o._frequencySampling),
-      _smoothing(o._smoothing),
-      _tapering(o._tapering),
-      _frequencyWindowRejection(o._frequencyWindowRejection)
-
-  {
-    TRACE;
-    _commonTimeWindows=o._commonTimeWindows;
-
-    _highPassFrequency=o._highPassFrequency;
-    _horizontal=o._horizontal;
-    _horizontalAzimuth=o._horizontalAzimuth;
-
-    _doMakeUp=o._doMakeUp;
-    _makeUpResults=o._makeUpResults;
-    _makeUpSummary=o._makeUpSummary;
-    _plotCountPerLineResults=o._plotCountPerLineResults;
-    _pageHeightResults=o._pageHeightResults;
-
-    _rotationStep=o._rotationStep;
-  }
-
-  void HVParameters::setHorizontal(const QString& h)
-  {
-    TRACE;
-    if(h.count()>0) {
-      QString hl=h.toLower();
-      switch(hl[0].unicode()) {
-      case 'e':
-        if(hl=="energy") {
-          _horizontal=Energy;
-        }
-        break;
-      case 'a':
-        if(hl=="azimuth") {
-          _horizontal=Azimuth;
-        }
-        break;
-      case 'g':
-        if(hl=="geometric") {
-          _horizontal=Geometric;
-        }
-        break;
-      case 's':
-        if(hl=="squared") {
-          _horizontal=Squared;
-        }
-        break;
-      default:
-        break;
-      }
-    }
-  }
-
-  QString HVParameters::horizontalString() const
-  {
-    TRACE;
-    switch(_horizontal) {
-    case Energy:
-      break;
-    case Azimuth:
-      return "Azimuth";
-    case Squared:
-      return "Squared";
-    case Geometric:
-      return "Geometric";
-    }
-    return "Energy";
-  }
+  ENUM_AS_STRING_BEGIN(HVParameters, HorizontalType)
+  ENUM_AS_STRING_DATA_4(Azimuth, Energy, Geometric, Squared);
+  ENUM_AS_STRING_END
 
   int HVParameters::keywordCount(PARAMETERS_KEYWORDCOUNT_ARGS) const
   {
-    return 11+AbstractParameters::keywordCount();
+    return 12+AbstractParameters::keywordCount();
   }
 
   int HVParameters::totalKeywordCount(PARAMETERS_TOTALKEYWORDCOUNT_ARGS) const
@@ -165,6 +93,7 @@ namespace HVCore {
   {
     TRACE;
     int baseIndex=AbstractParameters::keywordCount();
+    keywords.add(prefix+"OVER_SAMPLING_FACTOR"+suffix, this, baseIndex+11);
     keywords.add(prefix+"DO_HIGH_PASS"+suffix, this, baseIndex);         // Kept for compatibility
     keywords.add(prefix+"HIGH_PASS_FREQUENCY"+suffix, this, baseIndex+1);
     keywords.add(prefix+"HORIZONTAL_COMPONENTS"+suffix, this, baseIndex+2);
@@ -174,7 +103,7 @@ namespace HVCore {
     keywords.add(prefix+"SIGNAL_FILE_NAME"+suffix, this, baseIndex+6);   // Kept for compatibility
     keywords.add(prefix+"MINIMUM"+suffix, this, baseIndex+7);            // Kept for compatibility
     keywords.add(prefix+"MAXIMUM"+suffix, this, baseIndex+8);            // Kept for compatibility
-    keywords.add(prefix+"SAMPLES_NUMBER"+suffix, this, baseIndex+9);      // Kept for compatibility
+    keywords.add(prefix+"SAMPLES_NUMBER"+suffix, this, baseIndex+9);     // Kept for compatibility
     keywords.add(prefix+"SAMPLING_TYPE"+suffix, this, baseIndex+10);     // Kept for compatibility
     _timeRange.collectKeywords(keywords, prefix, suffix);
     _windowing.collectKeywords(keywords, prefix, suffix);
@@ -194,9 +123,12 @@ namespace HVCore {
     log+=_tapering.toString(prefix, suffix);
     log+=_smoothing.toString(prefix, suffix);
     log+=_frequencySampling.toString(prefix, "_FREQUENCY"+suffix);
+    log+="# Required when using short time windows when the number of frequency samples\n"
+         "# is higher than the number of points in the spectra.\n";
+    log+=prefix+"OVER_SAMPLING_FACTOR"+suffix+"="+QString::number(_oversamplingFactor)+"\n";
     log+=prefix+"HIGH_PASS_FREQUENCY"+suffix+"="+QString::number(_highPassFrequency)+"\n";
     log+="# Possible values for HORIZONTAL_COMPONENTS: Squared, Energy, Azimuth, Geometric\n";
-    log+=prefix+"HORIZONTAL_COMPONENTS"+suffix+"="+horizontalString()+"\n";
+    log+=prefix+"HORIZONTAL_COMPONENTS"+suffix+"="+convertHorizontalType(_horizontal)+"\n";
     log+="# HORIZONTAL_AZIMUTH is used only when HORIZONTAL_COMPONENTS==Azimuth\n";
     log+=prefix+"HORIZONTAL_AZIMUTH"+suffix+"="+QString::number(_horizontalAzimuth)+"\n";
     log+="# Used only for rotated output\n";
@@ -220,8 +152,8 @@ namespace HVCore {
       _highPassFrequency=value.toDouble(&ok);
       return ok && _highPassFrequency>=0.0;
     case 2:
-      setHorizontal(value);
-      return true;
+      _horizontal=convertHorizontalType(value, ok);
+      return ok;
     case 3:
       _horizontalAzimuth=value.toDouble(&ok);
       return ok;
@@ -238,6 +170,9 @@ namespace HVCore {
     case 10:        // kept for compatibility
       obsoleteKeyword(keywords, index-AbstractParameters::keywordCount());
       return true;
+    case 11:
+      _oversamplingFactor=value.toDouble(&ok);
+      return ok;
     default:
       break;
     }
