@@ -37,11 +37,11 @@ namespace HVCore {
   {
   public:
     HVParameters();
-    HVParameters(const HVParameters& o);
 
-    virtual AbstractParameters * clone() const {return new HVParameters(*this);}
+    AbstractParameters * clone() const {return new HVParameters(*this);}
 
     enum HorizontalType {Energy, Azimuth, Squared, Geometric};
+    ENUM_AS_STRING_DECL(HorizontalType)
 
     TimeRangeParameters& timeRange() {return _timeRange;}
     const TimeRangeParameters& timeRange() const {return _timeRange;}
@@ -62,6 +62,9 @@ namespace HVCore {
     const WindowFunctionParameters& tapering() const {return _tapering;}
     void setTapering(const WindowFunctionParameters& t) {_tapering=t;}
 
+    double oversamplingFactor() const {return _oversamplingFactor;}
+    void setOversamplingFactor(double f) {_oversamplingFactor=f;}
+
     SmoothingParameters& smoothing() {return _smoothing;}
     const SmoothingParameters& smoothing() const {return _smoothing;}
     void setSmoothing(const SmoothingParameters& s) {_smoothing=s;}
@@ -70,9 +73,7 @@ namespace HVCore {
     void setHighPassFrequency(double h) {_highPassFrequency=h;}
 
     HorizontalType horizontal() const {return _horizontal;}
-    QString horizontalString() const;
     void setHorizontal(HorizontalType h) {_horizontal=h;}
-    void setHorizontal(const QString& h);
 
     double horizontalAzimuth() const {return _horizontalAzimuth;}
     void setHorizontalAzimuth(double h) {_horizontalAzimuth=h;}
@@ -112,6 +113,7 @@ namespace HVCore {
     SmoothingParameters _smoothing;
     WindowFunctionParameters _tapering;
     FrequencyWindowRejection _frequencyWindowRejection;
+    double _oversamplingFactor;
     double _horizontalAzimuth;
     double _highPassFrequency;
 
