@@ -34,7 +34,7 @@ namespace HVCore {
   class HVCORE_EXPORT HVRotateTool : public HVTool
   {
   public:
-    HVRotateTool(QObject * parent=nullptr);
+    HVRotateTool(QObject * parent);
   protected:
     virtual AbstractStation * createStation(StationSignals * sigs);
     virtual QString toolName() {return tr("HV Rotate spectral ratio");}
