@@ -79,16 +79,5 @@ namespace HVCore {
     ParallelTask::init();
   }
 
-  void HVTask::polish()
-  {
-    App::log(tr("Get statistics...\n"));
-    int n=_station->resultCount();
-    for(int i=0; i<n; i++) {
-      AbstractResults * r=_station->results(i);
-      r->setStatistics();
-      r->setPeaks();
-    }
-  }
-
 } // namespace HVCore
 
