@@ -48,7 +48,15 @@ bool SpectrumStationSignals::setProcessed(const StationProcessSignals * from,
   psig->subtractValue();
   TaperDelegate window(&specParam->tapering());
   window.createFunction(0.0, tw.lengthSeconds(), psig->samplingFrequency(), psig->nSamples());
-  psig->taper(window);
+  if(!psig->taper(window)) {
+    App::log(tr("Error applying taper, skipping\n"));
+  }
+  if(specParam->oversamplingFactor()>1.0) {
+    DoubleSignal * sigLarge=new DoubleSignal;
+    sigLarge->frequencyOverSample(specParam->oversamplingFactor(), psig);
+    delete psig;
+    psig=sigLarge;
+  }
   // Correction factor required for PSD. See Mc Namara 2004
   double factor=window.correctionFactor();
   App::log(1, tr("PSD taper correction factor: %1\n").arg(factor, 0, 'f', 6));
