@@ -84,7 +84,14 @@ namespace HVGui {
     connect(azimuthValue, SIGNAL(valueChanged(double)), this, SLOT(procParamChanged()));
     connect(horizontalEnergy, SIGNAL(toggled(bool)), this, SLOT(procParamChanged()));
     connect(azimuth, SIGNAL(toggled(bool)), this, SLOT(procParamChanged()));
+    connect(doOversampling, SIGNAL(toggled(bool)), this, SLOT(procParamChanged()));
+    connect(oversamplingFactor, SIGNAL(valueChanged(double)), this, SLOT(procParamChanged()));
+    connect(doHighPass, SIGNAL(toggled(bool)), this, SLOT(procParamChanged()));
     connect(highPassFrequency, SIGNAL(valueChanged(double)), this, SLOT(procParamChanged()));
+
+    // Add a menu to start button to adjust the numer of parallel jobs
+    detailedStatus->setButtons(startBut, stopBut);
+    connect(detailedStatus, SIGNAL(startJobs(int)), this, SLOT(start(int)));
   }
 
   /*!
@@ -118,6 +125,7 @@ namespace HVGui {
     smoothing->updateAllFields();
     on_useMakeUpResults_toggled();
     on_useMakeUpSummary_toggled();
+    on_doOversampling_toggled();
     on_doHighPass_toggled();
     currentDisplayStation->setCurrentIndex(0);
     timeLimits->setSubPool(_tool->subPool());
@@ -293,10 +301,10 @@ namespace HVGui {
     TRACE;
     AbstractStation * stat=belongsTo(sig);
     if(stat) {
-      updateParameters();
       QString log=tr("Add windows in range [%1, %2]\n")
                       .arg(r.start().toString(DateTime::defaultUserFormat))
                       .arg(r.end().toString(DateTime::defaultUserFormat));
+      parametersFromGui();
 
       LayerLocker ll(timeWindowLayer());
       tool()->addWindows(stat, &r, log);
@@ -311,7 +319,8 @@ namespace HVGui {
     TRACE;
     AbstractStation * stat=belongsTo(sig);
     if(stat) {
-      updateParameters();
+      parametersFromGui();
+
       LayerLocker ll(timeWindowLayer());
       tool()->removeWindows(stat, r);
       ll.unlock();
@@ -324,7 +333,7 @@ namespace HVGui {
     TRACE;
     QList<AbstractStation *> statList=selectedStations();
     if(statList.isEmpty()) return;
-    updateParameters();
+    parametersFromGui();
 
     LayerLocker ll(timeWindowLayer());
     tool()->autoWindows(&statList);
@@ -338,7 +347,7 @@ namespace HVGui {
     TRACE;
     QList<AbstractStation *> statList=selectedStations();
     if(statList.isEmpty()) return;
-    updateParameters();
+    parametersFromGui();
 
     LayerLocker ll(timeWindowLayer());
     tool()->inverseWindows(&statList);
@@ -350,28 +359,20 @@ namespace HVGui {
   /*!
     One of the signals changed (mostly enlarged by DynamicSignal), check for supplementary windows
   */
-  void AbstractHVWidget::refreshSignal(Signal * sig)
+  void AbstractHVWidget::endSignalChange(Signal * sig)
   {
     TRACE;
     if(!dynamicUpdate->isChecked()) return;
-    updateParameters();
+    parametersFromGui();
 
-    LayerLocker ll(timeWindowLayer());
     if(tool()->addWindows(sig)) {
-      /* Temporarily removed the automatic computation
-
-      SpectrumParameters hvparam;
-      hvparam.setFromDialog(_d);
-      for(int i=0;i < n;i++ ) {
-        AbstractStation * stat=_stations[ i ];
-        if(oldWindowsCount[i]<stat->windowCount()) {
-          TimeRangeList addedList(stat->windows(), oldWindowsCount[i]);
-          stat->start(addedList, hvparam);
-        }
-      }*/
+      LayerLocker ll(timeWindowLayer());
+      parametersFromGui();
+      tool()->autoWindows();
+      ll.unlock();
+      windowsChanged();
+      setWinParamChanged(false);
     }
-    ll.unlock();
-    windowsChanged();
   }
 
   void AbstractHVWidget::clearWindows()
@@ -427,7 +428,7 @@ namespace HVGui {
     return true;
   }
 
-  void AbstractHVWidget::start()
+  void AbstractHVWidget::start(int threadCount)
   {
     TRACE;
     if(subPoolLocked()) {
@@ -440,16 +441,16 @@ namespace HVGui {
     if(statList.isEmpty()) {
       return;
     }
-    if(!updateParameters()) {
-      Message::warning(MSG_ID, tr("Starting"), tr("Error(s) found in parameters, check log."));
+    parametersFromGui();
+    if(!tool()->setLoop()) {
       return;
     }
     lockSubPool();
     detailedStatus->setLoop(tool()->loop());
-    setRunning(true);
+    selectBut->setEnabled(false);
     tool()->setWindowColors();
     // High pass filter to be integrated in core tool
-    tool()->start();
+    tool()->start(threadCount, true);
     for(int i=statList.count()-1; i>=0; i--) {
       statList.at(i)->setWindowsChanged(false);
     }
@@ -464,7 +465,8 @@ namespace HVGui {
   void AbstractHVWidget::finish()
   {
     unlockSubPool();
-    setRunning(false);
+    detailedStatus->setRunning(false);
+    selectBut->setEnabled(true);
     _winResults->showValues();
     _winResults->setParameters(*tool()->parameters());
     if(_summary) {
@@ -487,35 +489,18 @@ namespace HVGui {
     _forceReProcessAll=false;
   }
 
-  void AbstractHVWidget::setRunning(bool r, const QString& message)
-  {
-    TRACE;
-    selectBut->setEnabled(!r);
-    startBut->setEnabled(!r);
-    stopBut->setEnabled(r);
-    if(r) {
-      if(message.isEmpty()) {
-        mainStatus->setText(tr("Running..."));
-      } else {
-        mainStatus->setText(message);
-      }
-    } else {
-      mainStatus->setText(tr("Not running"));
-    }
-  }
-
   void AbstractHVWidget::setMakeUp()
   {
     TRACE;
-    HVParameters param;
-    getParameters(param);
-    if(param.doMakeUp()) {
-      if(!param.makeUpResults().isEmpty()) {
-        _winResults->restoreMakeUp(param.makeUpResults());
+    parametersFromGui();
+    HVParameters * param=tool()->parameters();
+    if(param->doMakeUp()) {
+      if(!param->makeUpResults().isEmpty()) {
+        _winResults->restoreMakeUp(param->makeUpResults());
       }
-      _winResults->setLayout(param.plotCountPerLineResults(), param.pageHeightResults());
-      if(_summary && !param.makeUpSummary().isEmpty()) {
-        _summary->sheet()->restoreMakeUp(param.makeUpSummary());
+      _winResults->setLayout(param->plotCountPerLineResults(), param->pageHeightResults());
+      if(_summary && !param->makeUpSummary().isEmpty()) {
+        _summary->sheet()->restoreMakeUp(param->makeUpSummary());
       }
     }
   }
@@ -540,22 +525,6 @@ namespace HVGui {
     }
   }
 
-  AbstractParameters * AbstractHVWidget::parameters(AbstractParameters * param) const
-  {
-    TRACE;
-    if(!param) {
-      param=new HVParameters;
-    }
-    getParameters(*static_cast<HVParameters *>(param));
-    return param;
-  }
-
-  void AbstractHVWidget::setParameters(const AbstractParameters * param)
-  {
-    TRACE;
-    setParameters(*static_cast<const HVParameters *>(param));
-  }
-
   void AbstractHVWidget::loadWindows(QStringList fileNames)
   {
     TRACE;
@@ -692,6 +661,13 @@ namespace HVGui {
     procParamChanged();
   }
 
+  void AbstractHVWidget::on_doOversampling_toggled()
+  {
+    TRACE;
+    oversamplingFactor->setEnabled(doOversampling->isChecked());
+    procParamChanged();
+  }
+
   void AbstractHVWidget::on_makeUpResultsBrowse_clicked()
   {
     TRACE;
@@ -722,40 +698,35 @@ namespace HVGui {
     makeUpSummaryBrowse->setEnabled(b);
   }
 
-  bool AbstractHVWidget::updateParameters()
-  {
-    HVParameters param;
-    getParameters(param);
-    return tool()->setParameters(param);
-  }
-
-  void AbstractHVWidget::setParameters(const HVParameters& param)
+  void AbstractHVWidget::parametersToGui()
   {
     TRACE;
-    makeUp->setChecked(param.doMakeUp());
-    if(param.makeUpResults().isEmpty()) {
+    const HVParameters& hvparam=*tool()->parameters();
+
+    makeUp->setChecked(hvparam.doMakeUp());
+    if(hvparam.makeUpResults().isEmpty()) {
       useMakeUpResults->setChecked(false);
     } else {
       useMakeUpResults->setChecked(true);
-      makeUpResults->setText(param.makeUpResults());
+      makeUpResults->setText(hvparam.makeUpResults());
     }
-    if(param.makeUpSummary().isEmpty()) {
+    if(hvparam.makeUpSummary().isEmpty()) {
       useMakeUpSummary->setChecked(false);
     } else {
       useMakeUpSummary->setChecked(true);
-      makeUpSummary->setText(param.makeUpSummary());
+      makeUpSummary->setText(hvparam.makeUpSummary());
     }
-    nPlotsPerLineResults->setValue(param.plotCountPerLineResults());
-    pageHeightResults->setValue(param.pageHeightResults());
+    nPlotsPerLineResults->setValue(hvparam.plotCountPerLineResults());
+    pageHeightResults->setValue(hvparam.pageHeightResults());
 
-    timeLimits->setParameters(param.timeRange());
-    winParam->setParameters(param.windowing());
-    sampling->setParameters(param.frequencySampling());
-    smoothing->setParameters(param.smoothing());
-    tapering->setParameters(param.tapering());
+    timeLimits->setParameters(hvparam.timeRange());
+    winParam->setParameters(hvparam.windowing());
+    sampling->setParameters(hvparam.frequencySampling());
+    smoothing->setParameters(hvparam.smoothing());
+    tapering->setParameters(hvparam.tapering());
     if(hComponentsGroup) {
       if(squaredAverage) {
-        switch(param.horizontal()) {
+        switch(hvparam.horizontal()) {
         case HVParameters::Energy:
           horizontalEnergy->setChecked(true);
           break;
@@ -769,59 +740,74 @@ namespace HVGui {
           geometricMean->setChecked(true);
           break;
         }
-        azimuthValue->setValue(param.horizontalAzimuth());
+        azimuthValue->setValue(hvparam.horizontalAzimuth());
       }
       if(rotationStepEdit) {
-        rotationStepEdit->setValue(Angle::radiansToDegrees(param.rotationStep()));
+        rotationStepEdit->setValue(Angle::radiansToDegrees(hvparam.rotationStep()));
       }
     }
-    if(param.highPassFrequency()>0.0) {
+    if(hvparam.oversamplingFactor()>1.0) {
+      doOversampling->setChecked(true);
+      oversamplingFactor->setValue(hvparam.oversamplingFactor());
+    } else {
+      doOversampling->setChecked(false);
+    }
+    if(hvparam.highPassFrequency()>0.0) {
       doHighPass->setChecked(true);
-      highPassFrequency->setValue(param.highPassFrequency());
+      highPassFrequency->setValue(hvparam.highPassFrequency());
     } else {
       doHighPass->setChecked(false);
     }
   }
 
-  void AbstractHVWidget::getParameters(HVParameters& param) const
+  void AbstractHVWidget::parametersFromGui()
   {
     TRACE;
-    param.setDoMakeUp(makeUp->isChecked());
+    HVParameters& hvparam=*tool()->parameters();
+
+    hvparam.setDoMakeUp(makeUp->isChecked());
     if(useMakeUpResults->isChecked()) {
-      param.setMakeUpResults(makeUpResults->text());
+      hvparam.setMakeUpResults(makeUpResults->text());
     }
     if(useMakeUpSummary->isChecked()) {
-      param.setMakeUpSummary(makeUpSummary->text());
+      hvparam.setMakeUpSummary(makeUpSummary->text());
     }
-    param.setPlotCountPerLineResults(nPlotsPerLineResults->value());
-    param.setPageHeightResults(pageHeightResults->value());
+    hvparam.setPlotCountPerLineResults(nPlotsPerLineResults->value());
+    hvparam.setPageHeightResults(pageHeightResults->value());
 
-    timeLimits->getParameters(param.timeRange());
-    winParam->getParameters(param.windowing());
-    sampling->getParameters(param.frequencySampling());
-    smoothing->getParameters(param.smoothing());
-    tapering->getParameters(param.tapering());
+    timeLimits->getParameters(hvparam.timeRange());
+    winParam->getParameters(hvparam.windowing());
+    sampling->getParameters(hvparam.frequencySampling());
+    smoothing->getParameters(hvparam.smoothing());
+    tapering->getParameters(hvparam.tapering());
     if(hComponentsGroup) {
       if(squaredAverage) {
         if(horizontalEnergy->isChecked()) {
-          param.setHorizontal(HVParameters::Energy);
+          hvparam.setHorizontal(HVParameters::Energy);
         } else if(azimuth->isChecked()) {
-          param.setHorizontal(HVParameters::Azimuth);
-          param.setHorizontalAzimuth(azimuthValue->value());
+          hvparam.setHorizontal(HVParameters::Azimuth);
+          hvparam.setHorizontalAzimuth(azimuthValue->value());
         } else if(geometricMean->isChecked()) {
-          param.setHorizontal(HVParameters::Geometric);
+          hvparam.setHorizontal(HVParameters::Geometric);
         } else {
-          param.setHorizontal(HVParameters::Squared);
+          hvparam.setHorizontal(HVParameters::Squared);
         }
       }
       if(rotationStepEdit) {
-        param.setRotationStep(Angle::degreesToRadians(rotationStepEdit->value()));
+        hvparam.setRotationStep(Angle::degreesToRadians(rotationStepEdit->value()));
       }
     }
     if(doHighPass->isChecked()) {
-      param.setHighPassFrequency(highPassFrequency->value());
+      hvparam.setHighPassFrequency(highPassFrequency->value());
+    } else {
+      hvparam.setHighPassFrequency(0.0);
     }
-    param.setCommonTimeWindows(commonTimeWindows->isChecked());
+    if(doOversampling->isChecked()) {
+      hvparam.setOversamplingFactor(oversamplingFactor->value());
+    } else {
+      hvparam.setOversamplingFactor(1.0);
+    }
+    hvparam.setCommonTimeWindows(commonTimeWindows->isChecked());
   }
 
 } // namespace HVGui
