@@ -220,7 +220,7 @@ namespace HVGui {
     } else if(fileName.isEmpty()) {
       if(Message::warning(MSG_ID, tr("Saving results"),
                           tr("Station at (%1): empty station name, please provide a file name to export results")
-                            .arg(res->coordinates().toString(0, 'f')),
+                            .arg(res->coordinates().toString('f', 0)),
                           Message::ok(), Message::cancel(), true)==Message::Answer1) {
         return;
       }
