@@ -105,7 +105,7 @@ namespace HVGui {
     int _mapPeakIndex;
     bool _mapShowBubbles;
     Legend _categories;
-    QVector<RealStatisticalValue> _peaks;
+    VectorList<RealStatisticalValue> _peaks;
     SummaryMapOptions * _mapOptions;
 
   };
