@@ -67,7 +67,7 @@ namespace HVGui {
     _averageLayer=new LineLayer(g);
     _averageLayer->setObjectName("Average");
     line=new PlotLine2D;
-    line->setPen(Pen(Qt::black, 0.6, Qt::SolidLine));
+    line->setPen(Pen(Qt::black, 0.6, Pen::SolidLine));
     line->setSymbol(Symbol());
     _averageLayer->setReferenceLine(line);
     _averageLayer->addLine();
@@ -75,7 +75,7 @@ namespace HVGui {
     _stddevLayer=new LineLayer(g);
     _stddevLayer->setObjectName("Stddev");
     line=static_cast<PlotLine2D *>(line->clone());
-    line->setPen(Pen(Qt::black, 0.6, Qt::DashLine));
+    line->setPen(Pen(Qt::black, 0.6, Pen::DashLine));
     _stddevLayer->setReferenceLine(line);
     _stddevLayer->addLine();
     _stddevLayer->addLine();
@@ -100,12 +100,21 @@ namespace HVGui {
     AbstractResultWidget::setValues(res);
     // A bit ugly to disconnect and reconnect right after, but no way to test is already
     // connected. It avoids multiple connections
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    disconnect(_windowsLayer, SIGNAL(dataSelected(int, const QList<int>*)),
+               _values, SLOT(blackWindows(int, const QList<int>*)));
+    disconnect(values(), SIGNAL(peakChanged()), this, SIGNAL(peakChanged()));
+    connect(_windowsLayer, SIGNAL(dataSelected(int, const QList<int>*)),
+            _values, SLOT(blackWindows(int, const QList<int>*)));
+    connect(values(), SIGNAL(peakChanged()), this, SIGNAL(peakChanged()));
+#else
     disconnect(_windowsLayer, SIGNAL(dataSelected(int, const QVector<int>*)),
-            _values, SLOT(blackWindows(int, const QVector<int>*)));
+               _values, SLOT(blackWindows(int, const QVector<int>*)));
     disconnect(values(), SIGNAL(peakChanged()), this, SIGNAL(peakChanged()));
     connect(_windowsLayer, SIGNAL(dataSelected(int, const QVector<int>*)),
             _values, SLOT(blackWindows(int, const QVector<int>*)));
     connect(values(), SIGNAL(peakChanged()), this, SIGNAL(peakChanged()));
+#endif
   }
 
   void CurveResultWidget::setValueTitle(const QString& t)
@@ -170,7 +179,7 @@ namespace HVGui {
       _noiseModelLayer=new LineLayer(_t10Layer->graph());
       _noiseModelLayer->setObjectName("NewNoiseModel");
       PlotLine2D * line=new PlotLine2D;
-      line->setPen(Pen(Qt::gray, 1.0, Qt::DotLine));
+      line->setPen(Pen(Qt::gray, 1.0, Pen::DotLine));
       _noiseModelLayer->setReferenceLine(line);
       _noiseModelLayer->addLine();
       _noiseModelLayer->addLine();
