@@ -61,7 +61,7 @@ namespace HVGui {
       _frequencyLayers.append(new ParallelBands(w));
       _averageLayers.append(new LineLayer(w) );
       PlotLine2D * line=new PlotLine2D;
-      line->setPen(Pen( Qt::black, 0.6, Qt::SolidLine));
+      line->setPen(Pen( Qt::black, 0.6, Pen::SolidLine));
       line->setSymbol(Symbol());
       _averageLayers.last()->setReferenceLine(line);
       x-=0.5;
@@ -76,8 +76,8 @@ namespace HVGui {
     LineLayer * plot=averageLayer(graphIndex);
     plot->clear();
     plot->addLine();
-    plot->addLine(Pen( Qt::black, 0.6, Qt::DashLine), Symbol());
-    plot->addLine(Pen( Qt::black, 0.6, Qt::DashLine), Symbol());
+    plot->addLine(Pen(Qt::black, 0.6, Pen::DashLine), Symbol());
+    plot->addLine(Pen(Qt::black, 0.6, Pen::DashLine), Symbol());
   }
 
   void StatisticResults::setStatPlot(int graphIndex,
@@ -188,8 +188,8 @@ namespace HVGui {
     int is;
     LineLayer * plotVar=statRes->averageLayer(2);
     plotVar->clear();
-    plotVar->addLine(Pen( Qt::black, 0.6, Qt::SolidLine), Symbol());
-    plotVar->addLine(Pen( Qt::black, 0.6, Qt::DashLine), Symbol());
+    plotVar->addLine(Pen( Qt::black, 0.6, Pen::SolidLine), Symbol());
+    plotVar->addLine(Pen( Qt::black, 0.6, Pen::DashLine), Symbol());
     Curve<Point2D>& varRef=static_cast<PlotLine2D *>(plotVar->line(0))->curve();
     Curve<Point2D>& varTest=static_cast<PlotLine2D *>(plotVar->line(1))->curve();
     varRef.resize(nSamples);
@@ -302,12 +302,20 @@ namespace HVGui {
       f0Ref=ref->peak(0, CurveResults::PeakFrequency);
       df0Ref=f0Ref-ref->peakMinimum(0);
       cmt+="Reference: %1 %2 %3 Hz   ";
-    } else cmt+="No peak for Reference   ";
+    } else {
+      f0Ref=0.0;
+      df0Ref=0.0;
+      cmt+="No peak for Reference   ";
+    }
     if(test->peakCount()>0) {
       f0Test=test->peak(0, CurveResults::PeakFrequency);
       df0Test=f0Test-test->peakMinimum(0);
       cmt+="Test: %4 %5 %6 Hz\n";
-    } else cmt+="No peak for Test\n";
+    } else {
+      f0Test=0.0;
+      df0Test=0.0;
+      cmt+="No peak for Test\n";
+    }
     if(ref->peakCount()>0 && test->peakCount()>0) {
       double varf0Ref=df0Ref*df0Ref;
       double varf0Test=df0Test*df0Test;
