@@ -76,31 +76,32 @@ bool CompatDataPoint::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
+  bool ok=true;
   switch(memberID) {
-  case 0: _mean=content.toDouble(); return true;
-  case 1: _stddev=content.toDouble(); return true;
-  case 2: _weight=content.toDouble(); return true;
+  case 0: _mean=content.toDouble(ok); return ok;
+  case 1: _stddev=content.toDouble(ok); return ok;
+  case 2: _weight=content.toDouble(ok); return ok;
   default: return false;
   }
 }
 
-QVector<double> * CompatDataPointVector::meanVector() const
+VectorList<double> * CompatDataPointVector::meanVector() const
 {
-  QVector<double> * list=new QVector<double>;
+  VectorList<double> * list=new VectorList<double>;
   for(int i=0;i<size();i++) list->append(at(i).mean());
   return list;
 }
 
-QVector<double> * CompatDataPointVector::stddevVector() const
+VectorList<double> * CompatDataPointVector::stddevVector() const
 {
-  QVector<double> * list=new QVector<double>;
+  VectorList<double> * list=new VectorList<double>;
   for(int i=0;i<size();i++) list->append(at(i).stddev());
   return list;
 }
 
-QVector<double> * CompatDataPointVector::weightVector() const
+VectorList<double> * CompatDataPointVector::weightVector() const
 {
-  QVector<double> * list=new QVector<double>;
+  VectorList<double> * list=new VectorList<double>;
   for(int i=0;i<size();i++) list->push_back(at(i).weight());
   return list;
 }
@@ -128,30 +129,30 @@ void CompatDataPointVector::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
   }
 }
 
-QVector<double> * CompatVDataPointVector::valueVector() const
+VectorList<double> * CompatVDataPointVector::valueVector() const
 {
-  QVector<double> * list=new QVector<double>;
+  VectorList<double> * list=new VectorList<double>;
   for(int i=0;i<size();i++) list->append(at(i).value());
   return list;
 }
 
-QVector<double> * CompatVDataPointVector::meanVector() const
+VectorList<double> * CompatVDataPointVector::meanVector() const
 {
-  QVector<double> * list=new QVector<double>;
+  VectorList<double> * list=new VectorList<double>;
   for(int i=0;i<size();i++) list->append(at(i).mean());
   return list;
 }
 
-QVector<double> * CompatVDataPointVector::stddevVector() const
+VectorList<double> * CompatVDataPointVector::stddevVector() const
 {
-  QVector<double> * list=new QVector<double>;
+  VectorList<double> * list=new VectorList<double>;
   for(int i=0;i<size();i++) list->append(at(i).stddev());
   return list;
 }
 
-QVector<double> * CompatVDataPointVector::weightVector() const
+VectorList<double> * CompatVDataPointVector::weightVector() const
 {
-  QVector<double> * list=new QVector<double>;
+  VectorList<double> * list=new VectorList<double>;
   for(int i=0;i<size();i++) list->push_back(at(i).weight());
   return list;
 }
