@@ -331,10 +331,10 @@ double CompatDispersionData::maxDataFrequency()
   return maxFreq/twopi;
 }
 
-QVector<double> * CompatDispersionData::groupSlowness(int iMode)
+VectorList<double> * CompatDispersionData::groupSlowness(int iMode)
 {
   ASSERT(iMode<CompatMultiModalFrequency::_modesCount);
-  QVector<double> * list=new QVector<double>;
+  VectorList<double> * list=new VectorList<double>;
   double * values=_measurements[iMode];
   int n=CompatMultiModalFrequency::_omegasCount-1;
   for(int i=1;i<n;i++) {
