@@ -49,11 +49,11 @@ CompatModalFrequency::CompatModalFrequency()
 void CompatModalFrequency::operator=(CompatModalFrequency& o)
 {
   TRACE;
-  QVector<double>::operator=(o);
+  VectorList<double>::operator=(o);
   _nRayleighModes=o._nRayleighModes;
 }
 
-void CompatModalFrequency::setFrequencies(QVector<double>& values)
+void CompatModalFrequency::setFrequencies(VectorList<double>& values)
 {
   TRACE;
   if(nOmegas()==(int)values.size()) {
@@ -111,9 +111,9 @@ bool CompatModalFrequency::isSameOmegas(const CompatModalFrequency& o) const
   return true;
 }
 
-QVector<double> * CompatModalFrequency::frequencies() const
+VectorList<double> * CompatModalFrequency::frequencies() const
 {
-  QVector<double> * list=new QVector<double>;
+  VectorList<double> * list=new VectorList<double>;
   list->reserve(nOmegas());
   double fac=0.5/M_PI;
   for(int i=0;i<nOmegas();i++)
@@ -161,7 +161,7 @@ void CompatModalFrequency::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
   }
   tmp+=s.indent();
   tmp+="</values>";
-  s << tmp << endl;
+  s << tmp << Qt::endl;
 }
 
 XMLMember CompatModalFrequency::xml_member(XML_MEMBER_ARGS)
@@ -193,6 +193,7 @@ bool CompatModalFrequency::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
+  bool ok=true;
   switch(memberID) {
   case 0: {
       const QChar * ptr=0;
@@ -201,16 +202,25 @@ bool CompatModalFrequency::xml_setProperty(XML_SETPROPERTY_ARGS)
       clear();
       while(true) {
         f=content.nextField(ptr, sep, true);
-        if(f.isValid()) append(f.toDouble()); else break;
+        if(f.isValid()) {
+          double v=f.toDouble(ok);
+          if(ok) {
+            append(v);
+          } else {
+            return false;
+          }
+        } else {
+          break;
+        }
       }
     }
     return true;
   case 1:
-    append(content.toDouble());
-    return true;
+    append(content.toDouble(ok));
+    return ok;
   case 2:
-    _nRayleighModes=content.toInt();
-    return true;
+    _nRayleighModes=content.toInt(ok);
+    return ok;
   default:
     return false;
   }
