@@ -30,6 +30,7 @@
 #define Angle_H
 
 #include <math.h>
+#include <QtCore>
 
 #include "QGpCoreMathDLLExport.h"
 
@@ -43,9 +44,9 @@ namespace QGpCoreMath {
     inline Angle();
     Angle(double dx, double dy) {set(dx, dy);}
     inline Angle(double dx, double dy, double r) {set(dx,dy,r);}
-    ~Angle() {}
 
-    inline Angle& operator=(const Angle& o);
+    enum Mode {Degrees, Radians, Gradians};
+
     bool operator<(const Angle& o) const {return _rad<o._rad;}
     bool operator==(const Angle& o) const {return _rad==o._rad;}
     void operator+=(const Angle& o);
@@ -53,16 +54,22 @@ namespace QGpCoreMath {
 
     inline void set(double dx, double dy);
     inline void set(double dx, double dy, double r);
-    void setDegreeAzimuth(double azimuth) {setDegrees(90.0-azimuth);}
-    void setRadianAzimuth(double azimuth) {setRadians(0.5*M_PI-azimuth);}
+    void setGeographicDegrees(double degrees) {setDegrees(90.0-degrees);}
+    void setGeographicRadians(double radians) {setRadians(0.5*M_PI-radians);}
+    void setGeographicGradians(double gradians) {setGradians(100.0-gradians);}
     inline void setDegrees(double degrees);
     inline void setRadians(double radians);
+    inline void setGradians(double gradians);
+    void setValue(Mode m, double v);
+    void setGeographicValue(Mode m, double v);
 
     inline void initDegrees();
     inline void initRadians();
 
     double degrees() const {return _deg;}
     double radians() const {return _rad;}
+    double gradians() const {return degreesToGradians(_deg);}
+    double value(Mode m) const;
     double cos() const {return _cos;}
     double sin() const {return _sin;}
     double tan() const {return _sin/_cos;}
@@ -77,16 +84,27 @@ namespace QGpCoreMath {
     static double DMToDegrees(double angle);
     static inline double radiansToDegrees(double angle);
     static inline double degreesToRadians(double angle);
-    static inline double geographicToMath(double angle);
-    static inline double mathToGeographic(double angle);
-    static double aroundZero(double angle);
+    static inline double gradiansToDegrees(double angle);
+    static inline double degreesToGradians(double angle);
+    static inline double radiansToGradians(double angle);
+    static inline double gradiansToRadians(double angle);
+
+    static inline double geographicToMath(double radians);
+    static inline double mathToGeographic(double radians);
+    static double aroundZero(double radians);
 
-    static double canonicalRadians(double angle);
     static double canonicalDegrees(double angle);
-    static double differenceRadians(double a1, double a2);
+    static double canonicalRadians(double angle);
+    static double canonicalGradians(double angle);
     static double differenceDegrees(double a1, double a2);
+    static double differenceRadians(double a1, double a2);
+    static double differenceGradians(double a1, double a2);
 
-    static inline bool isInside(double angle, double min, double max);
+    static inline bool isInsideDegrees(double angle, double min, double max);
+    static inline bool isInsideRadians(double angle, double min, double max);
+    static inline bool isInsideGradians(double angle, double min, double max);
+
+    static double fromString(QString angle);
   private:
     double _deg;
     double _rad;
@@ -96,24 +114,42 @@ namespace QGpCoreMath {
 
   inline double Angle::radiansToDegrees(double angle)
   {
-    return angle*180.0/M_PI;
+    return angle*(180.0/M_PI);
   }
 
   inline double Angle::degreesToRadians(double angle)
   {
-    return angle*M_PI/180.0;
+    return angle*(M_PI/180.0);
   }
 
-  inline double Angle::geographicToMath(double angle)
+  inline double Angle::gradiansToDegrees(double angle)
   {
-    angle=degreesToRadians(angle);
-    return angle<=0.5*M_PI ? 0.5*M_PI-angle : 2.5*M_PI-angle;
+    return angle*(180.0/200.0);
   }
 
-  inline double Angle::mathToGeographic(double angle)
+  inline double Angle::degreesToGradians(double angle)
   {
-    angle=radiansToDegrees(angle);
-    return angle<=90.0 ? 90.0-angle : 450.0-angle;
+    return angle*(200.0/180.0);
+  }
+
+  inline double Angle::radiansToGradians(double angle)
+  {
+    return angle*(200.0/M_PI);
+  }
+
+  inline double Angle::gradiansToRadians(double angle)
+  {
+    return angle*(M_PI/200.0);
+  }
+
+  inline double Angle::geographicToMath(double radians)
+  {
+    return radians<=0.5*M_PI ? 0.5*M_PI-radians : 2.5*M_PI-radians;
+  }
+
+  inline double Angle::mathToGeographic(double radians)
+  {
+    return radians<=0.5*M_PI ? 0.5*M_PI-radians : 2.5*M_PI-radians;
   }
 
   inline Angle::Angle()
@@ -151,15 +187,6 @@ namespace QGpCoreMath {
     }
   }
 
-  inline Angle& Angle::operator=(const Angle& o)
-  {
-    _deg=o._deg;
-    _rad=o._rad;
-    _cos=o._cos;
-    _sin=o._sin;
-    return *this;
-  }
-
   inline void Angle::initDegrees()
   {
     _deg=radiansToDegrees(_rad);
@@ -185,6 +212,14 @@ namespace QGpCoreMath {
     _sin=::sin(_rad);
   }
 
+  inline void Angle::setGradians(double gradians)
+  {
+    _deg=gradiansToDegrees(gradians);
+    _rad=degreesToRadians(_deg);
+    _cos=::cos(_rad);
+    _sin=::sin(_rad);
+  }
+
   inline void Angle::chSign()
   {
     _deg=-_deg;
@@ -200,7 +235,21 @@ namespace QGpCoreMath {
     if(_rad>M_PI) _rad-=M_PI; else _rad+=M_PI;
   }
 
-  bool Angle::isInside(double angle, double min, double max)
+  inline bool Angle::isInsideDegrees(double angle, double min, double max)
+  {
+    // If testing only for negative angles, two conditions will be systematically checked
+    // If testing directly with min which is between 0 and 2*pi, there a maximum of two
+    // tests to achive, but only one if lucky enough.
+    if(angle<min) {
+      angle+=360.0;
+      if(angle<min) {
+        angle+=360.0;
+      }
+    }
+    return angle<max;
+  }
+
+  inline bool Angle::isInsideRadians(double angle, double min, double max)
   {
     // If testing only for negative angles, two conditions will be systematically checked
     // If testing directly with min which is between 0 and 2*pi, there a maximum of two
@@ -214,6 +263,20 @@ namespace QGpCoreMath {
     return angle<max;
   }
 
+  inline bool Angle::isInsideGradians(double angle, double min, double max)
+  {
+    // If testing only for negative angles, two conditions will be systematically checked
+    // If testing directly with min which is between 0 and 2*pi, there a maximum of two
+    // tests to achive, but only one if lucky enough.
+    if(angle<min) {
+      angle+=400.0;
+      if(angle<min) {
+        angle+=400.0;
+      }
+    }
+    return angle<max;
+  }
+
 } // namespace QGpCoreMath
 
 #endif // ANGLE_H
