@@ -27,30 +27,15 @@
 #ifndef ANGLESEARCH_H
 #define ANGLESEARCH_H
 
-#include "FunctionSearch.h"
+#include "GridSearch1D.h"
 #include "QGpCoreMathDLLExport.h"
 
 namespace QGpCoreMath {
 
-  class QGPCOREMATH_EXPORT AngleSearch : public FunctionSearch
+  class QGPCOREMATH_EXPORT AngleSearch : public GridSearch1D
   {
   public:
-    AngleSearch();
-    ~AngleSearch();
-
     void setGrid(int stepCount);
-
-    double value(int index) const {return FunctionSearch::value(_angles[index], index);}
-
-    virtual void globalMax(double absThres);
-    virtual void localMax(int nMax, double absThres, double relThres);
-  private:
-    double refineMax(const double& min, const double& max, double maxVal);
-    inline void checkForMax(double angle, double& maxVal);
-    inline void refineMax(int k, double maxVal);
-
-    int _n;
-    double * _angles;
   };
 
 } // namespace QGpCoreMath
