@@ -72,12 +72,6 @@ namespace QGpCoreMath {
     }
   }
 
-  Circle::Circle(const Circle &o)
-  {
-    _c=o._c;
-    _r=o._r;
-  }
-
   double Circle::distanceTo(const Point2D& p) const
   {
     TRACE;
@@ -109,10 +103,10 @@ namespace QGpCoreMath {
   /*!
     Calculate intersections between this and \a o.
   */
-  QVector<Point2D> Circle::intersect(const Circle& o) const
+  VectorList<Point2D> Circle::intersect(const Circle& o) const
   {
     TRACE;
-    QVector<Point2D> inter;
+    VectorList<Point2D> inter;
     double r02=_r*_r;
     double r12=o._r*o._r;
     double x02=_c.x()*_c.x();
@@ -182,7 +176,7 @@ namespace QGpCoreMath {
   Point2D Circle::intersect(const Circle& o, bool& ok, const Circle& disc) const
   {
     TRACE;
-    QVector<Point2D> solutions=intersect(o);
+    VectorList<Point2D> solutions=intersect(o);
     switch(solutions.count()) {
     case 1:
       ok=true;
