@@ -43,61 +43,60 @@
 namespace QGpCoreMath {
 
   template <class pointType>
-  class QGPCOREMATH_EXPORT Curve : private QVector<pointType>
+  class QGPCOREMATH_EXPORT Curve : private VectorList<pointType>
   {
     TRANSLATIONS("Curve")
   public:
     Curve() {_sorted=false;}
-    Curve(int n) : QVector<pointType>(n) {_sorted=false;}
-    Curve(const Curve<pointType>& o) : QVector<pointType>(o) {_sorted=o._sorted;}
-    Curve(const QVector<pointType>& o) : QVector<pointType>(o) {_sorted=false;}
+    Curve(int n) : VectorList<pointType>(n) {_sorted=false;}
+    Curve(const VectorList<pointType>& o) : VectorList<pointType>(o) {_sorted=false;}
 
     void sort();
     void checkSort();
     bool isSorted() const {return _sorted;}
     void unique();
 
-    bool operator==(const Curve<pointType>& o) const {return QVector<pointType>::operator==(o);}
+    bool operator==(const Curve<pointType>& o) const {return VectorList<pointType>::operator==(o);}
     bool operator<(const Curve<pointType>& o) const;
-    int count() const {return QVector<pointType>::count();}
-    bool isEmpty() const {return QVector<pointType>::isEmpty();}
-    void resize(int n) {if(n>count()) {_sorted=false;} QVector<pointType>::resize(n);}
+    int count() const {return VectorList<pointType>::count();}
+    bool isEmpty() const {return VectorList<pointType>::isEmpty();}
+    void resize(int n) {if(n>count()) {_sorted=false;} VectorList<pointType>::resize(n);}
     int indexAfter(double valX) const;
     int indexOf(double valX, double relPrec) const;
-    int indexOf(const pointType& p) const {return QVector<pointType>::indexOf(p);}
+    int indexOf(const pointType& p) const {return VectorList<pointType>::indexOf(p);}
     void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const;
-    pointType interpole(double x) const;
+    pointType interpole(double x,
+                        SamplingOptions xSampling,
+                        SamplingOptions ySampling) const;
     bool isInsideRange(double x) const;
 
-    const pointType& constAt(int index) const {return QVector<pointType>::at(index);}
-    const pointType& constAt(int index) {return QVector<pointType>::at(index);}
-    pointType& constXAt(int index) {return QVector<pointType>::operator[](index);}
-    pointType& at(int index) {_sorted=false; return QVector<pointType>::operator[](index);}
+    const pointType& constAt(int index) const {return VectorList<pointType>::at(index);}
+    const pointType& constAt(int index) {return VectorList<pointType>::at(index);}
+    pointType& constXAt(int index) {return VectorList<pointType>::operator[](index);}
+    pointType& at(int index) {_sorted=false; return VectorList<pointType>::operator[](index);}
 
     double x(int index) const {return constAt(index).x();}
-    double firstX() const {return QVector<pointType>::first().x();}
-    double lastX() const {return QVector<pointType>::last().x();}
+    void firstValid(int& startIndex) const;
+    void lastValid(int& startIndex) const;
     void setX(int index, double x) {at(index).setX(x);}
     inline double y(int index, const CurvePointOptions * pointOptions=nullptr) const;
-    double firstY(const CurvePointOptions * pointOptions=nullptr) const {return QVector<pointType>::first().y(pointOptions);}
-    double lastY(const CurvePointOptions * pointOptions=nullptr) const {return QVector<pointType>::last().y(pointOptions);}
     inline void setY(int index, double y, const CurvePointOptions * pointOptions=nullptr);
     bool isValid(int index) const {return constAt(index).isValid();}
     void setValid(int index, bool v) {constXAt(index).setValid(v);}
 
-    void remove(int index) {QVector<pointType>::remove(index);}
-    void insert(int index, const pointType& p) {_sorted=false; QVector<pointType>::insert(index, p);}
+    void remove(int index) {VectorList<pointType>::remove(index);}
+    void insert(int index, const pointType& p) {_sorted=false; VectorList<pointType>::insert(index, p);}
     void insert(const pointType& p);
-    void clear() {_sorted=false; QVector<pointType>::clear();}
+    void clear() {_sorted=false; VectorList<pointType>::clear();}
     void prepend(const pointType& p);
     void append(const pointType& p);
     void append(const Curve<pointType>& c);
-    typedef pointType * iterator;
-    typedef const pointType * const_iterator;
-    const_iterator begin() const {return QVector<pointType>::begin();}
-    const_iterator end() const {return QVector<pointType>::end();}
-    iterator begin() {_sorted=false; return QVector<pointType>::begin();}
-    iterator end() {_sorted=false; return QVector<pointType>::end();}
+    typedef typename VectorList<pointType>::const_iterator const_iterator;
+    typedef typename VectorList<pointType>::iterator iterator;
+    const_iterator begin() const {return VectorList<pointType>::begin();}
+    const_iterator end() const {return VectorList<pointType>::end();}
+    iterator begin() {_sorted=false; return VectorList<pointType>::begin();}
+    iterator end() {_sorted=false; return VectorList<pointType>::end();}
 
     bool sameSampling(const Curve<pointType>& o) const;
 
@@ -111,6 +110,7 @@ namespace QGpCoreMath {
     void ySetMaximumValue(double value, const CurvePointOptions * pointOptions=nullptr);
     void ySum(double value, const CurvePointOptions * pointOptions=nullptr);
     void ySum(const Curve<pointType>& o, const CurvePointOptions * pointOptions=nullptr);
+    void ySubtract(const Curve<pointType>& o, const CurvePointOptions * pointOptions=nullptr);
     void yMultiply(double factor, const CurvePointOptions * pointOptions=nullptr);
     void yMultiply(const Curve<pointType>& o, const CurvePointOptions * pointOptions=nullptr);
     void yDivide(const Curve<pointType>& o, const CurvePointOptions * pointOptions=nullptr);
@@ -129,7 +129,7 @@ namespace QGpCoreMath {
                   const CurvePointOptions * pointOptions=nullptr);
     void resample(int n, double min, double max, SamplingOptions options=LinearScale);
     void resample(const Curve<pointType>& xModel);
-    void resample(const QVector<double>& xModel);
+    void resample(const VectorList<double>& xModel);
     void cut(double min, double max, SamplingOptions options=LinearScale);
     void validate(double min, double max, bool value, SamplingOptions options=LinearScale);
     void smooth(const SamplingParameters& sampling, const SmoothingParameters& param,
@@ -144,10 +144,11 @@ namespace QGpCoreMath {
 
     bool leastSquare(double& a, double& b, const CurvePointOptions * pointOptions=nullptr) const;
     double azimuth(const CurvePointOptions * pointOptions=nullptr) const;
-    QVector<double> project(const CurvePointOptions * pointOptions=nullptr) const;
+    VectorList<double> project(const CurvePointOptions * pointOptions=nullptr) const;
 
     void swapXY(const CurvePointOptions * pointOptions=nullptr);
     Curve<pointType> derivative(const CurvePointOptions * pointOptions=nullptr) const;
+    double integrate(double from, double to, const CurvePointOptions * pointOptions=nullptr) const;
     Curve<pointType> curvature(const CurvePointOptions * pointOptions=nullptr) const;
     Curve<pointType> angles(const CurvePointOptions * pointOptions=nullptr) const;
     QList<Curve<pointType>> split(double maxX, SamplingOptions options,
@@ -165,10 +166,10 @@ namespace QGpCoreMath {
     double minimumStep(SamplingOptions options);
     int closestMax(int index);
 
-    QVector<double> xVector() const;
+    VectorList<double> xVector() const;
     Curve<Point2D> xyCurve() const;
 
-    QString toString(int precision=6, char format='g') const;
+    QString toString(char format='g', int precision=6) const;
     bool fromStream(QTextStream& s, QString * comments=nullptr);
 
     void operator+=(const Curve<pointType>& o);
@@ -182,7 +183,10 @@ namespace QGpCoreMath {
   protected:
     bool _sorted;
   private:
-    void firstValid(int& startIndex) const;
+    double firstX() const {return VectorList<pointType>::first().x();}
+    double lastX() const {return VectorList<pointType>::last().x();}
+    //double firstY(const CurvePointOptions * pointOptions=nullptr) const {return VectorList<pointType>::first().y(pointOptions);}
+    //double lastY(const CurvePointOptions * pointOptions=nullptr) const {return VectorList<pointType>::last().y(pointOptions);}
     inline static bool lessThan(const pointType& p1, const pointType& p2);
   };
 
@@ -203,10 +207,10 @@ namespace QGpCoreMath {
   {
     if(isEmpty()) {
       _sorted=true;
-    } else if(p.x()>=QVector<pointType>::first().x()) {
+    } else if(p.x()>=VectorList<pointType>::first().x()) {
       _sorted=false;
     }
-    QVector<pointType>::prepend(p);
+    VectorList<pointType>::prepend(p);
   }
 
   template <class pointType>
@@ -214,10 +218,10 @@ namespace QGpCoreMath {
   {
     if(isEmpty()) {
       _sorted=true;
-    } else if(p.x()<=QVector<pointType>::last().x()) {
+    } else if(p.x()<=VectorList<pointType>::last().x()) {
       _sorted=false;
     }
-    QVector<pointType>::append(p);
+    VectorList<pointType>::append(p);
   }
 
   template <class pointType>
@@ -225,10 +229,10 @@ namespace QGpCoreMath {
   {
     if(isEmpty()) {
       _sorted=c._sorted;
-    } else if(!c.isEmpty() && QVector<pointType>::last().x()>=c.QVector<pointType>::first().x()) {
+    } else if(!c.isEmpty() && VectorList<pointType>::last().x()>=c.VectorList<pointType>::first().x()) {
       _sorted=false;
     }
-    QVector<pointType>::operator+=(c);
+    VectorList<pointType>::operator+=(c);
   }
 
   template <class pointType>
@@ -248,8 +252,8 @@ namespace QGpCoreMath {
       f.squeeze();
       // This is quite fast with implicit sharing
       *this=f;
-      _sorted=true;
     }
+    _sorted=true;  // Even empty curves are sorted
   }
 
   template <class pointType>
@@ -398,17 +402,23 @@ namespace QGpCoreMath {
     ASSERT(_sorted);
     if(count()<2) {
       if(count()==1) {
-        return firstX()==x;
+        return constAt(0).x()==x;
       } else {
         return false;
       }
     } else {
-      return firstX()<=x && x<=lastX();
+      int firstIndex=0, lastIndex=count()-1;
+      firstValid(firstIndex);
+      lastValid(lastIndex);
+      return constAt(firstIndex).x()*(1.0-1e-12) <=x &&
+             x<=constAt(lastIndex).x()*(1.0+1e-12);
     }
   }
 
   template <class pointType>
-  pointType Curve<pointType>::interpole(double x) const
+  pointType Curve<pointType>::interpole(double x,
+                                        SamplingOptions xSampling,
+                                        SamplingOptions ySampling) const
   {
     ASSERT(_sorted);
     if(count()<2) {
@@ -422,7 +432,7 @@ namespace QGpCoreMath {
       if(i==0) i++;                // Force interpolation if outside range
       else if(i==count()) i--;
       pointType p;
-      p.interpole(x, constAt(i-1), constAt(i));
+      p.interpole(x, constAt(i-1), constAt(i), xSampling, ySampling);
       return p;
     }
   }
@@ -433,13 +443,13 @@ namespace QGpCoreMath {
     TRACE;
     if(count()<2) {
       if(isEmpty()) {
-        QVector<pointType>::append(p);
+        VectorList<pointType>::append(p);
       } else if(p.x()<firstX()) {
-        QVector<pointType>::prepend(p);
+        VectorList<pointType>::prepend(p);
       } else if(p.x()>firstX()) {
-        QVector<pointType>::append(p);
+        VectorList<pointType>::append(p);
       } else {
-        QVector<pointType>::operator[](0)=p;
+        VectorList<pointType>::operator[](0)=p;
       }
       _sorted=true;
     } else {
@@ -447,8 +457,9 @@ namespace QGpCoreMath {
       if(i<count() && x(i)==p.x()) {
         (*this)[i]=p;
       } else {
-        if(interpole(p.x()).y()!=p.y()) {
+        if(interpole(p.x(), LinearScale, LinearScale).y()!=p.y()) {
           insert(i, p);
+          _sorted=true;
         }
       }
     }
@@ -460,7 +471,7 @@ namespace QGpCoreMath {
   {
     TRACE;
     // Transforms X scale according to options (log and inv)
-    if(options & InversedScale) {
+    if(options & InverseScale) {
       xInverse();
       valX=1.0/valX;
     }
@@ -473,10 +484,10 @@ namespace QGpCoreMath {
       }
     }
     if(_sorted) {
-      if(min<QVector<pointType>::first().x())
-        min=QVector<pointType>::first().x();
-      if(max>QVector<pointType>::last().x())
-        max=QVector<pointType>::last().x();
+      if(min<VectorList<pointType>::first().x())
+        min=VectorList<pointType>::first().x();
+      if(max>VectorList<pointType>::last().x())
+        max=VectorList<pointType>::last().x();
     }
     int currentN=count();
 
@@ -500,10 +511,12 @@ namespace QGpCoreMath {
       Point2D p;
       int i;
       i=distances.indexAfter(min);
-      p.interpole(min, distances.constAt(i-1), distances.constAt(i));
+      p.interpole(min, distances.constAt(i-1), distances.constAt(i),
+                  LinearScale, LinearScale);
       distMin=p.y();
       i=distances.indexAfter(max);
-      p.interpole(max, distances.constAt(i-1), distances.constAt(i));
+      p.interpole(max, distances.constAt(i-1), distances.constAt(i),
+                  LinearScale, LinearScale);
       distMax=p.y();
     } else {
       distMin=0;
@@ -515,12 +528,13 @@ namespace QGpCoreMath {
     distances.swapXY();
 
     // Intepolate x for constant step distance
-    QVector<double> x(n);
+    VectorList<double> x(n);
     double dist=distMin;
     Point2D p;
     for(int i=0; i<n; i++, dist+=cstStep) {
       int iDist=distances.indexAfter(dist );
-      p.interpole(dist, distances.constAt(iDist-1), distances.constAt(iDist));
+      p.interpole(dist, distances.constAt(iDist-1), distances.constAt(iDist),
+                  LinearScale, LinearScale);
       x[i]=p.y();
     }
     resample(x);
@@ -529,7 +543,7 @@ namespace QGpCoreMath {
     if(options & LogScale) {
       xExp();
     }
-    if(options & InversedScale) {
+    if(options & InverseScale) {
       xInverse();
     }
   }
@@ -540,7 +554,7 @@ namespace QGpCoreMath {
     TRACE;
     ASSERT(_sorted);
     // Transforms X scale according to options (log and inv)
-    if(options & InversedScale) {
+    if(options & InverseScale) {
       xInverse();
       double tmp=min;
       min=1.0/max;
@@ -553,7 +567,7 @@ namespace QGpCoreMath {
     }
     // Calculate the constant step
     double cstStep=(max-min)/(n-1);
-    QVector<double> x(n);
+    VectorList<double> x(n);
     for(int i=0; i<n; i++) {
       x[i]=min+(double)i*cstStep;
     }
@@ -563,7 +577,7 @@ namespace QGpCoreMath {
     if(options & LogScale) {
       xExp();
     }
-    if(options & InversedScale) {
+    if(options & InverseScale) {
       xInverse();
     }
   }
@@ -573,7 +587,7 @@ namespace QGpCoreMath {
   {
     TRACE;
     ASSERT(_sorted);
-    QVector<double> x(xModel.count());
+    VectorList<double> x(xModel.count());
     for(int i=0; i<xModel.count(); i++) {
       x[i]=xModel.x(i);
     }
@@ -581,7 +595,7 @@ namespace QGpCoreMath {
   }
 
   template <class pointType>
-  void Curve<pointType>::resample(const QVector<double>& xModel)
+  void Curve<pointType>::resample(const VectorList<double>& xModel)
   {
     TRACE;
     ASSERT(_sorted);
@@ -600,7 +614,7 @@ namespace QGpCoreMath {
       }
       const pointType& p1=constAt(iCurve-1);
       const pointType& p2=constAt(iCurve);
-      interpolated[i].interpole(x, p1, p2);
+      interpolated[i].interpole(x, p1, p2, LinearScale, LinearScale);
       if(p1.isValid()) {
         if(p2.isValid()) {
           // Both are valid, avoid extrapolation
@@ -648,21 +662,22 @@ namespace QGpCoreMath {
     ASSERT(_sorted);
     // Assert that count()>1 is made by indexAfter()
     // Transforms X scale according to options (log and inv)
-    if(options & InversedScale) {
+    if(options & InverseScale) {
       xInverse();
     }
-    if(min<QVector<pointType>::first().x())
-      min=QVector<pointType>::first().x();
-    if(max>QVector<pointType>::last().x())
-      max=QVector<pointType>::last().x();
+    if(min<VectorList<pointType>::first().x())
+      min=VectorList<pointType>::first().x();
+    if(max>VectorList<pointType>::last().x())
+      max=VectorList<pointType>::last().x();
     // Find the first point
     int ix=indexAfter(min);
     if(ix>0) {
-      if(fabs(min-x(ix-1)) < 1e-15) {
+      if(fabs(min-x(ix-1))<1e-15) {
         ix--;
       } else if((options & Interpole) && fabs(min-x(ix))>1e-15) {
         ix--;
-        QVector<pointType>::operator[](ix).interpole(min, constAt(ix), constAt(ix+1));
+        VectorList<pointType>::operator[](ix).interpole(min, constAt(ix), constAt(ix+1),
+                                                     LinearScale, LinearScale);
       }
     }
     // Remove everything before
@@ -675,7 +690,8 @@ namespace QGpCoreMath {
       if(fabs(max-x(ix))<1e-15) {
         ix++;
       } else if((options & Interpole) && fabs(max-x(ix-1))>1e-15) {
-        QVector<pointType>::operator[](ix).interpole(max, constAt(ix-1), constAt(ix));
+        VectorList<pointType>::operator[](ix).interpole(max, constAt(ix-1), constAt(ix),
+                                                     LinearScale, LinearScale);
         ix++;
       }
     }
@@ -684,7 +700,7 @@ namespace QGpCoreMath {
       remove(i);
     }
     // Re-Transforms axis according options (log and inv)
-    if(options & InversedScale) {
+    if(options & InverseScale) {
       xInverse();
     }
   }
@@ -696,13 +712,26 @@ namespace QGpCoreMath {
     ASSERT(_sorted);
     // Assert that count()>1 is made by indexAfter()
     // Transforms X scale according to options (log and inv)
-    if(options & InversedScale) {
+    if(options & InverseScale) {
       xInverse();
     }
-    if(min<QVector<pointType>::first().x())
-      min=QVector<pointType>::first().x();
-    if(max>QVector<pointType>::last().x())
-      max=QVector<pointType>::last().x();
+    int firstIndex=0, lastIndex=count()-1;
+    firstValid(firstIndex);
+    lastValid(lastIndex);
+    if(firstIndex==count()) {
+      firstIndex=0;
+    }
+    if(lastIndex<0) {
+      lastIndex=count()-1;
+    }
+    double currentMin=constAt(firstIndex).x();
+    double currentMax=constAt(lastIndex).x();
+    if(min<currentMin) {
+      min=currentMin;
+    }
+    if(max>currentMax) {
+      max=currentMax;
+    }
     // Find the first and last points
     int ixs=indexAfter(min);
     int ixe=indexAfter(max);
@@ -720,10 +749,10 @@ namespace QGpCoreMath {
       ixe--;
     }
     for(int i=ixs; i<=ixe; i++) {
-      QVector<pointType>::operator[](i).setValid(value);
+      VectorList<pointType>::operator[](i).setValid(value);
     }
     // Re-Transforms axis according options (log and inv)
-    if(options & InversedScale) {
+    if(options & InverseScale) {
       xInverse();
     }
   }
@@ -767,7 +796,7 @@ namespace QGpCoreMath {
       if(i0==0) {
         i0++;
       }
-      sum.interpole(x, constAt(i0-1), constAt(i0));
+      sum.interpole(x, constAt(i0-1), constAt(i0), LinearScale, LinearScale);
       return sum;
     }
     switch(param.method()) {
@@ -796,7 +825,7 @@ namespace QGpCoreMath {
           sum/=sumWeight;
           sum.yExp();
           break;
-        case SamplingParameters::Inversed:
+        case SamplingParameters::Inverse:
           for(int i=i0; i<n; i++) {
             pointType p=constAt(i);
             p.yInverse();
@@ -837,7 +866,7 @@ namespace QGpCoreMath {
       return;
     }
     // Set the same sampling for both curves
-    QVector<double> x=xVector();
+    VectorList<double> x=xVector();
     x+=o.xVector();
     std::sort(x.begin(), x.end());
     ::QGpCoreTools::unique(x);
@@ -852,7 +881,7 @@ namespace QGpCoreMath {
     oResamp.resample(x);
     // Take the average of the two curves
     for(int i=x.count()-1; i>=0; i--) {
-      QVector<pointType>::operator[](i).average(oResamp.at(i));
+      VectorList<pointType>::operator[](i).average(oResamp.at(i));
     }
     sort();
   }
@@ -883,7 +912,7 @@ namespace QGpCoreMath {
   {
     TRACE;
     iterator it;
-    for(it=QVector<pointType>::begin(); it!=QVector<pointType>::end(); ++it) {
+    for(it=VectorList<pointType>::begin(); it!=VectorList<pointType>::end(); ++it) {
       double tmp=it->x();
       it->setX(it->y(pointOptions));
       it->setY(tmp, pointOptions);
@@ -912,6 +941,20 @@ namespace QGpCoreMath {
     return d;
   }
 
+  template <class pointType>
+  double Curve<pointType>::integrate(double from, double to, const CurvePointOptions * pointOptions) const
+  {
+    double sum=0.0;
+    int fromIndex=indexAfter(from);
+    int toIndex=indexAfter(to);
+    sum+=0.5*(interpole(from, LinearScale, LinearScale).y(pointOptions)+y(fromIndex, pointOptions))*(x(fromIndex)-from);
+    for(int i=fromIndex; i<toIndex; i++) {
+      sum+=0.5*(y(i-1, pointOptions)+y(i, pointOptions))*(x(i)-x(i-1));
+    }
+    sum+=0.5*(interpole(to, LinearScale, LinearScale).y(pointOptions)+y(toIndex-1, pointOptions))*(to-x(toIndex-1));
+    return sum;
+  }
+
   template <class pointType>
   Curve<pointType> Curve<pointType>::curvature(const CurvePointOptions * pointOptions) const
   {
@@ -1063,6 +1106,24 @@ namespace QGpCoreMath {
     }
   }
 
+  template <class pointType>
+  void Curve<pointType>::ySubtract(const Curve<pointType>& o, const CurvePointOptions * pointOptions)
+  {
+    if(isEmpty()) {
+      *this=o;
+      return;
+    }
+    int n=count();
+    if(n!=o.count()) {
+      App::log(tr("Curve::ySum(): uncompatible sampling (count=%1 & %2).\n").arg(n).arg(o.count()) );
+      return;
+    }
+    for(int i=0; i<n; i++) {
+      pointType& p=constXAt(i);
+      p.setY(p.y(pointOptions)-o.y(i, pointOptions), pointOptions);
+    }
+  }
+
   template <class pointType>
   void Curve<pointType>::yMultiply(double factor, const CurvePointOptions * pointOptions)
   {
@@ -1216,10 +1277,10 @@ namespace QGpCoreMath {
   }
 
   template <class pointType>
-  QVector<double> Curve<pointType>::xVector() const
+  VectorList<double> Curve<pointType>::xVector() const
   {
     int n=count();
-    QVector<double> x(n);
+    VectorList<double> x(n);
     for(int i=0; i<n; i++) {
       x[i]=Curve<pointType>::x(i);
     }
@@ -1251,6 +1312,20 @@ namespace QGpCoreMath {
     }
   }
 
+  template <class pointType>
+  void Curve<pointType>::lastValid(int& startIndex) const
+  {
+    int n=count();
+    if(startIndex<0) {
+      startIndex=0;
+    } else if(startIndex>=n) {
+      startIndex=n-1;
+    }
+    while(startIndex>=0 && !isValid(startIndex)) {
+      startIndex--;
+    }
+  }
+
   template <class pointType>
   int Curve<pointType>::minimumX(int startIndex) const
   {
@@ -1423,9 +1498,32 @@ namespace QGpCoreMath {
     else if(index>=n) {
       index=n;
       di=-1;
-    } else if(y(index)>y(index-1)) di=1;
-    else if(y(index)<y(index-1)) di=-1;
-    else return index;
+    } else if(y(index)>y(index-1)) {
+      di=1;
+    } else if(y(index)<y(index-1)) {
+      di=-1;
+    } else { // Values are the same, look for the maximum in both directions
+             // and keep the closest one.
+      int indexp=index;
+      while(indexp<n) {
+        if(y(indexp)<y(indexp-1)) {
+          indexp--;
+          break;
+        }
+        indexp+=1;
+      }
+      if(indexp==n) indexp--;
+      int indexm=index;
+      while(indexm>0) {
+        if(y(indexm)>y(indexm-1)) break;
+        indexm-=1;
+      }
+      if(indexp-index>index-indexm) {
+        return indexm;
+      } else {
+        return indexp;
+      }
+    }
 
     if(di>0) {
       while(index<n) {
@@ -1446,12 +1544,12 @@ namespace QGpCoreMath {
   }
 
   template <class pointType>
-  QString Curve<pointType>::toString(int precision, char format) const
+  QString Curve<pointType>::toString(char format, int precision) const
   {
     TRACE;
     QString s;
     for(const_iterator it=begin(); it!=end(); ++it) {
-      s+=it->toString(precision, format);
+      s+=it->toString(format, precision);
       s+="\n";
     }
     return s;
@@ -1535,7 +1633,7 @@ namespace QGpCoreMath {
     TRACE;
     int n=count();
     if(n>1) {
-      double invn=1.0/(double)n;
+      double invn=1.0/static_cast<double>(n);
       double sx=sumX();
       double sy=sumY(pointOptions);
       double sxy=sumXY(pointOptions);
@@ -1580,12 +1678,12 @@ namespace QGpCoreMath {
     Returns the distances along the profile
   */
   template <class pointType>
-  QVector<double> Curve<pointType>::project(const CurvePointOptions * pointOptions) const
+  VectorList<double> Curve<pointType>::project(const CurvePointOptions * pointOptions) const
   {
     TRACE;
     int n=count();
-    if(!n) return QVector<double>();
-    QVector<double> projections(n);
+    if(!n) return VectorList<double>();
+    VectorList<double> projections(n);
     if(n>1) {
       double a, b;
       double min=std::numeric_limits<double>::infinity();
@@ -1657,7 +1755,7 @@ namespace QGpCoreMath {
   }
 
   template <class pointType>
-  QList<Curve<pointType>> Curve<pointType>::split(double maxX,
+  QList<Curve<pointType> > Curve<pointType>::split(double maxX,
                                                   SamplingOptions options,
                                                   double maxErr,
                                                   int minCount,
@@ -1708,7 +1806,7 @@ namespace QGpCoreMath {
     int nc=splitter.clusterCount();
     QList<Curve<pointType>> list;
     for(int ic=0; ic<nc; ic++) {
-      QVector<int> indexList=splitter.pointIndex(ic);
+      VectorList<int> indexList=splitter.pointIndex(ic);
       int ni=indexList.count();
       if(ni>minCount) {
         Curve<pointType> c(ni);
