@@ -35,7 +35,7 @@ namespace QGpCoreMath {
     \class CurveSplitter CurveSplitter.h
     \brief Brief description of class still missing
 
-    Store relations between indexes (for instance of a QVector). A value is assigned
+    Store relations between indexes (for instance of a VectorList). A value is assigned
     to all added pairs of indexes. If some values are similar, indexes are considered
     as friends. Clusters are built with reciprocical friends.
 
@@ -293,12 +293,14 @@ namespace QGpCoreMath {
     for(int i=_items.count()-1; i>=0; i--) {
       _items[i].sortFriends(maxErr, np);
     }
-    Cluster c(proximity(np));
-    delete _clusters;
-    _clusters=c.singleLinkage();
-    if(App::verbosity()>=3) {
-      XMLHeader hdr(_clusters);
-      QTextStream(stdout) << hdr.xml_saveString() << Qt::endl;
+    if(np>0) {
+      Cluster c(proximity(np));
+      delete _clusters;
+      _clusters=c.singleLinkage();
+      if(App::verbosity()>=3) {
+        XMLHeader hdr(_clusters);
+        QTextStream(stdout) << hdr.xml_saveString() << Qt::endl;
+      }
     }
   }
 
@@ -308,12 +310,14 @@ namespace QGpCoreMath {
   void CurveSplitter::validSegments(double maxErr, const Curve<Point2D>& curve)
   {
     _validClusters.clear();
-    validSegments(_clusters, maxErr, curve);
+    if(_clusters) {
+      validSegments(_clusters, maxErr, curve);
+    }
   }
 
   void CurveSplitter::validSegments(Cluster::Node * clusters, double maxErr, const Curve<Point2D>& curve)
   {
-    QVector<int> indexList=clusters->indexList();
+    VectorList<int> indexList=clusters->indexList();
     int n=indexList.count();
     if(n>1) {  // Get rid of very small clusters
       std::sort(indexList.begin(), indexList.end());
@@ -339,11 +343,11 @@ namespace QGpCoreMath {
   /*!
     \a x is the unsorted list of x values
   */
-  void CurveSplitter::continuousSegments(const QVector<double>& x)
+  void CurveSplitter::continuousSegments(const VectorList<double>& x)
   {
     return;
     // Get a map of possible x values
-    QVector<double> xSort(x);
+    VectorList<double> xSort(x);
     std::sort(xSort.begin(), xSort.end());
     unique(xSort);
     QMap<double, int> xMap;
@@ -356,10 +360,10 @@ namespace QGpCoreMath {
   }
 
   void CurveSplitter::continuousSegments(Cluster::Node * clusters,
-                                         const QVector<double>& x,
+                                         const VectorList<double>& x,
                                          const QMap<double, int>& xMap)
   {
-    QVector<int> indexList=clusters->indexList();
+    VectorList<int> indexList=clusters->indexList();
     int n=indexList.count();
     if(n>1) {  // Get rid of small clusters
       std::sort(indexList.begin(), indexList.end());
