@@ -27,7 +27,7 @@
 #ifndef CURVESPLITTER_H
 #define CURVESPLITTER_H
 
-#include <QtCore>
+#include <QGpCoreTools.h>
 
 #include "QGpCoreMathDLLExport.h"
 #include "TriangularMatrix.h"
@@ -40,6 +40,7 @@ namespace QGpCoreMath {
 
   class QGPCOREMATH_EXPORT CurveSplitter
   {
+    TRANSLATIONS("CurveSplitter")
   public:
     CurveSplitter();
     ~CurveSplitter();
@@ -47,7 +48,7 @@ namespace QGpCoreMath {
     void addPair(int i1, int i2, double x0, double y0, double dx, double y1);
     void clusterize(double maxErr);
     void validSegments(double maxErr, const Curve<Point2D>& curve);
-    void continuousSegments(const QVector<double>& x);
+    void continuousSegments(const VectorList<double>& x);
   private:
     class Item;
 
@@ -57,7 +58,7 @@ namespace QGpCoreMath {
     Item * item(int index) {return &_items[index];}
     void validSegments(Cluster::Node * clusters, double maxErr, const Curve<Point2D>& curve);
     void continuousSegments(Cluster::Node * clusters,
-                            const QVector<double>& x,
+                            const VectorList<double>& x,
                             const QMap<double, int>& xMap);
 
     class ItemFriend
@@ -75,12 +76,6 @@ namespace QGpCoreMath {
         _dx=dx;
         _y=value;
       }
-      ItemFriend(const ItemFriend& o) {
-        _index=o._index;
-        _slope=o._slope;
-        _dx=o._dx;
-        _y=o._y;
-      }
 
       bool operator<(const ItemFriend& o) const {return _index<o._index;}
       bool operator==(const ItemFriend& o) const {return _index==o._index;}
@@ -103,11 +98,12 @@ namespace QGpCoreMath {
       double distanceTo(const FriendMap& o) const;
     private:
       bool * _map;
-      QVector<int> _list;
+      VectorList<int> _list;
     };
 
     class Item
     {
+      TRANSLATIONS("CurveSplitter::Item")
     public:
       Item();
       ~Item();
@@ -118,17 +114,17 @@ namespace QGpCoreMath {
 
       int _index;
       double _x, _y;
-      QVector<ItemFriend> _friends;
+      VectorList<ItemFriend> _friends;
       QList<FriendMap *> _goodFriends;
     };
 
-    QVector<Item> _items;
+    VectorList<Item> _items;
     Cluster::Node * _clusters;
-    QVector<QVector<int>> _validClusters;
+    VectorList<VectorList<int>> _validClusters;
 
   public:
     int clusterCount() const {return _validClusters.count();}
-    QVector<int> pointIndex(int cluster) const {return _validClusters.at(cluster);}
+    VectorList<int> pointIndex(int cluster) const {return _validClusters.at(cluster);}
   };
 
 } // namespace QGpCoreMath
