@@ -52,10 +52,9 @@ namespace QGpCoreMath {
 void DoubleMatrix::rotation(int axis1, int axis2, const Angle& angle)
 {
   TRACE;
-  int n=rowCount();
-  ASSERT(n==columnCount());
+  ASSERT(rowCount()==columnCount());
   ASSERT(axis1<axis2);
-  identity(0.0);
+  identity();
   at(axis1, axis1)=angle.cos();
   at(axis1, axis2)=-angle.sin();
   at(axis2, axis2)=angle.cos();
@@ -140,7 +139,7 @@ void DoubleMatrix::rotation3D(AxisType ax, const Angle& angle)
   }
 
   /*!
-    Based on LAPACK LU decomposition, for general matrix type.
+    Based on LAPACK LU decomposition, for square matrices.
   */
   bool DoubleMatrix::invert()
   {
@@ -175,6 +174,47 @@ void DoubleMatrix::rotation3D(AxisType ax, const Angle& angle)
     return true;
   }
 
+  /*!
+    Based on LAPACK LU decomposition, for square matrices.
+  */
+  double DoubleMatrix::determinant() const
+  {
+    ASSERT(rowCount()==columnCount());
+    int n=rowCount()*columnCount();
+    double * values=new double[n];
+    memcpy(values, _d->values(), sizeof(double)*n);
+    int m=rowCount();
+    if(m==1) {  // Not accepted by dgetrf
+      return values[0];
+    }
+    n=columnCount();                    // The order of matrix A
+    int lda=m;                          // The leading dimension of A
+    int * ipiv=new int[n];              // Pivot indices
+    int lwork=5*n;                      // Dimension of workspace
+    double * work=new double[lwork];    // work space
+    int info;                           // dimension of workspaces
+    dgetrf_(&m, &n, values, &lda, ipiv, &info);
+    double det;
+    if(info==0) { // Not singular matrix
+      det=1.0;
+      for(int i=0; i<n; i++) {
+        det*=values[i*(n+1)];
+      }
+      // Adjust sign according to the number of permutations
+      for(int i=0; i<n; i++) {
+        if(ipiv[i]!=i+1){  // Pivot indices in Fortran starting from 1
+          det=-det;
+        }
+      }
+    } else {
+      det=0.0;
+    }
+    delete [] values;
+    delete [] ipiv;
+    delete [] work;
+    return det;
+  }
+
   /*!
     Fills the matrix with random values between \a min and \a max
   */
@@ -198,7 +238,7 @@ void DoubleMatrix::rotation3D(AxisType ax, const Angle& angle)
   /*!
     Computes singular value decomposition U SIGMA Vt
   */
-  void DoubleMatrix::singularValues(QVector<double>& values, DoubleMatrix * u, DoubleMatrix * vt) const
+  void DoubleMatrix::singularValues(VectorList<double>& values, DoubleMatrix * u, DoubleMatrix * vt) const
   {
     int m=rowCount();
     int n=columnCount();
@@ -262,7 +302,7 @@ void DoubleMatrix::rotation3D(AxisType ax, const Angle& angle)
   /*!
     Compute eigen values of a symetric matrix
   */
-  QVector<double> DoubleMatrix::symetricEigenValues(bool& ok) const
+  VectorList<double> DoubleMatrix::symetricEigenValues(bool& ok) const
   {
     int m=rowCount();
     int n=columnCount();
@@ -277,7 +317,7 @@ void DoubleMatrix::rotation3D(AxisType ax, const Angle& angle)
       a[i]=aValues[i];
     }
 
-    QVector<double> values(minDim);
+    VectorList<double> values(minDim);
     double * d=values.data();
     double * e=new double[minDim-1];
     double * tau=new double[minDim-1];
@@ -372,9 +412,54 @@ void DoubleMatrix::rotation3D(AxisType ax, const Angle& angle)
     return x;
   }
 
+  extern "C" {
+    // LAPACK call for double precision matrix eigen values
+    void dgeev_(char *jobvl, char *jobvr, int *n,
+                double *a, int *lda,
+                double *wr, double *wi,
+                double *vl, int* ldvl, double *vr, int *ldvr,
+                double *work, int *lwork, int *info);
+  }
+
+  /*!
+    Eigen values for a general matrix
+  */
+  VectorList<Complex> DoubleMatrix::eigenValues() const
+  {
+    int n=rowCount();
+    ASSERT(n==columnCount());
+
+    int n2=n*n;
+    double * a=new double[n2];           // A copy of matrix values because its content will be destroyed
+    const double * aValues=values();
+    for(int i=0; i<n2; i++) {
+      a[i]=aValues[i];
+    }
+
+    char jobvl='N';
+    char jobvr='N';
+    int lda=n;
+    int info=0;
+    int ldvl=1;
+    int lwork=6*n;
+    double * work=new double[lwork];
+    double * wr=new double[n];
+    double * wi=new double[n];
+    dgeev_(&jobvl, &jobvr, &n, a, &lda, wr, wi, nullptr, &ldvl, nullptr, &ldvl, work, &lwork, &info);
+    delete [] work;
+    delete [] a;
+    VectorList<Complex> eigenValues(n);
+    for(int i=0; i<n; i++) {
+      eigenValues[i]=Complex(wr[i], wi[i]);
+    }
+    delete [] wr;
+    delete [] wi;
+    return eigenValues;
+  }
+
   double Matrix2x2::determinant() const
   {
-    return at(0, 0)*at(1, 1)-at(0, 1)*at(0, 1);
+    return at(0, 0)*at(1, 1)-at(0, 1)*at(1, 0);
   }
 
   Segment Matrix3x3::operator*(const Segment& s) const
