@@ -258,15 +258,19 @@ bool Grid2D<ValueType>::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
+  bool ok=true;
   switch(memberID) {
   case 0: _origin.fromString(content); return true;
   case 1:
-    _delta.fromString(content);
-    _invDelta.setX(1.0/_delta.x());
-    _invDelta.setY(1.0/_delta.y());
-    return true;
-  case 2: _nx=content.toInt(); return true;
-  case 3: _ny=content.toInt(); return true;
+    if(_delta.fromString(content)) {
+      _invDelta.setX(1.0/_delta.x());
+      _invDelta.setY(1.0/_delta.y());
+      return true;
+    } else {
+      return false;
+    }
+  case 2: _nx=content.toInt(ok); return ok;
+  case 3: _ny=content.toInt(ok); return ok;
   }
   return false;
 }
@@ -295,8 +299,8 @@ QTextStream& operator>>(QTextStream& s, Grid2D<ValueType>& grd)
     str=s.readLine().trimmed(); line++;
   }
   if(str=="x y val" ) {
-    QVector<Point2D> points;
-    QVector<ValueType> values;
+    VectorList<Point2D> points;
+    VectorList<ValueType> values;
     Point2D p;
     ValueType val;
     const QChar * ptr;
@@ -308,11 +312,23 @@ QTextStream& operator>>(QTextStream& s, Grid2D<ValueType>& grd)
       StringSection pStr(str);
       ptr=0;
       f=pStr.nextField(ptr);
-      if(f.isValid()) p.setX(f.toDouble()); else ok=false;
+      if(f.isValid()) {
+        p.setX(f.toDouble(ok));
+      } else {
+        ok=false;
+      }
       f=pStr.nextField(ptr);
-      if(f.isValid()) p.setY(f.toDouble()); else ok=false;
+      if(f.isValid()) {
+        p.setY(f.toDouble(ok));
+      } else {
+        ok=false;
+      }
       f=pStr.nextField(ptr);
-      if(f.isValid()) val=f.toDouble(); else ok=false;
+      if(f.isValid())  {
+        val=f.toDouble(ok);
+      } else  {
+        ok=false;
+      }
       if( !ok) {
         App::log(QCoreApplication::translate("Grid2D", "Wrong format at line %1, expected: float value\n").arg(line));
         return s;
@@ -323,7 +339,7 @@ QTextStream& operator>>(QTextStream& s, Grid2D<ValueType>& grd)
     // Deduce nx, ny, delta and origin from x and y vectors
     QMap<double,int> xMap, yMap;
     QMap<double,int>::iterator itMap;
-    for(QVector<Point2D>::iterator it=values.begin();it!=values.end(); it++) {
+    for(VectorList<Point2D>::iterator it=values.begin();it!=values.end(); it++) {
       itMap=xMap.find(it->x());
       if(itMap==xMap.end()) {
         xMap.insert(it->x(),0);
