@@ -38,11 +38,7 @@ namespace QGpCoreMath {
     GridSearchTest();
     ~GridSearchTest();
 
-    virtual double value(const Point& p) const;
-
-    virtual double thirdMinimum() const;
-    virtual double thirdMaximum() const;
-    virtual double thirdStep() const;
+    double value(Vector<double>& p) const;
   };
 
 } // namespace QGpCoreMath
