@@ -113,7 +113,7 @@ QTextStream& operator>>(QTextStream& s, IrregularGrid2D& grd)
               str=="x y z" ) {  // Compatibility with snapshot release
     QList<Point> values;
     Point p;
-    while( !s.atEnd()) {
+    while(!s.atEnd()) {
       str=s.readLine().trimmed(); line++;
       if(str.isEmpty() || str[0]=='#') break;
       StringSection pStr(str);
@@ -179,18 +179,18 @@ QTextStream& operator<<(QTextStream& s, const IrregularGrid2D& grd)
   }
 #if 0
   // Old format for grid, not practical for processing with matlab or gnuplot for instance
-  s << "nx=" << grd.nx() << endl;
-  s << "ny=" << grd.ny() << endl;
-  s << "x" << endl;
+  s << "nx=" << grd.nx() << Qt::endl;
+  s << "ny=" << grd.ny() << Qt::endl;
+  s << "x" << Qt::endl;
   int i;
-  for(i=0;i < grd.nx();i++ ) s << grd.x(i) << endl;
-  s << "y" << endl;
-  for(i=0;i < grd.ny();i++ ) s << grd.y(i) << endl;
-  s << "values" << endl;
+  for(i=0;i < grd.nx();i++ ) s << grd.x(i) << Qt::endl;
+  s << "y" << Qt::endl;
+  for(i=0;i < grd.ny();i++ ) s << grd.y(i) << Qt::endl;
+  s << "values" << Qt::endl;
   double * ptr=grd.valueAddress(0, 0);
   for(i=0;i < grd.ny();i++ ) {
     for(int ix=0;ix < grd.nx();ix++ )
-      s << *(ptr++ ) << " " << ix << " " << i << endl;
+      s << *(ptr++ ) << " " << ix << " " << i << Qt::endl;
   }
 #endif
   return s;
@@ -295,9 +295,25 @@ bool IrregularGrid2D::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
+  bool ok=true;
+  int n;
   switch(memberID) {
-  case 0: init(content.toInt(), ny()); return true;
-  case 1: init(nx(), content.toInt()); return true;
+  case 0:
+    n=content.toInt(ok);
+    if(ok && n>0) {
+      init(content.toInt(ok), ny());
+      return true;
+    } else {
+      return false;
+    }
+  case 1:
+    n=content.toInt(ok);
+    if(ok && n>0) {
+      init(nx(), content.toInt(ok));
+      return true;
+    } else {
+      return false;
+    }
   default: return false;
   }
 }
