@@ -30,7 +30,6 @@
 #define IrregularGrid2D_H
 
 #include "IrregularGrid2DData.h"
-#include "GridSearch.h"
 
 namespace QGpCoreMath {
 
@@ -58,7 +57,7 @@ public:
   void setLinear(AxisType axis, double min, double max) {_d->setLinear(axis, min, max);}
   void setLog(AxisType axis, double min, double max) {_d->setLog(axis, min, max);}
   // Resample the grid at x defined by xModel (e.g. from another curve)
-  void resample(AxisType axis, const QVector<double>& xModel) {_d->resample(axis, xModel);}
+  void resample(AxisType axis, const VectorList<double>& xModel) {_d->resample(axis, xModel);}
   void resample(AxisType axis, int n, double min, double max, SamplingOptions options) {_d->resample(axis, n, min, max, options);}
   // Cut function between two x values
   void cut(AxisType axis, double min, double max, SamplingOptions options) {_d->cut(axis, min, max, options);}
@@ -76,8 +75,9 @@ public:
   void setValue(int ix, int iy, double val) {return _d->setValue(ix, iy, val);}
   double * valuePointer(int ix, int iy) {return _d->valuePointer(ix, iy);}
   const double * valuePointer(int ix, int iy) const {return _d->valuePointer(ix, iy);}
-  QVector<double> x() const {return _d->x();}
-  QVector<double> y() const {return _d->y();}
+  double valueAt(const Point2D& p) const {return _d->valueAt(p);}
+  VectorList<double> x() const {return _d->x();}
+  VectorList<double> y() const {return _d->y();}
   double x(int ix) const {return _d->x(ix);}
   double y(int iy) const {return _d->y(iy);}
   void setX(int ix, double val) {_d->setX(ix,val);}
@@ -91,14 +91,16 @@ public:
   double maximumAxis(AxisType axis) const {return _d->maximumAxis(axis);}
   double minimumValue(AxisType along, int index, int& minIndex) const {return _d->minimumValue(along, index, minIndex);}
   double maximumValue(AxisType along, int index, int& maxIndex) const {return _d->maximumValue(along, index, maxIndex);}
-  double sum(AxisType along, int index) const {return _d->sum(along, index);}
+
+  // Obsolete functions, used only in max2curve
   double mean(AxisType along, int index) const {return _d->mean(along, index);}
   double median(AxisType along, int index) const {return _d->median(along, index);}
   double mode(AxisType along, int index) const {return _d->mode(along, index);}
   double variance(AxisType along, int index) const {return _d->variance(along, index);}
   double variance(AxisType along, int index, double average) const {return _d->variance(along, index, average);}
   double varianceFit(AxisType along, int index, double average) const {return _d->varianceFit(along, index, average);}
-  double misfit(AxisType along, int index, const GaussDistribution& gd) const {return _d->misfit(along, index, gd);}
+
+  double misfit(AxisType along, int index, const NormalDistribution& gd) const {return _d->misfit(along, index, gd);}
   double normalizeArea(AxisType along, int index) {return _d->normalizeArea(along, index);}
   void normalizeArea(AxisType along) {_d->normalizeArea(along);}
   double normalizeAmplitude(AxisType along, int index) {return _d->normalizeAmplitude(along, index);}
@@ -128,8 +130,9 @@ public:
   template <class CurveClass, class PointClass> CurveClass followMaximumX(int ixMin, int ixMax, int iyMax) const {
     return _d->followMaximumX<CurveClass, PointClass>(ixMin, ixMax, iyMax);
   }
-  template <class CurveClass, class PointClass> void followMaximumX(CurveClass& curve, double min, double max) const {
-    return _d->followMaximumX<CurveClass, PointClass>(curve, min, max);
+  template <class CurveClass, class PointClass> void followMaximumX(CurveClass& curve, double min, double max,
+                                                                    const CurvePointOptions * pointOptions=nullptr) const {
+    return _d->followMaximumX<CurveClass, PointClass>(curve, min, max, pointOptions);
   }
   template <class CurveClass, class PointClass> CurveClass followMaximumY() const {
     return _d->followMaximumY<CurveClass, PointClass>();
@@ -137,8 +140,9 @@ public:
   template <class CurveClass, class PointClass> CurveClass followMaximumY(int iyMin, int iyMax, int ixMax) const {
     return _d->followMaximumY<CurveClass, PointClass>(iyMin, iyMax, ixMax);
   }
-  template <class CurveClass, class PointClass> void followMaximumY(CurveClass& curve, double min, double max) const {
-    return _d->followMaximumY<CurveClass, PointClass>(curve, min, max);
+  template <class CurveClass, class PointClass> void followMaximumY(CurveClass& curve, double min, double max,
+                                                                    const CurvePointOptions * pointOptions=nullptr) const {
+    return _d->followMaximumY<CurveClass, PointClass>(curve, min, max, pointOptions);
   }
   // Geometries of cells
   double width(int ix) const {return _d->width(ix);}
