@@ -70,7 +70,7 @@ namespace QGpCoreMath {
     case SamplingParameters::Log:
       _b->at(index, 0)=::log(y);
       break;
-    case SamplingParameters::Inversed:
+    case SamplingParameters::Inverse:
       _b->at(index, 0)=1.0/y;
       break;
     }
@@ -89,7 +89,7 @@ namespace QGpCoreMath {
       break;
     case SamplingParameters::Log:
       return ::exp(sum);
-    case SamplingParameters::Inversed:
+    case SamplingParameters::Inverse:
       return 1.0/sum;
     }
     return sum;
