@@ -41,7 +41,6 @@ namespace QGpCoreMath {
     inline Line2D(double b, double c);
     Line2D(const Point2D& p1, const Point2D& p2);
     Line2D(double x1, double y1, double az);
-    inline Line2D(const Line2D& o);
     ~Line2D() {}
 
     Point2D intersect(const Line2D& o, bool& ok) const;
@@ -74,13 +73,6 @@ namespace QGpCoreMath {
     _c=c;
   }
 
-  inline Line2D::Line2D(const Line2D &o)
-  {
-    _a=o._a;
-    _b=o._b;
-    _c=o._c;
-  }
-
 } // namespace QGpCoreMath
 
 #endif // LINE2D.H
