@@ -42,48 +42,66 @@ namespace QGpCoreMath {
   template <typename T> class MutableMatrixRowIterator;
   template <typename T> class MatrixColumnIterator;
   template <typename T> class MutableMatrixColumnIterator;
-  template <typename T> class Vector;
 
   template <typename T> class QGPCOREMATH_EXPORT Matrix
   {
   public:
     Matrix() {_d=new MatrixData<T>;}
-    Matrix(int ndim) {_d=new MatrixData<T>; _d->resize(ndim);}
-    Matrix(int nrow, int ncol) {_d=new MatrixData<T>; _d->resize(nrow, ncol);}
+    Matrix(int ndim) {_d=new MatrixData<T>(ndim);}
+    Matrix(int nrow, int ncol) {_d=new MatrixData<T>(nrow, ncol);}
     Matrix(const Matrix<T>& o) : _d(o._d) {}
 
+    bool operator<(const Matrix<T>& m) const {return _d->operator<(*m._d);}
+    bool operator>(const Matrix<T>& m) const {return _d->operator<(*m._d);}
     Matrix<T> operator=(const Matrix<T>& m) {_d=m._d; return *this;}
     bool operator==(const Matrix<T>& m) const {return _d->operator==(*m._d);}
     bool operator!=(const Matrix<T>& m) const {return !_d->operator==(*m._d);}
     Matrix<T> operator+(const Matrix<T>& m) const {return _d->operator+(*m._d);}
-    void operator+=(const Matrix<T>& m);
+    void operator+=(const Matrix<T>& m) {_d->operator+=(*m._d);}
+    Matrix<T> operator-() const {return _d->operator-();}
     Matrix<T> operator-(const Matrix<T>& m) const {return _d->operator-(*m._d);}
-    void operator-=(const Matrix<T>& m);
+    void operator-=(const Matrix<T>& m) {_d->operator-=(*m._d);}
     Matrix<T> operator*(const Matrix<T>& m) const {return _d->operator*(*m._d);}
-    Vector<T> operator*(const Vector<T>& v) const {return _d->operator*(v);}
+    Matrix<T> operator*(const T& v) const {return _d->operator*(v);}
+    T scalarProduct(const Matrix<T>& m) const {return _d->scalarProduct(*m._d);}
     Matrix<T> dotMultiply(const Matrix<T>& m) const {return _d->dotMultiply(*m._d);}
+    void multiply(const Vector<T>& column, const Vector<T>& row, const T& factor) {_d->multiply(column, row, factor);}
     void operator*=(const Matrix<T>& m);
     void operator*=(const T& v) {_d->operator*=(v);}
-    void zero(const T& null) {_d->fill(null);}
-    void identity(const T& null) {_d->identity(null);}
+    void operator/=(const T& v) {_d->operator/=(v);}
+    void zero() {_d->fill(0);}
+    void identity() {_d->identity();}
+    void identity(const T& factor) {_d->identity(factor);}
+    void addIdentity() {_d->addIdentity();}
     void fill(const T& v) {_d->fill(v);}
     T& at(int row, int col) {return _d->at(row, col);}
     const T& at(int row, int col) const {return _d->at(row, col);}
+    T& at(int index) {return _d->at(index);}
+    const T& at(int index) const {return _d->at(index);}
     const T * values() const {return _d->values();}
     T * values() {return _d->values();}
+    T minimum() const {return _d->minimum();}
+    T maximum() const {return _d->maximum();}
     T * copyOfValues() const {return _d->copyOfValues();}
-    QVector<T> rowAt(int row) const;
-    QVector<T> columnAt(int col) const;
+    VectorList<T> rowAt(int row) const;
+    VectorList<T> columnAt(int col) const;
     Matrix<T> transposed() const {return _d->transposed();}
+    Matrix<T> transposedVector() const;
     void transpose() {*this=transposed();}
+    void transposeVector() {_d->transposeVector();}
     T trace(const T& null) const {return _d->trace(null);}
+    void abs() {_d->abs();}
     void mergeRow(const Matrix<T>& row1, const Matrix<T>& row2) {_d->mergeRow(*row1._d, *row2._d);}
     void mergeColumn(const Matrix<T>& col1, const Matrix<T>& col2) {_d->mergeColumn(*col1._d, *col2._d);}
     void copyAt(int row, int col, const Matrix<T>& m, int nRow=-1, int nCol=-1) {_d->copyAt(row, col, *m._d, nRow, nCol);}
+    void copySubMatrixAt(int row, int col, const Matrix<T>& m, int mRow, int mCol, int nRow=-1, int nCol=-1, double factor=1.0) {
+      _d->copySubMatrixAt(row, col, *m._d, mRow, mCol, nRow, nCol, factor);
+    }
     Matrix<T> subMatrix(int rowStart, int colStart, int rowEnd, int colEnd) const {return _d->subMatrix(rowStart, colStart, rowEnd, colEnd);}
     Matrix<T> sortedRows(const PermutationVector& p) {return _d->sortedRows(p);}
     Matrix<T> sortedColumns(const PermutationVector& p) {return _d->sortedColumns(p);}
 
+    bool isVector() const {return _d->isVector();}
     bool isEmpty() const {return _d->columnCount()==0 || _d->rowCount()==0;}
     int columnCount() const {return _d->columnCount();}
     int rowCount() const {return _d->rowCount();}
@@ -97,6 +115,7 @@ namespace QGpCoreMath {
     QString toGridString() const {return _d->toGridString();}
     QString toString() const {return _d->toString();}
     bool fromString(const StringSection& s) {return _d->fromString(s);}
+    void toOctaveFile(const QString& fileName, const QString& variableName) const {_d->toOctaveFile(fileName, variableName);}
   protected:
     void swapRowColumn() {_d->swapRowColumn();}
 
@@ -122,6 +141,16 @@ namespace QGpCoreMath {
     return r;
   }
 
+  template <typename T> Matrix<T> MatrixData<T>::operator-() const
+  {
+    Matrix<T> r(_nrow, _ncol);
+    T * rValues=r._d->values();
+    for(int i=_nrow*_ncol-1; i>=0; i--) {
+      rValues[i]=-_values[i];
+    }
+    return r;
+  }
+
   template <typename T> Matrix<T> MatrixData<T>::operator-(const MatrixData<T>& m) const
   {
     ASSERT(_nrow==m._nrow && _ncol==m._ncol);
@@ -133,11 +162,22 @@ namespace QGpCoreMath {
     return r;
   }
 
+  template <typename T> Matrix<T> MatrixData<T>::operator*(const T& v) const
+  {
+    Matrix<T> r(_nrow, _ncol);
+    T * rValues=r._d->_values;
+    const T * thisValues=_values;
+    for(int i=_nrow*_ncol-1; i>=0; i--) {
+      rValues[i]=thisValues[i]*v;
+    }
+    return r;
+  }
+
   template <typename T> Matrix<T> MatrixData<T>::operator*(const MatrixData<T>& m) const
   {
     ASSERT(_ncol==m._nrow);
     Matrix<T> rMatrix(_nrow, m._ncol);
-    rMatrix.zero(0.0);
+    rMatrix.zero();
     T * r=rMatrix._d->_values;
     const T * m1=_values;
     const T * m2;
@@ -166,33 +206,6 @@ namespace QGpCoreMath {
     return rMatrix;
   }
 
-  template <typename T> Vector<T> MatrixData<T>::operator*(const Vector<T>& m) const
-  {
-    ASSERT(_ncol==m.rowCount());
-    Vector<T> rMatrix(_nrow);
-    rMatrix.zero(0.0);
-    T * r=rMatrix._d->_values;
-    const T * m1=_values;
-    const T * m2=m._d->_values;
-    const T * m1_end=m1+_nrow;
-    T * r0;
-    const T * m10, * m20, * m20_end;
-    while(m1<m1_end) {
-      r0=r;
-      m10=m1;
-      m20=m2;
-      m20_end=m2+_ncol;
-      while(m20<m20_end) {
-        *r0+=*m10**m20;
-        m10+=_nrow;
-        m20++;
-      }
-      m1++;
-      r++;
-    }
-    return rMatrix;
-  }
-
   template <typename T> Matrix<T> MatrixData<T>::dotMultiply(const MatrixData<T>& m) const
   {
     ASSERT(_ncol==m._ncol);
@@ -219,6 +232,19 @@ namespace QGpCoreMath {
     return t;
   }
 
+  template <typename T> void MatrixData<T>::transposeVector()
+  {
+    ASSERT(isVector());
+    qSwap(_nrow, _ncol);
+  }
+
+  template <typename T> Matrix<T> Matrix<T>::transposedVector() const
+  {
+    Matrix<T> t(*this);
+    t.transposeVector();
+    return t;
+  }
+
   template <typename T> Matrix<T> MatrixData<T>::subMatrix(int rowStart, int colStart, int rowEnd, int colEnd) const
   {
     ASSERT(rowStart>=0 && rowStart<=rowEnd && rowEnd<_nrow);
@@ -267,19 +293,9 @@ namespace QGpCoreMath {
     *this=_d->operator*(*m._d);
   }
 
-  template <typename T> inline void Matrix<T>::operator+=(const Matrix<T>& m)
+  template <typename T> VectorList<T> Matrix<T>::rowAt(int row) const
   {
-    *this=_d->operator+(*m._d);
-  }
-
-  template <typename T> inline void Matrix<T>::operator-=(const Matrix<T>& m)
-  {
-    *this=_d->operator-(*m._d);
-  }
-
-  template <typename T> QVector<T> Matrix<T>::rowAt(int row) const
-  {
-    QVector<T> r(columnCount());
+    VectorList<T> r(columnCount());
     MatrixColumnIterator<T> it(*this, row);
     int i=0;
     while(it.hasNext()) {
@@ -288,9 +304,9 @@ namespace QGpCoreMath {
     return r;
   }
 
-  template <typename T> QVector<T> Matrix<T>::columnAt(int col) const
+  template <typename T> VectorList<T> Matrix<T>::columnAt(int col) const
   {
-    QVector<T> r(rowCount());
+    VectorList<T> r(rowCount());
     MatrixColumnIterator<T> it(*this, col);
     int i=0;
     while(it.hasNext()) {
