@@ -42,31 +42,52 @@ namespace QGpCoreMath {
   {
   public:
     inline MatrixData();
+    inline MatrixData(int ndim);
+    inline MatrixData(int nrow, int ncol);
     inline MatrixData(const MatrixData<T>& m);
     inline ~MatrixData();
 
     inline void operator=(const MatrixData<T>& m);
     inline bool operator==(const MatrixData<T>& m) const;
+    bool operator<(const MatrixData<T>& m) const;
+    bool operator>(const MatrixData<T>& m) const;
     Matrix<T> operator+(const MatrixData<T>& m) const;
+    void operator+=(const MatrixData<T>& m);
+    Matrix<T> operator-() const;
     Matrix<T> operator-(const MatrixData<T>& m) const;
+    void operator-=(const MatrixData<T>& m);
+    Matrix<T> operator*(const T& v) const;
     Matrix<T> operator*(const MatrixData<T>& m) const;
     Vector<T> operator*(const Vector<T>& v) const;
+    T scalarProduct(const MatrixData<T>& m) const;
     Matrix<T> dotMultiply(const MatrixData<T>& m) const;
+    void multiply(const Vector<T>& column, const Vector<T>& row, const T& factor);
     void operator*=(const T& v) const;
-    void zero(const T& null) {fill(null);}
-    void identity(const T& null);
+    void operator/=(const T& v) const;
+    void identity();
+    void identity(const T& factor);
+    void addIdentity();
     void fill(const T& v);
     inline T& at(int row, int col);
     inline const T& at(int row, int col) const;
+    inline T& at(int index);
+    inline const T& at(int index) const;
+    T minimum() const;
+    T maximum() const;
     Matrix<T> transposed() const;
+    void transposeVector();
+    Matrix<T> transposedVector() const;
     T trace(const T& null) const;
+    void abs();
     void mergeRow(const MatrixData<T>& row1, const MatrixData<T>& row2);
     void mergeColumn(const MatrixData<T>& col1, const MatrixData<T>& col2);
     void copyAt(int row, int col, const MatrixData<T>& m, int nRow, int nCol);
+    void copySubMatrixAt(int row, int col, const MatrixData<T>& m, int mRow, int mCol, int nRow, int nCol, double factor);
     Matrix<T> subMatrix(int rowStart, int colStart, int rowEnd, int colEnd) const;
     Matrix<T> sortedRows(const PermutationVector& p);
     Matrix<T> sortedColumns(const PermutationVector& p);
 
+    bool isVector() const {return _nrow==1 || _ncol==1;}
     int columnCount() const {return _ncol;}
     int rowCount() const {return _nrow;}
     T * values() {return _values;}
@@ -84,6 +105,7 @@ namespace QGpCoreMath {
     QString toGridString() const;
     QString toString() const;
     bool fromString(const StringSection& s);
+    void toOctaveFile(const QString& fileName, const QString& variableName) const;
 
     void swapRowColumn();
   protected:
@@ -99,15 +121,28 @@ namespace QGpCoreMath {
     _values=nullptr;
   }
 
+  template <typename T> inline MatrixData<T>::MatrixData(int ndim)
+     : QSharedData()
+  {
+    _nrow=ndim;
+    _ncol=ndim;
+    _values=new T[_nrow*_ncol];
+  }
+
+  template <typename T> inline MatrixData<T>::MatrixData(int nrow, int ncol)
+     : QSharedData()
+  {
+    _nrow=nrow;
+    _ncol=ncol;
+    _values=new T[_nrow*_ncol];;
+  }
+
   template <typename T> inline MatrixData<T>::MatrixData(const MatrixData<T>& m)
      : QSharedData()
   {
     _values=nullptr;
     resize(m._nrow, m._ncol);
-    // Using memcpy, we get awful warnings about non trivial copy constructor for Complex
-    for(int i=_nrow*_ncol-1; i>=0; i--) {
-      _values[i]=m._values[i];
-    }
+    memcpy(_values, m._values, sizeof(T)*_nrow*_ncol);
   }
 
   template <typename T> inline MatrixData<T>::~MatrixData()
@@ -118,10 +153,27 @@ namespace QGpCoreMath {
   template <typename T> inline void MatrixData<T>::operator=(const MatrixData<T>& m)
   {
     resize(m._nrow, m._ncol);
-    // Using memcpy, we get awful warnings about non trivial copy constructor for Complex
+    memcpy(_values, m._values, sizeof(T)*_nrow * _ncol);
+  }
+
+  template <typename T> bool MatrixData<T>::operator<(const MatrixData<T>& m) const
+  {
     for(int i=_nrow*_ncol-1; i>=0; i--) {
-      _values[i]=m._values[i];
+      if(_values[i]<m._values[i]) {
+        return true;
+      }
     }
+    return false;
+  }
+
+  template <typename T> bool MatrixData<T>::operator>(const MatrixData<T>& m) const
+  {
+    for(int i=_nrow*_ncol-1; i>=0; i--) {
+      if(_values[i]>m._values[i]) {
+        return true;
+      }
+    }
+    return false;
   }
 
   template <typename T> inline void MatrixData<T>::resize(int nrow, int ncol)
@@ -147,12 +199,51 @@ namespace QGpCoreMath {
     return true;
   }
 
-  template <typename T> inline void MatrixData<T>::identity(const T& null)
+  template <typename T> void MatrixData<T>::operator+=(const MatrixData<T>& m)
   {
-    fill(null);
-    int offset=_ncol+1;
+    ASSERT(_nrow==m._nrow && _ncol==m._ncol);
+    for(int i=_nrow*_ncol-1; i>=0; i--) {
+      _values[i]+=m._values[i];
+    }
+  }
+
+  template <typename T> void MatrixData<T>::operator-=(const MatrixData<T>& m)
+  {
+    ASSERT(_nrow==m._nrow && _ncol==m._ncol);
+    for(int i=_nrow*_ncol-1; i>=0; i--) {
+      _values[i]-=m._values[i];
+    }
+  }
+
+template <typename T> void MatrixData<T>::operator*=(const T& v) const
+{
+  for(int i=_nrow*_ncol-1; i>=0;i--) {
+    _values[i]*=v;
+  }
+}
+
+template <typename T> void MatrixData<T>::operator/=(const T& v) const
+{
+  T inv=1.0/v;
+  for(int i=_nrow*_ncol-1; i>=0;i--) {
+    _values[i]*=inv;
+  }
+}
+
+  template <typename T> inline void MatrixData<T>::identity()
+  {
+    fill(0);
+    int offset=_nrow+1;
     int n=_nrow*_ncol;
-    for(int i=0; i<n; i+=offset) _values[i]=1.0;
+    for(int i=0; i<n; i+=offset) _values[i]=1;
+  }
+
+  template <typename T> inline void MatrixData<T>::identity(const T& factor)
+  {
+    fill(0);
+    int offset=_nrow+1;
+    int n=_nrow*_ncol;
+    for(int i=0; i<n; i+=offset) _values[i]=factor;
   }
 
   template <typename T> void MatrixData<T>::fill(const T& v)
@@ -186,6 +277,18 @@ namespace QGpCoreMath {
     return _values[col*_nrow+row];
   }
 
+  template <typename T> inline T& MatrixData<T>::at(int index)
+  {
+    ASSERT(index>=0 && index<_ncol*_nrow);
+    return _values[index];
+  }
+
+  template <typename T> inline const T& MatrixData<T>::at(int index) const
+  {
+    ASSERT(index>=0 && index<_ncol*_nrow);
+    return _values[index];
+  }
+
   template <typename T> void MatrixData<T>::mergeRow(const MatrixData<T>& row1, const MatrixData<T>& row2)
   {
     ASSERT(row1._ncol==row2._ncol);
@@ -334,6 +437,18 @@ namespace QGpCoreMath {
     return true;
   }
 
+  template <typename T> void MatrixData<T>::toOctaveFile(const QString& fileName, const QString& variableName) const
+  {
+    QFile f(fileName);
+    if(!f.open(QIODevice::Append)) {
+      App::log(tr("Cannot write to %1\n").arg(fileName));
+      return;
+    }
+    QTextStream s(&f);
+    s << variableName << "=" << toOctaveString('g', 20) << ";" << Qt::endl;
+    f.close();
+  }
+
   template <typename T> void MatrixData<T>::copyAt(int row, int col, const MatrixData<T>& m, int nRow, int nCol)
   {
     T * thisValues=_values;
@@ -381,16 +496,134 @@ namespace QGpCoreMath {
     }
   }
 
+  template <typename T>
+  void MatrixData<T>::copySubMatrixAt(int row, int col, const MatrixData<T>& m,
+                                      int mRow, int mCol, int nRow, int nCol,
+                                      double factor)
+  {
+    T * thisValues=_values;
+    T * values=m._values;
+
+    if(nRow<0) {
+      nRow=m.rowCount();
+    }
+    thisValues+=row;
+    values+=mRow;
+    if(row+nRow>_nrow) {
+      nRow=_nrow-row;
+    }
+
+    if(nCol<0) {
+      nCol=m.columnCount();
+    }
+    thisValues+=col*_nrow;
+    values+=mCol*m.rowCount();
+    if(col+nCol>_ncol) {
+      nCol=_ncol-col;
+    }
+
+    T * lastValue=values+nCol*m.rowCount();
+    ASSERT(nRow>0);
+    if(factor==1.0) {
+      int length=sizeof(T)*nRow;
+      while(values<lastValue) {
+        memcpy(thisValues, values, length);
+        values+=m.rowCount();
+        thisValues+=_nrow;
+      }
+    } else {
+      while(values<lastValue) {
+        for(int i=0; i<nRow; i++) {
+          thisValues[i]=values[i]*factor;
+        }
+        values+=m.rowCount();
+        thisValues+=_nrow;
+      }
+    }
+  }
+
+  template <typename T> T MatrixData<T>::scalarProduct(const MatrixData<T>& m) const
+  {
+    ASSERT(_ncol==1 && m._ncol==1); // Vectors
+    ASSERT(_nrow==m._nrow);
+    T s=0.0;
+    for(int i=_nrow-1; i>=0; i--) {
+      s+=_values[i]*m._values[i];
+    }
+    return s;
+  }
+
+  template <typename T> void MatrixData<T>::abs()
+  {
+    for(int i=_nrow*_ncol-1; i>=0; i--) {
+      _values[i]=QGpCoreTools::abs(_values[i]);
+    }
+  }
+
+  template <typename T> T MatrixData<T>::minimum() const
+  {
+    int i=_nrow*_ncol-1;
+    if(i>0) {
+      T m=_values[i];
+      for(i--; i>=0; i--) {
+        if(_values[i]<m) {
+          m=_values[i];
+        }
+      }
+      return m;
+    } else {
+      return 0.0;
+    }
+  }
+
+  template <typename T> T MatrixData<T>::maximum() const
+  {
+    int i=_nrow*_ncol-1;
+    if(i>0) {
+      T m=_values[i];
+      for(i--; i>=0; i--) {
+        if(_values[i]>m) {
+          m=_values[i];
+        }
+      }
+      return m;
+    } else {
+      return 0.0;
+    }
+  }
+
   template <typename T> T* MatrixData<T>::copyOfValues() const
   {
     int mn=_nrow*_ncol;
-    double * a=new T[mn];
-    for(int i=mn-1; i>=0; i--) {
-      a[i]=_values[i];
-    }
+    T * a=new T[mn];
+    memcpy(a, _values, mn*sizeof(T));
     return a;
   }
 
+  template <typename T>
+  void MatrixData<T>::multiply(const Vector<T>& column, const Vector<T>& row, const T& factor)
+  {
+    ASSERT(static_cast<int>(column.count())==_nrow &&
+           static_cast<int>(row.count())==_ncol);
+    T * r=_values;
+    const T * m1=column.values();
+    const T * m2=row.values();
+    for(int i=0; i<_ncol; i++) {
+      T v1f=m2[i]*factor;
+      for(int j=0; j<_nrow; j++) {
+        *(r++)=v1f*m1[j];
+      }
+    }
+  }
+
+  template <typename T>
+  void MatrixData<T>::addIdentity()
+  {
+    int offset=_nrow+1;
+    int n=_nrow*_ncol;
+    for(int i=0; i<n; i+=offset) _values[i]+=1;
+  }
+
 } // namespace QGpCoreMath
 
 #endif // MATRIXDATA_H
