@@ -48,8 +48,7 @@ public:
   inline Point(const QPoint& p);
   inline Point(const QPointF& p);
   inline Point(const Point2D& p);
-  inline Point(const Point& p);
-  inline Point(const QVector<double>& p);
+  inline Point(const VectorList<double>& p);
 
   double z() const {return _z;}
   void setZ(double v) {_z=v;}
@@ -59,7 +58,6 @@ public:
   inline void average(const Point& p);
 
   // Copy operators
-  inline Point& operator=(const Point& p);
   inline Point& operator=(const Point2D& p);
   inline void set(double xi, double yi, double zi=0.0);
 
@@ -95,10 +93,11 @@ public:
 
   // I/O functions
   bool fromString(const StringSection& str);
-  QString toString(int precision=6, char format='g') const;
+  QString toString(char format='g', int precision=6) const;
 
   double length() const {return ::sqrt(x()*x()+y()*y()+_z*_z);}
   double distanceTo(const Point &p) const;
+  double horizontalDistanceTo(const Point &p) const;
   double distanceToSegment(const Point &p1, const Point &p2) const;
   double elevationTo(const Point &p) const;
   void move(double distance, const Angle& azimuth, const Angle& elevation);
@@ -145,19 +144,6 @@ inline Point::Point(const Point2D& p)
   _z=0.0;
 }
 
-inline Point::Point(const Point& p)
-  : Point2D(p)
-{
-  _z=p._z;
-}
-
-inline Point& Point::operator=(const Point& p)
-{
-  Point2D::operator=(p);
-  _z=p._z;
-  return *this;
-}
-
 inline Point& Point::operator=(const Point2D& p)
 {
   Point2D::operator=(p);
