@@ -59,11 +59,11 @@ namespace QGpCoreMath {
   /*!
     Copy constructor from a vector
   */
-  Point2D::Point2D(const QVector<double>& p)
+  Point2D::Point2D(const VectorList<double>& p)
   {
     ASSERT(p.count()>1);
-    _x=p.at(0);
-    _y=p.at(1);
+    _x[0]=p.at(0);
+    _x[1]=p.at(1);
   }
 
   /*!
@@ -81,17 +81,27 @@ namespace QGpCoreMath {
     Always return true. Used by Curve.
   */
 
+  /*!
+    \fn double Point2D::scalarProduct(const Point2D& p) const
+    Returns scalar product of this with point \a p.
+  */
+
+  /*!
+    \fn double Point2D::scalarProduct(const double * p) const
+    Returns scalar product of this with array \a p supposed to have two elements.
+  */
+
   /*!
     Returns the point as a string with space separation between coordinates.
     \a precision is the number of significant digits. \a format is 'g' or 'f'.
   */
-  QString Point2D::toString(int precision, char format) const
+  QString Point2D::toString(char format, int precision) const
   {
     TRACE;
     QString tmp;
-    tmp+=QString::number(_x, format, precision);
+    tmp+=QString::number(_x[0], format, precision);
     tmp+=" ";
-    tmp+=QString::number(_y, format, precision);
+    tmp+=QString::number(_x[1], format, precision);
     return tmp;
   }
 
@@ -102,12 +112,21 @@ namespace QGpCoreMath {
   {
     TRACE;
     const QChar * ptr=nullptr;
+    bool ok=true;
     StringSection f;
     f=str.nextField(ptr);
-    if(f.isValid()) _x=f.toDouble(); else return false;
+    if(f.isValid()) {
+      _x[0]=f.toDouble(ok);
+    } else {
+      return false;
+    }
     f=str.nextField(ptr);
-    if(f.isValid()) _y=f.toDouble(); else return false;
-    return true;
+    if(f.isValid()) {
+      _x[1]=f.toDouble(ok);
+    } else {
+      return false;
+    }
+    return ok;
   }
 
   /*!
@@ -115,8 +134,8 @@ namespace QGpCoreMath {
   */
   bool Point2D::isHit(const Point2D &p, double tolX, double tolY) const
   {
-    if((_x-tolX<=p.x() && p.x()<_x+tolX)
-        && (_y-tolY<=p.y() && p.y()<_y+tolY))
+    if((_x[0]-tolX<=p.x() && p.x()<_x[0]+tolX)
+        && (_x[1]-tolY<=p.y() && p.y()<_x[1]+tolY))
       return true;
     else
       return false;
@@ -135,9 +154,9 @@ namespace QGpCoreMath {
     double tmp, dist;
 
     dist=0.;
-    tmp=_x-p.x();
+    tmp=_x[0]-p.x();
     dist+=tmp*tmp;
-    tmp=_y-p.y();
+    tmp=_x[1]-p.y();
     dist+=tmp*tmp;
     return ::sqrt(dist);
   }
@@ -150,9 +169,9 @@ namespace QGpCoreMath {
     double tmp, dist;
 
     dist=0.;
-    tmp=_x-p.x();
+    tmp=_x[0]-p.x();
     dist+=tmp*tmp;
-    tmp=_y-p.y();
+    tmp=_x[1]-p.y();
     dist+=tmp*tmp;
     return dist;
   }
@@ -162,7 +181,7 @@ namespace QGpCoreMath {
   */
   double Point2D::azimuth() const
   {
-    double a=atan2(_y, _x);
+    double a=atan2(_x[1], _x[0]);
     if(a<0.0) a+=2.0*M_PI;
     return a;
   }
@@ -172,7 +191,7 @@ namespace QGpCoreMath {
   */
   double Point2D::azimuthTo(const Point2D &p) const
   {
-    double a=atan2(p.y()-_y, p.x()-_x);
+    double a=atan2(p.y()-_x[1], p.x()-_x[0]);
     if(a<0.0) a+=2*M_PI;
     return a;
   }
@@ -186,13 +205,13 @@ namespace QGpCoreMath {
   */
   double Point2D::geographicalAzimuthTo(const Point2D &p) const
   {
-    double phi1=Angle::degreesToRadians(_y);
-    double phi2=Angle::degreesToRadians(p._y);
+    double phi1=Angle::degreesToRadians(_x[1]);
+    double phi2=Angle::degreesToRadians(p._x[1]);
     double cphi1=::cos(phi1);
     double cphi2=::cos(phi2);
     double sphi1=::sin(phi1);
     double sphi2=::sin(phi2);
-    double deltaL=Angle::degreesToRadians(p._x-_x);
+    double deltaL=Angle::degreesToRadians(p._x[0]-_x[0]);
     double a=::atan2(cphi2*::sin(deltaL), cphi1*sphi2-sphi1*cphi2*::cos(deltaL));
     if(a<0.0) a+=2*M_PI;
     return a;
@@ -208,9 +227,9 @@ namespace QGpCoreMath {
   */
   double Point2D::geographicalDistanceTo(const Point2D &p) const
   {
-    double phi1=Angle::degreesToRadians(_y);
-    double phi2=Angle::degreesToRadians(p._y);
-    double deltaL=Angle::degreesToRadians(p._x-_x);
+    double phi1=Angle::degreesToRadians(_x[1]);
+    double phi2=Angle::degreesToRadians(p._x[1]);
+    double deltaL=Angle::degreesToRadians(p._x[0]-_x[0]);
     double sdeltaphi=::sin(0.5*(phi2-phi1));
     sdeltaphi*=sdeltaphi;
     double sdeltalamda=::sin(0.5*deltaL);
@@ -231,28 +250,28 @@ namespace QGpCoreMath {
     double dys=p2.y()-p1.y();
     if(dys==0.0) {
       if(p1.x()<p2.x()) {
-        if(_x>p2.x()) return distanceTo(p2);
-        if(_x<p1.x()) return distanceTo(p1);
+        if(_x[0]>p2.x()) return distanceTo(p2);
+        if(_x[0]<p1.x()) return distanceTo(p1);
       } else {
-        if(_x>p1.x()) return distanceTo(p1);
-        if(_x<p2.x()) return distanceTo(p2);
+        if(_x[0]>p1.x()) return distanceTo(p1);
+        if(_x[0]<p2.x()) return distanceTo(p2);
       }
-      return fabs(_y-p1.y());
+      return fabs(_x[1]-p1.y());
     }
     double dxs=p2.x()-p1.x();
     if(dxs==0.0) {
       if(p1.y()<p2.y()) {
-        if(_y>p2.y()) return distanceTo(p2);
-        if(_y<p1.y()) return distanceTo(p1);
+        if(_x[1]>p2.y()) return distanceTo(p2);
+        if(_x[1]<p1.y()) return distanceTo(p1);
       } else {
-        if(_y>p1.y()) return distanceTo(p1);
-        if(_y<p2.y()) return distanceTo(p2);
+        if(_x[1]>p1.y()) return distanceTo(p1);
+        if(_x[1]<p2.y()) return distanceTo(p2);
       }
-      return fabs(_x-p1.x());
+      return fabs(_x[0]-p1.x());
     }
     double coeff=dys/dxs;
     double coeffp=dxs/dys;
-    double interx=(coeff*p1.x()-coeffp*_x+_y-p1.y())/(coeff-coeffp);
+    double interx=(coeff*p1.x()-coeffp*_x[0]+_x[1]-p1.y())/(coeff-coeffp);
     if(p1.x()<p2.x()) {
       if(interx>p2.x()) return distanceTo(p2);
       if(interx<p1.x()) return distanceTo(p1);
@@ -260,7 +279,7 @@ namespace QGpCoreMath {
       if(interx>p1.x()) return distanceTo(p1);
       if(interx<p2.x()) return distanceTo(p2);
     }
-    double intery=coeffp*(interx-_x)+_y;
+    double intery=coeffp*(interx-_x[0])+_x[1];
     if(p1.y()<p2.y()) {
       if(intery>p2.y()) return distanceTo(p2);
       if(intery<p1.y()) return distanceTo(p1);
@@ -276,8 +295,8 @@ namespace QGpCoreMath {
   */
   void Point2D::move(double distance, const Angle& azimuth)
   {
-    _x+=distance*azimuth.cos();
-    _y+=distance*azimuth.sin();
+    _x[0]+=distance*azimuth.cos();
+    _x[1]+=distance*azimuth.sin();
   }
 
   /*!
@@ -285,9 +304,9 @@ namespace QGpCoreMath {
   */
   void Point2D::rotate(const Angle& a)
   {
-    double y=a.cos()*_y-a.sin()*_x;
-    _x=a.sin()*_y+a.cos()*_x;
-    _y=y;
+    double y=a.cos()*_x[1]-a.sin()*_x[0];
+    _x[0]=a.sin()*_x[1]+a.cos()*_x[0];
+    _x[1]=y;
   }
 
   /*!
@@ -296,8 +315,8 @@ namespace QGpCoreMath {
   */
   void Point2D::round(double maximum)
   {
-    _x=Number::round(_x, maximum);
-    _y=Number::round(_y, maximum);
+    _x[0]=Number::round(_x[0], maximum);
+    _x[1]=Number::round(_x[1], maximum);
   }
 
   double Point2D::utmM(double phi)
@@ -487,17 +506,17 @@ namespace QGpCoreMath {
     snr=::sin((double)rotation * DRAD);
     csr=::cos((double)rotation * DRAD);
 
-    _y *= 60.0;
-    _x *= 60.0;
+    _x[1] *= 60.0;
+    _x[0] *= 60.0;
 
-    tmp_x=_x - olon;
-    tmp_y=_y - olat;
-    tmp  =::atan(DRLT * ::tan(DRAD * (_y+olat)/120.0));
+    tmp_x=_x[0] - olon;
+    tmp_y=_x[1] - olat;
+    tmp  =::atan(DRLT * ::tan(DRAD * (_x[1]+olat)/120.0));
     tmp_x=(double)tmp_x * lon_fac * ::cos(tmp);
     tmp_y=(double)tmp_y * lat_fac;
 
-    _x=(csr*tmp_x - snr*tmp_y)*1000.0;
-    _y=(csr*tmp_y + snr*tmp_x)*1000.0;
+    _x[0]=(csr*tmp_x - snr*tmp_y)*1000.0;
+    _x[1]=(csr*tmp_y + snr*tmp_x)*1000.0;
   }
 
   /*!
@@ -524,8 +543,8 @@ namespace QGpCoreMath {
     double tmp_x, tmp_y;
 
     // Convert to km
-    _x*=0.001;
-    _y*=0.001;
+    _x[0]*=0.001;
+    _x[1]*=0.001;
 
     /* convert everything to minutes */
     olon=60.0 * ref.x();
@@ -546,8 +565,8 @@ namespace QGpCoreMath {
     /* rotation */
     snr=::sin((double)rotation * DRAD);
     csr=::cos((double)rotation * DRAD);
-    tmp_x=snr* _y + csr* _x;
-    tmp_y=csr* _y - snr* _x;
+    tmp_x=snr* _x[1] + csr* _x[0];
+    tmp_y=csr* _x[1] - snr* _x[0];
 
     tmp_y=tmp_y/lat_fac;
     tmp_y += olat;
@@ -556,8 +575,8 @@ namespace QGpCoreMath {
     tmp_x=tmp_x/(lon_fac * ::cos(tmp));
     tmp_x += olon;
 
-    _x=tmp_x/60.0;
-    _y=tmp_y/60.0;
+    _x[0]=tmp_x/60.0;
+    _x[1]=tmp_y/60.0;
   }
 
   /*!
@@ -567,8 +586,8 @@ namespace QGpCoreMath {
   */
   void Point2D::degreesToDMS()
   {
-    _x=Angle::degreesToDMS(_x);
-    _y=Angle::degreesToDMS(_y);
+    _x[0]=Angle::degreesToDMS(_x[0]);
+    _x[1]=Angle::degreesToDMS(_x[1]);
   }
 
   /*!
@@ -578,8 +597,8 @@ namespace QGpCoreMath {
   */
   void Point2D::DMSToDegrees()
   {
-    _x=Angle::DMSToDegrees(_x);
-    _y=Angle::DMSToDegrees(_y);
+    _x[0]=Angle::DMSToDegrees(_x[0]);
+    _x[1]=Angle::DMSToDegrees(_x[1]);
   }
 
   /*!
@@ -589,8 +608,8 @@ namespace QGpCoreMath {
   */
   void Point2D::degreesToDM()
   {
-    _x=Angle::degreesToDM(_x);
-    _y=Angle::degreesToDM(_y);
+    _x[0]=Angle::degreesToDM(_x[0]);
+    _x[1]=Angle::degreesToDM(_x[1]);
   }
 
   /*!
@@ -600,8 +619,8 @@ namespace QGpCoreMath {
   */
   void Point2D::DMToDegrees()
   {
-    _x=Angle::DMToDegrees(_x);
-    _y=Angle::DMToDegrees(_y);
+    _x[0]=Angle::DMToDegrees(_x[0]);
+    _x[1]=Angle::DMToDegrees(_x[1]);
   }
 
 
@@ -687,9 +706,9 @@ namespace QGpCoreMath {
   {
     switch(index) {
     case 1:
-      return _y;
+      return _x[1];
     default:
-      return _x;
+      return _x[0];
     }
   }
 
