@@ -33,6 +33,7 @@
 
 #include "Angle.h"
 #include "QGpCoreMathDLLExport.h"
+#include "SamplingParameters.h"
 
 namespace QGpCoreMath {
 
@@ -47,19 +48,20 @@ public:
   inline Point2D(double x, double y);
   inline Point2D(const QPoint& p);
   inline Point2D(const QPointF& p);
-  inline Point2D(const Point2D& p);
-  Point2D(const QVector<double>& p);
+  Point2D(const VectorList<double>& p);
 
-  double x() const {return _x;}
-  double y() const {return _y;}
-  double y(const CurvePointOptions *) const {return _y;}
-  void setX(double v) {_x=v;}
-  void setY(double v) {_y=v;}
-  void setY(double v, const CurvePointOptions *) {_y=v;}
+  double x() const {return _x[0];}
+  double y() const {return _x[1];}
+  const double * data() const {return _x;}
+  double * data() {return _x;}
+  double y(const CurvePointOptions *) const {return _x[1];}
+  void setX(double v) {_x[0]=v;}
+  void setY(double v) {_x[1]=v;}
+  void setY(double v, const CurvePointOptions *) {_x[1]=v;}
   double at(int index) const;
   void setValid(bool) {}
   bool isValid() const {return true;}
-  void average(const Point2D& p) {_y= 0.5*(_y+p._y);}
+  void average(const Point2D& p) {_x[1]=0.5*(_x[1]+p._x[1]);}
 
   void degreesToDMS();
   void DMSToDegrees();
@@ -70,12 +72,9 @@ public:
   void geographicalToUtm(UtmZone& zone);
   void utmToGeographical(const UtmZone& zone);
 
-  // Copy operators
-  inline Point2D& operator=(const Point2D& p);
   inline void set(double xi, double yi);
-  inline QPointF pointF() const {return QPointF(_x, _y);}
+  inline QPointF pointF() const {return QPointF(_x[0], _x[1]);}
 
-  // Comparison operators
   inline bool operator<(const Point2D& p) const;
   inline bool operator>(const Point2D& p) const;
   inline bool operator==(const Point2D& p) const;
@@ -83,11 +82,9 @@ public:
   inline short compare(const Point2D& p) const;
   inline bool isSimilar(const Point2D& p, double tolerance) const;
 
-  // I/O functions
   bool fromString(const StringSection& str);
-  QString toString(int precision=6, char format='g') const;
+  QString toString(char format='g', int precision=6) const;
 
-  // Arithmetic operation
   inline void operator+=(const Point2D& p);
   inline void operator-=(const Point2D& p);
   inline void operator*=(const Point2D& p);
@@ -96,7 +93,9 @@ public:
   void operator/=(double div) {operator*=(1.0/div);}
   void operator*=(const Matrix2x2& transformation);
   inline double scalarProduct(const Point2D& p) const;
-  inline void interpole(double valX, const Point2D& p1, const Point2D& p2);
+  inline double scalarProduct(const double * p) const;
+  inline void interpole(double valX, const Point2D& p1, const Point2D& p2,
+                        SamplingOptions xSampling, SamplingOptions ySampling);
   void translate(const Point2D& p) {operator+=(p);}
   void rotate(const Angle& a);
 
@@ -108,7 +107,6 @@ public:
   inline Point2D operator/(double div) const {return operator*(1.0/div);}
   inline Point2D operator/(const Point2D& p) const;
 
-  // Miscellaneous
   bool isHit(const Point2D &p,double tolX, double tolY) const;
   double length() const {return ::sqrt(abs2());}
   double distanceTo(const Point2D &p) const;
@@ -127,8 +125,8 @@ public:
   inline void yInverse();
 private:
   static double utmM(double phi);
-  // Coordinates of the point
-  double _x, _y;
+
+  double _x[2];
 };
 
 QGPCOREMATH_EXPORT uint qHash(Point2D key);
@@ -139,52 +137,39 @@ namespace QGpCoreMath {
 
 inline Point2D::Point2D()
 {
-  _x=0.;
-  _y=0.;
+  _x[0]=0.;
+  _x[1]=0.;
 }
 
 inline Point2D::Point2D(double xi, double yi)
 {
-  _x=xi;
-  _y=yi;
+  _x[0]=xi;
+  _x[1]=yi;
 }
 
 inline Point2D::Point2D(const QPoint& p)
 {
-  _x=p.x();
-  _y=p.y();
+  _x[0]=p.x();
+  _x[1]=p.y();
 }
 
 inline Point2D::Point2D(const QPointF& p)
 {
-  _x=p.x();
-  _y=p.y();
-}
-
-inline Point2D::Point2D(const Point2D& p)
-{
-  _x=p.x();
-  _y=p.y();
-}
-
-inline Point2D& Point2D::operator= (const Point2D& p)
-{
-  _x=p._x;
-  _y=p._y;
-  return *this;
+  _x[0]=p.x();
+  _x[1]=p.y();
 }
 
 inline void Point2D::set(double xi, double yi)
 {
-  _x=xi;
-  _y=yi;
+  _x[0]=xi;
+  _x[1]=yi;
 }
 
 inline bool Point2D::operator<(const Point2D& p) const
 {
-  if(_x<p._x) {
+  if(_x[0]<p._x[0]) {
     return true;
-  } else if(_x==p._x && _y<p._y) {
+  } else if(_x[0]==p._x[0] && _x[1]<p._x[1]) {
     return true;
   }
   return false;
@@ -192,9 +177,9 @@ inline bool Point2D::operator<(const Point2D& p) const
 
 inline bool Point2D::operator>(const Point2D& p) const
 {
-  if(_x>p._x) {
+  if(_x[0]>p._x[0]) {
     return true;
-  } else if(_x==p._x && _y>p._y) {
+  } else if(_x[0]==p._x[0] && _x[1]>p._x[1]) {
     return true;
   }
   return false;
@@ -202,93 +187,125 @@ inline bool Point2D::operator>(const Point2D& p) const
 
 inline bool Point2D::operator==(const Point2D& p) const
 {
-  return _x==p._x && _y==p._y;;
+  return _x[0]==p._x[0] && _x[1]==p._x[1];;
 }
 
 inline bool Point2D::operator!=(const Point2D& p) const
 {
-  return _x!=p._x || _y!=p._y;;
+  return _x[0]!=p._x[0] || _x[1]!=p._x[1];;
 }
 
 inline short Point2D::compare (const Point2D& p) const
 {
-  if(_x<p._x) return(-1);
-  else if(_x>p._x) return(1);
-  else if(_y<p._y) return(-1);
-  else if(_y>p._y) return(1);
+  if(_x[0]<p._x[0]) return(-1);
+  else if(_x[0]>p._x[0]) return(1);
+  else if(_x[1]<p._x[1]) return(-1);
+  else if(_x[1]>p._x[1]) return(1);
   else return(0);
 }
 
 inline Point2D Point2D::operator+(const Point2D& p) const
 {
-  return Point2D(_x+p._x, _y+p._y);
+  return Point2D(_x[0]+p._x[0], _x[1]+p._x[1]);
 }
 
 inline Point2D Point2D::operator-(const Point2D& p) const
 {
-  return Point2D(_x-p._x, _y-p._y);
+  return Point2D(_x[0]-p._x[0], _x[1]-p._x[1]);
 }
 
 inline Point2D Point2D::operator-() const
 {
-  return Point2D(-_x, -_y);
+  return Point2D(-_x[0], -_x[1]);
 }
 
 inline Point2D Point2D::operator*(double mul) const
 {
-  return Point2D(_x*mul, _y*mul);
+  return Point2D(_x[0]*mul, _x[1]*mul);
 }
 
 inline Point2D Point2D::operator*(const Point2D& p) const
 {
-  return Point2D(_x*p._x, _y*p._y);
+  return Point2D(_x[0]*p._x[0], _x[1]*p._x[1]);
 }
 
 inline Point2D Point2D::operator/(const Point2D& p) const
 {
-  return Point2D(_x/p._x, _y/p._y);
+  return Point2D(_x[0]/p._x[0], _x[1]/p._x[1]);
 }
 
 inline void Point2D::operator+=(const Point2D& p)
 {
-  _x+=p._x;
-  _y+=p._y;
+  _x[0]+=p._x[0];
+  _x[1]+=p._x[1];
 }
 
 inline void Point2D::operator-=(const Point2D& p)
 {
-  _x-=p._x;
-  _y-=p._y;
+  _x[0]-=p._x[0];
+  _x[1]-=p._x[1];
 }
 
 inline void Point2D::operator*=(const Point2D& p)
 {
-  _x*=p._x;
-  _y*=p._y;
+  _x[0]*=p._x[0];
+  _x[1]*=p._x[1];
 }
 
 inline void Point2D::operator*=(double mul)
 {
-  _x*=mul;
-  _y*=mul;
+  _x[0]*=mul;
+  _x[1]*=mul;
 }
 
 inline void Point2D::operator/=(const Point2D& p)
 {
-  _x/=p._x;
-  _y/=p._y;
+  _x[0]/=p._x[0];
+  _x[1]/=p._x[1];
 }
 
 inline double Point2D::scalarProduct(const Point2D& p) const
 {
-  return _x*p._x+_y*p._y;
+  return _x[0]*p._x[0]+_x[1]*p._x[1];
 }
 
-inline void Point2D::interpole(double valX, const Point2D& p1, const Point2D& p2)
+inline double Point2D::scalarProduct(const double * p) const
+{
+  return _x[0]*p[0]+_x[1]*p[1];
+}
+
+inline void Point2D::interpole(double valX, const Point2D& p1, const Point2D& p2,
+                               SamplingOptions xSampling, SamplingOptions ySampling)
 {
-  double factor=(valX - p1.x())/(p2.x()-p1.x());
   setX(valX);
-  setY(p1.y()+ (p2.y()-p1.y()) * factor);
+  double x1, x2;
+  double y1, y2;
+  if(xSampling & InverseScale) {
+    valX=1.0/valX;
+    x1=1.0/p1.x();
+    x2=1.0/p2.x();
+  } else if(xSampling & LogScale) {
+    valX=log(valX);
+    x1=log(p1.x());
+    x2=log(p2.x());
+  } else {
+    x1=p1.x();
+    x2=p2.x();
+  }
+  double factor=(valX-x1)/(x2-x1);
+  if(ySampling & InverseScale) {
+    y1=1.0/p1.y();
+    y2=1.0/p2.y();
+    this->setY(1.0/(y1+(y2-y1)*factor));
+  } else if(ySampling & LogScale) {
+    y1=log(p1.y());
+    y2=log(p2.y());
+    this->setY(exp(y1+(y2-y1)*factor));
+  } else {
+    y1=p1.y();
+    y2=p2.y();
+    this->setY(y1+(y2-y1)*factor);
+  }
 }
 
 inline bool Point2D::isSimilar(const Point2D& p, double tolerance) const
@@ -299,28 +316,28 @@ inline bool Point2D::isSimilar(const Point2D& p, double tolerance) const
 
 inline void Point2D::abs()
 {
-  _x=fabs(_x);
-  _y=fabs(_y);
+  _x[0]=fabs(_x[0]);
+  _x[1]=fabs(_x[1]);
 }
 
 inline double Point2D::abs2() const
 {
-  return _x*_x+_y*_y;
+  return _x[0]*_x[0]+_x[1]*_x[1];
 }
 
 inline void Point2D::yLog()
 {
-  _y=::log(_y);
+  _x[1]=::log(_x[1]);
 }
 
 inline void Point2D::yExp()
 {
-  _y=::exp(_y);
+  _x[1]=::exp(_x[1]);
 }
 
 inline void Point2D::yInverse()
 {
-  _y=1.0/_y;
+  _x[1]=1.0/_x[1];
 }
 
 QGPCOREMATH_EXPORT QTextStream& operator<< (QTextStream& s, const QList<Point2D>& plist);
