@@ -30,6 +30,7 @@
 
 #include <QGpCoreTools.h>
 
+#include "SamplingParameters.h"
 #include "QGpCoreMathDLLExport.h"
 
 namespace QGpCoreMath {
@@ -41,9 +42,9 @@ class QGPCOREMATH_EXPORT PointND
 {
 public:
   PointND() {_x=0.0;}
-  PointND(double x, const QVector<double>& y) {_x=x; _y=y;}
+  PointND(double x, const VectorList<double>& y) {_x=x; _y=y;}
   PointND(const PointND& o) {_x=o._x; _y=o._y;}
-  PointND(const QVector<double>& p);
+  PointND(const VectorList<double>& p);
 
   int count() const {return _y.count();}
 
@@ -62,7 +63,8 @@ public:
 
   void setValid(bool) {}
   bool isValid() const {return true;}
-  inline void interpole(double valX, const PointND& p1, const PointND& p2);
+  inline void interpole(double valX, const PointND& p1, const PointND& p2,
+                        SamplingOptions xSampling, SamplingOptions ySampling);
   inline void average(const PointND&);
 
   void operator+=(const PointND& p);
@@ -74,10 +76,10 @@ public:
 
   // I/O functions
   bool fromString(const StringSection& str);
-  QString toString(int precision=6, char format='g') const;
+  QString toString(char format='g', int precision=6) const;
 private:
   double _x;
-  QVector<double> _y;
+  VectorList<double> _y;
 };
 
 inline bool PointND::operator==(const PointND& p) const
@@ -116,15 +118,48 @@ inline void PointND::setY(int index, double y)
   _y[index]=y;
 }
 
-inline void PointND::interpole(double valX, const PointND& p1, const PointND& p2)
+inline void PointND::interpole(double valX, const PointND& p1, const PointND& p2,
+                               SamplingOptions xSampling, SamplingOptions ySampling)
 {
   TRACE;
-  double factor=(valX - p1.x())/(p2.x()-p1.x());
   setX(valX);
+  double x1, x2;
+  double y1, y2;
+  if(xSampling & InverseScale) {
+    valX=1.0/valX;
+    x1=1.0/p1.x();
+    x2=1.0/p2.x();
+  } else if(xSampling & LogScale) {
+    valX=log(valX);
+    x1=log(p1.x());
+    x2=log(p2.x());
+  } else {
+    x1=p1.x();
+    x2=p2.x();
+  }
+  double factor=(valX-x1)/(x2-x1);
   int n=p1.count();
-  if(n<p2.count()) n=p2.count();
-  for(int i=0; i< n; i++) {
-    setY(i, p1.y(i)+ (p2.y(i)-p1.y(i)) * factor);
+  if(n<p2.count()) {
+    n=p2.count();
+  }
+  if(ySampling & InverseScale) {
+    for(int i=0; i< n; i++) {
+      y1=1.0/p1.y(i);
+      y2=1.0/p2.y(i);
+      this->setY(i, 1.0/(y1+(y2-y1)*factor));
+    }
+  } else if(ySampling & LogScale) {
+    for(int i=0; i< n; i++) {
+      y1=log(p1.y(i));
+      y2=log(p2.y(i));
+      this->setY(i, exp(y1+(y2-y1)*factor));
+    }
+  } else {
+    for(int i=0; i< n; i++) {
+      y1=p1.y(i);
+      y2=p2.y(i);
+      this->setY(i, y1+(y2-y1)*factor);
+    }
   }
 }
 
