@@ -35,7 +35,7 @@ namespace QGpCoreMath {
 
     The scale is defined by a minimum() and a maximum() which correspond to the visible
     minimum and maximum of a Axis. The scale tranformation is defined by the type of
-    scale (Normal, Inversed or Log) by its reversed flag (isReversed()) and by a() and b().
+    scale (Normal, Inverse or Log) by its reversed flag (isReversed()) and by a() and b().
     a() and b() are set indirectly by setVerticalTransformation() or
     setHorizontalTransformation().
 
@@ -54,8 +54,8 @@ namespace QGpCoreMath {
   Scale::Scale()
   {
     TRACE;
-    _globalMinimum=0;
-    _globalMaximum=100;
+    _globalMinimum=0.0;
+    _globalMaximum=100.0;
     _minimum=0.0;
     _maximum=100.0;
     _type=Linear;
@@ -66,41 +66,19 @@ namespace QGpCoreMath {
     _b=0.0;
   }
 
-  /*!
-  */
-  void Scale::operator=(const Scale& o)
-  {
-    TRACE;
-    _globalMinimum=o._globalMinimum;
-    _globalMaximum=o._globalMaximum;
-    _minimum=o._minimum;
-    _maximum=o._maximum;
-    _type=o._type;
-    _reversed=o._reversed;
-    _a=o._a;
-    _b=o._b;
-    _majorTicks=o._majorTicks;
-    _minorTicks=o._minorTicks;
-    _timeReference=o._timeReference;
-    _majorTickValues=o._majorTickValues;
-    _majorTickPrecision=o._majorTickPrecision;
-    _minorTickValues=o._minorTickValues;
-    _timeFormat= o._timeFormat;
-  }
-
   void Scale::setGlobalMinimum(double m)
   {
     TRACE;
     switch(_type) {
     case Log:
-    case InversedLog:
+    case InverseLog:
       if(m<=0) {
         _globalMinimum=1e-16;
       } else {
         _globalMinimum=m;
       }
       break;
-    case Inversed:
+    case Inverse:
     case Linear:
     case AbsoluteTime:
     case RelativeTime:
@@ -114,14 +92,14 @@ namespace QGpCoreMath {
     TRACE;
     switch(_type) {
     case Log:
-    case InversedLog:
+    case InverseLog:
       if(m<=0) {
         _globalMaximum=1e-16;
       } else {
         _globalMaximum=m;
       }
       break;
-    case Inversed:
+    case Inverse:
     case Linear:
     case AbsoluteTime:
     case RelativeTime:
@@ -130,6 +108,37 @@ namespace QGpCoreMath {
     }
   }
 
+  void Scale::setMajorTicks(double m)
+  {
+    _majorTicks=m;
+    cacheTicks();
+  }
+
+  void Scale::setMinorTicks(double m)
+  {
+    _minorTicks=m;
+    cacheTicks();
+  }
+
+
+  /*!
+    The scale is considered as zoomed if the either minimum or maximum is different from
+    the corresponding global value. This condition is also true if the limits are not
+    regular. This should not occur but for robustness we check also the regularity of the
+    limits.
+  */
+  bool Scale::isZoomed() const
+  {
+    TRACE;
+    if(_globalMinimum<_minimum) {
+      return _minimum<_maximum && _maximum<=_globalMaximum;
+    } else if(_globalMinimum==_minimum) {
+      return _minimum<_maximum && _maximum<_globalMaximum;
+    } else { // irregular limits
+      return false;
+    }
+  }
+
   /*!
     \fn double Scale::s2r(int val) const
     Conversion from screen coordinate to real coordinate
@@ -159,9 +168,9 @@ namespace QGpCoreMath {
     switch(_type) {
     case Log:
       return LogScale;
-    case Inversed:
-      return InversedScale;
-    case InversedLog:
+    case Inverse:
+      return InverseScale;
+    case InverseLog:
       return LogScale;
     case Linear:
     case AbsoluteTime:
@@ -172,23 +181,27 @@ namespace QGpCoreMath {
   }
 
   /*!
-    Make sure minimum() and maximum() are within \a min and \a max.
+    Make sure minimum() and maximum() are within globalMinimum() and globalMaximum().
     If not, they are corrected keeping the difference between minimum() and maximum() constant
   */
   void Scale::checkLimits()
   {
     TRACE;
-    double delta=r2a(_maximum)-r2a(_minimum);
-    if(_minimum<_globalMinimum) {
-      _maximum=a2r(r2a(_globalMinimum)+delta);
-      _minimum=_globalMinimum;
-      if(_maximum>_globalMaximum)
-        _maximum=_globalMaximum;
-    } else if(_maximum>_globalMaximum) {
-      _minimum=a2r(r2a(_globalMaximum)-delta);
-      _maximum=_globalMaximum;
-      if(_minimum<_globalMinimum)
+    if(_globalMinimum<=_globalMaximum) {
+      double delta=r2a(_maximum)-r2a(_minimum);
+      if(_minimum<_globalMinimum) {
+        _maximum=a2r(r2a(_globalMinimum)+delta);
         _minimum=_globalMinimum;
+        if(_maximum>_globalMaximum) {
+          _maximum=_globalMaximum;
+        }
+      } else if(_maximum>_globalMaximum) {
+        _minimum=a2r(r2a(_globalMaximum)-delta);
+        _maximum=_globalMaximum;
+        if(_minimum<_globalMinimum) {
+          _minimum=_globalMinimum;
+        }
+      }
     }
   }
 
@@ -571,11 +584,11 @@ namespace QGpCoreMath {
     case RelativeTime:
       delta=_maximum-_minimum;
       break;
-    case Inversed:
+    case Inverse:
       delta=1.0/_minimum-1.0/_maximum;
       break;
     case Log:
-    case InversedLog:
+    case InverseLog:
       _majorTicks=2.0;
       _minorTicks=0.5;
       return;
@@ -636,7 +649,7 @@ namespace QGpCoreMath {
       minorTicks=_minorTicks;
       inv_majorTicks=1.0/majorTicks;
       break;
-    case Inversed:
+    case Inverse:
       visMin=1.0/_maximum;
       visMax=1.0/_minimum;
       majorTicks=_majorTicks;
@@ -653,7 +666,7 @@ namespace QGpCoreMath {
       baseTicks*=10.0;
       eps_baseTicks=baseTicks*(1-1e-10);
       break;
-    case InversedLog:
+    case InverseLog:
       visMin=1.0/_maximum;
       visMax=1.0/_minimum;
       baseTicks=pow(10.0, floor(log10(visMin)));
@@ -673,7 +686,7 @@ namespace QGpCoreMath {
       switch (_type) {
       case Linear:
       case RelativeTime:
-      case Inversed:
+      case Inverse:
         while(majorX<=visMax) {
           _majorTickValues.append(majorX);
           minorX=majorX;
@@ -698,7 +711,10 @@ namespace QGpCoreMath {
         }
         break;
       case Log:
-      case InversedLog:
+      case InverseLog:
+        if(majorX>eps_baseTicks) {  // First label is already a precision turning point
+          numberPrecision++;
+        }
         while(majorX<=visMax) {
           _majorTickValues.append(majorX);
           if(majorX>eps_baseTicks) {
@@ -751,5 +767,13 @@ namespace QGpCoreMath {
     _timeReference.roundSeconds(1.0);
   }
 
+  ENUM_AS_STRING_BEGIN(Scale, Type)
+  ENUM_AS_STRING_DATA_6(AbsoluteTime, Inverse, InverseLog, Linear, Log, RelativeTime);
+  ENUM_AS_STRING_SYNONYM("n", Linear);
+  ENUM_AS_STRING_SYNONYM("l", Log);
+  ENUM_AS_STRING_SYNONYM("i", Inverse);
+  ENUM_AS_STRING_SYNONYM("Inversed", Inverse);
+  ENUM_AS_STRING_SYNONYM("InversedLog", InverseLog);
+  ENUM_AS_STRING_END
 
 } // namespace QGpCoreMath
