@@ -40,13 +40,15 @@ namespace QGpCoreMath {
   {
   public:
     SmoothingParameters();
-    SmoothingParameters(const SmoothingParameters& o);
 
-    virtual AbstractParameters * clone() const {return new SmoothingParameters(*this);}
+    AbstractParameters * clone() const {return new SmoothingParameters(*this);}
 
     enum Method {Function, SavitzkyGolay};
     enum WidthType {Constant, Proportional, Log};
 
+    ENUM_AS_STRING_DECL(Method)
+    ENUM_AS_STRING_DECL(WidthType)
+
     Method method() const {return _method;}
     void setMethod(Method m) {_method=m;}
 
@@ -75,9 +77,6 @@ namespace QGpCoreMath {
     int keywordCount(PARAMETERS_KEYWORDCOUNT_ARGS) const;
     bool setValue(PARAMETERS_SETVALUE_ARGS);
   private:
-    QString methodString() const;
-    void setMethod(const QString& t);
-
     QString widthTypeString() const;
     void setWidthType(const QString& t);
     void setWidthTypeCompatibility(const QString& t);
