@@ -33,14 +33,11 @@
 #include <QGpCoreTools.h>
 
 #include "Value.h"
+#include "Misfit.h"
 #include "QGpCoreMathDLLExport.h"
 
 namespace QGpCoreMath {
 
-  enum MisfitType {L1, L1_Normalized, L1_LogNormalized, L1_NormalizedBySigmaOnly,
-                   L2, L2_Normalized, L2_LogNormalized, L2_NormalizedBySigmaOnly,
-                   RMS, Akaike, AkaikeFewSamples, Determinant};
-
   template <class numberType>
   class QGPCOREMATH_EXPORT StatisticalValue : public XMLClass
   {
@@ -48,7 +45,6 @@ namespace QGpCoreMath {
     inline StatisticalValue();
     inline StatisticalValue (const numberType& mean, double stddev=0.0, double weight=1.0, bool valid=true);
 
-    inline void operator=(const StatisticalValue& o);
     inline bool operator==(const StatisticalValue& o) const;
 
     inline void operator+=(const StatisticalValue& o);
@@ -66,10 +62,7 @@ namespace QGpCoreMath {
     void setValid(bool f) {_valid=f; if(_valid && _weight==0.0) _weight=1.0;}
     bool isValid() const {return _valid;}
 
-    static QString misfitTypeString(MisfitType type);
-    static MisfitType misfitType(QString type);
-
-    double misfit(int& nValues, int& nData, const Value<numberType>& value, MisfitType type, double min) const;
+    double misfit(int& nValues, int& nData, const Value<numberType>& value, Misfit::Type type, double min) const;
 
     inline void average(const StatisticalValue& p);
     static bool compareWeights(const StatisticalValue<numberType>& v1, const StatisticalValue<numberType>& v2);
@@ -83,9 +76,9 @@ namespace QGpCoreMath {
     double _weight;
     bool _valid;
   protected:
-    virtual void xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const;
-    virtual XMLMember xml_member(XML_MEMBER_ARGS);
-    virtual bool xml_setProperty(XML_SETPROPERTY_ARGS);
+    void xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const;
+    XMLMember xml_member(XML_MEMBER_ARGS);
+    bool xml_setProperty(XML_SETPROPERTY_ARGS);
   };
 
   class QGPCOREMATH_EXPORT RealStatisticalValue : public StatisticalValue<double>
@@ -95,7 +88,7 @@ namespace QGpCoreMath {
     RealStatisticalValue (const double& mean, double stddev=0.0, double weight=1.0, bool valid=true)
       : StatisticalValue<double>(mean, stddev, weight, valid) {}
 
-    virtual const QString& xml_tagName() const {return xmlRealStatisticalValueTag;}
+    const QString& xml_tagName() const {return xmlRealStatisticalValueTag;}
     static const QString xmlRealStatisticalValueTag;
   };
 
@@ -106,7 +99,7 @@ namespace QGpCoreMath {
     ComplexStatisticalValue (const double& mean, double stddev=0.0, double weight=1.0, bool valid=true)
       : StatisticalValue<Complex>(mean, stddev, weight, valid) {}
 
-    virtual const QString& xml_tagName() const {return xmlComplexStatisticalValueTag;}
+    const QString& xml_tagName() const {return xmlComplexStatisticalValueTag;}
     static const QString xmlComplexStatisticalValueTag;
   };
 
@@ -131,16 +124,6 @@ namespace QGpCoreMath {
     _valid=valid;
   }
 
-  template <class numberType>
-  inline void StatisticalValue<numberType>::operator=(const StatisticalValue<numberType>& o)
-  {
-    TRACE;
-    _mean=o._mean;
-    _stddev=o._stddev;
-    _weight=o._weight;
-    _valid=o._valid;
-  }
-
   template <class numberType>
   inline bool StatisticalValue<numberType>::operator==(const StatisticalValue<numberType>& o) const
   {
@@ -238,83 +221,25 @@ namespace QGpCoreMath {
     Q_UNUSED(tag)
     Q_UNUSED(attributes)
     Q_UNUSED(context)
+    bool ok=true;
     switch(memberID) {
     case 0: {
         numberType tmp;
         SAFE_UNINITIALIZED(tmp, 0);
-        _mean=content.to(tmp);
+        _mean=content.to(tmp, ok);
       }
-      return true;
-    case 1: _stddev=content.toDouble(); return true;
-    case 2: _weight=content.toDouble(); return true;
-    case 3: _valid=content.toBool(); return true;
+      return ok;
+    case 1: _stddev=content.toDouble(ok); return ok;
+    case 2: _weight=content.toDouble(ok); return ok;
+    case 3: _valid=content.toBool(ok); return ok;
     default: return false;
     }
   }
 
-  template <class numberType>
-  QString StatisticalValue<numberType>::misfitTypeString(MisfitType type)
-  {
-    TRACE;
-    switch (type) {
-    case L1:
-      return "L1";
-    case L1_Normalized:
-      return "L1_Normalized";
-    case L1_LogNormalized:
-      return "L1_LogNormalized";
-    case L1_NormalizedBySigmaOnly:
-      return "L1_NormalizedBySigmaOnly";
-    case L2:
-      return "L2";
-    case L2_Normalized:
-      return "L2_Normalized";
-    case L2_LogNormalized:
-      return "L2_LogNormalized";
-    case L2_NormalizedBySigmaOnly:
-      return "L2_NormalizedBySigmaOnly";
-    case Akaike:
-      return "Akaike";
-    case AkaikeFewSamples:
-      return "AkaikeFewSamples";
-    case RMS:
-      return "RMS";
-    case Determinant:
-      return "Determinant";
-    }
-    return QString();
-  }
-
-  template <class numberType>
-  MisfitType StatisticalValue<numberType>::misfitType(QString type)
-  {
-    TRACE;
-    if(type.count()>1) {
-      switch(type[1].unicode()) {
-      case '1':
-        if(type=="L1") return L1; else return L1_Normalized;
-      case '2':
-        if(type=="L2") return L2;
-        else if(type=="L2_Normalized") return L2_Normalized;
-        else return L2_NormalizedBySigmaOnly;
-      case 'm':
-        return RMS;
-      case 'e':
-        return Determinant;
-      case 'k':
-        if(type=="Akaike") return Akaike; else return AkaikeFewSamples;
-        break;
-      default:
-        break;
-      }
-    }
-    return L2_Normalized;
-  }
-
   template <class numberType>
   double StatisticalValue<numberType>::misfit(int& nValues, int& nData,
                                               const Value<numberType>& val,
-                                              MisfitType type, double min) const
+                                              Misfit::Type type, double min) const
   {
     TRACE;
     if(isValid()) {
@@ -323,13 +248,13 @@ namespace QGpCoreMath {
         nValues++;
         double diff;
         switch (type) {
-        case L1:
+        case Misfit::L1:
           diff=QGpCoreTools::abs(_mean-val.value());
           if(diff<min) {
             diff=min;
           }
           return diff;
-        case L1_Normalized:
+        case Misfit::L1_Normalized:
           if(_stddev>0.0) {
             diff=QGpCoreTools::abs((_mean-val.value())/_stddev);
           } else {
@@ -339,7 +264,7 @@ namespace QGpCoreMath {
             diff=min;
           }
           return diff;
-        case L1_LogNormalized:
+        case Misfit::L1_LogNormalized:
           if(_stddev>1.0) {
             diff=QGpCoreTools::abs((log(_mean/val.value()))/log(_stddev));
           } else {
@@ -357,7 +282,7 @@ namespace QGpCoreMath {
             diff=min;
           }
           return diff;
-        case L1_NormalizedBySigmaOnly:
+        case Misfit::L1_NormalizedBySigmaOnly:
           if(_stddev>0.0) {
             diff=QGpCoreTools::abs((_mean-val.value())/_stddev);
           } else {
@@ -367,16 +292,22 @@ namespace QGpCoreMath {
             diff=min;
           }
           return diff;
-        case L2:
-        case RMS:
+        case Misfit::L2:
+        case Misfit::RMS:
           diff=QGpCoreTools::abs(_mean-val.value());
           if(diff<min) {
             diff=min;
           }
           return diff*diff;
-        case Akaike:
-        case AkaikeFewSamples:
-        case L2_Normalized:
+        case Misfit::L2_Inverse:
+          diff=QGpCoreTools::abs(1.0/_mean-1.0/val.value());
+          if(diff<min) {
+            diff=min;
+          }
+          return diff*diff;
+        case Misfit::Akaike:
+        case Misfit::AkaikeFewSamples:
+        case Misfit::L2_Normalized:
           if(_stddev>0.0) {
             diff=QGpCoreTools::abs((_mean-val.value())/_stddev);
           } else {
@@ -386,7 +317,7 @@ namespace QGpCoreMath {
             diff=min;
           }
           return diff*diff;
-        case L2_LogNormalized:
+        case Misfit::L2_LogNormalized:
           if(_stddev>1.0) {
             diff=QGpCoreTools::abs((log(_mean/val.value()))/log(_stddev));
           } else {
@@ -404,7 +335,7 @@ namespace QGpCoreMath {
             diff=min;
           }
           return diff*diff;
-        case L2_NormalizedBySigmaOnly:
+        case Misfit::L2_NormalizedBySigmaOnly:
           if(_stddev>0.0) {
             diff=QGpCoreTools::abs((_mean-val.value())/_stddev);
           } else {
@@ -414,7 +345,8 @@ namespace QGpCoreMath {
             diff=min;
           }
           return diff*diff;
-        case Determinant:
+        case Misfit::Determinant:
+        case Misfit::TypeCount:
           return 0.0;
         }
         return 0.0;
