@@ -44,33 +44,39 @@ namespace QGpCoreStat {
   HistogramReader::HistogramReader()
       : ArgumentStdinReader()
   {
-    TRACE;
-    _ignoreStdin=true;
     _action=Gui;
-    _xSampling=nullptr;
-    _xLogSampling=false;
-    _ySampling.setCount(200);
-    _yFactor=1.0;
     _manual.flags=0;
+
     _xColumn=0;
     _yColumn=1;
-    _maxVariables=SlownessFrequency;
-    _noiseColumn=-1;
+    _verticalNoiseColumn=-1;
+    _horizontalNoiseColumn=-1;
     _powerColumn=-1;
+    _ringColumn=-1;
     _validColumn=-1;
+
+    _angularEllipticity=true;
+
+    _ignoreStdin=true;
+    _normalize=true;
+    _xLogSampling=false;
+    _yPeriodic=false;
+    _yFactor=1.0;
     _relativePowerThreshold=0.0;
     _noiseThreshold=std::numeric_limits<double>::infinity();
-    _ignoreValid=false;
-    _normalize=true;
+    _maxVariables=SlownessFrequency;
+    _ring=-1;
+
+    _xSampling=nullptr;
+    _ySampling.setCount(200);
     _xScaleType=Scale::Linear;
     _yScaleType=Scale::Linear;
-    _ringColumn=-1;
-    _ring=-1;
+
+    _ignoreValid=false;
   }
 
   HistogramReader::~HistogramReader()
   {
-    TRACE;
     delete _xSampling;
   }
 
@@ -96,7 +102,9 @@ namespace QGpCoreStat {
             _xSampling=nullptr;
             _manual.xValuesAsIs=true;
           } else {
-            if(!_xSampling->setScaleType(QString(argv[i]))) {
+            bool ok=true;
+            _xSampling->setScaleType(SamplingParameters::convertScaleType(QString(argv[i]), ok));
+            if(!ok) {
               App::log(tr("Error setting X sampling\n"));
               return false;
             }
@@ -148,7 +156,9 @@ namespace QGpCoreStat {
           _manual.y.column=true;
         } else if(arg=="-y-sampling") {
           CoreApplication::checkOptionArg(i, argc, argv);
-          if(!_ySampling.setScaleType(QString(argv[i]))) {
+          bool ok=true;
+          _ySampling.setScaleType(SamplingParameters::convertScaleType(QString(argv[i]), ok));
+          if(!ok) {
             App::log(tr("Error setting Y sampling\n"));
             return false;
           }
@@ -182,6 +192,8 @@ namespace QGpCoreStat {
         } else if(arg=="-y-factor") {
           CoreApplication::checkOptionArg(i, argc, argv);
           _yFactor=CoreApplication::toDouble(i, i-1, argv);
+        } else if(arg=="-y-periodic") {
+          _yPeriodic=true;
         } else if(arg=="-y-title") {
           CoreApplication::checkOptionArg(i, argc, argv);
           _yTitle=argv[i];
@@ -189,8 +201,6 @@ namespace QGpCoreStat {
           CoreApplication::checkOptionArg(i, argc, argv);
           _validColumn=CoreApplication::toInt(i, i-1, argv);
           _manual.validColumn=true;
-        } else if(arg=="-grid") {
-          _action=Grid;
         } else if(arg=="-mean") {
           _action=Mean;
         } else if(arg=="-median") {
@@ -203,6 +213,8 @@ namespace QGpCoreStat {
           _action=Plot;
         } else if(arg=="-min-velocity") {
           _action=MinimumVelocity;
+        } else if(arg=="-misfit") {
+          _action=Misfit;
         } else if(arg=="-max") {
           CoreApplication::checkOptionArg(i, argc, argv);
           _exportMaxFileName=argv[i];
@@ -210,6 +222,8 @@ namespace QGpCoreStat {
         } else if(arg=="-pattern" || arg=="-p") {
           CoreApplication::checkOptionArg(i, argc, argv);
           _pattern=argv[i];
+        } else if(arg=="-hist-values") {
+          _action=HistogramValues;
         } else if(arg=="-ring") {
           CoreApplication::checkOptionArg(i, argc, argv);
           _ring=CoreApplication::toInt(i, i-1, argv);
@@ -221,24 +235,18 @@ namespace QGpCoreStat {
         } else if(arg=="-max-noise") {
           CoreApplication::checkOptionArg(i, argc, argv);
           _noiseThreshold=CoreApplication::toDouble(i, i-1, argv);
-        } else if(arg=="-gm-type") {
-          CoreApplication::checkOptionArg(i, argc, argv);
-          _gaussMix.setInversionType(argv[i]);
         } else if(arg=="-gm-count") {
           CoreApplication::checkOptionArg(i, argc, argv);
           _gaussMix.setModeCount(CoreApplication::toInt(i, i-1, argv));
+        } else if(arg=="-gm-mean-spacing") {
+          CoreApplication::checkOptionArg(i, argc, argv);
+          _gaussMix.setMeanSpacingFactor(CoreApplication::toDouble(i, i-1, argv));
         } else if(arg=="-gm-kmin") {
           CoreApplication::checkOptionArg(i, argc, argv);
           _gaussMix.setKmin(CoreApplication::toDouble(i, i-1, argv));
         } else if(arg=="-gm-kmax") {
           CoreApplication::checkOptionArg(i, argc, argv);
           _gaussMix.setKmax(CoreApplication::toDouble(i, i-1, argv));
-        } else if(arg=="-gm-relerr") {
-          CoreApplication::checkOptionArg(i, argc, argv);
-          _gaussMix.setRelativeError(CoreApplication::toDouble(i, i-1, argv));
-        } else if(arg=="-gm-abserr") {
-          CoreApplication::checkOptionArg(i, argc, argv);
-          _gaussMix.setAbsoluteError(CoreApplication::toDouble(i, i-1, argv));
         } else if(arg=="-gm-verbose") {
           _gaussMix.setVerbose(true);
         } else if(arg=="-curve") {
@@ -255,14 +263,20 @@ namespace QGpCoreStat {
           _maxVariables=EllipticityFrequency;
         } else if(arg=="-ell-abs") {
           _maxVariables=EllipticityAbsFrequency;
+        } else if(arg=="-ell-neg") {
+          _maxVariables=EllipticityOppositeFrequency;
         } else if(arg=="-ell-deg") {
           _maxVariables=EllipticityDegFrequency;
-        } else if(arg=="-ell-inv-deg") {
-          _maxVariables=EllipticityDegInversedFrequency;
+        } else if(arg=="-ell-abs-deg") {
+          _maxVariables=EllipticityDegAbsFrequency;
+        } else if(arg=="-ell-neg-deg") {
+          _maxVariables=EllipticityDegOppositeFrequency;
         } else if(arg=="-ell-rad") {
           _maxVariables=EllipticityRadFrequency;
-        } else if(arg=="-ell-inv-rad") {
-          _maxVariables=EllipticityRadInversedFrequency;
+        } else if(arg=="-ell-abs-rad") {
+          _maxVariables=EllipticityRadAbsFrequency;
+        } else if(arg=="-ell-neg-rad") {
+          _maxVariables=EllipticityRadOppositeFrequency;
         } else if(arg=="-noise") {
           _maxVariables=NoiseFrequency;
         } else if(arg=="-s-k") {
@@ -301,7 +315,7 @@ namespace QGpCoreStat {
                                           "  asis       keep existing sampling\n"
                                           "  linear     regular sampling\n"
                                           "  log        regular sampling on a log scale\n"
-                                          "  inversed   regular sampling on an inversed");
+                                          "  inverse   regular sampling on an inverse scale");
     h->addOption("-x-min <MIN>","Minimum of range for X axis (default=deduced from data)");
     h->addOption("-x-max <MAX>","Maximum of range for X axis (default=deduced from data)");
     h->addOption("-x-step <STEP>","Step between samples along X.");
@@ -316,12 +330,14 @@ namespace QGpCoreStat {
     h->addOption("-y-sampling <SAMPLING>","Defines the Y sampling type:\n"
                                           "  linear     regular sampling (default)\n"
                                           "  log        regular sampling on a log scale\n"
-                                          "  inversed   regular sampling on an inversed");
+                                          "  inverse   regular sampling on an inverse scale");
     h->addOption("-y-min <MIN>","Minimum of range for Y axis (default=deduced from data)");
     h->addOption("-y-max <MAX>","Maximum of range for Y axis (default=deduced from data)");
     h->addOption("-x-step <STEP>","Step between samples along Y.");
     h->addOption("-y-count <COUNT>","Number of samples along Y");
     h->addOption("-y-factor <FACTOR>","Multiply all Y value by FACTOR (default=1)");
+    h->addOption("-y-periodic","Y values are periodic. The period is equal to the difference "
+                               "between min and max.");
     h->addOption("-y-title <TITLE>","Title for Y axis");
   }
 
@@ -333,7 +349,7 @@ namespace QGpCoreStat {
     h->addOption("-curve-format <FILE.ctparser>", "Use FILE to define curve format");
   }
 
-  bool HistogramReader::setDefaultXLimits(const QVector<double>& x)
+  bool HistogramReader::setDefaultXLimits(const VectorList<double>& x)
   {
     TRACE;
     _xValues=x;
@@ -361,9 +377,9 @@ namespace QGpCoreStat {
         }
         _xLogSampling=true;
         break;
-      case SamplingParameters::Inversed:
+      case SamplingParameters::Inverse:
         if(!_xSampling) {
-          App::log(tr("Identified an inversed scale for X\n"));
+          App::log(tr("Identified an inverse scale for X\n"));
         }
         _xLogSampling=false;
         break;
@@ -409,7 +425,7 @@ namespace QGpCoreStat {
 
   bool HistogramReader::setDefaultYLimits()
   {
-    QVector<Histogram2D::Sample>::iterator it;
+    VectorList<Histogram2D::Sample>::iterator it;
     double m;
     if(!_manual.y.minimum) {
       it=_samples.begin();
@@ -449,8 +465,8 @@ namespace QGpCoreStat {
       App::log(tr("No samples available\n") );
       return false;
     }
-    QVector<Histogram2D::Sample>::iterator it;
-    QVector<double> x;
+    VectorList<Histogram2D::Sample>::iterator it;
+    VectorList<double> x;
     for(it=_samples.begin(); it!=_samples.end(); it++) {
       x.append(it->x());
     }
@@ -482,8 +498,12 @@ namespace QGpCoreStat {
           maxFormatHeader=false;
         } else if(line=="# seconds from start | cfreq | slow | az | math-phi | semblance | beampow") {
           configureCapMaxFile();
+          maxFormatHeader=false;
         }
-      } while (maxFormatHeader || line.startsWith("#"));
+        if(s.atEnd()) {
+          break;
+        }
+      } while(maxFormatHeader || line.startsWith("#"));
     }
     // Effectively load samples, last line is provided because we may reading
     // stdin where seek() is not supported.
@@ -497,7 +517,8 @@ namespace QGpCoreStat {
     bool ok=true;
     QString line;
     if((_powerColumn<0 || _relativePowerThreshold==0.0) &&
-       (_noiseColumn<0 || _noiseThreshold==std::numeric_limits<double>::infinity()) &&
+       (_verticalNoiseColumn<0 || _noiseThreshold==std::numeric_limits<double>::infinity()) &&
+       (_horizontalNoiseColumn<0 || _noiseThreshold==std::numeric_limits<double>::infinity()) &&
        (_ringColumn<0 || _ring<0) &&
        !_manual.x.minimum && !_manual.x.maximum && !_manual.y.minimum && !_manual.y.maximum) {
       Histogram2D::Sample sample;
@@ -547,7 +568,9 @@ namespace QGpCoreStat {
       SampleFilter::Sample sample;
       SampleFilter filter;
       if(File::isDataLine(lastLine, _pattern)) {
-        if(sample.read(lastLine, _xColumn, _yColumn, _noiseColumn, _powerColumn, _ringColumn, _validColumn)) {
+        if(sample.read(lastLine, _xColumn, _yColumn,
+                       _verticalNoiseColumn, _horizontalNoiseColumn,
+                       _powerColumn, _ringColumn, _validColumn)) {
           if(_yFactor!=1.0) {
             sample.setY(sample.y()*_yFactor);
           }
@@ -559,7 +582,9 @@ namespace QGpCoreStat {
       if(_yFactor==1.0) {
         while(!s.atEnd()) {
           if(File::readLine(s, line, _pattern)) {
-            if(sample.read(line, _xColumn, _yColumn, _noiseColumn, _powerColumn, _ringColumn, _validColumn)) {
+            if(sample.read(line, _xColumn, _yColumn,
+                           _verticalNoiseColumn, _horizontalNoiseColumn,
+                           _powerColumn, _ringColumn, _validColumn)) {
               filter.append(sample);
             } else {
               ok=false;
@@ -571,7 +596,9 @@ namespace QGpCoreStat {
       } else {
         while(!s.atEnd()) {
           if(File::readLine(s, line, _pattern)) {
-            if(sample.read(line, _xColumn, _yColumn, _noiseColumn, _powerColumn, _ringColumn, _validColumn)) {
+            if(sample.read(line, _xColumn, _yColumn,
+                           _verticalNoiseColumn, _horizontalNoiseColumn,
+                           _powerColumn, _ringColumn, _validColumn)) {
               sample.setY(sample.y()*_yFactor);
               filter.append(sample);
             } else {
@@ -585,10 +612,9 @@ namespace QGpCoreStat {
       progress.end(filter.count());
       if(ok) {
         App::log(tr("Loaded %1 samples\n").arg(filter.count()) );
-        if(_yFactor!=1.0 || _maxVariables!=SlownessFrequency) {
+        if(_maxVariables!=SlownessFrequency) {
           for(SampleFilter::iterator it=filter.begin(); it!=filter.end(); it++) {
             SampleFilter::Sample& s=*it;
-            s.setY(s.y()*_yFactor);
             s=transformSample(s);
           }
         }
@@ -636,23 +662,66 @@ namespace QGpCoreStat {
     switch(_maxVariables) {
     case SlownessFrequency:
     case AzimuthFrequency:
-    case EllipticityFrequency:
     case NoiseFrequency:
       break;
-    case EllipticityAbsFrequency:
-      ns.setY(fabs(s.y()));
-      break;
     case EllipticityDegFrequency:
-      ns.setY(Angle::radiansToDegrees(::atan(s.y())));
+      if(!_angularEllipticity) {
+        ns.setY(Angle::radiansToDegrees(::atan(s.y())));
+      }
       break;
-    case EllipticityDegInversedFrequency:
-      ns.setY(Angle::radiansToDegrees(-::atan(s.y())));
+    case EllipticityDegAbsFrequency:
+      if(_angularEllipticity) {
+        ns.setY(fabs(s.y()));
+      } else {
+        ns.setY(fabs(Angle::radiansToDegrees(::atan(s.y()))));
+      }
+      break;
+    case EllipticityDegOppositeFrequency:
+      if(_angularEllipticity) {
+        ns.setY(-s.y());
+      } else {
+        ns.setY(-Angle::radiansToDegrees(::atan(s.y())));
+      }
+      break;
+    case EllipticityFrequency:
+      if(_angularEllipticity) {
+        ns.setY(::tan(Angle::degreesToRadians(s.y())));
+      }
+      break;
+    case EllipticityAbsFrequency:
+      if(_angularEllipticity) {
+        ns.setY(fabs(::tan(Angle::degreesToRadians(s.y()))));
+      } else {
+        ns.setY(fabs(s.y()));
+      }
+      break;
+    case EllipticityOppositeFrequency:
+      if(_angularEllipticity) {
+        ns.setY(-::tan(Angle::degreesToRadians(s.y())));
+      } else {
+        ns.setY(-s.y());
+      }
       break;
     case EllipticityRadFrequency:
-      ns.setY(::atan(s.y()));
+      if(_angularEllipticity) {
+        ns.setY(Angle::degreesToRadians(s.y()));
+      } else {
+        ns.setY(::atan(s.y()));
+      }
       break;
-    case EllipticityRadInversedFrequency:
-      ns.setY(-::atan(s.y()));
+    case EllipticityRadAbsFrequency:
+      if(_angularEllipticity) {
+        ns.setY(fabs(Angle::degreesToRadians(s.y())));
+      } else {
+        ns.setY(fabs(::atan(s.y())));
+      }
+      break;
+    case EllipticityRadOppositeFrequency:
+      if(_angularEllipticity) {
+        ns.setY(-Angle::degreesToRadians(s.y()));
+      } else {
+        ns.setY(-::atan(s.y()));
+      }
       break;
     case SlownessWaveNumber:
       ns.setX(2.0*M_PI*s.x()*s.y());
@@ -682,29 +751,41 @@ namespace QGpCoreStat {
   Histogram2D * HistogramReader::histogram(const SamplingParameters& ySampling) const
   {
     TRACE;
+    // Report first. In case of crash it is easier to debug.
+    if(_xSampling && _xSampling->isValid()) {
+      App::log(tr("  X axis %1\n").arg(_xSampling->toUserString()));
+    } else if(_xValues.count()>0) {
+      static const QString msg=tr("  X axis from %1 to %2 with %3 sample (step=as is)\n");
+      App::log(msg.arg(_xValues.first())
+                  .arg(_xValues.last())
+                  .arg(_xValues.count()));
+    }
+    App::log(tr("  Y axis %1\n").arg(ySampling.toUserString()));
+
+    if(!ySampling.isValid()) {
+      App::log(tr("  Y axis sampling not valid, try manual options.\n"));
+      return nullptr;
+    }
+
     Histogram2D * h;
-    if(_xSampling) {
+    if(_xSampling && _xSampling->isValid()) {
        h=new Histogram2D(_xSampling->count(), ySampling.count());
-       App::log(tr("X axis %1\n").arg(_xSampling->toUserString()));
        if(!h->setXSampling(*_xSampling)) {
          delete h;
          return nullptr;
        }
-    } else {
+    } else if(_xValues.count()>0) {
       h=new Histogram2D(_xValues.count(), ySampling.count());
-      static const QString msg=tr("X axis from %1 to %2 with %3 sample (step=as is)\n");
-      App::log(msg.arg(_xValues.first())
-                  .arg(_xValues.last())
-                  .arg(_xValues.count())
-                  .arg("asis")
-                  .arg("X"));
       if(!h->setXSampling(_xValues)) {
         delete h;
         return nullptr;
       }
+    } else {
+      App::log(tr("  X axis sampling not valid, try manual options.\n"));
+      return nullptr;
     }
     h->setXTitle(_xTitle);
-    h->setXTitleInversedScale(_xTitleInversedScale);
+    h->setXTitleInverseScale(_xTitleInverseScale);
     if(_manual.x.viewScaleType) {
       h->setXScaleType(_xScaleType);
     } else {
@@ -715,13 +796,13 @@ namespace QGpCoreStat {
       }
     }
 
-    App::log(tr("Y axis %1\n").arg(ySampling.toUserString()));
     if(!ySampling.isValid() || !h->setYSampling(ySampling)) {
       delete h;
       return nullptr;
     }
+    h->setPeriodic(_yPeriodic);
     h->setYTitle(_yTitle);
-    h->setYTitleInversedScale(_yTitleInversedScale);
+    h->setYTitleInverseScale(_yTitleInverseScale);
     if(_manual.y.viewScaleType) {
       h->setYScaleType(_yScaleType);
     } else {
@@ -732,8 +813,8 @@ namespace QGpCoreStat {
       case SamplingParameters::Log:
         h->setYScaleType(Scale::Log);
         break;
-      case SamplingParameters::Inversed:
-        h->setYScaleType(Scale::Inversed);
+      case SamplingParameters::Inverse:
+        h->setYScaleType(Scale::Inverse);
         break;
       }
     }
@@ -753,12 +834,25 @@ namespace QGpCoreStat {
   bool HistogramReader::configureFKMaxFile(const QString& line)
   {
     int slownessColumn=-1, azimuthColumn=-1, ellipticityColumn=-1;
+
     _validColumn=-1;
-    if(line=="# abs_time frequency slowness azimuth ellipticity noise power valid") {
+    if(line=="# abs_time frequency slowness azimuth ellipticity Rz/N Rh/N power valid") {
       slownessColumn=2;
       azimuthColumn=3;
       ellipticityColumn=4;
-      _noiseColumn=5;
+      _verticalNoiseColumn=5;
+      _horizontalNoiseColumn=6;
+      _powerColumn=7;
+      if(!_ignoreValid) {
+        _validColumn=8;
+      }
+    } else if(line=="# abs_time frequency slowness azimuth ellipticity noise power valid") {
+      slownessColumn=2;
+      azimuthColumn=3;
+      ellipticityColumn=4;
+      _angularEllipticity=false;
+      _verticalNoiseColumn=5;
+      _horizontalNoiseColumn=5;
       _powerColumn=6;
       if(!_ignoreValid) {
         _validColumn=7;
@@ -769,7 +863,9 @@ namespace QGpCoreStat {
       slownessColumn=3;
       azimuthColumn=4;
       ellipticityColumn=5;
-      _noiseColumn=6;
+      _angularEllipticity=false;
+      _verticalNoiseColumn=6;
+      _horizontalNoiseColumn=6;
       _powerColumn=7;
       if(!_ignoreValid) {
         _validColumn=8;
@@ -779,6 +875,9 @@ namespace QGpCoreStat {
       slownessColumn=3;
       azimuthColumn=4;
       ellipticityColumn=5;
+      _angularEllipticity=false;
+      _verticalNoiseColumn=-1;
+      _horizontalNoiseColumn=-1;
       _powerColumn=6;
       if(!_ignoreValid) {
         _validColumn=7;
@@ -788,6 +887,10 @@ namespace QGpCoreStat {
       slownessColumn=3;
       azimuthColumn=4;
       ellipticityColumn=5;
+      _angularEllipticity=false;
+      _verticalNoiseColumn=-1;
+      _horizontalNoiseColumn=-1;
+      _powerColumn=-1;
       if(!_ignoreValid) {
         _validColumn=6;
       }
@@ -796,6 +899,9 @@ namespace QGpCoreStat {
       // Option -ell* will ouput junk for these results
       slownessColumn=3;
       azimuthColumn=4;
+      _verticalNoiseColumn=-1;
+      _horizontalNoiseColumn=-1;
+      _powerColumn=-1;
       if(!_ignoreValid) {
         _validColumn=5;
       }
@@ -804,7 +910,7 @@ namespace QGpCoreStat {
       App::log(tr("Unrecognized header line:\n  '%1'\n").arg(line));
       return false;
     }
-    _headerLine="# abs_time frequency slowness azimuth ellipticity noise power valid\n";
+    _headerLine="# abs_time frequency slowness azimuth ellipticity Rz/N Rh/N power valid\n";
 
     // X title
     switch(_maxVariables) {
@@ -812,19 +918,22 @@ namespace QGpCoreStat {
     case AzimuthFrequency:
     case EllipticityFrequency:
     case EllipticityAbsFrequency:
+    case EllipticityOppositeFrequency:
     case EllipticityDegFrequency:
-    case EllipticityDegInversedFrequency:
+    case EllipticityDegAbsFrequency:
+    case EllipticityDegOppositeFrequency:
     case EllipticityRadFrequency:
-    case EllipticityRadInversedFrequency:
+    case EllipticityRadAbsFrequency:
+    case EllipticityRadOppositeFrequency:
     case NoiseFrequency:
     case WaveNumberFrequency:
     case WaveLengthFrequency:
       _xTitle=tr("Frequency (Hz)");
-      _xTitleInversedScale=tr("Period (s)");
+      _xTitleInverseScale=tr("Period (s)");
       break;
     case SlownessPeriod:
       _xTitle=tr("Period (s)");
-      _xTitleInversedScale=tr("Frequency (Hz)");
+      _xTitleInverseScale=tr("Frequency (Hz)");
       break;
     case SlownessWaveNumber:
     case FrequencyWaveNumber:
@@ -842,7 +951,7 @@ namespace QGpCoreStat {
     case SlownessWaveNumber:
     case SlownessWaveLength:
       _yTitle=tr("Slowness (s/m)");
-      _yTitleInversedScale=tr("Velocity (m/s)");
+      _yTitleInverseScale=tr("Velocity (m/s)");
       _yColumn=slownessColumn;
       break;
     case WaveNumberFrequency:
@@ -855,7 +964,7 @@ namespace QGpCoreStat {
       break;
     case FrequencyWaveNumber:
       _yTitle=tr("Frequency (Hz)");
-      _yTitleInversedScale=tr("Period (s)");
+      _yTitleInverseScale=tr("Period (s)");
       _yColumn=slownessColumn;
       break;
     case AzimuthFrequency:
@@ -865,24 +974,48 @@ namespace QGpCoreStat {
     case EllipticityFrequency:
       _yTitle=tr("Ellipticity");
       _yColumn=ellipticityColumn;
+      _yPeriodic=true;
       break;
     case EllipticityAbsFrequency:
-      _yTitle=tr("Ellipticity");
+      _yTitle=tr("Abs. ellipticity");
       _yColumn=ellipticityColumn;
       break;
+    case EllipticityOppositeFrequency:
+      _yTitle=tr("-ellipticity");
+      _yColumn=ellipticityColumn;
+      _yPeriodic=true;
+      break;
     case EllipticityDegFrequency:
-    case EllipticityDegInversedFrequency:
       _yTitle=tr("Ellipticity angle (deg)");
       _yColumn=ellipticityColumn;
+      _yPeriodic=true;
+      break;
+    case EllipticityDegAbsFrequency:
+      _yTitle=tr("Abs. ellipticity angle (deg)");
+      _yColumn=ellipticityColumn;
+      break;
+    case EllipticityDegOppositeFrequency:
+      _yTitle=tr("-Ellipticity angle (deg)");
+      _yColumn=ellipticityColumn;
+      _yPeriodic=true;
       break;
     case EllipticityRadFrequency:
-    case EllipticityRadInversedFrequency:
       _yTitle=tr("Ellipticity angle (rad)");
       _yColumn=ellipticityColumn;
+      _yPeriodic=true;
+      break;
+    case EllipticityRadAbsFrequency:
+      _yTitle=tr("Abs. ellipticity angle (rad)");
+      _yColumn=ellipticityColumn;
+      break;
+    case EllipticityRadOppositeFrequency:
+      _yTitle=tr("-Ellipticity angle (rad)");
+      _yColumn=ellipticityColumn;
+      _yPeriodic=true;
       break;
     case NoiseFrequency:
       _yTitle=tr("Relative incoherent noise");
-      _yColumn=_noiseColumn;
+      _yColumn=_verticalNoiseColumn;
       break;
     }
     // Y limits and sampling
@@ -898,7 +1031,7 @@ namespace QGpCoreStat {
           _ySampling.setStep(1.015);
           _manual.y.stepCount=true;
         }
-        _yScaleType=Scale::InversedLog;
+        _yScaleType=Scale::InverseLog;
         _manual.y.viewScaleType=true;
       }
       break;
@@ -922,6 +1055,7 @@ namespace QGpCoreStat {
       }
       break;
     case EllipticityFrequency:
+    case EllipticityOppositeFrequency:
       if(!_manual.y.minimum) {
         _ySampling.setMinimum(-10.0);
         _manual.y.minimum=true;
@@ -951,7 +1085,7 @@ namespace QGpCoreStat {
       }
       break;
     case EllipticityDegFrequency:
-    case EllipticityDegInversedFrequency:
+    case EllipticityDegOppositeFrequency:
       if(!_manual.y.minimum) {
         _ySampling.setMinimum(-90.0);
         _manual.y.minimum=true;
@@ -965,8 +1099,22 @@ namespace QGpCoreStat {
         _manual.y.stepCount=true;
       }
       break;
+    case EllipticityDegAbsFrequency:
+      if(!_manual.y.minimum) {
+        _ySampling.setMinimum(0.0);
+        _manual.y.minimum=true;
+      }
+      if(!_manual.y.maximum) {
+        _ySampling.setMaximum(90.0);
+        _manual.y.maximum=true;
+      }
+      if(!_manual.y.stepCount) {
+        _ySampling.setStep(1.0);
+        _manual.y.stepCount=true;
+      }
+      break;
     case EllipticityRadFrequency:
-    case EllipticityRadInversedFrequency:
+    case EllipticityRadOppositeFrequency:
       if(!_manual.y.minimum) {
         _ySampling.setMinimum(-0.5*M_PI);
         _manual.y.minimum=true;
@@ -980,6 +1128,20 @@ namespace QGpCoreStat {
         _manual.y.stepCount=true;
       }
       break;
+    case EllipticityRadAbsFrequency:
+      if(!_manual.y.minimum) {
+        _ySampling.setMinimum(0.0);
+        _manual.y.minimum=true;
+      }
+      if(!_manual.y.maximum) {
+        _ySampling.setMaximum(0.5*M_PI);
+        _manual.y.maximum=true;
+      }
+      if(!_manual.y.stepCount) {
+        _ySampling.setCount(200);
+        _manual.y.stepCount=true;
+      }
+      break;
     case NoiseFrequency:
       if(!_manual.y.minimum) {
         _ySampling.setMinimum(0.1);
@@ -1007,10 +1169,13 @@ namespace QGpCoreStat {
     case AzimuthFrequency:
     case EllipticityFrequency:
     case EllipticityAbsFrequency:
+    case EllipticityOppositeFrequency:
     case EllipticityDegFrequency:
-    case EllipticityDegInversedFrequency:
+    case EllipticityDegAbsFrequency:
+    case EllipticityDegOppositeFrequency:
     case EllipticityRadFrequency:
-    case EllipticityRadInversedFrequency:
+    case EllipticityRadAbsFrequency:
+    case EllipticityRadOppositeFrequency:
     case NoiseFrequency:
       break;
     case SlownessWaveLength:
@@ -1047,10 +1212,10 @@ namespace QGpCoreStat {
     _validColumn=5;
     _headerLine="# abs_time frequency polarization ring autocorr valid\n";
     _xTitle=tr("Frequency (Hz)");
-    _xTitleInversedScale=tr("Period (s)");
+    _xTitleInverseScale=tr("Period (s)");
     _xColumn=1;
     _yTitle=tr("Autocorr ratio");
-    _yTitleInversedScale="";
+    _yTitleInverseScale="";
     _yColumn=4;
     _ringColumn=3;
   }
@@ -1090,10 +1255,13 @@ namespace QGpCoreStat {
       break;
     case EllipticityFrequency:
     case EllipticityAbsFrequency:
+    case EllipticityOppositeFrequency:
     case EllipticityDegFrequency:
-    case EllipticityDegInversedFrequency:
+    case EllipticityDegAbsFrequency:
+    case EllipticityDegOppositeFrequency:
     case EllipticityRadFrequency:
-    case EllipticityRadInversedFrequency:
+    case EllipticityRadAbsFrequency:
+    case EllipticityRadOppositeFrequency:
     case NoiseFrequency:
     case SlownessWaveNumber:
     case SlownessWaveLength:
@@ -1107,4 +1275,96 @@ namespace QGpCoreStat {
     App::log(tr("Old slowness max file (before 2017)\n") );
   }
 
+  Curve<Point2D> HistogramReader::misfit(bool& ok) const
+  {
+    Curve<Point2D> m;
+    if(!_xSampling) {
+      App::log(tr("No sampling for X defined\n"));
+      ok=false;
+      return m;
+    }
+    for(int i=0; i<_xSampling->count(); i++) {
+      m.append(Point2D(_xSampling->value(i), 0.0));
+    }
+    if(_xSampling->scaleType()!=SamplingParameters::Log) {
+      App::log(tr("Only log sampling is accepted\n"));
+      ok=false;
+      return m;
+    }
+    if(_curveFileNames.isEmpty()) {
+      App::log(tr("No curves provided for misfit\n"));
+      ok=false;
+      return m;
+    }
+    QStringList expandedFileNames=File::expand(_curveFileNames);
+    QList<Curve<Point2D>> curves;
+    for(QStringList::const_iterator it=expandedFileNames.begin(); it!=expandedFileNames.end(); it++) {
+      Curve<Point2D> c;
+      QFile f(*it);
+      if(f.open(QIODevice::ReadOnly)) {
+        QTextStream s(&f);
+        while(c.fromStream(s)) {
+          if(!c.isEmpty()) {
+            c.sort();
+            curves.append(c);
+          }
+        }
+        if(!c.isEmpty()) {
+          c.sort();
+          curves.append(c);
+        }
+      } else {
+        App::log(tr("Cannot open file '%1'\n").arg(*it));
+        ok=false;
+        return m;
+      }
+    }
+    int * hitCount=new int[m.count()];
+    for(int i=m.count()-1; i>=0; i--) {
+      hitCount[i]=0;
+    }
+    misfit(curves, m, hitCount, 0.5*(_xSampling->step()-1.0));
+    for(int i=m.count()-1; i>=0; i--) {
+      Point2D& mp=m.constXAt(i);
+      if(hitCount[i]>0) {
+        mp.setY(mp.y()/static_cast<double>(hitCount[i]));
+      }
+    }
+    delete [] hitCount;
+    m.ySqrt();
+    return m;
+  }
+
+  void HistogramReader::misfit(const QList<Curve<Point2D>>& curves, Curve<Point2D>& m,
+                               int * hitCount, double precision) const
+  {
+    SamplingOptions xSamp, ySamp;
+    if(_xSampling) {
+      xSamp=SamplingParameters::samplingOptions(_xSampling->scaleType());
+    } else {
+      xSamp=LinearScale;
+    }
+    ySamp=SamplingParameters::samplingOptions(_ySampling.scaleType());
+    App::log(tr("%1 curves loaded, starting misfit on %2 samples...\n")
+             .arg(curves.count())
+             .arg(_samples.count()));
+    VectorList<Histogram2D::Sample>::const_iterator it;
+    QList<Curve<Point2D>>::const_iterator itc;
+    for(it=_samples.begin(); it!=_samples.end(); it++) {
+      // Get the curve with the minimum distance to the current sample.
+      double minDy=std::numeric_limits<double>::infinity();
+      for(itc=curves.begin(); itc!=curves.end(); it++) {
+        const Curve<Point2D>& c=*itc;
+        double dy=fabs(1.0-it->y()/c.interpole(it->x(), xSamp, ySamp).y());
+        if(dy<minDy) {
+          minDy=dy;
+        }
+      }
+      int i=m.indexOf(it->x(), precision);
+      Point2D& mp=m.constXAt(i);
+      mp.setY(mp.y()+minDy*minDy);
+      hitCount[i]++;
+    }
+  }
+
 } // namespace QGpCoreStat
