@@ -51,8 +51,14 @@ namespace QGpCoreTools {
     QMap<QString, Keyword>::const_iterator it;
     it=QMap<QString, Keyword>::find(cleanKey);
     if(it!=end()) {
-      return it.value().param->setValue(it.value().index, value, unit, *this);
+      if(it.value().param->setValue(it.value().index, value, unit, *this)) {
+        return true;
+      } else {
+        App::log(tr("Error setting value '%1' to keyword '%2'\n").arg(value).arg(cleanKey));
+        return false;
+      }
     } else {
+      App::log(tr("Unknown keyword '%1'\n").arg(cleanKey));
       return false;
     }
   }
@@ -74,13 +80,6 @@ namespace QGpCoreTools {
     _unit=unit;
   }
 
-  inline AbstractParameters::ParameterValue::ParameterValue(const ParameterValue& o)
-  {
-    _key=o._key;
-    _value=o._value;
-    _unit=o._unit;
-  }
-
   inline bool AbstractParameters::ParameterValue::set(const KeywordMap& map) const
   {
     return map.setValue(_key, _value, _unit);
@@ -169,6 +168,9 @@ namespace QGpCoreTools {
   /*!
     Do not call this function in re-implementations to avoid several
     'PARAMETERS VERSION' in file output. Called once directly by save().
+
+    TODO: on branch 3.5, add non virtual function toString() that includes the version
+          search for all direct usage of this function. Remove default values for the virtual function.
   */
   QString AbstractParameters::toString(PARAMETERS_TOSTRING_ARGS_IMPL) const
   {
@@ -177,7 +179,8 @@ namespace QGpCoreTools {
     Q_UNUSED(suffix)
     QString log;
     log+="# Version 0: all files generated with releases before 20170901 (default for input)\n";
-    log+=prefix+"PARAMETERS_VERSION"+suffix+"="+QString::number(_version)+"\n";
+    // Do not save the actual version but the latest.
+    log+=prefix+"PARAMETERS_VERSION"+suffix+"="+QString::number(PARAMETERS_VERSION)+"\n";
     return log;
   }
 
@@ -228,6 +231,29 @@ namespace QGpCoreTools {
           return true;
         }
       } else {
+        if(line.endsWith("\\")) {
+          QString subLine;
+          while(!s.atEnd()) {
+            subLine=s.readLine().trimmed();
+            if(subLine.left(1)=="#") {
+              if(!endPattern.isEmpty() && line.contains(endPattern)) {
+                App::log(tr("Truncated multi-line value\n"));
+                delete keywords;
+                return false;
+              }
+            } else {
+              line=line.chopped(1).trimmed()+subLine;
+              if(!line.endsWith("\\")) {
+                break;
+              }
+            }
+          }
+          if(line.endsWith("\\")) {
+            App::log(tr("Truncated multi-line value (end of file)\n"));
+            delete keywords;
+            return false;
+          }
+        }
         if(!parse(line, keywords)) {
           delete keywords;
           return false;
@@ -243,7 +269,7 @@ namespace QGpCoreTools {
     TRACE;
     QString keyword, unit, value;
     const QChar * ptrBegin=line.data();
-    const QChar * ptrEnd=ptrBegin+line.count();
+    const QChar * ptrEnd=ptrBegin+line.size();
     const QChar * ptr=ptrBegin;
     KeywordMap * myOwnKeywords;
     if(!keywords) {
@@ -258,10 +284,10 @@ namespace QGpCoreTools {
         if(keyword.isEmpty()) { // no unit found
           keyword=QString(ptrBegin, static_cast<int>(ptr-ptrBegin)).trimmed();
         }
-        value=QString(ptr+1, static_cast<int>(line.count()-(ptr-line.data()+1))).trimmed();
+        value=QString(ptr+1, static_cast<int>(line.size()-(ptr-line.data()+1))).trimmed();
         // Store modified values
         if(!_values) {
-          _values=new QVector<ParameterValue>;
+          _values=new VectorList<ParameterValue>;
         }
         _values->append(ParameterValue(keyword,value, unit));
         // Apply modification if keywords are provided
@@ -269,8 +295,6 @@ namespace QGpCoreTools {
           delete myOwnKeywords;
           return true;
         } else {
-          Message::warning(MSG_ID,tr("Loading parameters"),
-                           tr("Unknown keyword '%1' or error setting value '%2'").arg(keyword).arg(value), Message::cancel(), true);
           delete myOwnKeywords;
           return false;
         }
@@ -289,6 +313,8 @@ namespace QGpCoreTools {
       }
       ptr++;
     }
+    Message::warning(MSG_ID,tr("Loading parameters"),
+                     tr("No keyword found in line '%1'").arg(line), Message::cancel(), true);
     delete myOwnKeywords;
     return false;
   }
@@ -347,6 +373,10 @@ namespace QGpCoreTools {
     return keywords;
   }
 
+  /*!
+    While parsing the modified parameters are stored.
+    They can be applied to another parameter set.
+  */
   bool AbstractParameters::setValues(const AbstractParameters& o)
   {
     TRACE;
@@ -367,4 +397,15 @@ namespace QGpCoreTools {
     return true;
   }
 
+  void AbstractParameters::addValues(const AbstractParameters& o)
+  {
+    if(o._values) {
+      if(_values) {
+        _values->append(*o._values);
+      } else {
+        _values=new VectorList<ParameterValue>(*o._values);
+      }
+    }
+  }
+
 } // namespace QGpCoreTools
