@@ -42,7 +42,7 @@ namespace QGpCoreTools {
     \li columnCount() which counts the available columns. Columns are separated by blanks.
         Values fields cannot be retrieved. This is a fast way for counting columns only.
     \li readColumn() which reads only one value per line. Nothing else than this value can
-        be read. Access the field value with toInt(0), toDouble(0) and toString(0).
+        be read. Access the field value with toInt(0), toDouble(0) and toString('g', 0).
     \li readColumns() which reads a few values per line. Nothing else than these values can
         be read. Access the field value with toInt(), toDouble() and toString().
     \li use the toInt(), toDouble() and toString() functions with two integers as arguments
@@ -126,7 +126,7 @@ namespace QGpCoreTools {
   void AsciiLineParser::reset(QByteArray * buffer)
   {
     _buffer=buffer->data();
-    _bufferSize=buffer->count();
+    _bufferSize=buffer->size();
     _index=0;
   }
 
@@ -159,9 +159,14 @@ namespace QGpCoreTools {
       switch(_buffer[iBuffer]) {
       case '\n':
         _buffer[iBuffer]='\0';
-#if __clang__
-      [[clang::fallthrough]];
-#endif
+        if(iBuffer>iBeginValue || _emptyValues) {
+          _values[iValue]=_buffer+iBeginValue;
+          _valueCount=iValue+1;
+        } else {
+          _valueCount=iValue;
+        }
+        _index=iBuffer+1;
+        return;
       case '\0':
         if(iBuffer>iBeginValue || _emptyValues) {
           _values[iValue]=_buffer+iBeginValue;
@@ -662,7 +667,7 @@ namespace QGpCoreTools {
     return sep;
   }
 
-  AsciiLineParser::Separators AsciiLineParser::userStringToSeparators(const QString& s)
+  AsciiLineParser::Separators AsciiLineParser::userStringToSeparators(const StringView& s)
   {
     Separators sep=None;
     if(s.contains(tr("TAB"))) {
