@@ -43,14 +43,11 @@ typedef double v2df __attribute__ ((vector_size (16)));
 class QGPCORETOOLS_EXPORT Complex
 {
 public:
-  inline Complex(const Complex& c);
   inline Complex(double re=0, double im=0);
-  ~Complex() {}
 
   inline bool operator==(const Complex& c) const;
   inline bool operator!=(const Complex& c) const;
 
-  inline Complex& operator=(const Complex& c);
   inline Complex& operator+=(const Complex& c);
   inline Complex& operator-=(const Complex& c);
   inline Complex& operator*=(const Complex& c);
@@ -62,6 +59,8 @@ public:
   inline Complex& operator*=(const double& d);
   inline Complex& operator/=(const double& d);
 
+  inline Complex& imaginaryMultiply(const double& im);
+
   inline Complex operator+(const Complex& c) const;
   inline Complex operator-(const Complex& c) const;
   inline Complex operator*(const Complex& c) const;
@@ -89,6 +88,7 @@ public:
     _data.values.im=::sin(arg);
   }
   void conjugate() {_data.values.im=-_data.values.im;}
+  inline void conjugate(const Complex& o);
   double abs() const {return ::sqrt(abs2());}
   double abs2() const {return _data.values.re*_data.values.re+_data.values.im*_data.values.im;}
   double phase() const {return atan2(_data.values.im, _data.values.re);}
@@ -97,8 +97,6 @@ public:
 
   bool fromString(const StringSection& str);
   QString toString(char format='g', int precision=6) const;
-
-  static const Complex null;
 private:
   union {
     v2df vector;
@@ -115,6 +113,7 @@ inline Complex operator*(const double& d, const Complex& c);
 inline Complex operator/(const double& d, const Complex& c);
 
 inline Complex sqrt(const Complex& c);
+inline Complex pow(const Complex& c, double exp);
 inline Complex cos(const Complex& c);
 inline Complex sin(const Complex& c);
 inline Complex tan(const Complex& c);
@@ -131,16 +130,6 @@ QGPCORETOOLS_EXPORT QTextStream& operator>> (QTextStream& s, Complex& c);
 QGPCORETOOLS_EXPORT QDataStream& operator<< (QDataStream& s, const Complex& c);
 QGPCORETOOLS_EXPORT QDataStream& operator>> (QDataStream& s, Complex& c);
 
-inline Complex::Complex(const Complex& c)
-{
-#if defined(__SSE__)
-  _data.vector=c._data.vector;
-#else
-  _data.values.re=c._data.values.re;
-  _data.values.im=c._data.values.im;
-#endif
-}
-
 inline Complex::Complex(double re, double im)
 {
   _data.values.re=re;
@@ -164,17 +153,6 @@ inline Complex& Complex::operator=(const double& d)
   return *this;
 }
 
-inline Complex& Complex::operator=(const Complex& c)
-{
-#ifdef __SSE__
-  _data.vector=c._data.vector;
-#else
-  _data.values.re=c._data.values.re;
-  _data.values.im=c._data.values.im;
-#endif
-  return *this;
-}
-
 inline Complex& Complex::operator+=(const double& d)
 {
   _data.values.re+=d;
@@ -216,17 +194,25 @@ inline Complex& Complex::operator*=(const double& d)
   return *this;
 }
 
+inline Complex& Complex::imaginaryMultiply(const double& im)
+{
+  double re=_data.values.re;
+  _data.values.re=-_data.values.im*im;
+  _data.values.im=re*im;
+  return *this;
+}
+
 inline Complex& Complex::operator*=(const Complex& c)
 {
   // __builtin_ia32_shufpd not available for clang++ under Mac OS X
   // TODO switch to _builtin_shuffle() https://gcc.gnu.org/onlinedocs/gcc/Vector-Extensions.html#Vector-Extensions
-#if defined(__SSE3__) && !defined(Q_OS_MAC)
+#if defined(__SSE3__) && !defined(Q_OS_DARWIN)
   v2df thisIm=__builtin_ia32_shufpd(_data.vector, _data.vector, 3);       // Im part of this in both
   v2df thisRe=__builtin_ia32_shufpd(_data.vector, _data.vector, 0);       // Re part of this in both
   v2df c_flipped=__builtin_ia32_shufpd(c._data.vector, c._data.vector, 1);  // Swap re and im parts of c
   _data.vector=__builtin_ia32_addsubpd(__builtin_ia32_mulpd(thisRe, c._data.vector),
                                        __builtin_ia32_mulpd(thisIm, c_flipped));
-#elif defined(__SSE2__) && !defined(Q_OS_MAC)
+#elif defined(__SSE2__) && !defined(Q_OS_DARWIN)
   v2df thisIm=__builtin_ia32_shufpd(_data.vector, _data.vector,3);       // Im part of this in both
   v2df thisRe=__builtin_ia32_shufpd(_data.vector, _data.vector,0);       // Re part of this in both
   v2df c_flipped=__builtin_ia32_shufpd(c._data.vector,c._data.vector,1); // Swap re and im parts of c
@@ -346,6 +332,12 @@ inline Complex Complex::operator/(const Complex& c) const
   return r;
 }
 
+inline void Complex::conjugate(const Complex& o)
+{
+  _data.values.re=o._data.values.re;
+  _data.values.im=-o._data.values.im;
+}
+
 inline Complex sqrt(const Complex& c)
 {
   double r2=::sqrt(c.abs());
@@ -353,6 +345,13 @@ inline Complex sqrt(const Complex& c)
   return Complex(r2*::cos(phi2), r2*::sin(phi2));
 }
 
+inline Complex pow(const Complex& c, double exp)
+{
+  double r2=::pow(c.abs(), exp);
+  double phi2=c.phase()*exp;
+  return Complex(r2*::cos(phi2), r2*::sin(phi2));
+}
+
 inline Complex inverse(const Complex& c)
 {
   double m2=1.0/c.abs2();
@@ -398,6 +397,11 @@ inline Complex conjugate(const Complex& c)
   return Complex(c.re(), -c.im());
 }
 
+inline double conjugate(double r)
+{
+  return r;
+}
+
 double abs(const Complex& c)
 {
   return c.abs();
