@@ -45,11 +45,12 @@
 #  include <sys/types.h>
 #  include <sys/param.h>
 #endif
-#ifdef Q_OS_MAC
+#ifdef Q_OS_DARWIN
 #  include <sys/sysctl.h>
 #endif
 
 #include "CoreApplicationPrivate.h"
+#include "CoreApplication.h"
 #include "StandardStream.h"
 #include "Thread.h"
 #include "TraceBug.h"
@@ -64,7 +65,7 @@
 #include "XMLClassFactory.h"
 #include "MemoryCheckerPrivate.h"
 #include "QGpCoreToolsVersion.h"
-#include "Thread.h"
+#include "EnumAsString.h"
 
 namespace QGpCoreTools {
 
@@ -123,15 +124,8 @@ namespace QGpCoreTools {
     // Size of terminal
     _terminalCols=0;
     _terminalRows=0;
-    // Maximum number of thread for parallel jobs. On environment like OAR, maximum number of thread
-    // takes CPU affinity list into account.
-    Thread::initCPUAffinityList();
-    _maximumThreadCount=QThread::idealThreadCount(); // CPU Affinity is not considered by Qt
-    _maximumThreadCount=Thread::idealThreadCount();  // Uses maximumThreadCount initialized before
     // Debug or not user interrupts, can be turned on or off when waiting for stdin for instance.
-    _debugUserInterrupts=false;
-    _reportBugs=false;
-    _warningAsError=false;
+    _bugReportOptions=NoBugReport;
     _batch=true;    // Core application are by default in batch
                     // But their argument list is saved except if
                     // option -batch is explicitly used
@@ -155,41 +149,61 @@ namespace QGpCoreTools {
       } else if(arg=="--verbosity" || arg=="-verbosity") {
         checkOptionArg(i, argc, argv, true);
         AbstractStream::setApplicationVerbosity(toInt(i, i-1, argv));
-      } else if(arg=="-warning-critical") {
-        _warningAsError=true;
       } else if(arg=="-locale") {
         checkOptionArg(i, argc, argv, true);
         QLocale::setDefault(QLocale(argv[i]));
       } else if(arg=="-sleep") {
         checkOptionArg(i, argc, argv, true);
         sleep(toInt(i, i-1, argv)*1000);
-      } else if(arg=="-j" || arg=="-jobs") {
-        checkOptionArg(i, argc, argv, true);
-        _maximumThreadCount=toInt(i, i-1, argv);
-        QTextStream sOut(stderr);
-        if(_maximumThreadCount<1) {
-          sOut << tr("Negative or null maximum number of jobs: '%1'").arg(_maximumThreadCount) << ::endl;
-          ::exit(2);
-        }
-        if(_maximumThreadCount>2*QThread::idealThreadCount()) {
-          QTextStream sOut(stderr);
-          sOut << tr("Too many parallel jobs compared to the number of physical cores (option -j or -jobs).\n"
-              "Maximum value is %1.").arg(QThread::idealThreadCount()) << Qt::endl;
-          ::exit(2);
-        }
-#ifdef Q_OS_MAC
+#ifdef Q_OS_DARWIN
       } else if(arg.left(5)=="-psn_") { // does nothing: just get rid of that argument
-#endif // Q_OS_MAC
+#endif // Q_OS_DARWIN
       } else {
         argv[j++]=argv[i];
       }
     }
-    if(j < argc) {
+    if(j<argc) {
       argv[j]=nullptr;
       argc=j;
     }
-
+    // Option -locale may have changed default value
     _numberEngine=new Number;
+
+    // Set number of concurrent threads after reading verbosity option.
+    // Number of cores assuming hyperthreading
+    _maximumThreadCount=std::thread::hardware_concurrency()/2;
+    j=1;
+    for(i=1; i<argc; i++) {
+      QByteArray arg=argv[i];
+      if(arg=="-task-manager") {
+        // Maximum number of thread for parallel jobs. On environment like OAR, the maximum number of threads
+        // takes the CPU affinity list into account. Option -j is disregarded unless it is placed after this one.
+        setCPUAffinityList(0);
+      } else if(arg=="-j" || arg=="-jobs") {
+        checkOptionArg(i, argc, argv, true);
+        int userForcedMaxCount=toInt(i, i-1, argv);
+        QTextStream sOut(stderr);
+        if(userForcedMaxCount<1) {
+          sOut << tr("Negative or null maximum number of parallel jobs: '%1'").arg(userForcedMaxCount) << Qt::endl;
+          ::exit(2);
+        }
+        if(userForcedMaxCount>3*_maximumThreadCount) {
+          sOut << tr("Too many parallel jobs compared to the number of physical cores (option -j or -jobs).\n"
+                     "Optimal value is %1.").arg(_maximumThreadCount) << Qt::endl;
+          ::exit(2);
+        }
+        _maximumThreadCount=userForcedMaxCount;
+        if(_cpuAffinities.size()>_maximumThreadCount) {
+          setCPUAffinityList(_maximumThreadCount);
+        }
+      } else {
+        argv[j++]=argv[i];
+      }
+    }
+    if(j<argc) {
+      argv[j]=nullptr;
+      argc=j;
+    }
   }
 
   /*!
@@ -200,6 +214,8 @@ namespace QGpCoreTools {
     delete _numberEngine;
     delete _globalSettings;
     delete _settings;
+    _self=nullptr;
+
   }
 
   /*!
@@ -210,11 +226,21 @@ namespace QGpCoreTools {
   {
     delete _pathTranslator;
     XMLClassFactory::clearFactories();
+    EnumAsString::deleteAllEnums();
     delete _messageHandler;
     qDeleteAll(_plugins);
     TraceLog::clearMainVector();
-      // Cleanup global pointers
-    qDeleteAll(_globalPointers);
+    // Cleanup global pointers
+    // Some global pointers may delete other global pointers in their destructors.
+    // The list of global pointers must be maintained up-to-date while destroying.
+    // A qDeleteAll() is leading to a crash for instance with GeopsyCoreEngine.
+    QMutableListIterator<GlobalObject *> it(_globalPointers);
+    GlobalObject * ptr;
+    while(it.hasNext()) {
+      ptr=it.next();
+      it.remove();
+      delete ptr;
+    }
     // Clear streams
     foreach(AbstractStream * s, _streams) {
       AbstractStream::removeReference(s);
@@ -225,10 +251,55 @@ namespace QGpCoreTools {
     }
   }
 
-  void CoreApplicationPrivate::initInternalDebugger(bool reportBugs)
+  /*!
+    Get CPU affinity list.
+
+    If \a maxCoreCount is null, the physical core number is taken as a limit.
+  */
+  void CoreApplicationPrivate::setCPUAffinityList(int maxCoreCount)
   {
-    _reportBugs=reportBugs;
-    if(_reportBugs) {
+  #ifdef Q_OS_LINUX
+    cpu_set_t cpuset;
+    pthread_t thread=pthread_self();
+    // Get affinity mask of the main thread (children threads will inherits the same mask)
+
+    CPU_ZERO(&cpuset);
+    int s=pthread_getaffinity_np(thread, sizeof(cpu_set_t), &cpuset);
+    if(s!=0) {
+      App::log(tr("Thead affinity mask cannot be accessed, skipping CPU affinity\n"));
+      _maximumThreadCount=std::thread::hardware_concurrency()/2;  // Useless to use hyperthreading
+    } else {
+      if(maxCoreCount==0) {
+        maxCoreCount=std::thread::hardware_concurrency();
+      }
+      _cpuAffinities.clear();
+      for (int i=0; i<CPU_SETSIZE; i++) {
+        if(CPU_ISSET(i, &cpuset)) {
+          _cpuAffinities.append(i);
+          App::log(1, tr("CPU affinity[%1]=%2\n").arg(_cpuAffinities.count()-1).arg(i));
+          if(_cpuAffinities.count()>=maxCoreCount) {
+            break;
+          }
+        }
+      }
+      _maximumThreadCount=_cpuAffinities.count();
+    }
+  #else
+    Q_UNUSED(maxCoreCount)
+    // Under Windows and Mac, TODO: check how to get the physical number of cores
+    // We assume that on those user oriented platforms, hyperthreading is always active.
+    _maximumThreadCount=QThread::idealThreadCount()/2;
+  #endif
+    if(_maximumThreadCount<1) {
+      _maximumThreadCount=1;
+    }
+  }
+
+  void CoreApplicationPrivate::initInternalDebugger(BugReportOptions options)
+  {
+    _bugReportOptions=options;
+    if((_bugReportOptions & ReportBugs) ||
+       (_bugReportOptions & ReportDirectly)) {
       // Redirect exception signals
       signal (SIGABRT, osSignal);
       signal (SIGSEGV, osSignal);
@@ -236,21 +307,24 @@ namespace QGpCoreTools {
       signal (SIGBUS, osSignal);
 #endif
       // User interrupts
-      _debugUserInterrupts=true;
-      signal (SIGINT, osSignal);
-      signal (SIGTERM, osSignal);
-      // Redirect ASSERT messages
-#if(QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
-      qInstallMessageHandler(messageOutput);
-#else
-      qInstallMsgHandler(messageOutput);
-#endif
-    } else {
+      if(!(_bugReportOptions & NoUserInterruptReport)) {
+        signal (SIGINT, osSignal);
+        signal (SIGTERM, osSignal);
+      }
+    }
+    if(_bugReportOptions & WarningAsError) {
       // Redirect ASSERT messages
 #if(QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
       qInstallMessageHandler(messageOutputAbort);
 #else
       qInstallMsgHandler(messageOutputAbort);
+#endif
+    } else {
+      // Redirect ASSERT messages
+#if(QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+      qInstallMessageHandler(messageOutput);
+#else
+      qInstallMsgHandler(messageOutput);
 #endif
     }
   }
@@ -258,8 +332,8 @@ namespace QGpCoreTools {
   void CoreApplicationPrivate::debugUserInterrupts(bool d)
   {
     TRACE;
-    if(_reportBugs) {
-      if(_debugUserInterrupts!=d) {
+    if(_bugReportOptions!=NoBugReport) {
+      if((_bugReportOptions & NoUserInterruptReport)!=d) {
         if(d) {
           signal(SIGINT, osSignal);
           signal(SIGTERM, osSignal);
@@ -267,7 +341,10 @@ namespace QGpCoreTools {
           signal(SIGINT, nullptr);
           signal(SIGTERM, nullptr);
         }
-        _debugUserInterrupts=d;
+        _bugReportOptions=_bugReportOptions & (~NoUserInterruptReport);
+        if(!d) {
+          _bugReportOptions|=NoUserInterruptReport;
+        }
       }
     }
   }
@@ -281,10 +358,10 @@ namespace QGpCoreTools {
 #if(QT_VERSION >= QT_VERSION_CHECK(4, 4, 0))
     /* Currently not used in sesarray package so left commented
     if( !QAtomicInt::isReferenceCountingNative()) {
-      App::stream(1) << "WARNING: Atomic 'reference counting' is not available for your processor" << endl;
+      App::stream(1) << "WARNING: Atomic 'reference counting' is not available for your processor" << Qt::endl;
     }
     if(!QAtomicInt::isFetchAndAddNative()) {
-      App::stream(1) << "WARNING: Atomic 'fetch and add' is not available for your processor" << endl;
+      App::stream(1) << "WARNING: Atomic 'fetch and add' is not available for your processor" << Qt::endl;
     }
     */
     if(!QAtomicInt::isTestAndSetNative()) {
@@ -353,6 +430,17 @@ namespace QGpCoreTools {
     return QString();
   }
 
+  /*!
+    Install directories are set in QSettings that cannot be accessed before the creation
+    of QApplication to get a working Python module GeopsyPySciFigs.
+  */
+  void CoreApplicationPrivate::initInstallDirs()
+  {
+    for(QList<PackageInfo>::iterator it=PackageInfo::list()->begin();it!=PackageInfo::list()->end(); it++ ) {
+      it->setInstallDirs();
+    }
+  }
+
   void CoreApplicationPrivate::initTranslations()
   {
     QLocale current;
@@ -400,15 +488,16 @@ namespace QGpCoreTools {
   /*!
     Check for undeleted blocks
   */
-  void CoreApplicationPrivate::checkBlocks(bool showLib, bool showUndeleted, const char* file, int line)
+  bool CoreApplicationPrivate::checkBlocks(bool showLib, bool showUndeleted, const char* file, int line)
   {
 #ifdef DO_MEMORY_CHECK
-    MemoryCheckerPrivate::checkBlocks(showLib, showUndeleted, file, line);
+    return MemoryCheckerPrivate::checkBlocks(showLib, showUndeleted, file, line);
 #else
     Q_UNUSED(showLib)
     Q_UNUSED(showUndeleted)
     Q_UNUSED(file)
     Q_UNUSED(line)
+    return true;
 #endif
   }
 
@@ -709,8 +798,13 @@ namespace QGpCoreTools {
   */
   void CoreApplicationPrivate::reportBug(Message::Severity sev, const QString & msg)
   {
-    QString str=bugInfo(sev, msg);
     if(msg.startsWith("QNetworkReplyHttpImplPrivate")) return;
+    if(msg.startsWith("Incompatible version of OpenSSL")) return;
+    if(msg.startsWith("The backend \"cert-only\" does not support")) return;
+    if(msg.startsWith("The backend named \"cert-only\" does not support")) return;
+    if(msg.startsWith("Active TLS backend does not support key creation")) return;
+    if(msg.startsWith("QSslSocket::connectToHostEncrypted")) return;
+    QString str=bugInfo(sev, msg);
     printf("[bug report] %s: %s\n", Message::severityString(sev).toLatin1().data(), msg.toLatin1().data());
     // Bug submitted to trolltech internal to QWorkspace on closing application
     if(msg.startsWith("QCoreApplication::postEvent: Unexpected null receiver")) return;
@@ -740,15 +834,19 @@ namespace QGpCoreTools {
     // Message received when paper size is not supported by print driver
     if(msg.startsWith("QPrinter::setPaperSize: Illegal paper size")) return;
     // Message received under X11, when closing many Geopsy.org applications in one action
-    if(msg.startsWith("QClipboard::setData: Cannot set X11 selection owner for CLIPBOARD")) return;
+    if(msg.startsWith("QClipboard::setData:")) return;
+    if(msg.startsWith("QXcbClipboard::setMimeData:")) return;
+    if(msg.startsWith("Data set on unsupported clipboard mode.")) return;
     if(msg.startsWith("Numeric sorting unsupported on Windows versions older than Windows 7")) return;
     if(msg.startsWith("QNetworkReplyHttpImplPrivate::_q_startOperation was called more than once")) return;
     if(msg.startsWith("QMdiArea::closeAllSubWindows:null pointer")) return;
     if(msg.startsWith("failed to create compose table")) return;
+    if(msg.startsWith("scroll event from unregistered device")) return;
+    //if(msg.startsWith("QFont::fromString: Invalid description")) return;
     if(msg.startsWith("Application asked to unregister timer")) {
       reportBugNow(Message::Fatal, msg); // debug those warnings
     }
-    if(_warningAsError) {
+    if(_bugReportOptions & WarningAsError) {
       reportBugNow(sev, msg);
     } else {
       _errors << str;
@@ -781,20 +879,29 @@ namespace QGpCoreTools {
     XMLStringStream sReport(QIODevice::WriteOnly);
     XMLClass::writeChildren(sReport, "CrashReport", sError.toString() + appInfo());
     QString str=sReport.toString();
-    QProcess p;
-    p.setProcessChannelMode(QProcess::ForwardedChannels);
-    if(msg=="Terminated Signal" || msg=="Interrupted Signal") {
-      if(!hasGui()) instance()->askForUserInterrupt();
-      p.start("\""+QCoreApplication::applicationFilePath()+"\" -reportint");
-    } else {
-      p.start("\""+QCoreApplication::applicationFilePath()+"\" -reportbug");
-    }
-    p.write(str.toLatin1().data());
-    p.write("END\n");
-    if(p.waitForStarted(10000)) {
-      while(!p.waitForFinished(10000)) {}
-    } else {
+    if(_bugReportOptions & ReportDirectly) {
       reportBugDirectly(str);
+    } else {
+      QProcess p;
+      p.setProcessChannelMode(QProcess::ForwardedChannels);
+      QStringList args;
+      if(msg=="Terminated Signal" || msg=="Interrupted Signal") {
+        if(!hasGui()) instance()->askForUserInterrupt();
+        args << "-reportint";
+        args << QString::number(QCoreApplication::instance()->applicationPid());
+        p.start(QCoreApplication::applicationFilePath(), args);
+      } else {
+        args << "-reportbug";
+        args << QString::number(QCoreApplication::instance()->applicationPid());
+        p.start(QCoreApplication::applicationFilePath(), args);
+      }
+      p.write(str.toLatin1().data());
+      p.write("END\n");
+      if(p.waitForStarted(10000)) {
+        while(!p.waitForFinished(10000)) {}
+      } else {
+        reportBugDirectly(str);
+      }
     }
   }
 
@@ -822,10 +929,11 @@ namespace QGpCoreTools {
   /*!
     Analyse current stack and return it as a string
   */
-  QString CoreApplicationPrivate::backTrace()
+  QString CoreApplicationPrivate::backTrace(int maxDepth)
   {
     QString str;
 #ifdef TRACE_ENABLED
+    Q_UNUSED(maxDepth)
     QStringList tList=Thread::threadNames();
     Thread::lockThreads();
     QList< QStack<const TraceStamp *> * > sList=Thread::stacks();
@@ -837,17 +945,17 @@ namespace QGpCoreTools {
     }
     Thread::unlockThreads();
 #elif defined(Q_OS_UNIX) && !defined(Q_CC_SUN) && !defined(NO_BACKTRACE)
-    void *frames[50];
+    void ** frames=new void *[maxDepth];
     size_t size;
     char ** strings;
     size_t i;
-    size=backtrace (frames, 50);
-    strings=backtrace_symbols (frames, size);
+    size=backtrace(frames, maxDepth);
+    strings=backtrace_symbols(frames, size);
 
     size_t functionLen=0;
     int status;
     // Demangle, see doc at http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/namespaceabi.html
-    for(i=0; i < size; i++) {
+    for(i=0; i <size; i++) {
       // get value between (...+
       char * mangledName=strchr(strings[i], '(' );
       if(mangledName) {
@@ -874,6 +982,8 @@ namespace QGpCoreTools {
     }*/
 
     free (strings);
+#else
+    Q_UNUSED(maxDepth)
 #endif
     return str;
   }
@@ -893,7 +1003,7 @@ namespace QGpCoreTools {
       str += "\n";
       str += TraceBug::backTrace(sList.at(i));
     }
-    QList< QVector<TraceLog *> * > lList=Thread::logVectors();
+    QList< VectorList<TraceLog *> * > lList=Thread::logVectors();
     for(int i=0; i<lList.count(); i++ ) {
       str += "---- thread ";
       str += tList.at(i);
@@ -912,7 +1022,7 @@ namespace QGpCoreTools {
     XMLClass::writeProperty(s, "time", QDateTime::currentDateTime().toString("yyyy-MM-dd hh:mm:ss.zzz"));
     XMLClass::writeProperty(s, "threads", Thread::threadNames().join(","));
     XMLClass::writeProperty(s, "currentThread", _crashingThread);
-    XMLClass::writeProperty(s, "stack", backTrace());
+    XMLClass::writeProperty(s, "stack", backTrace(50));
     XMLClass::writeProperty(s, "bugStack", backTraceBug());
     return s.toString();
   }
@@ -968,6 +1078,8 @@ namespace QGpCoreTools {
                                           "Wihtout INDEX the last argument list is used."));
     h->addOption(tr("-version"), tr("Show version information"));
     h->addOption(tr("-app-version"), tr("Show short version information"));
+    h->addOption(tr("-task-manager"), tr("A resource and task manager for HPC cluster is used. The maximum umber of "
+                                         "threads is controlled by CPU affinities. '-j' option is disregarded if placed before this one."));
     h->addOption(tr("-j, -jobs <N>"), tr("Allow a maximum of N simulteneous jobs for parallel "
                                          "computations (default=%1).").arg(QThread::idealThreadCount()));
     h->addOption(tr("-verbosity <V>"), tr("Set level of verbosity (default=0)"));
@@ -978,14 +1090,14 @@ namespace QGpCoreTools {
     h->addGroup(tr("Debug"), "debug", 5);
     h->addOption(tr("-nobugreport"),
                  tr("Does not generate bug reports in case of error."));
-    h->addOption(tr("-reportbug"),
+    h->addOption(tr("-reportbug <PID>"),
                  tr("Starts bug report dialog, information about bug is passed through stdin. This "
                     "option is used internally to report bugs if option -nobugreport is not "
                     "specified."));
     h->addOption(tr("-warning-critical"),
                  tr("Consider warnings as critical, stops execution and issue a bug report. Mainly "
                     "used for debug, to be able to start the debugger even after a warning."));
-    h->addOption(tr("-reportint"),
+    h->addOption(tr("-reportint <PID>"),
                  tr("Starts bug report dialog, information about interruption is passed through stdin. This "
                     "option is used internally to report interruptions if option -nobugreport is not "
                     "specified."));
@@ -999,7 +1111,7 @@ namespace QGpCoreTools {
 
     This function can be used even without a CoreApplication running.
   */
-  bool CoreApplicationPrivate::checkOptionArg(int& i, int argc, char ** argv, bool mandatory)
+  bool CoreApplicationPrivate::checkOptionArg(int& i, int argc, char ** argv, bool mandatory, int optionIndex)
   {
     i++;
     if(i<argc) {
@@ -1016,8 +1128,13 @@ namespace QGpCoreTools {
       } else return true;
     }
     if(mandatory) {
+      if(optionIndex<0) {
+        optionIndex=i-1;
+      }
       // Do not use app because it is not sure whether it is already created.
-      QTextStream(stdout) << tr("Option '%1' requires an argument, see -help for details.\n").arg(argv[i-1]);
+      QTextStream(stderr) << tr("Option '%1' requires %2 argument(s), see -help for details.\n")
+                             .arg(argv[optionIndex])
+                             .arg(i-optionIndex);
       ::exit(2);
     }
     i--; // Not a mandatory argument
@@ -1057,7 +1174,7 @@ namespace QGpCoreTools {
                 .arg(argv[i])
                 .arg(argv[optionIndex]) << Qt::endl;
       } else {
-        sOut << tr("Error converting numerical value: '%1'.").arg(argv[i]) << ::endl;
+        sOut << tr("Error converting numerical value: '%1'.").arg(argv[i]) << Qt::endl;
       }
       ::exit(2);
     }
@@ -1078,7 +1195,7 @@ namespace QGpCoreTools {
                 .arg(argv[i])
                 .arg(argv[optionIndex]) << Qt::endl;
       } else {
-        sOut << tr("Error converting numerical value: '%1'.").arg(argv[i]) << ::endl;
+        sOut << tr("Error converting numerical value: '%1'.").arg(argv[i]) << Qt::endl;
       }
       ::exit(2);
     }
@@ -1138,6 +1255,7 @@ namespace QGpCoreTools {
       QStringList list=dloc.entryList(filters);
       if(list.isEmpty()) {
         App::log(tr("File '%1' not found\n").arg(file));
+        ::exit(2);
       }
       foreach(file, list) {
         result << dloc.absoluteFilePath(file);
@@ -1357,6 +1475,9 @@ namespace QGpCoreTools {
     return h.arg(email).arg(platform).arg(userInfo);
   }
 
+  /*!
+    Send the library path to the stdout.
+  */
   void CoreApplicationPrivate::printLibraryPaths() const
   {
     QStringList list=QCoreApplication::libraryPaths();
@@ -1368,20 +1489,24 @@ namespace QGpCoreTools {
     s << Qt::flush;
   }
 
+  /*!
+    Reads argument lists from user settings and returns them in a QList.
+  */
   QList<QStringList> CoreApplicationPrivate::argumentLists()
   {
     QList<QStringList> list;
     QSettings& reg=CoreApplication::instance()->settings();
     QList<QVariant> tmplist=reg.value("applicationArguments").toList();
-#if(QT_VERSION >= QT_VERSION_CHECK(4, 7, 0))
     list.reserve(tmplist.count());
-#endif
     for(QList<QVariant>::const_iterator it=tmplist.begin(); it!=tmplist.end(); it++) {
       list.append(it->toStringList());
     }
     return list;
   }
 
+  /*!
+    Send the arguments lists available in the user settings to the stdout.
+  */
   void CoreApplicationPrivate::printArgumentLists(int max) const
   {
     QList<QStringList> list=argumentLists();
@@ -1406,6 +1531,12 @@ namespace QGpCoreTools {
     s << Qt::flush;
   }
 
+  /*!
+    It must be called before parsing arguments which usually alters \a argv pointers.
+    If the Application or CoreAppliction object is created after parsing some options,
+    you must directly use this function. In all other case, the job is done inside
+    CoreApplication constructor.
+  */
   void CoreApplicationPrivate::setArgumentList(int argc, char ** argv)
   {
     _argumentList.reserve(argc);
@@ -1422,14 +1553,20 @@ namespace QGpCoreTools {
     }
   }
 
+  /*!
+    Used by CoreApplication and Application to add argument list to
+    user settings. This can be achieved only after setting the name and
+    organization properly.
+  */
   void CoreApplicationPrivate::updateArgumentLists()
   {
     // Make sure that settings has not been used so far
-    // If so, name and organisation are probably not preperly set
+    // If so, name and organisation are probably not properly set
     ASSERT(!_settings);
     if(_argumentList.isEmpty()) {
       return;
     }
+    // Get argument lists from settings
     QList<QStringList> list=argumentLists();
     int index=list.indexOf(_argumentList);
     if(index>-1) {
@@ -1442,7 +1579,7 @@ namespace QGpCoreTools {
     QList<QVariant> tmplist;
     tmplist.reserve(list.count());
     for(QList<QStringList>::const_iterator it=list.begin(); it!=list.end(); it++) {
-      if(it->count()>=2) { // Clean history generated by some old releases
+      if(it->count()>=1) { // Clean history generated by some old releases
         tmplist.append(*it);
       }
     }
@@ -1467,7 +1604,7 @@ namespace QGpCoreTools {
     }
     const QStringList& args=list.at(index);
     if(args.contains("-rargs")) {
-      sOut << tr("To prevent inifinte looping, '-rargs' option is not allowed in argument list.") << Qt::endl;
+      sOut << tr("To prevent infinite looping, '-rargs' option is not allowed in argument list.") << Qt::endl;
       return 2;
     }
     QString appPath=QCoreApplication::instance()->applicationFilePath();
@@ -1560,12 +1697,12 @@ namespace QGpCoreTools {
   */
   void CoreApplicationPrivate::setLibraryPath()
   {
-#ifdef Q_OS_MAC
+#ifdef Q_OS_DARWIN
     QString p("/Library/Geopsy.org/%1/plugins");
     QStringList paths;
     paths << p.arg(QGPCORETOOLS_VERSION_TYPE);
     QCoreApplication::setLibraryPaths(paths);
-#endif // Q_OS_MAC
+#endif // Q_OS_DARWIN
   }
 
   /*!
@@ -1593,7 +1730,7 @@ namespace QGpCoreTools {
   QSettings& CoreApplicationPrivate::globalSettings()
   {
     if(!_globalSettings) {
-#ifdef Q_OS_MAC
+#ifdef Q_OS_DARWIN
       _globalSettings=new QSettings(qApp->organizationDomain());
 #else
       _globalSettings=new QSettings(qApp->organizationName());
@@ -1612,7 +1749,8 @@ namespace QGpCoreTools {
          "# BEGIN COMMAND LINE ARGUMENTS\n"
          "#\n";
     s << CoreApplication::applicationFilePath() << " ";
-    s << argumentList().join(' ') << "\n";
+    s << argumentList().join(' ') << " $*\n";
+    s << "exit $?\n";   // Let the direct execution of files in a shell, even with additional arguments
     s << "#\n"
          "# END COMMAND LINE ARGUMENTS\n"
          "#\n"
