@@ -359,7 +359,7 @@ DateTimeData DateTimeFromString::value(bool& ok) const
   DateTimeData t;
   ok=true;
   if(!_current.isEmpty()) {
-    App::log(tr("unmatched characters: '%1'\n").arg(_current.toString()));
+    App::log(tr("unmatched characters: '%1'\n").arg(_current.toStringView()));
     ok=false;
     return t;
   }
@@ -408,20 +408,20 @@ bool DateTimeFromString::d_parsed()
   if(_current.size()>=1) {
     if(_current[0].isDigit() || _current[0].isSpace()) {
       if(_current.size()>=2 && _current[1].isDigit()) {
-        _day=_locale.toInt(_current.left(2).toString());
+        _day=_locale.toInt(_current.left(2).toStringView());
         if(_day>=1 && _day<=31) {
           _current+=2;
           return true;
         }
       } else {
-        _day=_locale.toInt(_current.left(1).toString());
+        _day=_locale.toInt(_current.left(1).toStringView());
         if(_day>=1) {
           _current+=1;
           return true;
         }
       }
     }
-    App::log(tr("expected a number between 1 and 31: '%1'\n").arg(_current.left(2).toString()));
+    App::log(tr("expected a number between 1 and 31: '%1'\n").arg(_current.left(2).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -436,13 +436,13 @@ bool DateTimeFromString::dd_parsed()
       if(_current.size()>=2 && _current[1].isDigit()) {
         l=2;
       }
-      _day=_locale.toInt(_current.left(l).toString());
+      _day=_locale.toInt(_current.left(l).toStringView());
       if(_day>=1 && _day<=31) {
         _current+=l;
         return true;
       }
     }
-    App::log(tr("expected a number between 1 and 31: '%1'\n").arg(_current.left(l).toString()));
+    App::log(tr("expected a number between 1 and 31: '%1'\n").arg(_current.left(l).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -456,11 +456,11 @@ bool DateTimeFromString::ddd_parsed()
       QString n=_locale.dayName(i, QLocale::ShortFormat);
       if(_current.beginWith(n)) {
         _dayShort=n;
-        _current+=n.count();
+        _current+=n.size();
         return true;
       }
     }
-    App::log(tr("expected a valid short day name: '%1'\n").arg(_current.left(3).toString()));
+    App::log(tr("expected a valid short day name: '%1'\n").arg(_current.left(3).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -474,11 +474,11 @@ bool DateTimeFromString::dddd_parsed()
       QString n=_locale.dayName(i, QLocale::LongFormat);
       if(_current.beginWith(n)) {
         _dayLong=n;
-        _current+=n.count();
+        _current+=n.size();
         return true;
       }
     }
-    App::log(tr("expected a valid long day name: '%1'\n").arg(_current.left(7).toString()));
+    App::log(tr("expected a valid long day name: '%1'\n").arg(_current.left(7).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -490,20 +490,20 @@ bool DateTimeFromString::M_parsed()
   if(_current.size()>=1) {
     if(_current[0].isDigit() || _current[0].isSpace()) {
       if(_current.size()>=2 && _current[1].isDigit()) {
-        _month=_locale.toInt(_current.left(2).toString());
+        _month=_locale.toInt(_current.left(2).toStringView());
         if(_month>=1 && _month<=12) {
           _current+=2;
           return true;
         }
       } else {
-        _month=_locale.toInt(_current.left(1).toString());
+        _month=_locale.toInt(_current.left(1).toStringView());
         if(_month>=1) {
           _current+=1;
           return true;
         }
       }
     }
-    App::log(tr("expected a number between 1 and 12: '%1'\n").arg(_current.left(2).toString()));
+    App::log(tr("expected a number between 1 and 12: '%1'\n").arg(_current.left(2).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -518,13 +518,13 @@ bool DateTimeFromString::MM_parsed()
       if(_current.size()>=2 && _current[1].isDigit()) {
         l=2;
       }
-      _month=_locale.toInt(_current.left(l).toString());
+      _month=_locale.toInt(_current.left(l).toStringView());
       if(_month>=1 && _month<=12) {
         _current+=l;
         return true;
       }
     }
-    App::log(tr("expected a number between 1 and 12: '%1'\n").arg(_current.left(l).toString()));
+    App::log(tr("expected a number between 1 and 12: '%1'\n").arg(_current.left(l).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -538,11 +538,11 @@ bool DateTimeFromString::MMM_parsed()
       QString n=_locale.monthName(i, QLocale::ShortFormat);
       if(_current.beginWith(n)) {
         _month=i;
-        _current+=n.count();
+        _current+=n.size();
         return true;
       }
     }
-    App::log(tr("expected a valid short month name: '%1'\n").arg(_current.left(3).toString()));
+    App::log(tr("expected a valid short month name: '%1'\n").arg(_current.left(3).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -556,11 +556,11 @@ bool DateTimeFromString::MMMM_parsed()
       QString n=_locale.monthName(i, QLocale::LongFormat);
       if(_current.beginWith(n)) {
         _month=i;
-        _current+=n.count();
+        _current+=n.size();
         return true;
       }
     }
-    App::log(tr("expected a valid long month name: '%1'\n").arg(_current.left(12).toString()));
+    App::log(tr("expected a valid long month name: '%1'\n").arg(_current.left(12).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -575,11 +575,11 @@ bool DateTimeFromString::yy_parsed()
       if(_current.size()>=2 && _current[1].isDigit()) {
         l=2;
       }
-      _year=(QDate::currentDate().year()/100)*100+_locale.toInt(_current.left(l).toString());
+      _year=(QDate::currentDate().year()/100)*100+_locale.toInt(_current.left(l).toStringView());
       _current+=l;
       return true;
     }
-    App::log(tr("expected a number between 0 and 99: '%1'\n").arg(_current.left(l).toString()));
+    App::log(tr("expected a number between 0 and 99: '%1'\n").arg(_current.left(l).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -602,11 +602,11 @@ bool DateTimeFromString::yyyy_parsed()
           l=2;
         }
       }
-      _year=_locale.toInt(_current.left(l).toString());
+      _year=_locale.toInt(_current.left(l).toStringView());
       _current+=l;
       return true;
     }
-    App::log(tr("expected a number between 0 and 9999: '%1'\n").arg(_current.left(l).toString()));
+    App::log(tr("expected a number between 0 and 9999: '%1'\n").arg(_current.left(l).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -618,18 +618,18 @@ bool DateTimeFromString::h_parsed()
   if(_current.size()>=1) {
     if(_current[0].isDigit() || _current[0].isSpace()) {
       if(_current.size()>=2 && _current[1].isDigit()) {
-        _hour=_locale.toInt(_current.left(2).toString());
+        _hour=_locale.toInt(_current.left(2).toStringView());
         if(_hour<=23) {
           _current+=2;
           return true;
         }
       } else {
-        _hour=_locale.toInt(_current.left(1).toString());
+        _hour=_locale.toInt(_current.left(1).toStringView());
         _current+=1;
         return true;
       }
     }
-    App::log(tr("expected a number between 0 and 23: '%1'\n").arg(_current.left(2).toString()) );
+    App::log(tr("expected a number between 0 and 23: '%1'\n").arg(_current.left(2).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -644,13 +644,13 @@ bool DateTimeFromString::hh_parsed()
       if(_current.size()>=2 && _current[1].isDigit()) {
         l=2;
       }
-      _hour=_locale.toInt(_current.left(l).toString());
+      _hour=_locale.toInt(_current.left(l).toStringView());
       if(_hour<=23) {
         _current+=l;
         return true;
       }
     }
-    App::log(tr("expected a number between 0 and 23: '%1'\n").arg(_current.left(l).toString()) );
+    App::log(tr("expected a number between 0 and 23: '%1'\n").arg(_current.left(l).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -662,18 +662,18 @@ bool DateTimeFromString::H_parsed()
   if(_current.size()>=1) {
     if(_current[0].isDigit() || _current[0].isSpace()) {
       if(_current.size()>=2 && _current[1].isDigit()) {
-        _hour=_locale.toInt(_current.left(2).toString());
+        _hour=_locale.toInt(_current.left(2).toStringView());
         if(_hour<=12) {
           _current+=2;
           return true;
         }
       } else {
-        _hour=_locale.toInt(_current.left(1).toString());
+        _hour=_locale.toInt(_current.left(1).toStringView());
         _current+=1;
         return true;
       }
     }
-    App::log(tr("expected a number between 0 and 12: '%1'\n").arg(_current.left(2).toString()) );
+    App::log(tr("expected a number between 0 and 12: '%1'\n").arg(_current.left(2).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -688,13 +688,13 @@ bool DateTimeFromString::HH_parsed()
       if(_current.size()>=2 && _current[1].isDigit()) {
         l=2;
       }
-      _hour=_locale.toInt(_current.left(l).toString());
+      _hour=_locale.toInt(_current.left(l).toStringView());
       if(_hour<=12) {
         _current+=l;
         return true;
       }
     }
-    App::log(tr("expected a number between 0 and 12: '%1'\n").arg(_current.left(l).toString()) );
+    App::log(tr("expected a number between 0 and 12: '%1'\n").arg(_current.left(l).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -706,18 +706,18 @@ bool DateTimeFromString::m_parsed()
   if(_current.size()>=1) {
     if(_current[0].isDigit() || _current[0].isSpace()) {
       if(_current.size()>=2 && _current[1].isDigit()) {
-        _minute=_locale.toInt(_current.left(2).toString());
+        _minute=_locale.toInt(_current.left(2).toStringView());
         if(_minute<=59) {
           _current+=2;
           return true;
         }
       } else {
-        _minute=_locale.toInt(_current.left(1).toString());
+        _minute=_locale.toInt(_current.left(1).toStringView());
         _current+=1;
         return true;
       }
     }
-    App::log(tr("expected a number between 0 and 59: '%1'\n").arg(_current.left(2).toString()) );
+    App::log(tr("expected a number between 0 and 59: '%1'\n").arg(_current.left(2).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -732,13 +732,13 @@ bool DateTimeFromString::mm_parsed()
       if(_current.size()>=2 && _current[1].isDigit()) {
         l=2;
       }
-      _minute=_locale.toInt(_current.left(l).toString());
+      _minute=_locale.toInt(_current.left(l).toStringView());
       if(_minute<=59) {
         _current+=l;
         return true;
       }
     }
-    App::log(tr("expected a number between 0 and 59: '%1'\n").arg(_current.left(l).toString()) );
+    App::log(tr("expected a number between 0 and 59: '%1'\n").arg(_current.left(l).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -750,18 +750,18 @@ bool DateTimeFromString::s_parsed()
   if(_current.size()>=1) {
     if(_current[0].isDigit() || _current[0].isSpace()) {
       if(_current.size()>=2 && _current[1].isDigit()) {
-        _second=_locale.toInt(_current.left(2).toString());
+        _second=_locale.toInt(_current.left(2).toStringView());
         if(_second<=59) {
           _current+=2;
           return true;
         }
       } else {
-        _second=_locale.toInt(_current.left(1).toString());
+        _second=_locale.toInt(_current.left(1).toStringView());
         _current+=1;
         return true;
       }
     }
-    App::log(tr("expected a number between 0 and 59: '%1'\n").arg(_current.left(2).toString()) );
+    App::log(tr("expected a number between 0 and 59: '%1'\n").arg(_current.left(2).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -776,13 +776,13 @@ bool DateTimeFromString::ss_parsed()
       if(_current.size()>=2 && _current[1].isDigit()) {
         l=2;
       }
-      _second=_locale.toInt(_current.left(l).toString());
+      _second=_locale.toInt(_current.left(l).toStringView());
       if(_second<=59) {
         _current+=l;
         return true;
       }
     }
-    App::log(tr("expected a number between 0 and 59: '%1'\n").arg(_current.left(l).toString()) );
+    App::log(tr("expected a number between 0 and 59: '%1'\n").arg(_current.left(l).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -799,17 +799,17 @@ bool DateTimeFromString::sz_parsed()
       } else {
         i=1;
       }
-      _second=_locale.toInt(_current.left(i).toString());
+      _second=_locale.toInt(_current.left(i).toStringView());
       _current+=i;
 
       if(_current.size()>=1 && (_current[0]=='.' || _current[0]==',')) {
         for(i=1; i<_current.size() && _current[i].isDigit(); i++) {}
-        _fraction=_locale.toDouble(_current.left(i).toString());
+        _fraction=_locale.toDouble(_current.left(i).toStringView());
         _current+=i;
       }
       return true;
     }
-    App::log(tr("expected a decimal number between 0 and 60 (excluding 60): '%1'\n").arg(_current.left(10).toString()) );
+    App::log(tr("expected a decimal number between 0 and 60 (excluding 60): '%1'\n").arg(_current.left(10).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -824,17 +824,17 @@ bool DateTimeFromString::ssz_parsed()
       if(_current.size()>=2 && _current[1].isDigit()) {
         l=2;
       }
-      _second=_locale.toInt(_current.left(l).toString());
+      _second=_locale.toInt(_current.left(l).toStringView());
       _current+=l;
       if(_current.size()>=1 && (_current[0]=='.' || _current[0]==',')) {
         int i;
         for(i=1; i<_current.size() && _current[i].isDigit(); i++) {}
-        _fraction=_locale.toDouble(_current.left(i).toString());
+        _fraction=_locale.toDouble(_current.left(i).toStringView());
         _current+=i;
       }
       return true;
     }
-    App::log(tr("expected a decimal number between 0 and 60 (excluding 60): '%1'\n").arg(_current.left(10).toString()));
+    App::log(tr("expected a decimal number between 0 and 60 (excluding 60): '%1'\n").arg(_current.left(10).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -847,19 +847,19 @@ bool DateTimeFromString::z_parsed()
     if(_current[0].isDigit() || _current[0].isSpace()) {
       if(_current.size()>=2 && _current[1].isDigit()) {
         if(_current.size()>=3 && _current[2].isDigit()) {
-          _fraction=_locale.toInt(_current.left(3).toString())*0.001;
+          _fraction=_locale.toInt(_current.left(3).toStringView())*0.001;
           _current+=3;
         } else {
-          _fraction=_locale.toInt(_current.left(2).toString())*0.001;
+          _fraction=_locale.toInt(_current.left(2).toStringView())*0.001;
           _current+=2;
         }
       } else {
-        _fraction=_locale.toInt(_current.left(1).toString())*0.001;
+        _fraction=_locale.toInt(_current.left(1).toStringView())*0.001;
         _current+=1;
       }
       return true;
     }
-    App::log(tr("expected a number between 0 and 999: '%1'\n").arg(_current.left(3).toString()));
+    App::log(tr("expected a number between 0 and 999: '%1'\n").arg(_current.left(3).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -872,11 +872,11 @@ bool DateTimeFromString::zzz_parsed()
     if(_current[0].isDigit() &&
        _current[1].isDigit() &&
        _current[2].isDigit()) {
-      _fraction=_locale.toInt(_current.left(3).toString())*0.001;
+      _fraction=_locale.toInt(_current.left(3).toStringView())*0.001;
       _current+=3;
       return true;
     }
-    App::log(tr("expected a number between 000 and 999: '%1'\n").arg(_current.left(3).toString()));
+    App::log(tr("expected a number between 000 and 999: '%1'\n").arg(_current.left(3).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -895,7 +895,7 @@ bool DateTimeFromString::ap_parsed()
       _current+=2;
       return true;
     }
-    App::log(tr("expected am or pm: '%1'\n").arg(_current.left(2).toString()));
+    App::log(tr("expected am or pm: '%1'\n").arg(_current.left(2).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -914,7 +914,7 @@ bool DateTimeFromString::AP_parsed()
       _current+=2;
       return true;
     }
-    App::log(tr("expected AM or PM: '%1'\n").arg(_current.left(2).toString()));
+    App::log(tr("expected AM or PM: '%1'\n").arg(_current.left(2).toStringView()));
     return false;
   } else {
     return truncatedError();
@@ -923,12 +923,17 @@ bool DateTimeFromString::AP_parsed()
 
 bool DateTimeFromString::quote_parsed(const StringSection& text)
 {
-  QRegExp reg(text.toString());
-  if(reg.indexIn(_current.toString())==0) {
-    _current+=reg.matchedLength();
+  QRegularExpression reg(text.toStringBuffer());
+  QRegularExpressionMatch match;
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+  if(_current.toStringView().indexOf(reg, 0, &match)==0) {
+#else
+  if(_current.toStringBuffer().indexOf(reg, 0, &match)==0) {
+#endif
+    _current+=match.capturedLength();
     return true;
   }
-  App::log(tr("expected '%1'\n").arg(text.toString()));
+  App::log(tr("expected '%1'\n").arg(text.toStringView()));
   return false;
 }
 
@@ -936,7 +941,7 @@ bool DateTimeFromString::other_parsed(const QChar& c)
 {
   if(_current.size()>=1) {
     if(c!=_current[0]) {
-      App::log(tr("wrong character: '%1'\n").arg(_current.left(1).toString()));
+      App::log(tr("wrong character: '%1'\n").arg(_current.left(1).toStringView()));
       return false;
     } else {
       _current+=1;
@@ -1051,7 +1056,7 @@ DateTimeToString::DateTimeToString(const DateTimeData& t, int precision)
   _t=t;
   _precision=precision;
   _numberFormat="%L1";
-  _t.roundSeconds(pow(10.0, -_precision));
+  _t.roundSeconds(::pow(10.0, -_precision));
 }
 
 bool DateTimeToString::parse(const QString& format)
@@ -1060,7 +1065,7 @@ bool DateTimeToString::parse(const QString& format)
   //
   DateTimePrecision p(_precision);
   p.parse(format);
-  _t.roundSeconds(pow(10.0, -p.precision()));
+  _t.roundSeconds(::pow(10.0, -p.precision()));
   return DateTimeParser::parse(format);
 }
 
@@ -1274,7 +1279,7 @@ bool DateTimeToString::AP_parsed()
 
 bool DateTimeToString::quote_parsed(const StringSection& text)
 {
-  _text+=text.toString();
+  _text+=text.toStringView();
   return true;
 }
 
@@ -1449,7 +1454,7 @@ void DateTimeData::fromTime_t(time_t t)
 {
   QDateTime dt;
   dt.setTimeSpec(Qt::UTC);
-  dt.setTime_t(t);
+  dt.setSecsSinceEpoch(t);
   _date=dt.date();
   _seconds=dt.time().hour()*3600+dt.time().minute()*60+dt.time().second();
   _fractions=0.0;
@@ -1467,7 +1472,7 @@ void DateTimeData::fromTime_t(double t)
 
 void DateTimeData::fromTime_t(QString t)
 {
-  QRegExp dec("[\\.,]");
+  QRegularExpression dec("[\\.,]");
   int decIndex=t.indexOf(dec, 0);
   if(decIndex==-1) {
     fromTime_t(static_cast<time_t>(t.toInt()));
@@ -1486,7 +1491,7 @@ time_t DateTimeData::toTime_t() const
   int s=_seconds-m*60-h*3600;
   dt.setTimeSpec(Qt::UTC);
   dt.setTime(QTime(h, m, s));
-  return dt.toTime_t();
+  return dt.toSecsSinceEpoch();
 }
 
 QString DateTimeData::toTime_t(int precision) const
