@@ -155,7 +155,7 @@ void ExpressionFunction::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
 {
   TRACE;
   Q_UNUSED(context)
-  for(QVector<ExpressionAction *>::const_iterator it=_args.begin(); it!=_args.end();++it) {
+  for(VectorList<ExpressionAction *>::const_iterator it=_args.begin(); it!=_args.end();++it) {
     (*it)->xml_save(s, context);
   }
 }
@@ -182,13 +182,21 @@ QVariant ExpressionAction::sum(const QVariant& op1, const QVariant& op2)
   TRACE;
   double val;
   bool ok;
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+  switch (op1.typeId()) {
+#else
   switch (op1.type()) {
-  case QVariant::Double:
+#endif
+  case QMetaType::Double:
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    switch (op2.typeId()) {
+#else
     switch (op2.type()) {
-    case QVariant::Double:
-    case QVariant::Int:
+#endif
+    case QMetaType::Double:
+    case QMetaType::Int:
       return op1.toDouble()+op2.toDouble();
-    case QVariant::String:
+    case QMetaType::QString:
       val=op2.toString().toDouble(&ok);
       if(ok)
         return op1.toDouble()+val;
@@ -197,13 +205,17 @@ QVariant ExpressionAction::sum(const QVariant& op1, const QVariant& op2)
     default:
       return op1;
     }
-  case QVariant::Int:
+  case QMetaType::Int:
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    switch (op2.typeId()) {
+#else
     switch (op2.type()) {
-    case QVariant::Double:
+#endif
+    case QMetaType::Double:
       return op1.toDouble()+op2.toDouble();
-    case QVariant::Int:
+    case QMetaType::Int:
       return op1.toInt()+op2.toInt();
-    case QVariant::String:
+    case QMetaType::QString:
       val=op2.toString().toDouble(&ok);
       if(ok)
         return op1.toDouble()+val;
@@ -212,30 +224,38 @@ QVariant ExpressionAction::sum(const QVariant& op1, const QVariant& op2)
     default:
       return op1;
     }
-  case QVariant::String:
+  case QMetaType::QString:
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    switch (op2.typeId()) {
+#else
     switch (op2.type()) {
-    case QVariant::Double:
+#endif
+    case QMetaType::Double:
       val=op1.toString().toDouble(&ok);
       if(ok)
         return val+op2.toDouble();
       else
         return op1.toString()+op2.toString();
-    case QVariant::Int:
+    case QMetaType::Int:
       val=op1.toString().toDouble(&ok);
       if(ok)
         return val+op2.toInt();
       else
         return op1.toString()+op2.toString();
-    case QVariant::String:
+    case QMetaType::QString:
       return op1.toString()+op2.toString();
     default:
       return op1;
     }
   default:
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    switch (op2.typeId()) {
+#else
     switch (op2.type()) {
-    case QVariant::Double:
-    case QVariant::Int:
-    case QVariant::String:
+#endif
+    case QMetaType::Double:
+    case QMetaType::Int:
+    case QMetaType::QString:
       return op2;
     default:
       return QVariant();
@@ -251,13 +271,21 @@ QVariant ExpressionAction::subtract(const QVariant& op1, const QVariant& op2)
   TRACE;
   double val;
   bool ok;
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+  switch (op1.typeId()) {
+#else
   switch (op1.type()) {
-  case QVariant::Double:
+#endif
+  case QMetaType::Double:
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    switch (op2.typeId()) {
+#else
     switch (op2.type()) {
-    case QVariant::Double:
-    case QVariant::Int:
+#endif
+    case QMetaType::Double:
+    case QMetaType::Int:
       return op1.toDouble()-op2.toDouble();
-    case QVariant::String:
+    case QMetaType::QString:
       val=op2.toString().toDouble(&ok);
       if(ok)
         return op1.toDouble()-val;
@@ -266,13 +294,17 @@ QVariant ExpressionAction::subtract(const QVariant& op1, const QVariant& op2)
     default:
       return op1;
     }
-  case QVariant::Int:
+  case QMetaType::Int:
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    switch (op2.typeId()) {
+#else
     switch (op2.type()) {
-    case QVariant::Double:
+#endif
+    case QMetaType::Double:
       return op1.toDouble()-op2.toDouble();
-    case QVariant::Int:
+    case QMetaType::Int:
       return op1.toInt()-op2.toInt();
-    case QVariant::String:
+    case QMetaType::QString:
       val=op2.toString().toDouble(&ok);
       if(ok)
         return op1.toDouble()-val;
@@ -281,7 +313,7 @@ QVariant ExpressionAction::subtract(const QVariant& op1, const QVariant& op2)
     default:
       return op1;
     }
-  case QVariant::String:
+  case QMetaType::QString:
     val=op1.toString().toDouble(&ok);
     if(ok) {
       double val2=op2.toString().toDouble(&ok);
@@ -297,9 +329,13 @@ QVariant ExpressionAction::subtract(const QVariant& op1, const QVariant& op2)
         return QVariant();
     }
   default:
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    switch (op2.typeId()) {
+#else
     switch (op2.type()) {
-    case QVariant::Double:
-    case QVariant::Int:
+#endif
+    case QMetaType::Double:
+    case QMetaType::Int:
       return -op2.toDouble();
     default:
       return QVariant();
@@ -315,13 +351,21 @@ QVariant ExpressionAction::mult(const QVariant& op1, const QVariant& op2)
   TRACE;
   double val;
   bool ok;
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+  switch (op1.typeId()) {
+#else
   switch (op1.type()) {
-  case QVariant::Double:
+#endif
+  case QMetaType::Double:
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    switch (op2.typeId()) {
+#else
     switch (op2.type()) {
-    case QVariant::Double:
-    case QVariant::Int:
+#endif
+    case QMetaType::Double:
+    case QMetaType::Int:
       return op1.toDouble()*op2.toDouble();
-    case QVariant::String:
+    case QMetaType::QString:
       val=op2.toString().toDouble(&ok);
       if(ok)
         return op1.toDouble()*val;
@@ -330,13 +374,17 @@ QVariant ExpressionAction::mult(const QVariant& op1, const QVariant& op2)
     default:
       return QVariant();
     }
-  case QVariant::Int:
+  case QMetaType::Int:
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    switch (op2.typeId()) {
+#else
     switch (op2.type()) {
-    case QVariant::Double:
+#endif
+    case QMetaType::Double:
       return op1.toDouble()*op2.toDouble();
-    case QVariant::Int:
+    case QMetaType::Int:
       return op1.toInt()*op2.toInt();
-    case QVariant::String:
+    case QMetaType::QString:
       val=op2.toString().toDouble(&ok);
       if(ok)
         return op1.toDouble()*val;
@@ -345,7 +393,7 @@ QVariant ExpressionAction::mult(const QVariant& op1, const QVariant& op2)
     default:
       return QVariant();
     }
-  case QVariant::String:
+  case QMetaType::QString:
     val=op1.toString().toDouble(&ok);
     if(ok) {
       double val2=op2.toString().toDouble(&ok);
@@ -369,13 +417,21 @@ QVariant ExpressionAction::floatDiv(const QVariant& op1, const QVariant& op2)
   TRACE;
   double val;
   bool ok;
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+  switch (op1.typeId()) {
+#else
   switch (op1.type()) {
-  case QVariant::Double:
+#endif
+  case QMetaType::Double:
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    switch (op2.typeId()) {
+#else
     switch (op2.type()) {
-    case QVariant::Double:
-    case QVariant::Int:
+#endif
+    case QMetaType::Double:
+    case QMetaType::Int:
       return op1.toDouble()/op2.toDouble();
-    case QVariant::String:
+    case QMetaType::QString:
       val=op2.toString().toDouble(&ok);
       if(ok)
         return op1.toDouble()/val;
@@ -384,11 +440,15 @@ QVariant ExpressionAction::floatDiv(const QVariant& op1, const QVariant& op2)
     default:
       return QVariant();
     }
-  case QVariant::Int:
+  case QMetaType::Int:
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    switch (op2.typeId()) {
+#else
     switch (op2.type()) {
-    case QVariant::Double:
+#endif
+    case QMetaType::Double:
       return op1.toDouble()/op2.toDouble();
-    case QVariant::Int: {
+    case QMetaType::Int: {
         int v2=op2.toInt();
         if(v2!=0) {
           return op1.toInt()/v2;
@@ -397,7 +457,7 @@ QVariant ExpressionAction::floatDiv(const QVariant& op1, const QVariant& op2)
           return QVariant();
         }
       }
-    case QVariant::String:
+    case QMetaType::QString:
       val=op2.toString().toDouble(&ok);
       if(ok)
         return op1.toDouble()/val;
@@ -409,7 +469,7 @@ QVariant ExpressionAction::floatDiv(const QVariant& op1, const QVariant& op2)
       App::log(tr("Division by zero\n") );
       return QVariant();
     }
-  case QVariant::String:
+  case QMetaType::QString:
     val=op1.toString().toDouble(&ok);
     if(ok) {
       double val2=op2.toString().toDouble(&ok);
@@ -434,19 +494,27 @@ int ExpressionAction::compare(const QVariant& op1, const QVariant& op2, bool& ok
 {
   TRACE;
   ok=true;
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+  switch (op1.typeId()) {
+#else
   switch (op1.type()) {
-  case QVariant::Double:
-  case QVariant::Int:
+#endif
+  case QMetaType::Double:
+  case QMetaType::Int:
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    switch (op2.typeId()) {
+#else
     switch (op2.type()) {
-    case QVariant::Double:
-    case QVariant::Int: {
+#endif
+    case QMetaType::Double:
+    case QMetaType::Int: {
         double op1d=op1.toDouble();
         double op2d=op2.toDouble();
         if(op1d<op2d) return -1;
         else if(op1d>op2d) return 1;
         else return 0;
       }
-    case QVariant::String: {
+    case QMetaType::QString: {
         QString op1s=op1.toString();
         QString op2s=op2.toString();
         if(op1s<op2s) return -1;
@@ -457,11 +525,15 @@ int ExpressionAction::compare(const QVariant& op1, const QVariant& op2, bool& ok
       ok=false;
       return 0;
     }
-  case QVariant::String:
+  case QMetaType::QString:
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    switch (op2.typeId()) {
+#else
     switch (op2.type()) {
-    case QVariant::String:
-    case QVariant::Double:
-    case QVariant::Int: {
+#endif
+    case QMetaType::QString:
+    case QMetaType::Double:
+    case QMetaType::Int: {
         QString op1s=op1.toString();
         QString op2s=op2.toString();
         if(op1s<op2s) return -1;
@@ -665,7 +737,11 @@ void ExpressionOperator::replaceArgument(ExpressionAction * oldA, ExpressionActi
 void ExpressionFunction::replaceArgument(ExpressionAction * oldA, ExpressionAction * newA)
 {
   TRACE;
+#ifndef QT_NO_DEBUG
   ASSERT(_currentArg==oldA);
+#else
+  Q_UNUSED(oldA);
+#endif
   _currentArg=newA;
   newA->setParent(this);
 }
@@ -673,7 +749,11 @@ void ExpressionFunction::replaceArgument(ExpressionAction * oldA, ExpressionActi
 void ExpressionBracket::replaceArgument(ExpressionAction * oldA, ExpressionAction * newA)
 {
   TRACE;
+#ifndef QT_NO_DEBUG
   ASSERT(_arg==oldA);
+#else
+  Q_UNUSED(oldA);
+#endif
   _arg=newA;
   newA->setParent(this);
 }
@@ -681,7 +761,11 @@ void ExpressionBracket::replaceArgument(ExpressionAction * oldA, ExpressionActio
 void ExpressionVariable::replaceArgument(ExpressionAction * oldA, ExpressionAction * newA)
 {
   TRACE;
+#ifndef QT_NO_DEBUG
   ASSERT(_index==oldA);
+#else
+  Q_UNUSED(oldA);
+#endif
   _index=newA;
   newA->setParent(this);
 }
