@@ -69,8 +69,8 @@ QStringList File::expand(const QStringList& fileNames)
   bool hasWildCards[fileNames.count()];
   bool hasOneWildCard=false;
   for (int i=fileNames.count()-1; i>=0; i--) {
-    //QTextStream(stdout) << fileNames.at(i) << ::endl;
-    hasWildCards[i]=fileNames.at(i).contains(QRegExp("[*?]"));
+    //QTextStream(stdout) << fileNames.at(i) << Qt::endl;
+    hasWildCards[i]=fileNames.at(i).contains(QRegularExpression("[*?]"));
     if(hasWildCards[i]) hasOneWildCard=true;
   }
   if(!hasOneWildCard) {
@@ -132,10 +132,10 @@ QStringList File::expand(QDir d, QStringList filters, QString levelName, int lev
     d.cd(levelName); // cd is here to avoid modification of d for each sub-directory
     level--;
   }
-  //QTextStream(stdout) << level << " " << filters.join(",") << " " << d.absolutePath() << ::endl;
+  //QTextStream(stdout) << level << " " << filters.join(",") << " " << d.absolutePath() << Qt::endl;
   QStringList allFiles;
   QString name=filters.at(level);
-  if(name.contains(QRegExp("[*?]"))) {
+  if(name.contains(QRegularExpression("[*?]"))) {
     QStringList f;
     f << name;
     QStringList files=d.entryList(f, QDir::AllEntries | QDir::NoDotAndDotDot | QDir::CaseSensitive, QDir::NoSort);
@@ -212,10 +212,10 @@ QString File::uniqueName(QString fileName, const QDir& d)
 /*!
   Return the list of all files inside \a path and its subfolders.
 */
-QMap<QString, QString> File::fileMap(const QDir& d)
+QMultiMap<QString, QString> File::fileMap(const QDir& d)
 {
   TRACE;
-  QMap<QString, QString> map;
+  QMultiMap<QString, QString> map;
   fileMap(d, map);
   return map;
 }
@@ -223,7 +223,7 @@ QMap<QString, QString> File::fileMap(const QDir& d)
 /*!
   Insert all files inside \a path and its subfolders in \a map.
 */
-void File::fileMap(const QDir& d, QMap<QString, QString>& map)
+void File::fileMap(const QDir& d, QMultiMap<QString, QString>& map)
 {
   TRACE;
   QStringList dirs=d.entryList(QDir::AllDirs | QDir::NoDotAndDotDot);
@@ -234,7 +234,7 @@ void File::fileMap(const QDir& d, QMap<QString, QString>& map)
   }
   QStringList files=d.entryList(QDir::Files);
   for(QStringList::iterator it=files.begin(); it!=files.end(); it++) {
-    map.insertMulti(*it, d.absoluteFilePath(*it));
+    map.insert(*it, d.absoluteFilePath(*it));
   }
 }
 
@@ -246,7 +246,7 @@ QString File::fileName(QString filePath, QChar sep)
   TRACE;
   int i=filePath.lastIndexOf(sep);
   if(i!=-1) {
-    return filePath.right(filePath.count()-i-1);
+    return filePath.right(filePath.size()-i-1);
   } else {
     return filePath;
   }
@@ -571,7 +571,7 @@ QStringList File::getLibList(QStringList pathList)
 {
   TRACE;
   QStringList libFilter;
-#if defined(Q_OS_MAC)
+#if defined(Q_OS_DARWIN)
   libFilter << "*.dylib";
 #elif defined(Q_OS_WIN)
   libFilter << "*.dll";
