@@ -45,8 +45,8 @@ namespace QGpCoreTools {
     static QStringList expand(const QStringList& fileNames);
     static QStringList expand(const QString& fileName);
     static QString uniqueName(QString fileName, const QDir& d);
-    static QMap<QString, QString> fileMap(const QDir &d);
-    static void fileMap(const QDir& d, QMap<QString, QString>& map);
+    static QMultiMap<QString, QString> fileMap(const QDir &d);
+    static void fileMap(const QDir& d, QMultiMap<QString, QString>& map);
     static QString fileName(QString filePath, QChar sep);
 
     static char * readAll(const char * fileName);
