@@ -36,7 +36,7 @@ namespace QGpCoreTools {
     \class Message Message.h
     \brief Show messages to user
     If not graphical user interface is running this class send messages to and get information from the user through
-    the console. In graphical user interface, a GuiMessage class is also available (in library qtbguitools), which
+    the console. In graphical user interface, a GuiMessage class is also available (in library QGpGuiTools), which
     transparently (for the developer) send the message to dialog boxes. Those two classes have eaxctly the same API.
     So always use this class for send messages and automatically the messages will be displayed in the appropriate way.
 
@@ -118,11 +118,59 @@ namespace QGpCoreTools {
     Generate a unique message id from position in source file.
 
     Use C macros __FILE__ and __LINE__ as argument of this function.
+
+    CRC32 is used instead of qhash to provide a stable value across Qt versions.
+    Checked with all instances of MSG_ID (202311): no identical values.
+    Checked with all .cpp files of geopsy repository(202311): no identical values.
+    Checked also with all .cpp for all line numbers from 30 to 1000: 265/1185340 identical values.
+
+    Insert in figue/src/main.cpp:
+    int main(int argc, char ** argv)
+    {
+      printf("%u\n", Message::messageId(argv[1], atoi(argv[2])));
+      return 0;
+    }
+
+    srcfind "MSG_ID" | awk '{print $1}' | awk 'BEGIN{FS=":"}{if(NR>2) print $1,$2}' > toto
+    cat toto | xargs -n 2 figue > titi
+    cat titi | sort -n | awk '{print a-$0;a=$0}' | sort -n
   */
   uint Message::messageId(const char * fileName, int lineNumber)
   {
     TRACE;
-    return qHash(QByteArray(fileName))-lineNumber;
+    quint32 val=::crc32(0L, Z_NULL, 0);
+    val=::crc32(val, reinterpret_cast<const uchar *>(fileName), strlen(fileName));
+    val*=lineNumber;
+    return val;
+  }
+
+  /*!
+    Generate a unique filter key from filter name.
+
+    CRC32 is used instead of qhash to provide a stable value across Qt versions.
+    Check with 54 filters grabbed from source files (202311): no identical values
+
+    Insert in figue/src/main.cpp:
+    int main(int argc, char ** argv)
+    {
+      printf("%s\n", Message::filterKey(argv[1]).toLatin1().data());
+      return 0;
+    }
+    rm -f filters
+    srcfind "getOpenFileName" -e "-A 10" > toto
+    gpreplace -f toto -p ";;\"\n[^\"]*\"" -s ";;" | egrep -o "tr\(\"[A-Za-z0-9 ]+ \(.*\)\"\)" | sed "s/tr.\"//" | sed "s/\".$//" >> filters
+    srcfind "getSaveFileName" -e "-A 10" > toto
+    gpreplace -f toto -p ";;\"\n[^\"]*\"" -s ";;" | egrep -o "tr\(\"[A-Za-z0-9 ]+ \(.*\)\"\)" | sed "s/tr.\"//" | sed "s/\".$//" >> filters
+    srcfind "getOpenFileNames" -e "-A 10" > toto
+    gpreplace -f toto -p ";;\"\n[^\"]*\"" -s ";;" | egrep -o "tr\(\"[A-Za-z0-9 ]+ \(.*\)\"\)" | sed "s/tr.\"//" | sed "s/\".$//" >> filters
+    cat filters | sort | uniq | awk '{printf("figue \"%s\"\n", $0)}' > toto
+    bash ./toto | awk 'BEGIN{FS="-"}{print $2}' | sort -n | awk '{print $1-a;a=$1}'
+  */
+  QString Message::filterKey(const QString& filter)
+  {
+    quint32 val=::crc32(0L, Z_NULL, 0);
+    val=::crc32(val, reinterpret_cast<const uchar *>(filter.toLatin1().data()), filter.size());
+    return "filter-"+QString::number(val);
   }
 
   /*!
