@@ -55,6 +55,8 @@ public:
   static inline QString toString(const RealMP& val, char format, int precision);
   static inline QString toString(const ComplexMP& val, char format, int precision);
 #endif
+  static void toOctaveFile(double val, const QString& fileName, const QString& variableName);
+  static void toOctaveFile(const Complex& val, const QString& fileName, const QString& variableName);
 
   static double toDouble(const QString& str, bool &ok, QLocale * locale=&_locale);
   static double toDouble(const QVariant& val, bool &ok, QLocale * locale=&_locale);
