@@ -38,7 +38,11 @@ namespace QGpCoreTools {
   StandardStream::StandardStream(FILE * fileHandle)
     : AbstractStream(), _s(fileHandle, QIODevice::WriteOnly)
   {
+#if(QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+    _s.setEncoding(QStringConverter::Utf8);
+#else
     _s.setCodec("UTF-8");
+#endif
   }
 
 } // namespace QGpCoreTools
