@@ -206,7 +206,7 @@ inline void XMLMember::release()
     delete _child;
     _child=nullptr;
   }
-  if(_context) {
+  if(_context && _context->isDeletable()) {
     delete _context;
   }
 }
