@@ -26,8 +26,6 @@
 ***************************************************************************/
 
 #include "XMLContext.h"
-#include "Trace.h"
-#include "MemoryChecker.h"
 
 namespace QGpCoreTools {
 
