@@ -35,8 +35,12 @@ namespace QGpCoreTools {
 class QGPCORETOOLS_EXPORT XMLContext
 {
 public:
-  XMLContext() {}
+  XMLContext(bool deletable) {_deletable=deletable;}
   ~XMLContext() {}
+
+  bool isDeletable() const {return _deletable;}
+private:
+  bool _deletable;
 };
 
 } // namespace QGpCoreTools
