@@ -31,6 +31,8 @@
 #include "Global.h"
 #include "MemoryChecker.h"
 
+//#define XML_DEBUG
+
 namespace QGpCoreTools {
 
 /*!
@@ -79,7 +81,7 @@ XMLClass::Error XMLParser::parse(XMLClass * object)
   _current.setObject(object);
 //#define XML_DEBUG
 #ifdef XML_DEBUG
-  printf("Entering context %s\n", _current->xml_tagName().toLatin1().data());
+  printf("Entering context %s\n", _current.object()->xml_tagName().toLatin1().data());
 #endif
   _error=XMLClass::NoError;
   // In case restore is called for an XML item with no children, just content
@@ -110,13 +112,13 @@ XMLClass::Error XMLParser::parse(XMLClass * object)
           switch(_tagType) {
           case OpenTagAttributes:
 #ifdef XML_DEBUG
-            printf("%5i=%5i === <%s att>\n", __LINE__, _line, _tag.toString().toLatin1().data());
+            printf("%5i=%5i === <%s att>\n", __LINE__, _line, _tag.toStringBuffer().toLatin1().data());
 #endif
             openContext();
             break;
           case SingleTagAttributes:
 #ifdef XML_DEBUG
-            printf("%5i=%5i === <%s att/>\n", __LINE__, _line, _tag.toString().toLatin1().data());
+            printf("%5i=%5i === <%s att/>\n", __LINE__, _line, _tag.toStringBuffer().toLatin1().data());
 #endif
             smallContext();
             break;
@@ -129,23 +131,24 @@ XMLClass::Error XMLParser::parse(XMLClass * object)
           _tmpStrings.clear();
           _attributes.clear();
 #ifdef XML_DEBUG
-          printf("%5i=%5i === <%s>\n", __LINE__, _line, _tag.toString().toLatin1().data());
+          printf("%5i=%5i === <%s>\n", __LINE__, _line, _tag.toStringBuffer().toLatin1().data());
 #endif
           openContext();
           break;
         case CloseTag:
 #ifdef XML_DEBUG
-          printf("%5i=%5i === %s</%s>\n", __LINE__, _line, _content.toString().toLatin1().data(),
-                                              _tag.toString().toLatin1().data());
+          printf("%5i=%5i === %s</%s>\n", __LINE__, _line, _content.toStringBuffer().toLatin1().data(),
+                                              _tag.toStringBuffer().toLatin1().data());
 #endif
           closeContext();
           break;
         case SingleTagNoAttributes:
+        case CData:
           qDeleteAll(_tmpStrings);
           _tmpStrings.clear();
           _attributes.clear();
 #ifdef XML_DEBUG
-          printf("%5i=%5i === <%s/>\n", __LINE__, _line, _tag.toString().toLatin1().data());
+          printf("%5i=%5i === <%s/>\n", __LINE__, _line, _tag.toStringBuffer().toLatin1().data());
 #endif
           smallContext();
           break;
@@ -175,9 +178,9 @@ void XMLParser::openContext()
 {
   _member=_current.object()->xml_member(_tag, _attributes, _current.context());
 #ifdef XML_DEBUG
-  printf("%5i=%5i === xml_member(%s) for '%s': %i, %p\n", __LINE__, _line, _tag.toString().toLatin1().data(),
-                                                            _current->xml_tagName().toLatin1().data(),
-                                                            _member.memberID(), _member.child());
+  printf("%5i=%5i === xml_member(%s) for '%s': %i, %p\n", __LINE__, _line, _tag.toStringBuffer().toLatin1().data(),
+                                                          _current.object()->xml_tagName().toLatin1().data(),
+                                                          _member.memberID(), _member.child());
 #endif
   if(_member.isValidMember()) {
     // Does nothing, attributes are already parsed, waiting for content and closing tag.
@@ -190,7 +193,7 @@ void XMLParser::openContext()
     _objectStack.push(_current);
     _current=Object(newContext, _member.child());
 #ifdef XML_DEBUG
-    printf("%5i=%5i =O= Enter object %s\n", __LINE__, _line, _current->xml_tagName().toLatin1().data());
+    printf("%5i=%5i =O= Enter object %s\n", __LINE__, _line, _current.object()->xml_tagName().toLatin1().data());
 #endif
   } else { // Bad member name... skipping or checking for binDataTag
     if(_tag!=XMLClass::binDataTag && _tag!=XMLClass::binData200510Tag) {
@@ -199,13 +202,13 @@ void XMLParser::openContext()
         App::log(tr("Unknown tag at line %1 for context %2: %3\n")
           .arg(_line)
           .arg(currentContextTag())
-          .arg(_tag.toString()));
+          .arg(_tag.toStringView()));
       }
       skip();
       return;
     }
   }
-  _content.set(_ptr + 1, 0);
+  _content.set(_ptr+1, 0);
   _specChar=nullptr;
   _tagStack.push(Tag(_tag,_member));
 }
@@ -219,7 +222,7 @@ void XMLParser::closeContext()
     } else {
       App::log(tr("Looking for tag '%1', found '%2'\n")
                     .arg(currentContextTag())
-                    .arg(_tag.toString()));
+                    .arg(_tag.toStringView()));
       finish(XMLClass::ErrorUnmatchedTag);
       return;
     }
@@ -248,7 +251,7 @@ void XMLParser::closeContext()
       // We are in a situation where a "parent" item has in fact no member specified in XML stream.
       // Used by XMLGenericItem, in this case before closing the current context we set properties
 #ifdef XML_DEBUG
-      printf("%5i=%5i =O= Leaving object %s\n", __LINE__, _line, _current->xml_tagName().toLatin1().data());
+      printf("%5i=%5i =O= Leaving object %s\n", __LINE__, _line, _current.object()->xml_tagName().toLatin1().data());
 #endif
       if(_specChar) {
         restoreSpecChar();
@@ -271,7 +274,7 @@ void XMLParser::closeContext()
   } else if(_member.child()) {
     // Usual exit of current context
 #ifdef XML_DEBUG
-    printf("%5i=%5i =O= Leaving object %s\n", __LINE__, _line, _current->xml_tagName().toLatin1().data());
+    printf("%5i=%5i =O= Leaving object %s\n", __LINE__, _line, _current.object()->xml_tagName().toLatin1().data());
 #endif
     if(!_current.object()->xml_polish(_current.context())) {
       finish(XMLClass::ErrorPolish);
@@ -284,7 +287,7 @@ void XMLParser::closeContext()
     _content.setInvalid();
   } else if(_tagStack.size()==0) {
 #ifdef XML_DEBUG
-    printf("%5i === Exiting context %s (Success, context stack empty)\n", __LINE__, _current->xml_tagName().toLatin1().data());
+    printf("%5i === Exiting context %s (Success, context stack empty)\n", __LINE__, _current.object()->xml_tagName().toLatin1().data());
 #endif
     finish(XMLClass::NoError);
   }
@@ -293,7 +296,7 @@ void XMLParser::closeContext()
 void XMLParser::smallContext()
 {
 #ifdef XML_DEBUG
-  printf("%5i === Member <%s/>\n", __LINE__, _tag.toString().toLatin1().data());
+  printf("%5i === Member <%s/>\n", __LINE__, _tag.toStringBuffer().toLatin1().data());
 #endif
   // The current context is definitively not a just a property with a valid content
   _content.setInvalid();
@@ -315,7 +318,7 @@ void XMLParser::smallContext()
 
 QString XMLParser::currentContextTag()
 {
-  return _tagStack.size()>0 ? _tagStack.top().tag().toString() : "[top level]";
+  return _tagStack.size()>0 ? _tagStack.top().tag().toStringBuffer() : "[top level]";
 }
 
 void XMLParser::restoreBinaryData()
@@ -325,7 +328,7 @@ void XMLParser::restoreBinaryData()
     if(_error!=XMLClass::NoError) return;
   }
   QByteArray binData;
-  if(_stream->file(_content.toString(), binData)) {
+  if(_stream->file(_content.toStringBuffer(), binData)) {
     QDataStream binStream(&binData, QIODevice::ReadOnly);
     QString binTag;
     binStream >> binTag;
@@ -349,7 +352,12 @@ void XMLParser::restoreBinaryData200510()
     if(_error!=XMLClass::NoError) return;
   }
   // Move to pointer specified by XML tag
-  qint64 offset=_content.toLongLong();
+  bool ok=true;
+  qint64 offset=_content.toLongLong(ok);
+  if(!ok) {
+    finish(XMLClass::ErrorSettingBinaryData);
+    return;
+  }
   QFile f(_stream->fileName()+".bin" );
   if(f.open(QIODevice::ReadOnly)) {
     QDataStream binStream(&f);
@@ -368,8 +376,8 @@ void XMLParser::restoreBinaryData200510()
       f.seek(offset);
       // Read again tag
       int n=_current.object()->xml_tagName().size()+1;
-      char * binTag=new char[ n ];
-      binStream.readRawData(binTag, sizeof(char) * n);
+      char * binTag=new char[n];
+      binStream.readRawData(binTag, sizeof(char)*n);
       if(_current.object()->xml_tagName().toLatin1()!=binTag) {
         finish(XMLClass::ErrorWrongBinaryOffset);
       } else {
@@ -504,6 +512,36 @@ void XMLParser::skipSimpleQuoteString()
   }
 }
 
+void XMLParser::skipCData()
+{
+  TRACE;
+  int line0=_line;
+  while(true) {
+    switch (_ptr->unicode()) {
+    case '\0':
+      if(_error!=XMLClass::NoError) {
+        _ptr--; // Remain just before the end
+        return;
+      }
+      _line=line0;
+      finish(XMLClass::ErrorEndTruncatedString);
+      return;
+    case ']':
+      _ptr++;
+      if(_ptr->unicode()==']' &&
+         _ptr[1].unicode()=='>') {
+        _ptr++;
+        return;
+      }
+      break;
+    case '\n':
+      _line++;
+      break;
+    }
+    _ptr++;
+  }
+}
+
 /*!
   This function is called when at least one special character sequence has been found
   in the content. \a specChar is a pointer to the first occurence, hence *specChar=='&'.
@@ -515,7 +553,7 @@ void XMLParser::skipSimpleQuoteString()
 */
 void XMLParser::restoreSpecChar()
 {
-  //App::log("Content before replacements ---" << content.toString() << "---" << endl;
+  //App::log("Content before replacements ---" << content.toString() << "---" << Qt::endl;
   StringSection cur(_content.data(), 0);
   StringSection code;
   QString& tmp=*new QString;
@@ -551,7 +589,7 @@ void XMLParser::restoreSpecChar()
   cur.appendTo(tmp);
   _tmpStrings.append(&tmp);
   _content.set(tmp.data(), tmp.size());
-  //App::log("Content after replacements ---" << restoredBuf << "---" << endl;
+  //App::log("Content after replacements ---" << restoredBuf << "---" << Qt::endl;
 }
 
 /*!
@@ -577,8 +615,37 @@ void XMLParser::setTag()
       _tag.setEnd(_ptr);
       _tagType=Attributes;
       return;
-    case '?':
     case '!':
+      if(_ptr[-1].unicode()=='<') {
+        if(_ptr[1].unicode()=='[' &&
+           _ptr[2].unicode()=='C' &&
+           _ptr[3].unicode()=='D' &&
+           _ptr[4].unicode()=='A' &&
+           _ptr[5].unicode()=='T' &&
+           _ptr[6].unicode()=='A' &&
+           _ptr[7].unicode()=='[') {
+          if(_content.end()!=_ptr-1) { // Can expand current content?
+            _content.set(_ptr-1, 0);
+          }
+          _ptr+=8;
+          skipCData();
+          _content.setEnd(_ptr);
+          _tagType=CData;
+        } else {
+          setTag();
+          if(_ptr->unicode()=='>') {
+            _tagType=QuestionTagNoAttributes;
+          } else {
+            _tagType=QuestionTagAttributes;
+          }
+        }
+      } else if(_ptr[1].unicode()=='>') {
+      } else {
+        finish(XMLClass::ErrorEmptyTag);
+        _tagType=Unknown;
+      }
+      return;
+    case '?':
       if(_ptr[-1].unicode()=='<') {
         setTag();
         if(_ptr->unicode()=='>') {
@@ -685,7 +752,7 @@ void XMLParser::setAttributes()
         skipSimpleQuoteString();
         break;
       default:
-        App::log(tr("No value given for attribute %1 at line %2\n").arg(attributeName.toString()).arg(_line) );
+        App::log(tr("No value given for attribute %1 at line %2\n").arg(attributeName.toStringView()).arg(_line) );
         _error=XMLClass::ErrorParsingAttributes;
         _tagType=Unknown;
         return;
@@ -718,7 +785,7 @@ QChar XMLParser::specialCharacter(const StringSection& code, bool& ok)
   case 'a':
     switch(code[1].unicode()) {
     case 'g':
-      if(code=="agrave") return 0x00E0;
+      if(code=="agrave") return QChar(0x00E0);
       break;
     case 'm':
       if(code=="amp") return '&';
@@ -733,7 +800,7 @@ QChar XMLParser::specialCharacter(const StringSection& code, bool& ok)
   case 'e':
     switch(code[1].unicode()) {
     case 'a':
-      if(code=="eacute") return 0x00E9;
+      if(code=="eacute") return QChar(0x00E9);
       break;
     }
     break;
@@ -769,7 +836,7 @@ void XMLParser::skip()
   int skippingLevel=_tagStack.count();
   _tagStack.push(_tag);
 #ifdef XML_DEBUG
-  printf("%5i === Skipping context %s, context size %i at line %i\n", __LINE__, _tag.toString().toLatin1().data(), skippingLevel, _line);
+  printf("%5i === Skipping context %s, context size %i at line %i\n", __LINE__, _tag.toStringBuffer().toLatin1().data(), skippingLevel, _line);
 #endif
   _ptr++;
   while(true) {
@@ -810,7 +877,7 @@ void XMLParser::skip()
             } else {
               App::log(tr("Looking for tag '%1', found '%2'\n")
                 .arg(currentContextTag())
-                .arg(_tag.toString()));
+                .arg(_tag.toStringView()));
               finish(XMLClass::ErrorUnmatchedTag);
               return;
             }
@@ -820,12 +887,13 @@ void XMLParser::skip()
           }
           if(_tagStack.size()==skippingLevel) {
 #ifdef XML_DEBUG
-            printf("%5i === End skipping context %s, context size %i at line %i\n", __LINE__, _tag.toString().toLatin1().data(), skippingLevel, _line);
+            printf("%5i === End skipping context %s, context size %i at line %i\n", __LINE__, _tag.toStringBuffer().toLatin1().data(), skippingLevel, _line);
 #endif
             return;
           }
           break;
         case SingleTagNoAttributes:
+        case CData:
           // nothing to do just continue
           break;
         default:
