@@ -153,7 +153,7 @@ namespace QGpCoreWave {
           _curves.append(ModalCurve());
           return XMLMember(&_curves.last());
         } else {
-          App::log(tr("Wrong type of modal curve %1\n").arg(it.value().toString()) );
+          App::log(tr("Wrong type of modal curve %1\n").arg(it.value().toStringView()));
           return XMLMember(XMLMember::Unknown);
         }
       } else {
@@ -192,7 +192,7 @@ namespace QGpCoreWave {
       const FactoryPoint& p=autocorr.constAt(ix);
       if(p.isValid()) {
         double omega=2.0*M_PI*p.x();
-        QVector<double> solutions=eng.dispersion(omega, p.y(), kmin, kmax);
+        VectorList<double> solutions=eng.dispersion(omega, p.y(), kmin, kmax);
         for(int i=0; i<solutions.count() && i<maxSolutionCount; i++) {
           dispersion.append(FactoryPoint(p.x(), solutions.at(i)));
         }
@@ -213,7 +213,10 @@ namespace QGpCoreWave {
     ASSERT(curve.isSorted());
     // Smooth the curve
     SamplingParameters s;
-    s.setRange(curve.firstX(), curve.lastX());
+    int firstIndex=0, lastIndex=curve.count()-1;
+    curve.firstValid(firstIndex);
+    curve.lastValid(lastIndex);
+    s.setRange(curve.constAt(firstIndex).x(), curve.constAt(lastIndex).x());
     s.setScaleType(SamplingParameters::Log);
     s.setCount(curve.count());
     SmoothingParameters p;
