@@ -54,11 +54,11 @@ double AutocorrDispersion::y(double k)
   Returns all the dispersion curve solutions for \a autocorr between \a kmin and \a kmax.
   The returned values are slowness sorted in ascending order.
 */
-QVector<double> AutocorrDispersion::dispersion(double omega, double autocorr,
+VectorList<double> AutocorrDispersion::dispersion(double omega, double autocorr,
                                                double kmin, double kmax)
 {
   TRACE;
-  QVector<double> results;
+  VectorList<double> results;
   RootSolver<AutocorrDispersion> solver(this);
   solver.setPrecision(1e-7);
   solver.setRelativeStep(0.1);
