@@ -72,9 +72,10 @@ bool AutocorrRing::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
+  bool ok=true;
   switch(memberID) {
-  case 0: _minRadius=content.toDouble(); return true;
-  case 1: _maxRadius=content.toDouble(); return true;
+  case 0: _minRadius=content.toDouble(ok); return ok;
+  case 1: _maxRadius=content.toDouble(ok); return ok;
   default: return false;
   }
 }
