@@ -45,7 +45,7 @@ class Dispersion : public ModalStorage
 {
   TRANSLATIONS("Dispersion")
 public:
-  QGPCOREWAVE_EXPORT Dispersion(int nModes, const QVector<double>* x);
+  QGPCOREWAVE_EXPORT Dispersion(int nModes, const VectorList<double>* x);
 
   QGPCOREWAVE_EXPORT void setGroupSlowness();
 
