@@ -27,6 +27,7 @@
 
 #include "DispersionFactory.h"
 #include "EllipticityFactory.h"
+#include "ModalCurve.h"
 #include "AutocorrFactory.h"
 #include "Dispersion.h"
 #include "Mode.h"
@@ -178,4 +179,23 @@ bool DispersionFactory::calculate(const Seismic1DModel * m, EllipticityFactory *
   return true;
 }
 
+/*!
+  Interpoles modes of Phase velocity for Rayleigh from the samples of curve \a c.
+  Only the modes available for \a c are assigned.
+*/
+void DispersionFactory::setPhaseRayleigh(const ModalCurve& c)
+{
+  if(_phaseRayleigh) {
+    double invTwoPi=0.5/M_PI;
+    for(int im=0; im<_phaseRayleigh->modeCount(); im++) {
+      if(c.hasMode(Mode(Mode::Phase, Mode::Rayleigh, im))) {
+        RealValue * values=_phaseRayleigh->mode(im);
+        for(int ix=0; ix<x()->count(); ix++) {
+          values[ix]=c.interpole(x()->at(ix)*invTwoPi, LogScale, LogScale).mean();
+        }
+      }
+    }
+  }
+}
+
 } // namespace QGpCoreWave
