@@ -221,7 +221,7 @@ namespace QGpCoreWave {
     }*/
     refineSort();
     disp.refineSort();
-    return floor(misfit*1000+0.5)*0.001; // frequency is estimated down to 1e-3, avoid classification within precision limits
+    return round(misfit*1e3)*1e-3; // frequency is estimated down to 1e-3, avoid classification within precision limits
   }
 
   /*!
@@ -272,8 +272,11 @@ namespace QGpCoreWave {
                fabs(lastVal)>signThreshold &&
                ((val.value()>0.0 && lastVal<0.0) ||
                 (val.value()<0.0 && lastVal>0.0))) {
-              s << comments;
-              s << "#";
+              if(comments.isEmpty()) {
+                s << "#\n";
+              } else {
+                s << comments;
+              }
             }
             s << fmt.arg(it.x()*xFactor, 0, 'g', 15).arg(val.value(), 0, 'g', 15);
             lastVal=val.value();
@@ -282,4 +285,5 @@ namespace QGpCoreWave {
       }
     }
   }
+
 } // namespace QGpCoreWave
