@@ -43,7 +43,7 @@ class QGPCOREWAVE_EXPORT Ellipticity :  public ModalStorage
 {
   TRANSLATIONS("EllipticityFactory")
 public:
-  Ellipticity(int nModes, const QVector<double>* x) : ModalStorage(nModes, x) {}
+  Ellipticity(int nModes, const VectorList<double>* x) : ModalStorage(nModes, x) {}
 
   QList<double> peaks(int modeIndex, Dispersion& disp, Rayleigh * waveModel);
   double peakMisfit(int modeIndex, const RealStatisticalValue& val, double minAbsEll,
