@@ -78,8 +78,8 @@ void ModalCurve::operator=(const Curve<RealStatisticalPoint>& o)
     at(i)=o.constAt(i);
   }
   _modes.clear();
-  _log="";
-  _name="";
+  clearLog();
+  setName(QString());
 }
 
 void ModalCurve::clear()
@@ -87,8 +87,8 @@ void ModalCurve::clear()
   TRACE;
   Curve<FactoryPoint>::clear();
   _modes.clear();
-  _log.clear();
-  _name.clear();
+  clearLog();
+  setName(QString());
 }
 
 void ModalCurve::addMode(const Mode& m)
@@ -126,7 +126,7 @@ bool ModalCurve::hasMode(const Mode& m) const
   Set the index in vector \a x of each sample of the curve. Each sample of the curve must have its
   corresponding value in vector \a x.
 */
-void ModalCurve::linkX(const ::QVector<double>& x)
+void ModalCurve::linkX(const ::VectorList<double>& x)
 {
   TRACE;
   int n=count();
@@ -160,7 +160,7 @@ int ModalCurve::indexOf(int factoryIndex) const
 
   \a minMisfit is the minimum value that can be reached for each sample individualy.
 */
-double ModalCurve::misfit(int& nValues, int& nData, const ModalFactory& f, MisfitType type, double minMisfit) const
+double ModalCurve::misfit(int& nValues, int& nData, const ModalFactory& f, Misfit::Type type, double minMisfit) const
 {
   TRACE;
   double res=0.0;
@@ -235,15 +235,15 @@ void ModalCurve::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
 {
   TRACE;
   Q_UNUSED(context)
-  writeProperty(s,"name", _name);
-  writeProperty(s,"log", _log);
+  writeProperty(s,"name", name());
+  writeProperty(s,"log", log());
   writeProperty(s,"enabled", _enabled ? "true" : "false");
 }
 
 void ModalCurve::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
 {
   TRACE;
-  for(QList<Mode>::ConstIterator it=_modes.begin(); it!=_modes.end(); it++ ) {
+  for(::QList<Mode>::ConstIterator it=_modes.begin(); it!=_modes.end(); it++ ) {
     it->xml_save(s, context);
   }
   const_iterator it;
@@ -276,9 +276,16 @@ bool ModalCurve::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
   switch(memberID) {
-  case 0: _name=content.toString(); return true;
-  case 1: _log=content.toString(); return true;
-  case 2: _enabled=(content=="true"); return true;
+  case 0:
+    setName(content.toStringBuffer());
+    return true;
+  case 1:
+    clearLog();
+    addLog(content.toStringBuffer());
+    return true;
+  case 2:
+    _enabled=(content=="true");
+    return true;
   default: return false;
   }
 }
