@@ -35,7 +35,10 @@ namespace QGpCoreWave {
     Full description of class still missing
   */
 
-  CURVEPROXY_BASICIMPLEMENTATIONS(ModalProxy)
+  CURVEPROXY_BASIC_IMPLEMENTATIONS(ModalProxy)
+  CURVEPROXY_ADVANCED_IMPLEMENTATIONS(ModalProxy,
+                                      ModalCurve,
+                                      FactoryPoint)
 
 } // namespace QGpCoreWave
 
