@@ -44,15 +44,15 @@ void RefractionCurve::clear()
 {
   TRACE;
   Curve<FactoryPoint>::clear();
-  _log="";
-  _name="";
+  setName(QString());
+  clearLog();
   _source=0.0;
 }
 
 /*!
   Set the index in vector \a xSrc of source. Source x must be in \a xSrc.
 */
-void RefractionCurve::linkSource(const ::QVector<double>& xSrc)
+void RefractionCurve::linkSource(const ::VectorList<double>& xSrc)
 {
   TRACE;
   _sourceIndex=xSrc.indexOf(_source);
@@ -63,7 +63,7 @@ void RefractionCurve::linkSource(const ::QVector<double>& xSrc)
   Set the index in vector \a xRec of each sample of the curve. Each sample of the curve must have its
   corresponding value in vector \a xRec.
 */
-void RefractionCurve::linkReceivers(const ::QVector<double>& xRec)
+void RefractionCurve::linkReceivers(const ::VectorList<double>& xRec)
 {
   TRACE;
   int n=count();
@@ -86,7 +86,7 @@ void RefractionCurve::linkReceivers(const ::QVector<double>& xRec)
 
   \a minMisfit2 is the square of the minimum misfit value that can be reached for each sample individualy.
 */
-double RefractionCurve::misfit(int& nValues, int& nData, const RefractionFactory& f, MisfitType type, double minMisfit) const
+double RefractionCurve::misfit(int& nValues, int& nData, const RefractionFactory& f, Misfit::Type type, double minMisfit) const
 {
   TRACE;
   double res=0;
@@ -106,9 +106,9 @@ void RefractionCurve::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
 {
   TRACE;
   Q_UNUSED(context)
-  writeProperty(s,"name",_name);
-  writeProperty(s,"log",_log);
-  writeProperty(s,"source",_source);
+  writeProperty(s,"name", name());
+  writeProperty(s,"log", log());
+  writeProperty(s,"source", _source);
 }
 
 void RefractionCurve::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
@@ -140,11 +140,20 @@ bool RefractionCurve::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
+  bool ok=true;
   switch(memberID) {
-  case 0: _name=content.toString(); return true;
-  case 1: _log=content.toString(); return true;
-  case 2: _source=content.toDouble(); return true;
-  default: return false;
+  case 0:
+    setName(content.toStringBuffer());
+    return true;
+  case 1:
+    clearLog();
+    addLog(content.toStringBuffer());
+    return true;
+  case 2:
+    _source=content.toDouble(ok);
+    return ok;
+  default:
+    return false;
   }
 }
 
