@@ -288,7 +288,6 @@ namespace QGpCoreWave {
       _qp[i]=0.0;
       _qs[i]=0.0;
     }
-    initCalculation();
   }
 
   /*!
@@ -315,7 +314,6 @@ namespace QGpCoreWave {
       _qp[i]=0.0;
       _qs[i]=0.0;
     }
-    initCalculation();
   }
 
   /*!
@@ -499,36 +497,47 @@ namespace QGpCoreWave {
 
     sq_cob means (c/b)^2 and sq_boa means (b/a)^2.
 
-    Equation : (2-sq_cob)-4*sqrt(1-sq_boa*sq_cob)*sqrt(1-sq_cob)=0
+    Equation : (2-sq_cob)^2-4*sqrt(1-sq_boa*sq_cob)*sqrt(1-sq_cob)=0
 
     The sqrt can be elevated to square, interiors are positive:
-    [(2-x)]=16* (1-sq_boa*x) * (1-x), where x=sq_cob
+    (2-x)^4=16* (1-sq_boa*x) * (1-x), where x=sq_cob
 
-    Calculating all terms:
-    x * [x-8*x+(24-16*sq_boa) *x+(16*sq_boa-16)]=0
+    Calculating all terms (equivalent to Malischewsky 2000, eq 2):
+
+    x * [x^3-8*x^2+(24-16*sq_boa)*x+(16*sq_boa-16)]=0
 
     x=0 is not a valid solution
     Thus we are looking for the roots of:
-    x-8*x+a3*x+a4
+    x^3-8*x^2+a3*x+a4
     where,
        a4=16*sq_boa-16
        a3=8-a4
 
     3rd degree poly which solutions are calculated by newton raphson
-    using the derivative : 3*x-16*x+a3
+    using the derivative : 3*x^2-16*x+a3
 
     This poly has a simple root in the neighborhood of the starting
     value (for all boa), thus there is no problem of convergence
+
+    \a nu is Poisson's ratio. It returns the ratio Vr/Vs
   */
-  double Seismic1DModel::halfSpaceRayleighSlowness(int iLayer) const
+  double Seismic1DModel::rayleighRelativeVelocity(double nu)
   {
     TRACE;
-    double y,x=0.9025;
-    /* (c/beta)=0.95 solution for a=std::numeric_limits<double>::infinity(), this is a maximum bound
+    double vsp2=(nu-0.5)/(nu-1.0);
+    double y,x=0.91262197461584826;
+    /* x=(c/beta)^2=0.91262197461584826
+     * c/beta=0.9553125010256320
+       solution for a=std::numeric_limits<double>::infinity(), this is a maximum bound
        value for the Rayleigh velocity
+    Polynomial p(3);
+    p.setCoefficient(0, -16);
+    p.setCoefficient(1, 24);
+    p.setCoefficient(2, -8.0);
+    p.setCoefficient(3, 1.0);
+    printf("infinite Vp solution: %.20lf\n", p.realRoots().first());
     */
-    double boa=_slowP[iLayer]/_slowS[iLayer];
-    double a4=16*boa*boa-16;
+    double a4=16*vsp2-16;
     double a3=8-a4;
     do {
       double sqx=x*x;
@@ -537,27 +546,126 @@ namespace QGpCoreWave {
       x-=y/dy;
     } while(fabs(y)>1e-10);
     // This condition over y achieves a precision over x of about 1e-15
-    return _slowS[iLayer]/sqrt(x);
+    return sqrt(x);
+  }
+
+  double Seismic1DModel::rayleighRelativeVelocityEigenvalue(double nu)
+  {
+    TRACE;
+    Polynomial p(3);
+    double vsp2=(nu-0.5)/(nu-1.0);
+    p.setCoefficient(0, 16.0*(vsp2-1.0));
+    p.setCoefficient(1, 8.0-p.coefficient(0));
+    p.setCoefficient(2, -8.0);
+    p.setCoefficient(3, 1.0);
+    VectorList<double> roots=p.realRoots();
+    ASSERT(roots.count()==1);  // First derivative strictly positive, hence single root
+    return sqrt(roots.first());
   }
 
   /*!
-    Return the ellipticity of half-space with the properties of layer \a iLayer.
+    Analytical formulation proposed by Malischewsky, 2000 in Wave Motion.
+    The same third degree equation as in rayleighRelativeVelocity() is solved.
+
+    From comparison with the numerical approach, the agreement is fairly good
+    around 1e-14 or 1e-16 except a nu=0.4. I should probably ask
+    Peter Malischewsky himself.
+  */
+  double Seismic1DModel::rayleighRelativeVelocityMalischewsky(double nu)
+  {
+    TRACE;
+    double g=(nu-0.5)/(nu-1.0);
+    // Use complex because h1r is negative if nu is lower that 0.27
+    Complex h1r=33.0-186.0*g+321.0*g*g-192.0*g*g*g;
+    Complex h1=3.0*sqrt(h1r);
+    Complex h2=-(17.0-45.0*g)+h1;
+    Complex h3=17.0-45.0*g+h1;
+    double h4=-g+1.0/6.0;
+    double sh4=Number::sign(h4);
+    Complex x=2.0/3.0*(4.0-pow(h3, 1.0/3.0)+sh4*pow(sh4*h2, 1.0/3.0));
+    // Imaginary part of x is always null.
+    // Check equation resolution
+    //Complex r=x*x*x-8.0*x*x+(24.0-16.0*g)*x+(16.0*g-16.0);
+    return sqrt(x.re());
+  }
+
+  void Seismic1DModel::timeComparisonRayleighRelativeVelocity()
+  {
+    QElapsedTimer t;
+    Random r;
+    int n;
+    double val;
+    val=0.0;
+    t.start();
+    for(int i=0; i<10000; i++) {
+      val+=r.uniform(0.1, 0.5);
+    }
+    n=t.elapsed();
+    printf("Random generation: %lf ms (%lf)\n", n*0.0001, val*0.0001);
+    val=0.0;
+    t.start();
+    for(int i=0; i<10000; i++) {
+      val+=rayleighRelativeVelocity(r.uniform(0.1, 0.5));
+    }
+    n=t.elapsed();
+    printf("Newton iterations: %lf ms (%lf)\n", n*0.0001, val*0.0001);
+    val=0.0;
+    t.start();
+    for(int i=0; i<10000; i++) {
+      val+=rayleighRelativeVelocityEigenvalue(r.uniform(0.1, 0.5));
+    }
+    n=t.elapsed();
+    printf("Eigenvalue: %lf ms (%lf)\n", n*0.0001, val*0.0001);
+    val=0.0;
+    t.start();
+    for(int i=0; i<10000; i++) {
+      val+=rayleighRelativeVelocityMalischewsky(r.uniform(0.1, 0.5));
+    }
+    n=t.elapsed();
+    printf("Malischewsky: %lf ms (%lf)\n", n*0.0001, val*0.0001);
+  }
+
+  double Seismic1DModel::ellipticityMalischewsky(double nu)
+  {
+    TRACE;
+    double nu2=nu*nu;
+    double nu3=nu2*nu;
+    Complex h1=(5.0-21.0*nu+16.0*nu2-32.0*nu3)/pow(nu-1.0,3.0);
+    h1=sqrt(h1);
+    double h2=(11.0-56.0*nu)/(nu-1.0);
+    Complex h3=4.0*(3.0*sqrt(3.0)*h1+h2);
+    h3=pow(h3, 1.0/3.0);
+    double s25n=Number::sign(2-5*nu);
+    Complex h4=s25n*pow(4.0*(-3.0*sqrt(3.0)*h1+h2)*s25n, 1.0/3.0);
+    Complex e=-2.0*sqrt(3.0*(h3+h4-5))/(h3+h4-2.0);
+    // Imaginary part of e is always null.
+    return e.re();
+  }
+
+  /*!
+    Convenient function
+  */
+  double Seismic1DModel::halfSpaceRayleighSlowness(int iLayer) const
+  {
+    TRACE;
+    return _slowS[iLayer]/rayleighRelativeVelocity(poisson(iLayer));
+  }
+
+  /*!
+    Return the ellipticity of a half-space with the properties of layer \a iLayer.
     From Boore and Toksoz (1969, equation 2), BSSA
 
     If Qs and Qp are not available, they are supposed to be infinite.
   */
-  Complex Seismic1DModel::halfSpaceEllipticity(int iLayer) const
+  Complex Seismic1DModel::halfSpaceEllipticity(double vp, double vs, double qp, double qs)
   {
     TRACE;
     // Compute Rayleigh phase velocity
-    double c=halfSpaceRayleighSlowness(iLayer);
-    double b=_slowS[iLayer]/c;
+    double b=rayleighRelativeVelocity(poisson(vp, vs));
+    double a=b*vs/vp;
     b*=b;
-    double a= _slowP[iLayer]/c;
     a*=a;
     double m=a*(2-b)*(1-b)/(a*(2-b)*(1-b)-b*(1-a)*(2-3*b));
-    double qs=_qs[iLayer];
-    double qp=_qp[iLayer];
     if(qs>0.0) {
       qs=1.0/qs;
     }
@@ -691,12 +799,19 @@ namespace QGpCoreWave {
   {
     TRACE;
     double slowP2=_slowP[iLayer];
-    slowP2 *= slowP2;
+    slowP2*=slowP2;
     double slowS2=_slowS[iLayer];
-    slowS2 *= slowS2;
+    slowS2*=slowS2;
     return (slowP2-0.5*slowS2)/(slowP2-slowS2);
   }
 
+  double Seismic1DModel::poisson(double vp, double vs)
+  {
+    vp*=vp;
+    vs*=vs;
+    return (vs-0.5*vp)/(vs-vp);
+  }
+
   /*!
     Returns true if model is elastic (quality factors all set to 0)
   */
@@ -713,7 +828,7 @@ namespace QGpCoreWave {
     TRACE;
     bool ok=true;
     if(field.isValid()) {
-      var=field.toDouble(&ok);
+      var=field.toDouble(ok);
       if(ok && var>0.0) {
         return true;
       } else {
@@ -767,9 +882,10 @@ namespace QGpCoreWave {
     field=fields.nextField(ptr);
     if(field.isValid()) {
       bool ok=true;
-      _layerCount=field.toInt(&ok);
+      _layerCount=field.toInt(ok);
       if(!ok && !field.isEmpty()) { // Not a blank line but failed
-        App::log(tr("Layered model: bad number of layers: \"%1\" interpreted as %2\n").arg(field.toString()).arg(_layerCount) );
+        App::log(tr("Layered model: bad number of layers: \"%1\" interpreted as %2\n")
+                     .arg(field.toStringView()).arg(_layerCount) );
          _layerCount=0;
          return false;
       }
@@ -793,21 +909,21 @@ namespace QGpCoreWave {
         ptr=0;
         if(i<_layerCount-1) {
           field=fields.nextField(ptr);
-          if(!setValue(_h[i], field, i, tr("thickness"), false) ) return false;
+          if(!setValue(_h[i], field, i, tr("thickness"), false)) return false;
         } else {
           fields.nextField(ptr);
         }
         field=fields.nextField(ptr);
-        if(!setValue(_slowP[i], field, i, tr("Vp"), false) ) return false;
+        if(!setValue(_slowP[i], field, i, tr("Vp"), false)) return false;
         field=fields.nextField(ptr);
-        if(!setValue(_slowS[i], field, i, tr("Vs"), false) ) return false;
+        if(!setValue(_slowS[i], field, i, tr("Vs"), false)) return false;
         field=fields.nextField(ptr);
-        if(!setValue(_rho[i], field, i, tr("density"), false) ) return false;
+        if(!setValue(_rho[i], field, i, tr("density"), false)) return false;
         // Not mandatory quality factors
         field=fields.nextField(ptr);
-        if(!setValue(_qp[i], field, i, tr("Qp"), true) ) _qp[i]=0.0;;
+        if(!setValue(_qp[i], field, i, tr("Qp"), true)) _qp[i]=0.0;
         field=fields.nextField(ptr);
-        if(!setValue(_qs[i], field, i, tr("Qs"), true) ) _qs[i]=0.0;;
+        if(!setValue(_qs[i], field, i, tr("Qs"), true)) _qs[i]=0.0;
         // Switch to slowness
         _slowP[i]=1/_slowP[i];
         _slowS[i]=1/_slowS[i];
@@ -847,7 +963,7 @@ namespace QGpCoreWave {
       s << str4.arg(0.0, 0, 'g', 20)
                .arg(_slowP[_layerCount-1]==0.0 ? 0.0 : 1/_slowP[_layerCount-1], 0, 'g', 20)
                .arg(_slowS[_layerCount-1]==0.0 ? 0.0 : 1/_slowS[_layerCount-1], 0, 'g', 20)
-               .arg(_rho[_layerCount-1], 0, 'g', 20) << flush;
+               .arg(_rho[_layerCount-1], 0, 'g', 20) << Qt::flush;
      } else {
       for(int i=0; i<nl1; i++) {
         s << str6.arg(_h[i], 0, 'g', 20)
@@ -862,7 +978,7 @@ namespace QGpCoreWave {
                .arg(_slowS[_layerCount-1]==0.0 ? 0.0 : 1/_slowS[_layerCount-1], 0, 'g', 20)
                .arg(_rho[_layerCount-1], 0, 'g', 20)
                .arg(_qp[_layerCount-1], 0, 'g', 20)
-               .arg(_qs[_layerCount-1], 0, 'g', 20) << flush;
+               .arg(_qs[_layerCount-1], 0, 'g', 20) << Qt::flush;
      }
   }
 
@@ -909,7 +1025,7 @@ namespace QGpCoreWave {
     s << str.arg(0.0, 0, 'f', 20)
             .arg(1/_slowP[_layerCount-1], 0, 'f', 20)
             .arg(1/_slowS[_layerCount-1], 0, 'f', 20)
-            .arg(_rho[_layerCount-1], 0, 'f', 20) << flush;
+            .arg(_rho[_layerCount-1], 0, 'f', 20) << Qt::flush;
   }
 
   /*!
