@@ -29,7 +29,7 @@
 
 #include "CurveBrowser.h"
 #include "CurveSelector.h"
-#include "CurveProperties.h"
+#include "CurvePropertiesWidget.h"
 #include "CurveBrowserResample.h"
 #include "CurveBrowserCut.h"
 #include "CurveBrowserValidate.h"
@@ -107,14 +107,18 @@ namespace QGpGuiMath {
   void CurveBrowser::setProxy(CurveProxy * proxy)
   {
     TRACE;
-    delete _proxy;
+    if(proxy!=_proxy) {
+      delete _proxy;
+    }
     _proxy=proxy;
   }
 
   void CurveBrowser::setPlotProxy(CurvePlotProxy * proxy)
   {
     TRACE;
-    delete _plotProxy;
+    if(proxy!=_plotProxy) {
+      delete _plotProxy;
+    }
     _plotProxy=proxy;
   }
 
@@ -143,38 +147,56 @@ namespace QGpGuiMath {
     return a;
   }
 
-  CurveProperties * CurveBrowser::createProperties()
+  CurvePropertiesWidget * CurveBrowser::createProperties()
   {
-    return new CurveProperties;
+    return new CurvePropertiesWidget;
   }
 
-  CurveProperties * CurveBrowser::addLine(AbstractLine * line)
+  /*!
+    Add \a line to the the browser. \a line must belong to the current layer.
+  */
+  CurvePropertiesWidget * CurveBrowser::addLine(AbstractLine * line)
   {
     TRACE;
     ASSERT(_proxy);
     ASSERT(_plotProxy);
-    CurveProperties * w=createProperties();
+    CurvePropertiesWidget * w=createProperties();
     w->setCurrentLayer(_currentLayer);
     w->setLine(line);
     connect(w, SIGNAL(curveModified()), this, SIGNAL(curveModified()));
     connect(w, SIGNAL(nameChanged(QString)), this, SLOT(setCurveName(QString)));
     CurveProxy * p=_proxy->clone();
-    _plotProxy->setCurve(line, p); // Curve must be set before setting proxy to CurveProperties
+    _plotProxy->setCurve(line, p); // Curve must be set before setting proxy to CurvePropertiesWidget
     w->setProxy(p);
     QString n=p->name();
     if(n.isEmpty()) {
       n="# "+QString::number(curveTabs->count()+1);
-      p->setName(n);
+      w->setCurveName(n);
     }
     curveTabs->addTab(w, n);
     _currentLayer->graph()->deepUpdate();
     return w;
   }
 
+  /*!
+    Convenient function for cases with several layers.
+    Add \a line to the the browser if \a layer is the current layer.
+    \a line must belong to \a layer.
+  */
+  CurvePropertiesWidget * CurveBrowser::addLine(AbstractLine * line, LineLayer * layer)
+  {
+    TRACE;
+    if(_currentLayer==layer) {
+      return addLine(line);
+    } else {
+      return nullptr;
+    }
+  }
+
   void CurveBrowser::takeLine(int index)
   {
     TRACE;
-    CurveProperties * w=static_cast<CurveProperties *>(curveTabs->widget(index));
+    CurvePropertiesWidget * w=static_cast<CurvePropertiesWidget *>(curveTabs->widget(index));
     curveTabs->removeTab(index);
     delete w;
   }
@@ -221,17 +243,17 @@ namespace QGpGuiMath {
       if(a.data().toBool()) a.setEnabled(e);
     }
     for(int i=curveTabs->count()-1; i>=0; i--) {
-      CurveProperties * p=static_cast<CurveProperties *>(curveTabs->widget(i));
+      CurvePropertiesWidget * p=static_cast<CurvePropertiesWidget *>(curveTabs->widget(i));
       p->setEditable(e);
     }
   }
 
-  CurveProperties * CurveBrowser::find(const QString& name) const
+  CurvePropertiesWidget * CurveBrowser::find(const QString& name) const
   {
     TRACE;
     int n=curveTabs->count();
     for(int i=0; i<n; i++) {
-      CurveProperties * p=static_cast<CurveProperties *>(curveTabs->widget(i));
+      CurvePropertiesWidget * p=static_cast<CurvePropertiesWidget *>(curveTabs->widget(i));
       if(p->proxy()->name()==name) {
         return p;
       }
@@ -239,6 +261,12 @@ namespace QGpGuiMath {
     return nullptr;
   }
 
+  CurvePropertiesWidget * CurveBrowser::curveAt(int index) const
+  {
+    ASSERT(index<curveTabs->count());
+    return static_cast<CurvePropertiesWidget *>(curveTabs->widget(index));
+  }
+
   /*!
     Setup browser layer and axis. Don't forget to call setReferenceLine().
   */
@@ -248,10 +276,10 @@ namespace QGpGuiMath {
     ASSERT(_plotProxy);
     AxisWindow * graph=curveLayer->graph();
     graph->xAxis()->setTitle(_proxy->xTitle());
-    graph->xAxis()->setTitleInversedScale(_proxy->xInversedTitle());
+    graph->xAxis()->setTitleInverseScale(_proxy->xInverseTitle());
     _plotProxy->setXAxisProperties(graph->xAxis());
     graph->yAxis()->setTitle(_proxy->yTitle());
-    graph->yAxis()->setTitleInversedScale(_proxy->yInversedTitle());
+    graph->yAxis()->setTitleInverseScale(_proxy->yInverseTitle());
     _plotProxy->setYAxisProperties(graph->yAxis());
     graph->updateExternalGeometry();
 
@@ -289,7 +317,7 @@ namespace QGpGuiMath {
         addLine(_currentLayer->line(i));
       }
       for(int i=curveTabs->count()-1; i>=0; i--) {
-        static_cast<CurveProperties *>(curveTabs->widget(i))->setCurrentLayer(_currentLayer);
+        static_cast<CurvePropertiesWidget *>(curveTabs->widget(i))->setCurrentLayer(_currentLayer);
       }
     }
     emit curveModified();
@@ -303,7 +331,8 @@ namespace QGpGuiMath {
     if(layer!=_currentLayer) {
       // TODO
     } else {
-      CurveProperties * p=addLine(line);
+      CurvePropertiesWidget * p=addLine(line);
+      setCurveName(tr("pick%1"), p);
       p->proxy()->addLog(tr("Manually picked\n"));
     }
   }
@@ -314,7 +343,7 @@ namespace QGpGuiMath {
     // Can be issued by a layer different from the current one
     LineLayer * layer=qobject_cast<LineLayer *>(sender());
     if(layer==_currentLayer) {
-      CurveProperties * p=properties(line);
+      CurvePropertiesWidget * p=properties(line);
       p->beginCurveChange();
     }
   }
@@ -325,7 +354,7 @@ namespace QGpGuiMath {
     // Can be issued by a layer different from the current one
     LineLayer * layer=qobject_cast<LineLayer *>(sender());
     if(layer==_currentLayer) {
-      CurveProperties * p=properties(line);
+      CurvePropertiesWidget * p=properties(line);
       p->endCurveChange();
       curveTabs->setCurrentWidget(p);
       emit curveModified();
@@ -338,10 +367,11 @@ namespace QGpGuiMath {
   int CurveBrowser::count() const
   {
     TRACE;
-    if(_currentLayer)
+    if(_currentLayer) {
       return _currentLayer->count();
-    else
+    } else {
       return 0;
+    }
   }
 
   /*!
@@ -369,23 +399,27 @@ namespace QGpGuiMath {
     w->yAxis()->setRange(r.y1() * 0.95, r.y2() * 1.05);
   }
 
-  QList<CurveProperties *> CurveBrowser::curves() const
+  QList<CurvePropertiesWidget *> CurveBrowser::curves() const
   {
     TRACE;
-    QList<CurveProperties *> list;
+    QList<CurvePropertiesWidget *> list;
     int n=curveTabs->count();
     for(int i=0; i<n; i++) {
-      list.append(static_cast<CurveProperties *>(curveTabs->widget(i)));
+      list.append(static_cast<CurvePropertiesWidget *>(curveTabs->widget(i)));
     }
     return list;
   }
 
-  CurveProperties * CurveBrowser::properties(AbstractLine * line) const
+  /*!
+    Returns the properties corresponding to \a line or null if \a line is not
+    managed by the browser.
+  */
+  CurvePropertiesWidget * CurveBrowser::properties(AbstractLine * line) const
   {
     TRACE;
     int n=curveTabs->count();
     for(int i=0; i<n; i++) {
-      CurveProperties * p=static_cast<CurveProperties *>(curveTabs->widget(i));
+      CurvePropertiesWidget * p=static_cast<CurvePropertiesWidget *>(curveTabs->widget(i));
       if(line==p->line()) {
         return p;
       }
@@ -405,7 +439,7 @@ namespace QGpGuiMath {
       }
     }
     for(int i=curveTabs->count()-1; i>=0; i--) {
-      CurveProperties * p=static_cast<CurveProperties *>(curveTabs->widget(i));
+      CurvePropertiesWidget * p=static_cast<CurvePropertiesWidget *>(curveTabs->widget(i));
       curveTabs->removeTab(i);
       delete p;
     }
@@ -419,7 +453,7 @@ namespace QGpGuiMath {
   void CurveBrowser::load()
   {
     TRACE;
-    QStringList fileNames=Message::getOpenFileNames(tr("Load curve(s)"),tr("Mutli-column file(*)"));
+    QStringList fileNames=Message::getOpenFileNames(tr("Load curve(s)"), tr("Mutli-column file(*)"));
     if(!fileNames.isEmpty()) {
       int curvesCount=count();
       ColumnTextParser * parser=nullptr;
@@ -474,7 +508,7 @@ namespace QGpGuiMath {
       } else {
         w=new QWidget;
         QVBoxLayout * layout=new QVBoxLayout(w);
-        layout->setMargin(0);
+        layout->setContentsMargins(0, 0, 0, 0);
         layout->addWidget(dg);
         sameParserForAll=new QCheckBox(w);
         sameParserForAll->setText(tr("Use the same parser for next files"));
@@ -503,7 +537,7 @@ namespace QGpGuiMath {
     ColumnTextIterator it(parser);
     int nCurves=0;
     while(!it.atEnd()) {
-      if(!loadMultiColumns(_currentLayer, it, fileName, nCurves)) {
+      if(!_currentLayer || !loadMultiColumns(_currentLayer, it, fileName, nCurves)) {
         return false;
       }
     }
@@ -514,7 +548,7 @@ namespace QGpGuiMath {
                                       const QString& fileName, int& nCurves)
   {
     TRACE;
-    CurveProperties * p=addLine(layer->addLine());
+    CurvePropertiesWidget * p=addLine(layer->addLine());
     p->beginCurveChange();
     CurveProxy * px=p->proxy();
     if(px->parse(it) && px->sampleCount()>0) {
@@ -531,6 +565,7 @@ namespace QGpGuiMath {
       }
       nCurves++;
       p->endCurveChange();
+      setCurveName(px->name(), p);
       curveTabs->setCurrentWidget(p);
       return true;
     } else {
@@ -551,13 +586,13 @@ namespace QGpGuiMath {
     int n=count();
     ASSERT(n==legend.count());
     for(int i=0; i<n; i++) {
-      legend.setText(i, static_cast<CurveProperties *>(curveTabs->widget(i))->proxy()->name());
+      legend.setText(i, static_cast<CurvePropertiesWidget *>(curveTabs->widget(i))->proxy()->name());
     }
 
     Dialog * d=new Dialog(this);
     ASSERT(!_legendEditor);
     _legendEditor=new LegendProperties(this);
-    _legendEditor->setPropertySections(LegendTable::All);
+    _legendEditor->setPropertySections(LegendTable::AllSections);
     d->setMainWidget(_legendEditor, Dialog::OkCancel);
     _legendEditor->setLegend(legend);
     _legendEditor->setReadOnlyText(true);
@@ -566,8 +601,9 @@ namespace QGpGuiMath {
     if(d->exec()!=QDialog::Accepted) {
       _currentLayer->setLegend(legend);
       _currentLayer->deepUpdate();
+    } else {
+      Settings::setRect(d, "CurveBrowser::legend");
     }
-    Settings::setRect(d, "CurveBrowser::legend");
     delete d;
     _legendEditor=nullptr;
   }
@@ -588,17 +624,17 @@ namespace QGpGuiMath {
     _currentLayer->deepUpdate();
   }
 
-  QList<CurveProperties *> CurveBrowser::selectCurves()
+  QList<CurvePropertiesWidget *> CurveBrowser::selectCurves()
   {
     TRACE;
-    QList<CurveProperties *> list;
-    CurveProperties * p;
+    QList<CurvePropertiesWidget *> list;
+    CurvePropertiesWidget * p;
     int n=count();
     switch(n) {
     case 0:
       return list;
     case 1:
-      p=static_cast<CurveProperties *>(curveTabs->widget(0));
+      p=static_cast<CurvePropertiesWidget *>(curveTabs->widget(0));
       if(p->proxy()->sampleCount()>0) {
         list.append(p);
       }
@@ -608,7 +644,7 @@ namespace QGpGuiMath {
     }
     CurveSelector * d=new CurveSelector(this);
     for(int i=0; i<n; i++) {
-      d->addCurve(static_cast<CurveProperties *>(curveTabs->widget(i)));
+      d->addCurve(static_cast<CurvePropertiesWidget *>(curveTabs->widget(i)));
     }
     d->selectAll();
     Settings::getWidget(d);
@@ -626,7 +662,7 @@ namespace QGpGuiMath {
   void CurveBrowser::average()
   {
     TRACE;
-    QList<CurveProperties *> list=selectCurves();
+    QList<CurvePropertiesWidget *> list=selectCurves();
     switch(list.count()) {
     case 0:
       return;
@@ -637,11 +673,11 @@ namespace QGpGuiMath {
       break;
     }
     // Create new averaged curve
-    CurveProperties * pa=addLine(_currentLayer->addLine());
+    CurvePropertiesWidget * pa=addLine(_currentLayer->addLine());
     pa->beginCurveChange();
     CurveProxy * pxa=pa->proxy();
     pxa->addLog(tr("Average of curves:\n"));
-    for(QList<CurveProperties *>::iterator it=list.begin(); it!=list.end(); it++) {
+    for(QList<CurvePropertiesWidget *>::iterator it=list.begin(); it!=list.end(); it++) {
       CurveProxy * px=(*it)->proxy();
       pxa->addLog("   "+px->name()+"\n{");
       pxa->addLog(px->log()+"}\n");
@@ -657,7 +693,7 @@ namespace QGpGuiMath {
   void CurveBrowser::validate()
   {
     TRACE;
-    QList<CurveProperties *> list=selectCurves();
+    QList<CurvePropertiesWidget *> list=selectCurves();
     if(list.isEmpty()) {
       return;
     }
@@ -665,19 +701,27 @@ namespace QGpGuiMath {
     curveRange(list, min, max);
     CurveBrowserValidate * d=new CurveBrowserValidate(this);
     d->setCurveLimits(min, max);
-    d->setAxisNames(_proxy->xName(), _proxy->xInversedName());
+    d->setAxisNames(_proxy->xName(), _proxy->xInverseName());
     Settings::getWidget(d, "CurveBrowserValidate");
     if(d->exec()==QDialog::Accepted) {
       Settings::setWidget(d, "CurveBrowserValidate");
       double minimum=d->minimumEdit->text().toDouble();
       double maximum=d->maximumEdit->text().toDouble();
       SamplingOptions options=LinearScale;
-      if(d->inversedBut->isChecked()) {
-        options|=InversedScale;
+      if(d->inverseBut->isChecked()) {
+        options|=InverseScale;
       }
-      bool value=d->validateBut->isChecked();
-      for(QList<CurveProperties *>::const_iterator it=list.begin(); it!=list.end(); it++) {
-        (*it)->validate(minimum, maximum, options, value);
+      if(d->validateInside->isChecked()) {
+        for(QList<CurvePropertiesWidget *>::const_iterator it=list.begin(); it!=list.end(); it++) {
+          (*it)->validate(-std::numeric_limits<double>::infinity(),
+                          std::numeric_limits<double>::infinity(), options, false);
+          (*it)->validate(minimum, maximum, options, true);
+        }
+      } else {
+        bool value=d->validateBut->isChecked();
+        for(QList<CurvePropertiesWidget *>::const_iterator it=list.begin(); it!=list.end(); it++) {
+          (*it)->validate(minimum, maximum, options, value);
+        }
       }
     }
     delete d;
@@ -686,7 +730,7 @@ namespace QGpGuiMath {
   void CurveBrowser::showLog()
   {
     TRACE;
-    QList<CurveProperties *> list=selectCurves();
+    QList<CurvePropertiesWidget *> list=selectCurves();
     if(list.isEmpty()) {
       return;
     }
@@ -695,7 +739,7 @@ namespace QGpGuiMath {
       Message::information(MSG_ID, tr("Curve log: %1").arg(p->name()), p->log(), Message::close());
     } else {
       QString log;
-      for(QList<CurveProperties *>::const_iterator it=list.begin(); it!=list.end(); it++) {
+      for(QList<CurvePropertiesWidget *>::const_iterator it=list.begin(); it!=list.end(); it++) {
         CurveProxy * p=(*it)->proxy();
         log+=tr("------- %1 ------- \n").arg(p->name());
         log+=p->log();
@@ -707,7 +751,7 @@ namespace QGpGuiMath {
   void CurveBrowser::save()
   {
     TRACE;
-    QList<CurveProperties *> list=selectCurves();
+    QList<CurvePropertiesWidget *> list=selectCurves();
     if(list.isEmpty()) {
       return;
     }
@@ -720,17 +764,17 @@ namespace QGpGuiMath {
         return;
       }
       QTextStream s(&f);
-      for(QList<CurveProperties *>::const_iterator it=list.begin(); it!=list.end(); it++) {
+      for(QList<CurvePropertiesWidget *>::const_iterator it=list.begin(); it!=list.end(); it++) {
         (*it)->proxy()->save(s);
       }
     }
   }
 
-  void CurveBrowser::curveRange(const QList<CurveProperties *>& list, double& min, double& max)
+  void CurveBrowser::curveRange(const QList<CurvePropertiesWidget *>& list, double& min, double& max)
   {
     TRACE;
     double v;
-    for(QList<CurveProperties *>::const_iterator it=list.begin(); it!=list.end(); it++) {
+    for(QList<CurvePropertiesWidget *>::const_iterator it=list.begin(); it!=list.end(); it++) {
       CurveProxy * p=(*it)->proxy();
       p->sort();
       v=p->minimumX();
@@ -750,7 +794,7 @@ namespace QGpGuiMath {
   void CurveBrowser::resample()
   {
     TRACE;
-    QList<CurveProperties *> list=selectCurves();
+    QList<CurvePropertiesWidget *> list=selectCurves();
     if(list.isEmpty()) {
       return;
     }
@@ -758,7 +802,7 @@ namespace QGpGuiMath {
     curveRange(list, min, max);
     CurveBrowserResample * d=new CurveBrowserResample(this);
     d->setCurveLimits(min, max);
-    d->setAxisNames(_proxy->xName(), _proxy->xInversedName());
+    d->setAxisNames(_proxy->xName(), _proxy->xInverseName());
     Settings::getWidget(d, "CurveBrowserResample");
     if(d->exec()==QDialog::Accepted) {
       Settings::setWidget(d, "CurveBrowserResample");
@@ -768,10 +812,10 @@ namespace QGpGuiMath {
       SamplingOptions options=LinearScale;
       if(d->logBut->isChecked()) {
         options|=LogScale;
-      } else if(d->inversedBut->isChecked()) {
-        options|=InversedScale;
+      } else if(d->inverseBut->isChecked()) {
+        options|=InverseScale;
       }
-      for(QList<CurveProperties *>::const_iterator it=list.begin(); it!=list.end(); it++) {
+      for(QList<CurvePropertiesWidget *>::const_iterator it=list.begin(); it!=list.end(); it++) {
         (*it)->resample(n, minimum, maximum, options, d->dsBut->isChecked());
       }
     }
@@ -784,7 +828,7 @@ namespace QGpGuiMath {
   void CurveBrowser::cut()
   {
     TRACE;
-    QList<CurveProperties *> list=selectCurves();
+    QList<CurvePropertiesWidget *> list=selectCurves();
     if(list.isEmpty()) {
       return;
     }
@@ -792,17 +836,17 @@ namespace QGpGuiMath {
     curveRange(list, min, max);
     CurveBrowserCut * d=new CurveBrowserCut(this);
     d->setCurveLimits(min, max);
-    d->setAxisNames(_proxy->xName(), _proxy->xInversedName());
+    d->setAxisNames(_proxy->xName(), _proxy->xInverseName());
     Settings::getWidget(d, "CurveBrowserCut" );
     if(d->exec()==QDialog::Accepted) {
       Settings::setWidget(d, "CurveBrowserCut" );
       double minimum=d->minimumEdit->text().toDouble();
       double maximum=d->maximumEdit->text().toDouble();
       SamplingOptions options=LinearScale;
-      if(d->inversedBut->isChecked()) {
-        options|=InversedScale;
+      if(d->inverseBut->isChecked()) {
+        options|=InverseScale;
       }
-      for(QList<CurveProperties *>::const_iterator it=list.begin(); it!=list.end(); it++) {
+      for(QList<CurvePropertiesWidget *>::const_iterator it=list.begin(); it!=list.end(); it++) {
         (*it)->cut(minimum, maximum, options);
       }
     }
@@ -815,7 +859,7 @@ namespace QGpGuiMath {
   void CurveBrowser::smooth()
   {
     TRACE;
-    QList<CurveProperties *> list=selectCurves();
+    QList<CurvePropertiesWidget *> list=selectCurves();
     if(list.isEmpty()) {
       return;
     }
@@ -823,7 +867,7 @@ namespace QGpGuiMath {
     curveRange(list, min, max);
     CurveBrowserSmooth * d=new CurveBrowserSmooth(this);
     d->setCurveLimits(min, max);
-    d->setAxisNames(_proxy->xName(), _proxy->xInversedName());
+    d->setAxisNames(_proxy->xName(), _proxy->xInverseName());
     Settings::getWidget(d, "CurveBrowserSmooth");
     d->updateAllFields();
     if(d->exec()==QDialog::Accepted) {
@@ -834,13 +878,13 @@ namespace QGpGuiMath {
       sampling.setRange(d->minimumEdit->text().toDouble(), d->maximumEdit->text().toDouble());
       if(d->logBut->isChecked()) {
         sampling.setScaleType(SamplingParameters::Log);
-      } else if(d->inversedBut->isChecked()) {
-        sampling.setScaleType(SamplingParameters::Inversed);
+      } else if(d->inverseBut->isChecked()) {
+        sampling.setScaleType(SamplingParameters::Inverse);
       } else {
         sampling.setScaleType(SamplingParameters::Linear);
       }
-      for(QList<CurveProperties *>::const_iterator it=list.begin(); it!=list.end(); it++) {
-        CurveProperties * curve=*it;
+      for(QList<CurvePropertiesWidget *>::const_iterator it=list.begin(); it!=list.end(); it++) {
+        CurvePropertiesWidget * curve=*it;
         sampling.setCount(curve->proxy()->sampleCount());
         curve->smooth(sampling, param);
       }
@@ -854,7 +898,7 @@ namespace QGpGuiMath {
   void CurveBrowser::split()
   {
     TRACE;
-    QList<CurveProperties *> list=selectCurves();
+    QList<CurvePropertiesWidget *> list=selectCurves();
     if(list.isEmpty()) {
       return;
     }
@@ -866,12 +910,12 @@ namespace QGpGuiMath {
       double maxErr=d->maxErr->value();
       int minCount=d->minCount->value();
       // Create new split curves
-      for(QList<CurveProperties *>::const_iterator it=list.begin(); it!=list.end(); it++) {
+      for(QList<CurvePropertiesWidget *>::const_iterator it=list.begin(); it!=list.end(); it++) {
         CurveProxy * px=(*it)->proxy();
         px->beginSplit(maxX, LogScale, maxErr, minCount);
         int n=px->splitCount();
         for(int i=0; i<n; i++) {
-          CurveProperties * pa=addLine(_currentLayer->addLine());
+          CurvePropertiesWidget * pa=addLine(_currentLayer->addLine());
           CurveProxy * pxa=pa->proxy();
           pa->beginCurveChange();
           pxa->addLog(tr("split of curve %1\n").arg((*it)->proxy()->name()));
@@ -890,26 +934,43 @@ namespace QGpGuiMath {
   void CurveBrowser::remove()
   {
     TRACE;
-    QList<CurveProperties *> list=selectCurves();
+    QList<CurvePropertiesWidget *> list=selectCurves();
     if(list.isEmpty()) {
       return;
     }
-    for(QList<CurveProperties *>::const_iterator it=list.begin(); it!=list.end(); it++) {
+    for(QList<CurvePropertiesWidget *>::const_iterator it=list.begin(); it!=list.end(); it++) {
       removeLine(curveTabs->indexOf(*it));
     }
     emit curveModified();
   }
 
+  /*!
+    Remove \a line from \a layer safely, if \a layer is possibly managed by the curve browser
+  */
+  void CurveBrowser::remove(LineLayer * layer, AbstractLine * line)
+  {
+    if(_currentLayer==layer) {
+      CurvePropertiesWidget * p=properties(line);
+      if(p) {
+        removeLine(curveTabs->indexOf(p));
+      }
+      emit curveModified();
+    } else if(layer) {
+      layer->removeLine(line);
+    }
+
+  }
+
   void CurveBrowser::showCurves()
   {
     TRACE;
-    QList<CurveProperties *> list=selectCurves();
+    QList<CurvePropertiesWidget *> list=selectCurves();
     if(list.isEmpty()) {
       return;
     }
-    for(QList<CurveProperties *>::const_iterator it=list.begin(); it!=list.end(); it++) {
+    for(QList<CurvePropertiesWidget *>::const_iterator it=list.begin(); it!=list.end(); it++) {
       int index=curveTabs->indexOf(*it);
-      CurveProperties * p=static_cast<CurveProperties *>(curveTabs->widget(index));
+      CurvePropertiesWidget * p=static_cast<CurvePropertiesWidget *>(curveTabs->widget(index));
       p->setCurveVisible(true);
     }
     emit curveModified();
@@ -918,13 +979,13 @@ namespace QGpGuiMath {
   void CurveBrowser::hideCurves()
   {
     TRACE;
-    QList<CurveProperties *> list=selectCurves();
+    QList<CurvePropertiesWidget *> list=selectCurves();
     if(list.isEmpty()) {
       return;
     }
-    for(QList<CurveProperties *>::const_iterator it=list.begin(); it!=list.end(); it++) {
+    for(QList<CurvePropertiesWidget *>::const_iterator it=list.begin(); it!=list.end(); it++) {
       int index=curveTabs->indexOf(*it);
-      CurveProperties * p=static_cast<CurveProperties *>(curveTabs->widget(index));
+      CurvePropertiesWidget * p=static_cast<CurvePropertiesWidget *>(curveTabs->widget(index));
       p->setCurveVisible(false);
     }
     emit curveModified();
@@ -933,7 +994,7 @@ namespace QGpGuiMath {
   void CurveBrowser::on_curveTabs_tabCloseRequested(int index)
   {
     TRACE;
-    QString curveName=static_cast<CurveProperties *>(curveTabs->widget(index))->proxy()->name();
+    QString curveName=static_cast<CurvePropertiesWidget *>(curveTabs->widget(index))->proxy()->name();
     if(Message::question(MSG_ID, tr("Removing curve %1").arg(curveName), tr("Are you sure?"),
                          Message::yes(), Message::no())==Message::Answer0) {
       removeLine(index);
@@ -950,16 +1011,66 @@ namespace QGpGuiMath {
     }
   }
 
-  void CurveBrowser::setCurveName(QString n)
+  void CurveBrowser::setCurveName(QString name, CurvePropertiesWidget * p)
   {
     TRACE;
-    CurveProperties * p=qobject_cast<CurveProperties *>(sender());
+    if(!p) {
+      p=qobject_cast<CurvePropertiesWidget *>(sender());
+    }
     if(p) {
       int i=curveTabs->indexOf(p);
-      if(n.isEmpty()) {
-        n="# "+QString::number(i+1);
+      if(name.isEmpty()) {
+        name="# "+QString::number(i+1);
+      } else if(name.contains("%1")) {
+        int p=name.indexOf("%1");
+        QString pattern=name.left(p);
+        int index=0;
+        for(int i=curveTabs->count()-1; i>=0; i--) {
+          const QString& cn=static_cast<CurvePropertiesWidget *>(curveTabs->widget(i))->proxy()->name();
+          if(cn.startsWith(pattern)) {
+            index++;
+          }
+        }
+        name=name.arg(index);
       }
-      curveTabs->setTabText(i, n);
+      p->setCurveName(name);
+      curveTabs->setTabText(i, name);
+    }
+  }
+
+  void CurveBrowser::setCurveName(LineLayer * layer, AbstractLine * line, const QString& name,
+                                  CurveProxy * proxy, CurvePlotProxy * plotProxy)
+  {
+    if(line) {
+      if(layer==_currentLayer) {
+        CurvePropertiesWidget * p=properties(line);
+        if(p) {
+          setCurveName(name, p);
+        }
+      } else {
+        plotProxy->setCurve(line, proxy);
+        proxy->setName(name);
+      }
+    }
+    delete proxy;
+    delete plotProxy;
+  }
+
+  void CurveBrowser::beginCurveChange(AbstractLine * line)
+  {
+    TRACE;
+    CurvePropertiesWidget * cp=properties(line);
+    if(cp) {
+      cp->beginCurveChange();
+    }
+  }
+
+  void CurveBrowser::endCurveChange(AbstractLine * line)
+  {
+    TRACE;
+    CurvePropertiesWidget * cp=properties(line);
+    if(cp) {
+      cp->endCurveChange();
     }
   }
 
