@@ -37,7 +37,7 @@
 
 namespace QGpGuiMath {
 
-  class CurveProperties;
+  class CurvePropertiesWidget;
   class CurvePlotProxy;
 
   class QGPGUIMATH_EXPORT CurveBrowser : public QWidget, protected Ui::CurveBrowser
@@ -53,9 +53,10 @@ namespace QGpGuiMath {
     void setPlotProxy(CurvePlotProxy * proxy);
     CurvePlotProxy * plotProxy() {return _plotProxy;}
 
-    CurveProperties * find(const QString& name) const;
-    CurveProperties * properties(AbstractLine * line) const;
-    QList<CurveProperties *> curves() const;
+    CurvePropertiesWidget * find(const QString& name) const;
+    CurvePropertiesWidget * properties(AbstractLine * line) const;
+    CurvePropertiesWidget * curveAt(int index) const;
+    QList<CurvePropertiesWidget *> curves() const;
     void dock(QWidget * w);
 
     QAction * addCurveAction(QString title, QString toolTip, bool editCurve);
@@ -64,7 +65,15 @@ namespace QGpGuiMath {
     void initLayer(LineLayer * curveLayer);
     void setCurrentLayer(LineLayer * curveLayer);
     LineLayer * currentLayer() const {return _currentLayer;}
-    CurveProperties * addLine(AbstractLine * line);
+    CurvePropertiesWidget * addLine(AbstractLine * line);
+    CurvePropertiesWidget * addLine(AbstractLine * line, LineLayer * layer);
+
+    void beginCurveChange(AbstractLine * line);
+    void endCurveChange(AbstractLine * line);
+
+    void remove(LineLayer * layer, AbstractLine * line);
+    void setCurveName(LineLayer * layer, AbstractLine * line, const QString& name,
+                      CurveProxy * proxy, CurvePlotProxy * plotProxy);
 
     int count() const;
     int currentLine() const;
@@ -78,7 +87,7 @@ namespace QGpGuiMath {
     void average();
     void validate();
     virtual void setLimits();
-    void setCurveName(QString n);
+    void setCurveName(QString name, CurvePropertiesWidget * p=nullptr);
     void showLog();
     void save();
     void remove();
@@ -102,9 +111,9 @@ namespace QGpGuiMath {
   protected:
     bool loadMultiColumns(LineLayer * layer, ColumnTextIterator& it,
                           const QString& fileName, int& nCurves);
-    virtual CurveProperties * createProperties();
-    static void curveRange(const QList<CurveProperties *> &list, double& min, double& max);
-    QList<CurveProperties *> selectCurves();
+    virtual CurvePropertiesWidget * createProperties();
+    static void curveRange(const QList<CurvePropertiesWidget *> &list, double& min, double& max);
+    QList<CurvePropertiesWidget *> selectCurves();
     void closeEvent(QCloseEvent * e);
     void takeLine(int index);
     void removeLine(int index);
