@@ -46,11 +46,11 @@ CurveBrowserSmooth::CurveBrowserSmooth(QWidget * parent)
   setupUi(this);
 }
 
-void CurveBrowserSmooth::setAxisNames(QString linearName, QString inversedName)
+void CurveBrowserSmooth::setAxisNames(QString linearName, QString inverseName)
 {
   TRACE;
   linearBut->setText(linearName);
-  inversedBut->setText(inversedName);
+  inverseBut->setText(inverseName);
 }
 
 void CurveBrowserSmooth::updateAllFields()
@@ -58,7 +58,7 @@ void CurveBrowserSmooth::updateAllFields()
   smoothing->updateAllFields();
 }
 
-void CurveBrowserSmooth::on_inversedBut_toggled(bool)
+void CurveBrowserSmooth::on_inverseBut_toggled(bool)
 {
   TRACE;
   double min=minimumEdit->text().toDouble();
