@@ -62,8 +62,21 @@ namespace QGpGuiMath {
   void SamplingParameterWidget::updateAllFields()
   {
     TRACE;
+    // Set scale of param without changing step/count value
+    switch(scaleTypeEdit->currentIndex()) {
+    case 0:
+      _param.setScaleType(SamplingParameters::Log, true);
+      break;
+    case 1:
+      _param.setScaleType(SamplingParameters::Linear, true);
+      break;
+    case 2:
+      _param.setScaleType(SamplingParameters::Inverse, true);
+      break;
+    }
     _param.setRange(fromValue->value(), toValue->value());
     on_stepCountValue_valueChanged(stepCountValue->value());
+    // Set again the scale type to adjust admissible ranges
     on_scaleTypeEdit_currentIndexChanged(scaleTypeEdit->currentIndex());
   }
 
@@ -148,7 +161,7 @@ namespace QGpGuiMath {
       if(toValue->minimum()<=0.0) {
         toValue->setMinimum(pow(10, -fromValue->decimals()));
       }
-      _param.setScaleType(SamplingParameters::Inversed, true);
+      _param.setScaleType(SamplingParameters::Inverse, true);
       break;
     }
     on_stepCountOption_currentIndexChanged(stepCountOption->currentIndex());
@@ -162,7 +175,7 @@ namespace QGpGuiMath {
       double minStep, delta;
       int ndec;
       switch(scaleTypeEdit->currentIndex()) {
-      case 0:
+      default:
         delta=_param.maximum()/_param.minimum();
         minStep=::pow(delta, 1.0/static_cast<double>(10000-1));
         ndec=1-qFloor(::log10(minStep-1.0));
@@ -220,7 +233,7 @@ namespace QGpGuiMath {
       case SamplingParameters::Linear:
         scaleTypeEdit->setCurrentIndex(1);
         break;
-      case SamplingParameters::Inversed:
+      case SamplingParameters::Inverse:
         scaleTypeEdit->setCurrentIndex(2);
         break;
       }
