@@ -43,30 +43,49 @@ DoubleSpinBox::DoubleSpinBox(QWidget * parent)
     : QDoubleSpinBox(parent)
 {
   TRACE;
-  switch(rand()%3) {
-  default:
-    setToolTip(tr("Need more precision? Press ALT while rolling wheel button."));
+  switch(rand()%6) {
+  default: // More chance to get this one
+    setToolTip(tr("Need more precision? Press SHIFT while rolling wheel button."));
     break;
   case 1:
-    setToolTip(tr("Need a smaller step? Press SHIFT while rolling wheel button."));
+    setToolTip(tr("Need a smaller step? Press ALT while rolling wheel button."));
     break;
   case 2:
     setToolTip(tr("Need a temporary bigger step? Press CTRL while rolling wheel button."));
     break;
   }
+  _originalValue=0.0;
 }
 
 /*!
-  Return the current value. If \a expectedValue is within the current precision of current value,
-  the expected value is returned rather than the rounded current value.
+  Keeps track of the original value:
+  \li if untouched, return the full precision value
+  \li when increasing precision, do not loose the original digits
 */
-double DoubleSpinBox::value(double expectedValue) const
+void DoubleSpinBox::setValue(double val)
 {
-  // getting precision
-  if(fabs((value()-expectedValue)*pow(10.0, decimals()))>1.0) {
-    return value();
+  _originalValue=val;
+  QDoubleSpinBox::setValue(val);
+}
+
+/*!
+  Returns true if the current value is the same as the original one, taking
+  the display precision into account.
+*/
+bool DoubleSpinBox::touched() const
+{
+  return fabs((QDoubleSpinBox::value()-_originalValue)*pow(10.0, decimals()))>=1.0;
+}
+
+/*!
+  Return the current value with its full precision if it is untouched
+*/
+double DoubleSpinBox::value() const
+{
+  if(touched()) {
+    return QDoubleSpinBox::value();
   } else {
-    return expectedValue;
+    return _originalValue;
   }
 }
 
@@ -76,8 +95,8 @@ double DoubleSpinBox::value(double expectedValue) const
 void DoubleSpinBox::wheelEvent(QWheelEvent *event)
 {
   TRACE;
-  if(event->modifiers() & Qt::ShiftModifier) {
-    if(event->angleDelta().y()>0) {
+  if(event->modifiers() & Qt::AltModifier) {
+    if(event->angleDelta().x()>0) {  // Noticed that x is required when ALT is pressed
       setSingleStep(singleStep()*10.0);
     } else {
       if(singleStep()>=pow(0.1,decimals()-1)) {
@@ -86,10 +105,15 @@ void DoubleSpinBox::wheelEvent(QWheelEvent *event)
     }
     showToolTip(tr("Step=%1").arg(singleStep()));
     event->accept();
-  } else if(event->modifiers() & Qt::AltModifier) {
-    if(event->angleDelta().x()>0) {  // Noticed that x is required when ALT is pressed
-      setDecimals(decimals()+1);
+  } else if(event->modifiers() & Qt::ShiftModifier) {
+    if(event->angleDelta().y()>0) {
+      int n=decimals();
+      double f=pow(10.0, n);
+      double d=QDoubleSpinBox::value()-round(_originalValue*f)/f;
+      setDecimals(n+1);
+      QDoubleSpinBox::setValue(_originalValue+d);
     } else {
+      // Rounding is handled by QDoubleSpinBox
       setDecimals(decimals()-1);
     }
     showToolTip(tr("Decimals=%1").arg(decimals()));
