@@ -46,7 +46,7 @@ DispersionLimitLayer::DispersionLimitLayer(AxisWindow * parent)
 {
   TRACE;
   PlotLine * l=new PlotLine;
-  l->setPen(Pen(Qt::black, 0.3, Qt::SolidLine));
+  l->setPen(Pen(Qt::black, 0.3, Pen::SolidLine));
   l->setSymbol(Symbol());
   setReferenceLine(l);
 }
@@ -77,13 +77,15 @@ void DispersionLimitLayer::setFrequencySampling(const SamplingParameters& fparam
 void DispersionLimitLayer::updateFrequencySampling()
 {
   TRACE;
-  Point fcurve;
-  for(int ic=count()-1; ic>=0; ic--) {
-    Curve<Point>& c=curve(ic);
-    c.clear();
-    for(int i=0; i<_freqSamp.count(); i++) {
-      fcurve.setX(_freqSamp.value(i));
-      c.append(fcurve);
+  if(_freqSamp.isValid()) {
+    Point fcurve;
+    for(int ic=count()-1; ic>=0; ic--) {
+      Curve<Point>& c=curve(ic);
+      c.clear();
+      for(int i=0; i<_freqSamp.count(); i++) {
+        fcurve.setX(_freqSamp.value(i));
+        c.append(fcurve);
+      }
     }
   }
 }
@@ -115,9 +117,9 @@ void DispersionLimitLayer::addArrayLimits()
 {
   TRACE;
   addLine();
-  addLine(Pen(Qt::black, 0.3, Qt::DotLine), Symbol());
-  addLine(Pen(Qt::black, 0.3, Qt::DotLine), Symbol());
-  addLine(Pen(Qt::black, 0.3, Qt::DashLine), Symbol());
+  addLine(Pen(Qt::black, 0.3, Pen::DotLine), Symbol());
+  addLine(Pen(Qt::black, 0.3, Pen::DotLine), Symbol());
+  addLine(Pen(Qt::black, 0.3, Pen::DashLine), Symbol());
 }
 
 void DispersionLimitLayer::setArrayKmin(double k)
