@@ -37,11 +37,11 @@ namespace QGpGuiWave {
   void DispersionPlotProxy::setYAxisProperties(Axis * a)
   {
     TRACE;
-    a->setScaleType(Scale::InversedLog);
+    a->setScaleType(Scale::InverseLog);
     a->setAutoTicks(false);
     a->setMajorTicks(1.0);
     a->setMinorTicks(0.2);
-    a->setRange(0.001, 0.01); // in slowness
+    a->setRange(1.0/3500.0, 1.0/50.0); // in slowness
   }
 
 } // namespace QGpGuiWave
