@@ -34,7 +34,7 @@ namespace QGpGuiWave {
   class QGPGUIWAVE_EXPORT DispersionPlotProxy : public ModalPlotProxy
   {
   public:
-    virtual void setYAxisProperties(Axis * a);
+    void setYAxisProperties(Axis * a);
   };
 
 } // namespace QGpGuiWave
