@@ -29,16 +29,31 @@ namespace QGpGuiWave {
 
   const QString MagnetoTelluricLine::xmlMagnetoTelluricLineTag="Line";
 
-  AbstractLine * MagnetoTelluricLine::clone() const
+  MagnetoTelluricLine::MagnetoTelluricLine(const MagnetoTelluricLine& o)
+    : AbstractLine(o)
   {
-    MagnetoTelluricLine * l=new MagnetoTelluricLine;
-    *l=*this;
-    return l;
+    TRACE;
+    _curve=o._curve;
   }
 
-  void MagnetoTelluricLine::operator=(const MagnetoTelluricLine& o)
+  AbstractLine * MagnetoTelluricLine::clone() const
   {
-    _curve=o._curve;
+    TRACE;
+    return new MagnetoTelluricLine(*this);
+  }
+
+  bool MagnetoTelluricLine::canCopy(const AbstractLine& o) const
+  {
+    TRACE;
+    return dynamic_cast<const MagnetoTelluricLine *>(&o);
+  }
+
+  void MagnetoTelluricLine::operator=(const AbstractLine& o)
+  {
+    TRACE;
+    const MagnetoTelluricLine * co=static_cast<const MagnetoTelluricLine *>(&o);
+    ASSERT(co);
+    _curve=co->_curve;
     AbstractLine::operator=(o);
   }
 
