@@ -36,28 +36,32 @@ namespace QGpGuiWave {
 class QGPGUIWAVE_EXPORT MagnetoTelluricLine : public AbstractLine
 {
 public:
-  virtual AbstractLine * clone() const;
-  virtual void operator=(const MagnetoTelluricLine& o);
+  MagnetoTelluricLine() {}
+  MagnetoTelluricLine(const MagnetoTelluricLine& o);
 
-  virtual const QString& xml_tagName() const {return xmlMagnetoTelluricLineTag;}
+  AbstractLine * clone() const;
+  void operator=(const AbstractLine& o);
+  bool canCopy(const AbstractLine& o) const;
+
+  const QString& xml_tagName() const {return xmlMagnetoTelluricLineTag;}
   static const QString xmlMagnetoTelluricLineTag;
 
-  virtual int count() const {return _curve.count();}
-  virtual void clear() {_curve.clear();}
-  virtual void append() {_curve.append(MagnetoTelluricPoint());}
-  virtual void insert(int index) {_curve.insert(index, MagnetoTelluricPoint());}
-  virtual void removeLast() {_curve.remove(_curve.count()-1);}
-  virtual bool isValid(int index) const {return _curve.isValid(index);}
-  virtual void setValid(int index, bool v) {_curve.setValid(index, v);}
-  virtual bool isSorted() const {return _curve.isSorted();}
-  virtual void checkSort() {_curve.checkSort();}
-  virtual void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
+  int count() const {return _curve.count();}
+  void clear() {_curve.clear();}
+  void append() {_curve.append(MagnetoTelluricPoint());}
+  void insert(int index) {_curve.insert(index, MagnetoTelluricPoint());}
+  void removeLast() {_curve.remove(_curve.count()-1);}
+  bool isValid(int index) const {return _curve.isValid(index);}
+  void setValid(int index, bool v) {_curve.setValid(index, v);}
+  bool isSorted() const {return _curve.isSorted();}
+  void checkSort() {_curve.checkSort();}
+  void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
     _curve.indexRange(xMin, xMax, indexMin, indexMax);
   }
-  virtual Point point(int index, const CurvePointOptions *) const;
-  virtual void setX(int index, double v) {_curve.setX(index, v);}
-  virtual void setY(int index, double v, const CurvePointOptions *);
-  virtual void setZ(int index, double v, const CurvePointOptions *) {_curve.constXAt(index).setStddev(v);}
+  Point point(int index, const CurvePointOptions *) const;
+  void setX(int index, double v) {_curve.setX(index, v);}
+  void setY(int index, double v, const CurvePointOptions *);
+  void setZ(int index, double v, const CurvePointOptions *) {_curve.constXAt(index).setStddev(v);}
 
   const MagnetoTelluricCurve& curve() const {return _curve;}
   MagnetoTelluricCurve& curve() {return _curve;}
