@@ -37,18 +37,31 @@ namespace QGpGuiWave {
 
 const QString ModalLine::xmlModalLineTag="RealStatisticalLine";
 
-AbstractLine * ModalLine::clone() const
-{
-  TRACE;
-  ModalLine * l=new ModalLine;
-  *l=*this;
-  return l;
-}
-
-void ModalLine::operator=(const ModalLine& o)
+ModalLine::ModalLine(const ModalLine& o)
+  : AbstractLine(o)
 {
   TRACE;
   _curve=o._curve;
+}
+
+AbstractLine * ModalLine::clone() const
+{
+  TRACE;
+  return new ModalLine(*this);
+}
+
+bool ModalLine::canCopy(const AbstractLine& o) const
+{
+  TRACE;
+  return dynamic_cast<const ModalLine *>(&o);
+}
+
+void ModalLine::operator=(const AbstractLine& o)
+{
+  TRACE;
+  const ModalLine * co=static_cast<const ModalLine *>(&o);
+  ASSERT(co);
+  _curve=co->_curve;
   AbstractLine::operator=(o);
 }
 
