@@ -30,36 +30,51 @@
 namespace QGpGuiWave {
 
 /*!
-  \class RefractionLine RefractionLine.h
-  \brief Brief description of class still missing
+    \class RefractionLine RefractionLine.h
+    \brief Brief description of class still missing
 
-  Full description of class still missing
-*/
+    Full description of class still missing
+  */
 
-const QString RefractionLine::xmlRefractionLineTag="RefractionLine";
+  const QString RefractionLine::xmlRefractionLineTag="RefractionLine";
 
-void RefractionLine::operator=(const RefractionLine& o)
-{
-  _curve=o._curve;
-  AbstractLine::operator=(o);
-}
+  RefractionLine::RefractionLine(const RefractionLine& o)
+    : AbstractLine(o)
+  {
+    TRACE;
+    _curve=o._curve;
+  }
 
-Point RefractionLine::point(int index, const CurvePointOptions *) const
-{
-  TRACE;
-  Point p;
-  const RealStatisticalPoint& dp=_curve.constAt(index);
-  p.setX(dp.x());
-  p.setY(dp.mean());
-  p.setZ(dp.stddev());
-  return p;
-}
+  AbstractLine * RefractionLine::clone() const
+  {
+    TRACE;
+    return new RefractionLine(*this);
+  }
 
-AbstractLine * RefractionLine::clone() const
-{
-  RefractionLine * l=new RefractionLine;
-  *l=*this;
-  return l;
-}
+  bool RefractionLine::canCopy(const AbstractLine& o) const
+  {
+    TRACE;
+    return dynamic_cast<const RefractionLine *>(&o);
+  }
+
+  void RefractionLine::operator=(const AbstractLine& o)
+  {
+    TRACE;
+    const RefractionLine * co=dynamic_cast<const RefractionLine *>(&o);
+    ASSERT(co);
+    _curve=co->_curve;
+    AbstractLine::operator=(o);
+  }
+
+  Point RefractionLine::point(int index, const CurvePointOptions *) const
+  {
+    TRACE;
+    Point p;
+    const RealStatisticalPoint& dp=_curve.constAt(index);
+    p.setX(dp.x());
+    p.setY(dp.mean());
+    p.setZ(dp.stddev());
+    return p;
+  }
 
 } // namespace QGpGuiWave
