@@ -36,10 +36,10 @@ namespace QGpGuiWave {
 class QGPGUIWAVE_EXPORT RefractionPlotProxy : public CurvePlotProxy
 {
 public:
-  virtual void setXAxisProperties(Axis * a);
-  virtual void setYAxisProperties(Axis * a);
+  void setXAxisProperties(Axis * a);
+  void setYAxisProperties(Axis * a);
 
-  virtual void setCurve(AbstractLine * line, CurveProxy * proxy);
+  void setCurve(AbstractLine * line, CurveProxy * proxy) const;
 };
 
 } // namespace QGpGuiWave
