@@ -38,11 +38,28 @@ namespace SciFigs {
 
 const QString AbstractLine::xmlAbstractLineTag="Line";
 
+AbstractLine::AbstractLine(const AbstractLine& o)
+{
+  TRACE;
+  _pen=o._pen;
+  _symbol=o._symbol;
+  _selected=o._selected;
+  _visible=o._visible;
+  _editable=o._editable;
+}
+
+bool AbstractLine::canCopy(const AbstractLine&) const
+{
+  TRACE;
+  return false;
+}
+
 /*!
   If overloaded you must call this function in your implementation.
 */
 void AbstractLine::operator=(const AbstractLine& o)
 {
+  TRACE;
   _pen=o._pen;
   _symbol=o._symbol;
   _selected=o._selected;
@@ -52,32 +69,30 @@ void AbstractLine::operator=(const AbstractLine& o)
 
 bool AbstractLine::fromString(int index, const StringSection& str, const QChar *& ptr, const CurvePointOptions * options)
 {
+  TRACE;
   bool ok=true;
   StringSection f;
   f=str.nextField(ptr);
   if(f.isValid()) {
-    setX(index, f.toDouble(&ok));
-    if(!ok) return false;
+    setX(index, f.toDouble(ok));
   } else {
     return false;
   }
   f=str.nextField(ptr);
   if(f.isValid()) {
-    setY(index, f.toDouble(&ok), options);
-    if(!ok) return false;
+    setY(index, f.toDouble(ok), options);
   } else {
     return false;
   }
   const QChar * oldPtr=ptr;
   f=str.nextField(ptr);
   if(f.isValid()) {
-    setZ(index, f.toDouble(&ok), options);
-    if(!ok) return false;
+    setZ(index, f.toDouble(ok), options);
   } else { // Z is optional
     setZ(index, 0.0, options);
     ptr=oldPtr;
   }
-  return true;
+  return ok;
 }
 
 /*!
@@ -104,7 +119,7 @@ void AbstractLine::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
     }
     tmp+=s.indent();
     tmp+="</points>";
-    s << tmp << endl;
+    s << tmp << Qt::endl;
   }
   if(scifigsContext->makeUp()) {
     writeProperty(s, "selected", isSelected());
@@ -120,8 +135,8 @@ void AbstractLine::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
   TRACE;
   XMLSciFigs * scifigsContext=static_cast<LineLayerContext *>(context)->parent();
   if(scifigsContext->makeUp()) {
-    _pen.xml_save(s, context);
-    _symbol.xml_save(s, context);
+    _pen.xml_save(s, scifigsContext);
+    _symbol.xml_save(s, scifigsContext);
   }
 }
 
@@ -139,8 +154,8 @@ XMLMember AbstractLine::xml_member(XML_MEMBER_ARGS)
     if(tag=="selected") return XMLMember(1);
     else if(tag=="visible") return XMLMember(2);
     else if(tag=="editable") return XMLMember(3);
-    else if(tag=="Pen") return XMLMember(&_pen);
-    else if(tag=="Symbol") return XMLMember(&_symbol);
+    else if(tag=="Pen") return XMLMember(&_pen, false, scifigsContext);
+    else if(tag=="Symbol") return XMLMember(&_symbol, false, scifigsContext);
   }
   return XMLMember(XMLMember::Unknown);
 }
@@ -152,6 +167,7 @@ bool AbstractLine::xml_setProperty(XML_SETPROPERTY_ARGS)
   TRACE;
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
+  bool ok=true;
   LineLayerContext * lineContext=static_cast<LineLayerContext *>(context);
   switch(memberID) {
   case 0: {
@@ -160,23 +176,28 @@ bool AbstractLine::xml_setProperty(XML_SETPROPERTY_ARGS)
       int i=0;
       while(true) {
         append();
-        if(!content.nextLine(ptr)) break;
-        if(!fromString(i, content, ptr, lineContext->options())) break;
+        if(!content.nextLine(ptr)) {
+          break;
+        }
+        if(!fromString(i, content, ptr, lineContext->options())) {
+          ok=false;
+          break;
+        }
         i++;
       }
       removeLast();
       checkSort();
     }
-    return true;
+    return ok;
   case 1:
-    _selected=content.toBool();
-    return true;
+    _selected=content.toBool(ok);
+    return ok;
   case 2:
-    _visible=content.toBool();
-    return true;
+    _visible=content.toBool(ok);
+    return ok;
   case 3:
-    _editable=content.toBool();
-    return true;
+    _editable=content.toBool(ok);
+    return ok;
   default:
     return false;
   }
