@@ -42,15 +42,15 @@ namespace SciFigs {
 
   The main properties are the minimum (minVal()) and maximum (maxVal()) values
   corresponding the end-points of the axis (expressed in real units).
-  The axis support normal, log and inversed scales (scaleType()).
+  The axis support normal, log and inverse scales (scaleType()).
   The direction of the axis may be reversed (reversedScale()).
-  position() manage the position of the axis relative to the GraphContent
+  position() manage the position of the axis relative to the GraphContents
   (left or right, and top or bottom).
 
   label() and tick() returns the interval for plotting the labels and the
   secondary ticks, respectively.
 
-  numtype(), numprec(), numberPrecisionInversedScale(), title(), titleInversedScale(),
+  numtype(), numprec(), numberPrecisionInverseScale(), title(), titleInverseScale(),
   and font() define the aspect of the axis title and of the labels.
   The labels may be defined by a list of names contained managed by stringLabels(),
   addStringLabel(), removeStringLabels(). In this case,
@@ -110,7 +110,7 @@ namespace SciFigs {
   */
 
   /*!
-    \fn QVector<QString> * Axis::stringLabels() const
+    \fn VectorList<QString> * Axis::stringLabels() const
     Return the pointer to the current list of names for labels (null if no names
     are used).
 
@@ -213,19 +213,19 @@ namespace SciFigs {
   */
 
   /*!
-    \fn void Axis::setTitleInversedScale(QString s)
+    \fn void Axis::setTitleInverseScale(QString s)
   */
 
   /*!
-    \fn QString Axis::titleInversedScale() const
+    \fn QString Axis::titleInverseScale() const
   */
 
   /*!
-    \fn void Axis::setNumberPrecisionInversedScale(int np)
+    \fn void Axis::setNumberPrecisionInverseScale(int np)
   */
 
   /*!
-    \fn int Axis::numberPrecisionInversedScale() const
+    \fn int Axis::numberPrecisionInverseScale() const
 
   */
 
@@ -306,7 +306,7 @@ namespace SciFigs {
     _numberPrecision=0;
     _unitFactor=1.0;
     _autoPrecision=true;
-    _numberPrecisionInversedScale=1;
+    _numberPrecisionInverseScale=1;
     _zoomEnabled=true;
     _autoTicks=true;
     _sizeType=TotalSize;
@@ -339,11 +339,11 @@ namespace SciFigs {
     _numberPrecision=o._numberPrecision;
     _unitFactor=o._unitFactor;
     _autoPrecision=o._autoPrecision;
-    _numberPrecisionInversedScale=o._numberPrecisionInversedScale;
+    _numberPrecisionInverseScale=o._numberPrecisionInverseScale;
     _zoomEnabled=o._zoomEnabled;
     _autoTicks=o._autoTicks;
     _title=o._title;
-    _titleInversedScale=o._titleInversedScale;
+    _titleInverseScale=o._titleInverseScale;
     _sizeType=o._sizeType;
     _sizeInfo=o._sizeInfo;
     _lineWeight=o._lineWeight;
@@ -369,9 +369,9 @@ namespace SciFigs {
       Scale& s=scale();
       s.setType(st);
       switch (s.type()) {
-      case Scale::Inversed:
+      case Scale::Inverse:
       case Scale::Log:
-      case Scale::InversedLog:
+      case Scale::InverseLog:
         if(s.globalMinimum()<=1e-16) {
           s.setGlobalMinimum(1e-16);
         }
@@ -397,6 +397,34 @@ namespace SciFigs {
     }
   }
 
+  void Axis::setScaleType(const QString& v)
+  {
+    bool ok=true;
+    Scale::Type t=Scale::convertType(v, ok);
+    if(ok) {
+      setScaleType(t);
+    }
+  }
+
+  QString Axis::scaleTypeString() const
+  {
+    return Scale::convertType(constScale().type());
+  }
+
+  void Axis::setSizeType(const QString& v)
+  {
+    bool ok=true;
+    SizeType t=convertSizeType(v, ok);
+    if(ok) {
+      setSizeType(t);
+    }
+  }
+
+  QString Axis::sizeTypeString() const
+  {
+    return convertSizeType(sizeType());
+  }
+
   /*!
     Set the minimum and the maximum values of the axis. The \a min and \a max are swaped
     if necessary. The scale is always updated.
@@ -407,7 +435,7 @@ namespace SciFigs {
   {
     TRACE;
     Scale& s=scale();
-    bool zoomed=isZoomed();
+    bool zoomed=s.isZoomed();
     s.setGlobalMinimum(min);
     s.setGlobalMaximum(max);
     setVisibleRange(zoomed);
@@ -464,15 +492,8 @@ namespace SciFigs {
   void Axis::setVisibleRange(bool zoomed)
   {
     TRACE;
-    const Scale& cs=constScale();
-    if(cs.globalMaximum()<cs.globalMinimum()) {
-      double tmp;
-      tmp=cs.globalMinimum();
-      Scale& s=scale();
-      s.setGlobalMinimum(cs.globalMaximum());
-      s.setGlobalMaximum(tmp);
-    }
     if(!zoomed) {
+      const Scale& cs=constScale();
       setVisibleRange(cs.globalMinimum(), cs.globalMaximum());
     }
     emit rangeChanged();
@@ -482,12 +503,9 @@ namespace SciFigs {
   {
     TRACE;
     Scale& s=scale();
-    if(val1<val2) {
+    if(val1<=val2) {
       s.setMinimum(val1);
       s.setMaximum(val2);
-    } else {
-      s.setMinimum(val2);
-      s.setMaximum(val1);
     }
     if(_autoTicks) {
       s.autoTicks();
@@ -503,7 +521,7 @@ namespace SciFigs {
   {
     TRACE;
     if( !_stringLabels) {
-      _stringLabels=new QVector<QString>;
+      _stringLabels=new VectorList<QString>;
     }
     _stringLabels->append(lab);
     if(updadeScale) {
@@ -539,16 +557,16 @@ namespace SciFigs {
 
   /*!
     Remove/set the lines that track the mouse position.
-    Usually connected by AxisWindow to GraphContent::mouseInside(bool)
+    Usually connected by AxisWindow to GraphContents::mouseInside(bool)
   */
-  void Axis::setMouseTrack (bool t)
+  void Axis::setMouseTrack(bool t)
   {
     TRACE;
     _mouseTrack=t;
     update();
   }
 
-  void Axis::setGraphContent(GraphContent * gc)
+  void Axis::setGraphContents(GraphContents * gc)
   {
     _content=gc;
   }
@@ -604,8 +622,8 @@ namespace SciFigs {
       visMax=s.maximum()*_unitFactor;
       majorTicks=s.majorTicks()*_unitFactor;
       break;
-    case Scale::Inversed:
-    case Scale::InversedLog:
+    case Scale::Inverse:
+    case Scale::InverseLog:
       visMin=_unitFactor/s.maximum();
       visMax=_unitFactor/s.minimum();
       majorTicks=s.majorTicks()*_unitFactor;
@@ -614,7 +632,7 @@ namespace SciFigs {
       visMin=s.minimum();
       visMax=s.maximum();
       if(visMax-visMin<=60.0) {
-        const QVector<double>& ticks=s.majorTickValues();
+        const VectorList<double>& ticks=s.majorTickValues();
         if(ticks.count()>=2) {
           majorTicks=ticks.at(1)-ticks.at(0);
         } else {
@@ -628,7 +646,7 @@ namespace SciFigs {
     int numberPrecision=0;
     switch(s.type()) {
     case Scale::Log:
-    case Scale::InversedLog:
+    case Scale::InverseLog:
       if(_numberType=='e') {
         numberPrecision=qCeil(round(-log10(s.majorTicks())*100.0)*0.01);
       } else {
@@ -638,7 +656,7 @@ namespace SciFigs {
       }
       break;
     case Scale::Linear:
-    case Scale::Inversed:
+    case Scale::Inverse:
     case Scale::AbsoluteTime:
     case Scale::RelativeTime:
       if(_numberType=='e') {
@@ -696,12 +714,12 @@ namespace SciFigs {
         break;
       case 0x002C:       // ','
         label.setEnd(p);
-        addStringLabel(label.toString());
+        addStringLabel(label.toStringBuffer());
         label.set(p + 1, 0);
         break;
       case 0x0000:
         label.setEnd(p);
-        if(!label.isEmpty()) addStringLabel(label.toString());
+        if(!label.isEmpty()) addStringLabel(label.toStringBuffer());
         return ;
       default:
         break;
@@ -710,85 +728,13 @@ namespace SciFigs {
     }
   }
 
-  QString Axis::scaleTypeString() const
-  {
-    TRACE;
-    switch (scaleType()) {
-    case Scale::Inversed:
-      return "Inversed";
-    case Scale::InversedLog:
-      return "InversedLog";
-    case Scale::Log:
-      return "Log";
-    case Scale::AbsoluteTime:
-      return "AbsoluteTime";
-    case Scale::RelativeTime:
-      return "RelativeTime";
-    default:
-      return "Linear";
-    }
-  }
+  ENUM_AS_STRING_BEGIN(Axis, SizeType)
+  ENUM_AS_STRING_DATA_3(AxisSize, Scaled, TotalSize);
+  ENUM_AS_STRING_END
 
-  void Axis::setScaleType(QString t)
-  {
-    TRACE;
-    switch(t.count()) {
-    case 0:
-      return;
-    case 1: // Compatibility
-      switch(t[0].unicode()) {
-      case 'l':
-        setScaleType(Scale::Log);
-        break;
-      case 'i':
-        setScaleType(Scale::Inversed);
-        break;
-      default:
-        setScaleType(Scale::Linear);
-        break;
-      }
-      break;
-    default:
-      switch(t[1].unicode()) {
-      case 'o':
-        if(t=="Log") {
-          setScaleType(Scale::Log);
-          return;
-        }
-        break;
-      case 'n':
-        if(t=="Inversed") {
-          setScaleType(Scale::Inversed);
-          return;
-        } else if(t=="InversedLog") {
-          setScaleType(Scale::InversedLog);
-          return;
-        }
-        break;
-      case 'b':
-        if(t=="AbsoluteTime") {
-          setScaleType(Scale::AbsoluteTime);
-          return;
-        }
-        break;
-      case 'e':
-        if(t=="RelativeTime") {
-          setScaleType(Scale::RelativeTime);
-          return;
-        }
-        break;
-      case 'i':
-        if(t=="Linear") {
-          setScaleType(Scale::Linear);
-          return;
-        }
-        break;
-      default:
-        break;
-      }
-    }
-    App::log(tr("Unknown scale type '%1'\n").arg(t));
-  }
+  ENUM_AS_STRING_BEGIN(Axis, Orientation)
+  ENUM_AS_STRING_DATA_4(East, North, South, West);
+  ENUM_AS_STRING_END
 
   /*!
     Compatibility function only. Never use it.
@@ -848,68 +794,18 @@ namespace SciFigs {
     emit orientationChanged();
   }
 
+  void Axis::setOrientation(const QString& v)
+  {
+    bool ok=true;
+    Orientation o=convertOrientation(v, ok);
+    if(ok) {
+      setOrientation(o);
+    }
+  }
+
   QString Axis::orientationString() const
   {
-    TRACE;
-    switch(_orientation) {
-    case North:
-      return "North";
-    case South:
-      return "South";
-    case East:
-      return "East";
-    default:
-      return "West";
-    }
-  }
-
-  void Axis::setOrientationString(QString o)
-  {
-    TRACE;
-    switch(o[0].unicode()) {
-    case 'S':
-      setOrientation(South);
-      break;
-    case 'W':
-      setOrientation(West);
-      break;
-    case 'E':
-      setOrientation(East);
-      break;
-    default:
-      setOrientation(North);
-      break;
-    }
-  }
-
-  QString Axis::sizeTypeString() const
-  {
-    TRACE;
-    switch (sizeType()) {
-    case Axis::Scaled:
-      return "Scaled";
-    case Axis::AxisSize:
-      return "AxisSize";
-    case Axis::TotalSize:
-      return "TotalSize";
-    }
-    return "TotalSize";
-  }
-
-  void Axis::setSizeType(QString st)
-  {
-    TRACE;
-    switch (st[0].unicode()) {
-    case 'S':
-      setSizeType(Axis::Scaled);
-      break;
-    case 'A':
-      setSizeType(Axis::AxisSize);
-      break;
-    default:
-      setSizeType(Axis::TotalSize);
-      break;
-    }
+    return convertOrientation(_orientation);
   }
 
   int Axis::currentNumberPrecision() const
@@ -921,9 +817,9 @@ namespace SciFigs {
     case Scale::AbsoluteTime:
     case Scale::RelativeTime:
       break;
-    case Scale::Inversed:
-    case Scale::InversedLog:
-      return numberPrecisionInversedScale();
+    case Scale::Inverse:
+    case Scale::InverseLog:
+      return numberPrecisionInverseScale();
     }
     return numberPrecision();
   }
@@ -938,14 +834,14 @@ namespace SciFigs {
     case Scale::RelativeTime:
       setNumberPrecision(p);
       break;
-    case Scale::Inversed:
-    case Scale::InversedLog:
-      setNumberPrecisionInversedScale(p);
+    case Scale::Inverse:
+    case Scale::InverseLog:
+      setNumberPrecisionInverseScale(p);
       break;
     }
   }
 
-  int Axis::currentInversedNumberPrecision() const
+  int Axis::currentInverseNumberPrecision() const
   {
     TRACE;
     switch(scaleType()) {
@@ -954,14 +850,14 @@ namespace SciFigs {
     case Scale::AbsoluteTime:
     case Scale::RelativeTime:
       break;
-    case Scale::Inversed:
-    case Scale::InversedLog:
+    case Scale::Inverse:
+    case Scale::InverseLog:
       return numberPrecision();
     }
-    return numberPrecisionInversedScale();
+    return numberPrecisionInverseScale();
   }
 
-  void Axis::setCurrentInversedNumberPrecision(int p)
+  void Axis::setCurrentInverseNumberPrecision(int p)
   {
     TRACE;
     switch(scaleType()) {
@@ -969,10 +865,10 @@ namespace SciFigs {
     case Scale::Log:
     case Scale::AbsoluteTime:
     case Scale::RelativeTime:
-      setNumberPrecisionInversedScale(p);
+      setNumberPrecisionInverseScale(p);
       break;
-    case Scale::Inversed:
-    case Scale::InversedLog:
+    case Scale::Inverse:
+    case Scale::InverseLog:
       setNumberPrecision(p);
       break;
     }
@@ -987,9 +883,9 @@ namespace SciFigs {
     case Scale::AbsoluteTime:
     case Scale::RelativeTime:
       break;
-    case Scale::Inversed:
-    case Scale::InversedLog:
-      return titleInversedScale();
+    case Scale::Inverse:
+    case Scale::InverseLog:
+      return titleInverseScale();
     }
     return title();
   }
@@ -1004,14 +900,14 @@ namespace SciFigs {
     case Scale::RelativeTime:
       setTitle(s);
       break;
-    case Scale::Inversed:
-    case Scale::InversedLog:
-      setTitleInversedScale(s);
+    case Scale::Inverse:
+    case Scale::InverseLog:
+      setTitleInverseScale(s);
       break;
     }
   }
 
-  QString Axis::currentInversedTitle() const
+  QString Axis::currentInverseTitle() const
   {
     TRACE;
     switch(scaleType()) {
@@ -1020,14 +916,14 @@ namespace SciFigs {
     case Scale::AbsoluteTime:
     case Scale::RelativeTime:
       break;
-    case Scale::Inversed:
-    case Scale::InversedLog:
+    case Scale::Inverse:
+    case Scale::InverseLog:
       return title();
     }
-    return titleInversedScale();
+    return titleInverseScale();
   }
 
-  void Axis::setCurrentInversedTitle(QString s)
+  void Axis::setCurrentInverseTitle(QString s)
   {
     TRACE;
     switch(scaleType()) {
@@ -1035,10 +931,10 @@ namespace SciFigs {
     case Scale::Log:
     case Scale::AbsoluteTime:
     case Scale::RelativeTime:
-      setTitleInversedScale(s);
+      setTitleInverseScale(s);
       break;
-    case Scale::Inversed:
-    case Scale::InversedLog:
+    case Scale::Inverse:
+    case Scale::InverseLog:
       setTitle(s);
       break;
     }
@@ -1093,7 +989,7 @@ namespace SciFigs {
     }
   }
 
-  void Axis::trackMouse (QPoint mouseP)
+  void Axis::trackMouse(const QPoint& mouseP)
   {
     TRACE;
     switch (_orientation) {
@@ -1109,13 +1005,13 @@ namespace SciFigs {
     update();
   }
 
-  void Axis::resizeEvent (QResizeEvent * )
+  void Axis::resizeEvent(QResizeEvent *)
   {
     TRACE;
     setScaleTransformation(width(), height());
   }
 
-  void Axis::paintEvent(QPaintEvent * )
+  void Axis::paintEvent(QPaintEvent *)
   {
     TRACE;
     QPainter p(this);
@@ -1126,7 +1022,7 @@ namespace SciFigs {
       paintHorizontal(p, SciFigsGlobal::screenResolution(), width(), height(), false);
       if(isMouseTrack()) {
         // draw a line on last mouse position
-        p.setPen(QPen( Qt::blue, 1, Qt::DotLine) );
+        p.setPen(QPen(Qt::blue, 1, Qt::DotLine));
         p.drawLine(_lastMousePosition, 0 , _lastMousePosition, height());
       }
       break;
@@ -1135,7 +1031,7 @@ namespace SciFigs {
       paintVertical(p, SciFigsGlobal::screenResolution(), width(), height(), false);
       if(isMouseTrack()) {
         // draw a line on last mouse position
-        p.setPen(QPen( Qt::blue, 1, Qt::DotLine) );
+        p.setPen(QPen(Qt::blue, 1, Qt::DotLine));
         p.drawLine(0, _lastMousePosition , width(), _lastMousePosition);
       }
       break;
@@ -1203,9 +1099,9 @@ namespace SciFigs {
           }
           return Number::toString(val*unitFactor, _numberType, numberPrecision);
         }
-      case Scale::Inversed:
+      case Scale::Inverse:
         return Number::toString(val*unitFactor, _numberType, numberPrecision);
-      case Scale::InversedLog:
+      case Scale::InverseLog:
         if(_numberType=='e') {
           return Number::toString(val*unitFactor, _numberType, numberPrecision);
         } else {
@@ -1278,7 +1174,7 @@ namespace SciFigs {
 
     // draw title
     str=currentTitle();
-    if(str.length() > 0) {
+    if(str.length()>0) {
       r=p.boundingRect(0, 0, w, INT_MAX, Qt::AlignHCenter | Qt::AlignTop | Qt::TextWordWrap, str);
       if(_orientation==North) {
         p.drawText(0, h-r.height(), w, r.height(),
@@ -1287,6 +1183,19 @@ namespace SciFigs {
         p.drawText(0, 0, w, r.height(), Qt::AlignHCenter | Qt::AlignTop | Qt::TextWordWrap, str);
       }
     }
+    // Draw complete absolute time
+    if(scl.type()==Scale::AbsoluteTime && scl.majorTickValues().count()>0) {
+      DateTime t(scl.timeReference());
+      t.addSeconds(floor(scl.majorTickValues().constFirst()));
+      str=t.toString("yyyy-MM-dd hh:mm:ss", 0);
+      r=p.boundingRect(0, 0, w, INT_MAX, Qt::AlignLeft | Qt::AlignTop | Qt::TextWordWrap, str);
+      if(_orientation==North) {
+        p.drawText(0, h-r.height(), w, r.height(),
+                   Qt::AlignLeft | Qt::AlignTop | Qt::TextWordWrap, str);
+      } else {
+        p.drawText(0, 0, w, r.height(), Qt::AlignLeft | Qt::AlignTop | Qt::TextWordWrap, str);
+      }
+    }
   }
 
   void Axis::paintVertical(QPainter& p, double dotpercm, int w, int h, bool mask)
@@ -1407,7 +1316,7 @@ namespace SciFigs {
       maxThickness+=(_tickSize+_lineWeight)*dotpercm*0.1;
       // title
       str=currentTitle();
-      if(!str.isEmpty()) {
+      if(!str.isEmpty() || constScale().type()==Scale::AbsoluteTime) {
         r=textBoundingRect(p, str, length, Qt::AlignLeft | Qt::AlignTop | Qt::TextWordWrap);
         maxThickness+=r.height();
       }
@@ -1447,8 +1356,8 @@ namespace SciFigs {
     return qRound(maxThickness);
   }
 
-  uint Axis::_tabScale=PropertyProxy::uniqueId();
-  uint Axis::_tabFormat=PropertyProxy::uniqueId();
+  uint Axis::_tabScale=PropertyTab::uniqueId();
+  uint Axis::_tabFormat=PropertyTab::uniqueId();
 
   /*!
 
@@ -1503,11 +1412,11 @@ namespace SciFigs {
         max=maximum()*_unitFactor;
         prec=numberPrecision();
         break;
-      case Scale::Inversed:
-      case Scale::InversedLog:
+      case Scale::Inverse:
+      case Scale::InverseLog:
         min=_unitFactor/maximum();
         max=_unitFactor/minimum();
-        prec=numberPrecisionInversedScale();
+        prec=numberPrecisionInverseScale();
         break;
       }
       prec+=2;
@@ -1545,8 +1454,8 @@ namespace SciFigs {
     switch(scaleType()) {
     case Scale::Linear:
     case Scale::Log:
-    case Scale::InversedLog:
-    case Scale::Inversed:
+    case Scale::InverseLog:
+    case Scale::Inverse:
       break;
     case Scale::RelativeTime:
       return Number::durationToSeconds(text, ok);
@@ -1568,7 +1477,7 @@ namespace SciFigs {
   {
     TRACE;
     bool visibleRangeChange=false;
-    bool previouslyZoomed=isZoomed();
+    bool previouslyZoomed=constScale().isZoomed();
     bool deepUpdateChange=false;
     bool ok=true;
     double dVal;
@@ -1585,8 +1494,8 @@ namespace SciFigs {
           case Scale::RelativeTime:
             setMinimum(dVal/_unitFactor);
             break;
-          case Scale::Inversed:
-          case Scale::InversedLog:
+          case Scale::Inverse:
+          case Scale::InverseLog:
             setMaximum(1.0/(dVal*_unitFactor));
             break;
           }
@@ -1603,8 +1512,8 @@ namespace SciFigs {
           case Scale::RelativeTime:
             setMaximum(dVal/_unitFactor);
             break;
-          case Scale::Inversed:
-          case Scale::InversedLog:
+          case Scale::Inverse:
+          case Scale::InverseLog:
             setMinimum(1.0/(dVal*_unitFactor));
             break;
           }
@@ -1618,7 +1527,6 @@ namespace SciFigs {
             setAutoTicks(false);
           }
           setMajorTicks(dVal);
-          scale().cacheTicks();
           deepUpdateChange=true;
           if(autoPrecision()) {
             calculatePrecicion();
@@ -1632,7 +1540,6 @@ namespace SciFigs {
             setAutoTicks(false);
           }
           setMinorTicks(dVal);
-          scale().cacheTicks();
           deepUpdateChange=true;
           if(autoPrecision()) {
             calculatePrecicion();
@@ -1664,12 +1571,12 @@ namespace SciFigs {
         if(sizeType()!=Axis::Scaled) {
           setSizeType(AxisScaleProperties::item2sizeType(val.toInt()));
           if(sizeType()==Axis::Scaled) {
-            setSizeInfo(( maximum()-minimum())/sizeInfo() * 100.0);
+            setSizeInfo((maximum()-minimum())/sizeInfo()*100.0);
           }
         } else {
           setSizeType(AxisScaleProperties::item2sizeType(val.toInt()));
           if(sizeType()!=Axis::Scaled) {
-            setSizeInfo(( maximum()-minimum())/sizeInfo() * 100.0);
+            setSizeInfo((maximum()-minimum())/sizeInfo()*100.0);
           }
         }
         deepUpdateChange=true;
@@ -1732,7 +1639,6 @@ namespace SciFigs {
       }
     }
     if(visibleRangeChange) {
-      setTimeReference(timeReference());
       bool tmp=zoomEnabled();
       setZoomEnabled(true);
       setVisibleRange(previouslyZoomed);
@@ -1802,8 +1708,28 @@ namespace SciFigs {
   {
     TRACE;
     setTitle(tr("Frequency (Hz)"));
-    setTitleInversedScale(tr("Period (s)"));
+    setTitleInverseScale(tr("Period (s)"));
     setScaleType(Scale::Log);
   }
 
+  /*!
+    Refresh all after changing the property value. Used from Python.
+  */
+  void Axis::setProperty(const QVariant& val, const QMetaProperty& p)
+  {
+    bool previouslyZoomed=constScale().isZoomed();
+
+    p.write(this, val);
+
+    if(autoPrecision()) {
+      calculatePrecicion();
+    }
+    bool tmp=zoomEnabled();
+    setZoomEnabled(true);
+    setVisibleRange(previouslyZoomed);
+    setZoomEnabled(tmp);
+    emit contentChanged();
+    emit sizeChanged();
+  }
+
 } // namespace SciFigs
