@@ -1,4 +1,4 @@
-/***************************************************************************
+﻿/***************************************************************************
 **
 **  This file is part of SciFigs.
 **
@@ -28,8 +28,10 @@
 
 #include "AxisWindow.h"
 #include "GraphicObjectFactory.h"
-#include "GraphContent.h"
+#include "GraphContents.h"
 #include "SciFigsGlobal.h"
+#include "LineLayer.h"
+#include "PlotLine2D.h"
 
 namespace SciFigs {
 
@@ -38,20 +40,20 @@ namespace SciFigs {
     \brief AxisWindow widget provides an XY graphic with two axis.
 
     AxisWindow has always three children:
-    \li GraphContent , the content of the graphic where data are plotted
+    \li GraphContents , the content of the graphic where data are plotted
     \li Axis , the X axis either at the top or at the bottom
     \li Axis , the Y axis either on the left or on the right
 
     \image html AxisWindow.png "A typical multi-layered AxisWindow"
     \image latex AxisWindow.ps "A typical multi-layered AxisWindow" width=10cm
 
-    The content is a 2D space, X and Y where you can stack several layers. Each layer carry distinct types of data and distinct way of plotting them to the content. The layers all inherits GraphContentLayer. Any new type of layers can be implemented and added to any content. The content stores a QPixmap to avoid long redrawing of huge data layers every time the content need refreshing. To force the redrawing of the content call update().
+    The content is a 2D space, X and Y where you can stack several layers. Each layer carry distinct types of data and distinct way of plotting them to the content. The layers all inherits GraphContentsLayer. Any new type of layers can be implemented and added to any content. The content stores a QPixmap to avoid long redrawing of huge data layers every time the content need refreshing. To force the redrawing of the content call update().
 
     For basic plotting tasks you generally use only a reduced set of class functions the main ones are:
     \li The constructors
-    \li Eventually setGraphContent(), if the GraphContent is not available of the time of the construction
+    \li Eventually setGraphContents(), if the GraphContents is not available of the time of the construction
     \li AxisWindow::xAxis and AxisWindow::yAxis to modify the properties of the axis like the minimum and maximum values
-    \li graphContent() to get the content Widget, either to change aspect properties or access the embedded data.
+    \li graphContents() to get the content Widget, either to change aspect properties or access the embedded data.
 
     Here is an example that creates a top level graphic (that appear directly on the desktop like any other windows)
 
@@ -94,7 +96,7 @@ namespace SciFigs {
 
     // Init the color map
     ColorMap pal;
-    pal.generateColorScale(20);
+    pal.generate(0, 19);
     pal.setValues(0, 1, SamplingParameters::Linear);
     plot->setColorMap(pal);
 
@@ -167,8 +169,8 @@ namespace SciFigs {
     _ySBar->setPageStep(10);
     _ySBar->setValue(1);
 
-    _content=new GraphContent(this);
-    _content->setObjectName("content");
+    _content=new GraphContents(this);
+    _content->setObjectName("contents");
 
     _xAxis=new Axis(this);
     _yAxis=new Axis(this);
@@ -179,8 +181,8 @@ namespace SciFigs {
     _yAxis->setTitle("Y");
     _xAxis->setOrientation(Axis::North);
     _yAxis->setOrientation(Axis::East);
-    _xAxis->setGraphContent(_content);
-    _yAxis->setGraphContent(_content);
+    _xAxis->setGraphContents(_content);
+    _yAxis->setGraphContents(_content);
     _xAxis->setOrientationBlocked(true);
     _yAxis->setOrientationBlocked(true);
 
@@ -199,18 +201,20 @@ namespace SciFigs {
             this, SLOT(zoomIn(double, double, double, double)));
     connect(_content, SIGNAL(zoomOut()), this, SLOT(zoomOut()));
     connect(_content, SIGNAL(browse(QRect&)), this, SLOT(browse(QRect&)));
-    connect(_content, SIGNAL(mouseMoved( QPoint, Qt::MouseButtons, Qt::KeyboardModifiers) ), _xAxis, SLOT(trackMouse( QPoint) ));
-    connect(_content, SIGNAL(mouseMoved( QPoint, Qt::MouseButtons, Qt::KeyboardModifiers) ), _yAxis, SLOT(trackMouse( QPoint) ));
-    connect(_content, SIGNAL(mouseInside( bool) ), _xAxis, SLOT(setMouseTrack( bool) ));
-    connect(_content, SIGNAL(mouseInside( bool) ), _yAxis, SLOT(setMouseTrack( bool) ));
+    connect(_content, SIGNAL(mouseMoved(QPoint, Qt::MouseButtons, Qt::KeyboardModifiers)),
+            _xAxis, SLOT(trackMouse(const QPoint&)));
+    connect(_content, SIGNAL(mouseMoved(QPoint, Qt::MouseButtons, Qt::KeyboardModifiers)),
+            _yAxis, SLOT(trackMouse(const QPoint&)));
+    connect(_content, SIGNAL(mouseInside(bool)), _xAxis, SLOT(setMouseTrack(bool)));
+    connect(_content, SIGNAL(mouseInside(bool)), _yAxis, SLOT(setMouseTrack(bool)));
 
     // Scroll bars signals
-    connect (_xSBar, SIGNAL(valueChanged( int) ), this, SLOT(xScrollChanged( int) ));
-    connect (_ySBar, SIGNAL(valueChanged( int) ), this, SLOT(yScrollChanged( int) ));
+    connect (_xSBar, SIGNAL(valueChanged(int)), this, SLOT(xScrollChanged(int)));
+    connect (_ySBar, SIGNAL(valueChanged(int)), this, SLOT(yScrollChanged(int)));
   }
 
   /*!
-    \fn GraphContent * AxisWindow::graphContent() const
+    \fn GraphContents * AxisWindow::graphContents() const
     Return the content widget
   */
 
@@ -353,9 +357,18 @@ namespace SciFigs {
   void AxisWindow::zoomIn(double rx1, double ry1, double rx2, double ry2)
   {
     TRACE;
+    // Make sure that values are ordered
+    if(rx2<rx1) {
+      qSwap(rx1, rx2);
+    }
+    if(ry2<ry1) {
+      qSwap(ry1, ry2);
+    }
     // Avoid integer overflow for scrollbars
-    if(_xSBar->maximum() > INT_MAX/2 || _ySBar->maximum() > INT_MAX/2) return ;
-    // save actual visible rectangle to zoom rectangles stack
+    if(_xSBar->maximum()>INT_MAX/2 || _ySBar->maximum()>INT_MAX/2) {
+      return;
+    }
+    // save current visible rectangle to the zoom rectangles stack
     if(!isZoomed()) {
       _xSBar->show();
       _ySBar->show();
@@ -366,26 +379,31 @@ namespace SciFigs {
       a=_content->action("Browse");
       if(a) a->setEnabled(true);
     }
-    _zoomRects.push_back(Rect( _xAxis->visibleMinimum(), _yAxis->visibleMinimum(),
-                                   _xAxis->visibleMaximum(), _yAxis->visibleMaximum()) );
+    _zoomRects.push_back(Rect(_xAxis->visibleMinimum(), _yAxis->visibleMinimum(),
+                              _xAxis->visibleMaximum(), _yAxis->visibleMaximum()));
     if(_xAxis->sizeType()==Axis::Scaled &&
-         _yAxis->sizeType()==Axis::Scaled) {
-      // Both axis are scaled, hence zoom in must respect the x/y ratio
-      double ratio=(_xAxis->visibleMaximum() - _xAxis->visibleMinimum()) /
-                     (_yAxis->visibleMaximum() - _yAxis->visibleMinimum());
-      if(ratio > 0 && ratio < 1000) {
-        if(rx2 < rx1) {double tmp=rx2; rx2=rx1; rx1=tmp;}
-        double dx=rx2 - rx1;
-        if(ry2 < ry1) {double tmp=ry2; ry2=ry1; ry1=tmp;}
-        double dy=ry2 - ry1;
-        if(dy * ratio > dx) rx2=rx1 + dy * ratio;
-        else ry1=ry2 - dx/ratio;
+       _yAxis->sizeType()==Axis::Scaled) {
+      // Both axis are scaled, hence zoomIn must respect the x/y ratio
+      double ratio=(_xAxis->visibleMaximum()-_xAxis->visibleMinimum())/
+                   (_yAxis->visibleMaximum()-_yAxis->visibleMinimum());
+      if(ratio>0 && ratio<1000) {
+        double dx=rx2-rx1;
+        double dy=ry2-ry1;
+        if(dy*ratio>dx) {
+          rx2=rx1+dy*ratio;
+        } else {
+          ry1=ry2-dx/ratio;
+        }
       }
     }
-    if(_xAxis->zoomEnabled()) _xAxis->setVisibleRange(rx1, rx2);
-    if(_yAxis->zoomEnabled()) _yAxis->setVisibleRange(ry1, ry2);
+    if(_xAxis->zoomEnabled()) {
+      _xAxis->setVisibleRange(rx1, rx2);
+    }
+    if(_yAxis->zoomEnabled()) {
+      _yAxis->setVisibleRange(ry1, ry2);
+    }
     updateScrollBars();
-    graphContent()->deepUpdate();
+    graphContents()->deepUpdate();
   }
 
   /*!
@@ -398,23 +416,29 @@ namespace SciFigs {
     if(!isZoomed()) return;
     Rect r=_zoomRects.back();
     _zoomRects.pop_back();
+    if(_xAxis->zoomEnabled()) {
+      _xAxis->setVisibleRange(r.x1(), r.x2());
+    }
+    if(_yAxis->zoomEnabled()) {
+      _yAxis->setVisibleRange(r.y1(), r.y2());
+    }
     if(!isZoomed()) {
       QAction * a;
       a=_content->action("Unzoom");
-      if(a) a->setEnabled(false);
+      if(a) {
+        a->setEnabled(false);
+      }
       a=_content->action("Browse");
-      if(a) a->setEnabled(false);
-      _content->browse(); // Force removal of Browse tracking
+      if(a) {
+        a->setEnabled(false);
+      }
+      _content->browse(); // Force removal of Browse tracking because zoomRects is empty
       _xSBar->hide();
       _ySBar->hide();
       updateInternalGeometry();
     }
-
-    if(_xAxis->zoomEnabled()) _xAxis->setVisibleRange(r.x1(), r.x2());
-    if(_yAxis->zoomEnabled()) _yAxis->setVisibleRange(r.y1(), r.y2());
-
     updateScrollBars();
-    graphContent()->deepUpdate();
+    graphContents()->deepUpdate();
   }
 
 
@@ -447,31 +471,35 @@ namespace SciFigs {
     Rect r(_xAxis->minimum(), _yAxis->minimum(), _xAxis->maximum(), _yAxis->maximum());
 
     if(!_zoomRects.empty()) {
-      QVector<Rect>::iterator it;
-      for(it=_zoomRects.begin();it!=_zoomRects.end(); )
-        if( !r.includes( *it) ) it=_zoomRects.erase(it);
-        else ++it;
-
+      VectorList<Rect>::iterator it;
+      for(it=_zoomRects.begin();it!=_zoomRects.end(); ) {
+        if(!r.includes(*it)) {
+          it=_zoomRects.erase(it);
+        } else {
+          ++it;
+        }
+      }
 
       if(_zoomRects.empty()) {
         // All zoom rects are deleted,
-        // then the actual visible area must be checked
+        // then the current visible area must be checked
         _zoomRects.push_back(r);
         // find intersection between old visible area and new total area
         Rect oldVis(_xAxis->visibleMinimum(), _yAxis->visibleMinimum(),
-                        _xAxis->visibleMaximum(), _yAxis->visibleMaximum());
+                    _xAxis->visibleMaximum(), _yAxis->visibleMaximum());
         Rect newVis=r.intersect(oldVis);
-        if(_xAxis->zoomEnabled()) _xAxis->setVisibleRange(newVis.x1(), newVis.x2());
-        if(_yAxis->zoomEnabled()) _yAxis->setVisibleRange(newVis.y1(), newVis.y2());
-      } else
-        // If there's at least one zoom rect the actual visible area is still ok
-        _zoomRects.begin() ->setLimits(_xAxis->minimum(), _yAxis->minimum(),
-                                        _xAxis->maximum(), _yAxis->maximum());
-    } else {
-      // old visible area is equal to the total area, the last has changed, thus
-      // updates the former one
-      //if(_xAxis->zoomEnabled()) _xAxis->setVisibleRange(_xAxis->minimum(), _xAxis->maximum());
-      //if(_yAxis->zoomEnabled()) _yAxis->setVisibleRange(_yAxis->minimum(), _yAxis->maximum());
+        if(_xAxis->zoomEnabled()) {
+          _xAxis->setVisibleRange(newVis.x1(), newVis.x2());
+        }
+        if(_yAxis->zoomEnabled()) {
+          _yAxis->setVisibleRange(newVis.y1(), newVis.y2());
+        }
+      } else {
+        // If there's at least one zoom rect the current visible area is still ok
+        // We are just changing the first rect which must must fit with min and max.
+        _zoomRects.first().setLimits(_xAxis->minimum(), _yAxis->minimum(),
+                                     _xAxis->maximum(), _yAxis->maximum());
+      }
     }
     updateScrollBars();
   }
@@ -570,7 +598,7 @@ namespace SciFigs {
   }
 
   /*!
-    For some high resolution bitmap image, fonts must scaled
+    For some high resolution bitmap image, fonts must be scaled
 
     Re-implentation to scale fonts in sub-widgets (axis and content)
   */
@@ -626,11 +654,11 @@ namespace SciFigs {
     Scale originalScaleY=_content->constScaleY();
     _xAxis->setPrintScale(xWidth, xHeight);
     _yAxis->setPrintScale(yWidth, yHeight);
-    // Print GraphContent
+    // Print GraphContents
     if(_xAxis->orientation()==Axis::North) {
       if(_yAxis->orientation()==Axis::East) {
         p.setWindow(0, 0, xWidth, yHeight);
-        p.setViewport(orX + yWidth, orY, xWidth, yHeight);
+        p.setViewport(orX+yWidth, orY, xWidth, yHeight);
       } else {
         p.setWindow(0, 0, xWidth, yHeight);
         p.setViewport(orX, orY, xWidth, yHeight);
@@ -638,10 +666,10 @@ namespace SciFigs {
     } else {
       if(_yAxis->orientation()==Axis::East) {
         p.setWindow(0, 0, xWidth, yHeight);
-        p.setViewport(orX + yWidth, orY + xHeight, xWidth, yHeight);
+        p.setViewport(orX + yWidth, orY+xHeight, xWidth, yHeight);
       } else {
         p.setWindow(0, 0, xWidth, yHeight);
-        p.setViewport(orX, orY + xHeight, xWidth, yHeight);
+        p.setViewport(orX, orY+xHeight, xWidth, yHeight);
       }
     }
     _content->print(p, dotpercm, xWidth, yHeight, mask);
@@ -651,10 +679,10 @@ namespace SciFigs {
         if(_xAxis->orientation()==Axis::North) {
           if(_yAxis->orientation()==Axis::East) {
             p.setWindow(0, 0, xWidth, xHeight);
-            p.setViewport(orX + yWidth, orY + yHeight, xWidth, xHeight);
+            p.setViewport(orX+yWidth, orY+yHeight, xWidth, xHeight);
           } else {
             p.setWindow(0, 0, xWidth, xHeight);
-            p.setViewport(orX, orY + yHeight, xWidth, xHeight);
+            p.setViewport(orX, orY+yHeight, xWidth, xHeight);
           }
         } else {
           if(_yAxis->orientation()==Axis::East) {
@@ -675,15 +703,15 @@ namespace SciFigs {
             p.setViewport(orX, orY, yWidth, yHeight);
           } else {
             p.setWindow(0, 0, yWidth, yHeight);
-            p.setViewport(orX + xWidth - 1, orY, yWidth, yHeight);
+            p.setViewport(orX + xWidth-1, orY, yWidth, yHeight);
           }
         } else {
           if(_yAxis->orientation()==Axis::East) {
             p.setWindow(0, 0, yWidth, yHeight);
-            p.setViewport(orX, orY + xHeight, yWidth, yHeight);
+            p.setViewport(orX, orY+xHeight, yWidth, yHeight);
           } else {
             p.setWindow(0, 0, yWidth, yHeight);
-            p.setViewport(orX + xWidth - 1, orY + xHeight, yWidth, yHeight);
+            p.setViewport(orX+xWidth-1, orY+xHeight, yWidth, yHeight);
           }
         }
         _yAxis->paint(p, dotpercm, yWidth, yHeight, mask);
@@ -874,7 +902,7 @@ namespace SciFigs {
       break;
     case Axis::Scaled:
       if(_printWidth==300.0) { // Widget was found too big, change the scale rather thant the axis limits
-        _xAxis->setSizeInfo((_xAxis->maximum()-_xAxis->minimum() )/xWidth*(100.0*dotpercm) );
+        _xAxis->setSizeInfo((_xAxis->maximum()-_xAxis->minimum() )/xWidth*(100.0*dotpercm));
       } else {
         _xAxis->setMaximum(_xAxis->minimum()+xWidth/(100.0*dotpercm)*_xAxis->sizeInfo());
       }
@@ -1026,15 +1054,17 @@ namespace SciFigs {
   {
     TRACE;
   #define N_BASESCALES 13
-    static const double baseScales[ N_BASESCALES ]={
+    static const double baseScales[ N_BASESCALES]={
           1, 1.25, 1.5, 1.75, 2.0, 2.5, 4.0, 5.0, 6.0, 7.5, 8.0, 9.0, 10.0
-        };
+    };
     // The true scale= 1.0/ (baseScaleFactor*baseScales[ibaseScale])
-    double baseScaleFactor=pow(10.0, floor(log10( startAt) ));
+    double baseScaleFactor=pow(10.0, floor(log10( startAt)));
     int ibaseScale=0;
-    while(baseScaleFactor * baseScales[ ibaseScale ] < startAt &&
-            ibaseScale < N_BASESCALES) ibaseScale++;
-    return baseScaleFactor*baseScales[ ibaseScale ];
+    while(baseScaleFactor*baseScales[ibaseScale]<startAt &&
+          ibaseScale<N_BASESCALES) {
+      ibaseScale++;
+    }
+    return baseScaleFactor*baseScales[ibaseScale];
   }
 
   /*!
@@ -1059,9 +1089,9 @@ namespace SciFigs {
   void AxisWindow::alignVScales(AxisWindow * ref, double at)
   {
     TRACE;
-    QPoint pRef(0, ref->_content->options().yr2s(at) );
+    QPoint pRef(0, ref->_content->options().yr2s(at));
     pRef=ref->_xAxis->mapToGlobal(pRef);
-    QPoint pThis(0,  _content->options().yr2s(at) );
+    QPoint pThis(0, _content->options().yr2s(at));
     pThis=_yAxis->mapToGlobal(pThis);
     _printAnchor.setY(_printAnchor.y()-(pThis.y()-pRef.y())/SciFigsGlobal::screenResolution());
     emit positionChanged();
@@ -1089,7 +1119,7 @@ namespace SciFigs {
     _xAxis->xml_save(s, context, att);
     value=valueVertical;
     _yAxis->xml_save(s, context, att);
-    graphContent()->xml_save(s, context);
+    graphContents()->xml_save(s, context);
   }
 
   XMLMember AxisWindow::xml_member(XML_MEMBER_ARGS)
@@ -1104,23 +1134,24 @@ namespace SciFigs {
         else if(it.value()=="Vertical")
           return XMLMember(_yAxis);
         else {
-          App::log(tr("Bad axis orientation: %1\n").arg(it.value().toString()));
+          App::log(tr("Bad axis orientation: %1\n").arg(it.value().toStringView()));
           return XMLMember(XMLMember::Unknown);
         }
       } else {
         App::log(tr("Attribute orientation not found\n"));
         return XMLMember(XMLMember::Unknown);
       }
-    } else if(tag=="GraphContent") {
+    } else if(tag=="GraphContents" ||
+              tag=="GraphContent") {    // Kept for compatibility
       // Lock any redraw of this graph
-      graphContent()->delayPainting();
-      return XMLMember(graphContent());
+      graphContents()->delayPainting();
+      return XMLMember(graphContents());
     }
     return GraphicObject::xml_member(tag, attributes, context);
   }
 
-  uint AxisWindow::categoryXAxis=PropertyProxy::uniqueId();
-  uint AxisWindow::categoryYAxis=PropertyProxy::uniqueId();
+  uint AxisWindow::categoryXAxis=PropertyCategory::uniqueId();
+  uint AxisWindow::categoryYAxis=PropertyCategory::uniqueId();
 
   /*!
 
@@ -1144,10 +1175,10 @@ namespace SciFigs {
   {
     TRACE;
     GraphicObject::removeProperties(pp);
-    if(pp->setCurrentCategory(categoryXAxis) ) {
+    if(pp->setCurrentCategory(categoryXAxis)) {
       xAxis()->removeProperties(pp);
     }
-    if(pp->setCurrentCategory(categoryYAxis) ) {
+    if(pp->setCurrentCategory(categoryYAxis)) {
       yAxis()->removeProperties(pp);
     }
     _content->removeProperties(pp);
@@ -1177,4 +1208,18 @@ namespace SciFigs {
     updateGeometry();
   }
 
+  void AxisWindow::addFreePicks()
+  {
+    LineLayer * pickLayer=new LineLayer(this);
+    pickLayer->setObjectName("free picks");
+    pickLayer->addTrackingAction(tr("&Pick"), LineLayer::Pick,
+                                 tr("Free picks."));
+    pickLayer->addTrackingAction(tr("&Edit"), LineLayer::Edit,
+                                 tr("Edit free picks."));
+    PlotLine2D * refLine=new PlotLine2D;
+    refLine->setPen(Pen(Qt::black, 0.6, Pen::DashLine));
+    refLine->setSymbol(Symbol(Symbol::Circle, 1.5, Pen(Qt::black, 0.6), Qt::NoBrush));
+    pickLayer->setReferenceLine(refLine);
+  }
+
 } // namespace SciFigs
