@@ -59,12 +59,12 @@ bool Brush::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(context)
   switch(memberID) {
   case 0: {
-      QColor col(content.toString());
+      QColor col(content.toStringView());
       setColor(col);
       return true;
     }
   case 1:
-    setStyle(styleValue(content.toString()));
+    setStyle(styleValue(content.toStringBuffer()));
     return true;
   default:
     return false;
@@ -149,9 +149,9 @@ QBrush Brush::qbrush(double dotpercm) const
   QPainter p;
   p.begin(&image);
   p.fillRect(0,0,s,s, Qt::white);
-  p.setPen(QPen(color(),(int)round(dotpercm*0.02), Qt::SolidLine, Qt::SquareCap, Qt::MiterJoin));
+  p.setPen(QPen(color(),qRound(dotpercm*0.02), Qt::SolidLine, Qt::SquareCap, Qt::MiterJoin));
   //p.fillRect(0,0,s,s, Qt::color0);
-  //p.setPen(QPen(Qt::color1,(int)round(dotpercm*0.02), Qt::SolidLine, Qt::SquareCap, Qt::MiterJoin));
+  //p.setPen(QPen(Qt::color1,(int)round(dotpercm*0.02), Pen::SolidLine, Qt::SquareCap, Qt::MiterJoin));
   switch (style()) {
   case Qt::HorPattern:
     x=s >> 2;
