@@ -40,16 +40,31 @@ const QString ComplexStatisticalLine::xmlComplexStatisticalLineTag="ComplexStati
 
 REGISTER_LINE(ComplexStatisticalLine, "ComplexStatisticalLine")
 
-AbstractLine * ComplexStatisticalLine::clone() const
+ComplexStatisticalLine::ComplexStatisticalLine(const ComplexStatisticalLine& o)
+  : AbstractLine(o)
 {
-  ComplexStatisticalLine * l=new ComplexStatisticalLine;
-  *l=*this;
-  return l;
+  TRACE;
+  _curve=o._curve;
 }
 
-void ComplexStatisticalLine::operator=(const ComplexStatisticalLine& o)
+AbstractLine * ComplexStatisticalLine::clone() const
 {
-  _curve=o._curve;
+  TRACE;
+  return new ComplexStatisticalLine(*this);
+}
+
+bool ComplexStatisticalLine::canCopy(const AbstractLine& o) const
+{
+  TRACE;
+  return dynamic_cast<const ComplexStatisticalLine *>(&o);
+}
+
+void ComplexStatisticalLine::operator=(const AbstractLine& o)
+{
+  TRACE;
+  const ComplexStatisticalLine * co=static_cast<const ComplexStatisticalLine *>(&o);
+  ASSERT(co);
+  _curve=co->_curve;
   AbstractLine::operator=(o);
 }
 
