@@ -35,28 +35,32 @@ namespace SciFigs {
 class SCIFIGS_EXPORT ComplexStatisticalLine : public AbstractLine
 {
 public:
-  virtual AbstractLine * clone() const;
-  virtual void operator=(const ComplexStatisticalLine& o);
+  ComplexStatisticalLine() {}
+  ComplexStatisticalLine(const ComplexStatisticalLine& o);
 
-  virtual const QString& xml_tagName() const {return xmlComplexStatisticalLineTag;}
+  AbstractLine * clone() const;
+  void operator=(const AbstractLine& o);
+  bool canCopy(const AbstractLine& o) const;
+
+  const QString& xml_tagName() const {return xmlComplexStatisticalLineTag;}
   static const QString xmlComplexStatisticalLineTag;
 
-  virtual int count() const {return _curve.count();}
-  virtual void clear() {_curve.clear();}
-  virtual void append() {_curve.append(ComplexStatisticalPoint());}
-  virtual void insert(int index) {_curve.insert(index, ComplexStatisticalPoint());}
-  virtual void removeLast() {_curve.remove(_curve.count()-1);}
-  virtual bool isValid(int index) const {return _curve.isValid(index);}
-  virtual void setValid(int index, bool v) {_curve.setValid(index, v);}
-  virtual bool isSorted() const {return _curve.isSorted();}
-  virtual void checkSort() {_curve.checkSort();}
-  virtual void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
+  int count() const {return _curve.count();}
+  void clear() {_curve.clear();}
+  void append() {_curve.append(ComplexStatisticalPoint());}
+  void insert(int index) {_curve.insert(index, ComplexStatisticalPoint());}
+  void removeLast() {_curve.remove(_curve.count()-1);}
+  bool isValid(int index) const {return _curve.isValid(index);}
+  void setValid(int index, bool v) {_curve.setValid(index, v);}
+  bool isSorted() const {return _curve.isSorted();}
+  void checkSort() {_curve.checkSort();}
+  void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
     return _curve.indexRange(xMin, xMax, indexMin, indexMax);
   }
-  virtual Point point(int index, const CurvePointOptions * options) const;
-  virtual void setX(int index, double v) {_curve.setX(index, v);}
-  virtual void setY(int index, double v, const CurvePointOptions * options);
-  virtual void setZ(int index, double v, const CurvePointOptions *) {_curve.constXAt(index).setStddev(v);}
+  Point point(int index, const CurvePointOptions * options) const;
+  void setX(int index, double v) {_curve.setX(index, v);}
+  void setY(int index, double v, const CurvePointOptions * options);
+  void setZ(int index, double v, const CurvePointOptions *) {_curve.constXAt(index).setStddev(v);}
 
   const Curve<ComplexStatisticalPoint>& curve() const {return _curve;}
   Curve<ComplexStatisticalPoint>& curve() {return _curve;}
