@@ -27,7 +27,7 @@
 ***************************************************************************/
 
 #include "CoordTip.h"
-#include "GraphContent.h"
+#include "GraphContents.h"
 #include "AxisWindow.h"
 
 namespace SciFigs {
@@ -37,7 +37,6 @@ CoordTipTip::CoordTipTip() :
 {
   TRACE;
   setObjectName("coordTip");
-  setAttribute(Qt::WA_DeleteOnClose);
 
   setPalette(QToolTip::palette());
 
@@ -71,7 +70,7 @@ CoordTip::CoordTip()
 {
   TRACE;
   _enabled=true;
-  _coordTip=nullptr;
+  _coordTip=new CoordTipTip();
   _currentGC=nullptr;
   connect(&_coordTipTimer, SIGNAL(timeout()), this, SLOT(fallAsleep()));
   connect(&_coordTipShowTimer, SIGNAL(timeout()), this, SLOT(hideTip()));
@@ -92,7 +91,7 @@ void CoordTip::setEnabled(bool e)
   if(!_enabled) hideTip();
 }
 
-void CoordTip::setMousePos(GraphContent * gc, QPoint& pt)
+void CoordTip::setMousePos(GraphContents * gc, QPoint& pt)
 {
   TRACE;
   if(_mousePos!=pt && _enabled) {
@@ -111,8 +110,6 @@ void CoordTip::fallAsleep()
   TRACE;
   hideTip();
   if(_currentGC && _currentGC->rect().contains(_mousePos) ) {
-    _coordTip=new CoordTipTip();
-    connect(_coordTip, SIGNAL(destroyed()), this, SLOT(hidden()) );
     _coordTip->setText(_currentGC->coordinateTipText(_mousePos));
     QPoint p=_currentGC->mapToGlobal(_mousePos);
 #if(QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
@@ -149,16 +146,7 @@ void CoordTip::hideTip()
   if(_coordTipTimer.isActive()) {
     _coordTipTimer.stop();
   }
-  if(_coordTip) {
-    _coordTip->deleteLater();
-    _coordTip=nullptr;
-  }
-}
-
-void CoordTip::hidden()
-{
-  TRACE;
-  _coordTip=nullptr;
+  _coordTip->hide();
 }
 
 } // namespace SciFigs
