@@ -128,6 +128,7 @@ namespace SciFigs {
     _printBottomMargin=0.5;
     _transparency=255;
     _mask=false;
+    _moveSelection=false;
   }
 
   /*!
@@ -869,7 +870,7 @@ namespace SciFigs {
     } else if(fileFormat.toLower()=="layer") {
       AxisWindow * w=qobject_cast<AxisWindow *>(this);
       if(w) {
-        w->graphContent()->saveLayers(fileName);
+        w->graphContents()->saveLayers(fileName);
       }
     } else {
       exportImage(fileName, fileFormat, dpi);
@@ -892,10 +893,9 @@ namespace SciFigs {
     if(fileName.isEmpty()) {
       fileName=Message::getSaveFileName(tr("Export image as ..." ), allImageFilter);
     }
-    if(fileName.length() > 0) {
+    if(fileName.length()>0) {
       if(imageFormat.isEmpty()) {
-        imageFormat=Settings::getFilter("filter-"+QString::number(qHash( allImageFilter))).
-                                        section(' ', 0, 0);
+        imageFormat=Settings::getFilter(Message::filterKey(allImageFilter)).section(' ', 0, 0);
       }
       if(imageFormat=="PDF") {
         QPrinter printer(QPrinter::HighResolution);
@@ -905,7 +905,7 @@ namespace SciFigs {
         printer.setOutputFileName(fileName);
         printer.setOutputFormat(QPrinter::PdfFormat);
         print(printer);
-      } else if(imageFormat =="SVG") {
+      } else if(imageFormat=="SVG") {
         printSvg(fileName, dpi);
       } else {
         QPixmap pixmap=image(dpi);
@@ -1012,21 +1012,22 @@ namespace SciFigs {
     gen.setResolution(dpi);
     double resolution=dpi/2.54;
     double factor=resolution/SciFigsGlobal::screenResolution();
-    double hMargins=_printLeftMargin + _printRightMargin;
-    double vMargins=_printTopMargin + _printBottomMargin;
+    double hMargins=_printLeftMargin+_printRightMargin;
+    double vMargins=_printTopMargin+_printBottomMargin;
     FontScales originalFonts;
     scaleFonts(originalFonts, factor);
     setPrintSize(resolution);
-    int totalw=(int) (( _printWidth + hMargins) * resolution);
-    int totalh=(int) (( _printHeight + vMargins) * resolution);
-    gen.setSize(QSize( totalw, totalh) );
+    int totalw=qRound((_printWidth+hMargins)*resolution);
+    int totalh=qRound((_printHeight+vMargins)*resolution);
+    gen.setSize(QSize(totalw, totalh));
+    gen.setViewBox(QRect(0, 0, totalw, totalh));
     QPainter p;
     p.begin(&gen);
     if(!_mask) {
       p.eraseRect(0, 0, totalw, totalh);
     }
     p.save();
-    p.translate( -(printLeft() - _printLeftMargin) * resolution, -(printTop() - _printTopMargin) * resolution);
+    p.translate(-(printLeft()-_printLeftMargin)*resolution, -(printTop()-_printTopMargin)*resolution);
     print(p, resolution, 0, 0, false);
     p.restore();
     p.end();
@@ -1044,7 +1045,7 @@ namespace SciFigs {
     if(fileName.isEmpty()) {
       fileName=Message::getSaveFileName(tr("Save object as a page"), tr("Page file (*.page)"));
     }
-    if(fileName.length() > 0) {
+    if(fileName.length()>0) {
       XMLSciFigs s;
       s.saveFile(fileName, this, XMLSciFigs::Page);
     }
@@ -1114,9 +1115,9 @@ namespace SciFigs {
   void GraphicObject::restoreMakeUp(QString fileName)
   {
     TRACE;
-    static QString title=tr( "Open an exisiting make-up" );
+    static QString title=tr("Open an exisiting make-up");
     if(fileName.isEmpty()) {
-      fileName=Message::getOpenFileName(title, tr( "Graph make-up (*.mkup)" ));
+      fileName=Message::getOpenFileName(title, tr("Graph make-up (*.mkup)"));
     }
     if(fileName.length() > 0) {
       XMLErrorReport xmler(XMLErrorReport::Read);
@@ -1128,10 +1129,10 @@ namespace SciFigs {
     }
   }
 
-  uint GraphicObject::_category=PropertyProxy::uniqueId();
-  uint GraphicObject::_tabId=PropertyProxy::uniqueId();
-  uint GraphicObject::_tabGeomery=PropertyProxy::uniqueId();
-  uint GraphicObject::_tabPrint=PropertyProxy::uniqueId();
+  uint GraphicObject::_category=PropertyCategory::uniqueId();
+  uint GraphicObject::_tabId=PropertyTab::uniqueId();
+  uint GraphicObject::_tabGeomery=PropertyTab::uniqueId();
+  uint GraphicObject::_tabPrint=PropertyTab::uniqueId();
 
   PropertyProxy * GraphicObject::proxy() const
   {
@@ -1145,7 +1146,7 @@ namespace SciFigs {
   void GraphicObject::addProperties(PropertyProxy * pp)
   {
     TRACE;
-    if( !pp->setCurrentCategory(_category) ) {
+    if(!pp->setCurrentCategory(_category)) {
       pp->addCategory(_category, tr("Object"), QIcon( ":graphicobject.png"));
     }
     if(pp->setCurrentTab(_tabId)) {
@@ -1332,6 +1333,27 @@ namespace SciFigs {
     }
   }
 
+  /*!
+    Refresh all after changing the property value. Used from Python.
+  */
+  void GraphicObject::setProperty(const QVariant& val, const QMetaProperty& p)
+  {
+    TRACE;
+    if(strcmp(p.name(), "printX")==0) {
+      setProperty(_tabGeomery, GraphicObjectGeometryProperties::X, val);
+    } else if(strcmp(p.name(), "printY")==0) {
+      setProperty(_tabGeomery, GraphicObjectGeometryProperties::Y, val);
+    } else if(strcmp(p.name(), "printWidth")==0) {
+      setProperty(_tabGeomery, GraphicObjectGeometryProperties::Width, val);
+    } else if(strcmp(p.name(), "printHeight")==0) {
+      setProperty(_tabGeomery, GraphicObjectGeometryProperties::Height, val);
+    } else {
+      p.write(this, val);
+      emit positionChanged();
+      emit sizeChanged();
+    }
+  }
+
   void GraphicObject::updateGeometryProperties(PropertyProxy * pp)
   {
     TRACE;
@@ -1540,6 +1562,7 @@ namespace SciFigs {
   }
 
   // Dirty method to avoid crash under Mac
+  // This is an old bug, TODO test if it is still necessary
   static bool antiReccurFlag=true;
 
   void GraphicObject::enterEvent(QEvent *)
@@ -1708,7 +1731,7 @@ namespace SciFigs {
   void GraphicObject::setAnchor(QString pa)
   {
     TRACE;
-    if(pa.count()>=6) {
+    if(pa.size()>=6) {
       switch(pa[0].unicode()) {
       case 'T':
         if(pa=="TopLeft") {
