@@ -170,8 +170,9 @@ namespace SciFigs {
     PropertyProxy * proxy() const;
     virtual void addProperties(PropertyProxy * pp);
     virtual void removeProperties(PropertyProxy * pp);
-    virtual void properties(PropertyWidget * w) const;
-    virtual void setProperty(uint wid, int pid, QVariant val);
+    void properties(PropertyWidget * w) const;
+    void setProperty(uint wid, int pid, QVariant val);
+    Q_INVOKABLE void setProperty(const QVariant& val, const QMetaProperty& p);
     void updateGeometryProperties(PropertyProxy * pp);
     void showProperties(uint category);
 
@@ -208,10 +209,10 @@ namespace SciFigs {
     void wantToStartDragging();
     void draggedTo(QPoint p);
   protected:
-    virtual void xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const {qobject_writeProperties(this, this, s, context);}
-    virtual XMLMember xml_member(XML_MEMBER_ARGS) {return qobject_member(this, tag, attributes, context);}
-    virtual bool xml_setProperty(XML_SETPROPERTY_ARGS) {return qobject_setProperty(this, memberID, tag, attributes, content, context);}
-    virtual bool xml_polish(XML_POLISH_ARGS);
+    void xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const {qobject_writeProperties(this, this, s, context);}
+    XMLMember xml_member(XML_MEMBER_ARGS) {return qobject_member(this, tag, attributes, context);}
+    bool xml_setProperty(XML_SETPROPERTY_ARGS) {return qobject_setProperty(this, memberID, tag, attributes, content, context);}
+    bool xml_polish(XML_POLISH_ARGS);
 
     QAction * action(const QString& name);
 
@@ -222,13 +223,13 @@ namespace SciFigs {
     double scaleWidgetFonts(QWidget * w, double scale);
     virtual void paint(QPainter& p, double dotpercm, int w, int h, bool mask);
     // Mouse events
-    virtual void mousePressEvent (QMouseEvent * e);
-    virtual void mouseReleaseEvent (QMouseEvent * e);
-    virtual void mouseMoveEvent (QMouseEvent * e);
-    virtual void mouseDoubleClickEvent (QMouseEvent * e);
-    virtual void showEvent (QShowEvent * e);
-    virtual void enterEvent (QEvent * e);
-    virtual void leaveEvent (QEvent * e);
+    void mousePressEvent (QMouseEvent * e);
+    void mouseReleaseEvent (QMouseEvent * e);
+    void mouseMoveEvent (QMouseEvent * e);
+    void mouseDoubleClickEvent (QMouseEvent * e);
+    void showEvent (QShowEvent * e);
+    void enterEvent (QEvent * e);
+    void leaveEvent (QEvent * e);
 
     void updateMask();
 
