@@ -39,8 +39,6 @@
 #include "SciFigsPreferences.h"
 #include "GraphicObjectFactory.h"
 #include "GraphicObjectGroup.h"
-#include "AxisWindow.h"
-#include "TextEdit.h"
 #include "XMLSciFigs.h"
 #include "SciFigsGlobal.h"
 #include "MakeUpFilter.h"
@@ -62,7 +60,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
   */
 
   GraphicSheet::GraphicSheet(QWidget *parent) :
-      QScrollArea(parent), _pageSize()
+      QScrollArea(parent)
   {
     TRACE;
     setWidgetColor(this, Qt::white);
@@ -71,11 +69,15 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
 
     _statusBar=nullptr;
     _activeObject=nullptr;
-    new QShortcut(Qt::Key_Tab, this, SLOT(selectNextChild()));
-    new QShortcut(Qt::Key_Tab + Qt::CTRL, this, SLOT(addSelectNextChild()));
+    ;
+    new QShortcut(QKeySequence(Qt::Key_Tab), this, SLOT(selectNextChild()));
+    new QShortcut(QKeySequence(Qt::CTRL & Qt::Key_Tab), this, SLOT(addSelectNextChild()));
     _orderIndex=-1;
     _transparency=255;
     _transparentMask=false;
+    setPaperSize(QPageSize::A4);
+    _paperOrientation=QPageLayout::Portrait;
+
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     _dragDelay.setSingleShot(true);
     _dragDelay.setInterval(50);
@@ -165,9 +167,20 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
     proxy()->setValues();
   }
 
-  uint GraphicSheet::_category=PropertyProxy::uniqueId();
-  uint GraphicSheet::_tabPrint=PropertyProxy::uniqueId();
-  uint GraphicSheet::_tabPageSize=PropertyProxy::uniqueId();
+  void GraphicSheet::copyProperties(const GraphicSheet& o)
+  {
+    TRACE;
+    _transparency=o._transparency;
+    _transparentMask=o._transparentMask;
+    _paperUnit=o._paperUnit;
+    _paperWidth=o._paperWidth;
+    _paperHeight=o._paperHeight;
+    _paperOrientation=o._paperOrientation;
+  }
+
+  uint GraphicSheet::_category=PropertyCategory::uniqueId();
+  uint GraphicSheet::_tabPrint=PropertyTab::uniqueId();
+  uint GraphicSheet::_tabPageSize=PropertyTab::uniqueId();
 
   /*!
 
@@ -188,6 +201,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
       pp->addReference(this);
     } else {
       PageSizeProperties * w=new PageSizeProperties;
+      w->setSheet(this);
       pp->addTab(_tabPageSize, tr("Page size"), w, this);
     }
   }
@@ -211,7 +225,19 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
       w->setValue(GraphicSheetProperties::Transparency, transparency());
       w->setValue(GraphicSheetProperties::TransparentMask, transparentMask());
     } else if(w->id()==_tabPageSize) {
-      _pageSize.properties(w);
+      QPageSize::PageSizeId id=QPageSize::id(QSizeF(_paperWidth, _paperHeight),
+                                               _paperUnit, QPageSize::ExactMatch);
+      w->setValue(PageSizeProperties::PaperSize, PageSizeProperties::paperSize2item(id));
+      w->setValue(PageSizeProperties::Unit, PageSizeProperties::unit2item(_paperUnit));
+      static_cast<PageSizeProperties *>(w)->setUnit(_paperUnit);
+      w->setValue(PageSizeProperties::Orientation, PageSizeProperties::orientation2item(_paperOrientation));
+      if(_paperOrientation==QPageLayout::Portrait) {
+        w->setValue(PageSizeProperties::Width, _paperWidth);
+        w->setValue(PageSizeProperties::Height, _paperHeight);
+      } else {
+        w->setValue(PageSizeProperties::Width, _paperHeight);
+        w->setValue(PageSizeProperties::Height, _paperWidth);
+      }
     }
   }
 
@@ -228,10 +254,43 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
         break;
       }
     } else if(wid==_tabPageSize) {
-      _pageSize.setProperty(pid, val);
+      switch(pid) {
+      case PageSizeProperties::PaperSize:
+        setPaperSize(PageSizeProperties::item2paperSize(val.toInt()));
+        break;
+      case PageSizeProperties::Unit:
+        _paperUnit=PageSizeProperties::item2unit(val.toInt());
+        break;
+      case PageSizeProperties::Width:
+        if(_paperOrientation==QPageLayout::Portrait) {
+          _paperWidth=val.toDouble();
+        } else {
+          _paperHeight=val.toDouble();
+        }
+        break;
+      case PageSizeProperties::Height:
+        if(_paperOrientation==QPageLayout::Portrait) {
+          _paperHeight=val.toDouble();
+        } else {
+          _paperWidth=val.toDouble();
+        }
+        break;
+      case PageSizeProperties::Orientation:
+        _paperOrientation=PageSizeProperties::item2orientation(val.toInt());
+        break;
+      }
     }
   }
 
+  /*!
+    Used from Python.
+  */
+  void GraphicSheet::setProperty(const QVariant& val, const QMetaProperty& p)
+  {
+    TRACE;
+    p.write(this, val);
+  }
+
   /*!
     \fn GraphicObjectList GraphicSheet::objects() const
     Return the list of GraphicObject objects.
@@ -269,7 +328,11 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
   {
     TRACE;
     QAction * a=qobject_cast<QAction *>(sender());
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    if(!a || a->data().typeId()!=QMetaType::QString) return nullptr;
+#else
     if(!a || a->data().type()!=QVariant::String) return nullptr;
+#endif
     GraphicObject * obj=GraphicObjectFactory::instance()->create(a->data().toString());
     if(!obj) {
       qWarning("Unkwown class name %s", a->data().toString().toLatin1().data());
@@ -352,7 +415,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
     // Reset properties to default
     _transparency=255;
     _transparentMask=false;
-    _pageSize=PageSize();
+
   }
 
   void GraphicSheet::showObject(GraphicObject * obj)
@@ -496,6 +559,9 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
     _selection->update();
   }
 
+  /*!
+    Selects objects that are hit by rectangle \a r
+  */
   void GraphicSheet::selectObjects(const QRect& r, Qt::KeyboardModifiers m)
   {
     TRACE;
@@ -521,6 +587,36 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
     }
   }
 
+  /*!
+    Selects objects by their names
+  */
+  void GraphicSheet::selectObjects(const QStringList& names, Qt::KeyboardModifiers m)
+  {
+    TRACE;
+    if(!(m & Qt::ControlModifier)) {
+      unselectAll();
+    } else {
+      if(proxy()) {
+        proxy()->saveStates();
+      }
+    }
+    GraphicObject * w;
+    GraphicObjectList wList=objects();
+    int nSelected=0;
+    foreach(w, wList) {
+      if(names.contains(w->objectName())) {
+        APP_LOG(1, tr("Object '%1' selected\n").arg(w->objectName()));
+        selectObjects(w, Qt::ControlModifier);
+        nSelected++;
+      }
+    }
+    APP_LOG(1, tr("%1/%2 objects effectively selected\n").arg(nSelected).arg(names.size()));
+    if(proxy()) {
+      proxy()->restoreStates();
+      proxy()->setValues();
+    }
+  }
+
   void GraphicSheet::addSelection(GraphicObject * obj, GraphicObject::SelectionState s)
   {
     TRACE;
@@ -534,7 +630,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
   }
 
   /*!
-    Used only by GraphContent::zoom, GraphContent::unzoom and GraphicObject::keyPopupMenu()
+    Used only by GraphContents::zoom, GraphContents::unzoom and GraphicObject::keyPopupMenu()
     These functions are not used in general. Some general code review may eventuelly remove
     this function.
   */
@@ -604,7 +700,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
   }
 
   void GraphicSheet::printSize(double& x0, double& y0, double& x1, double& y1,
-                               double& mx0, double& my0, double& mx1, double& my1)
+                               double& mx0, double& my0, double& mx1, double& my1) const
   {
     TRACE;
     // iterate on all graphs
@@ -638,6 +734,42 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
     }
   }
 
+  /*!
+    Returns maximum printRight() of all objects (excluding margins)
+  */
+  double GraphicSheet::printRight() const
+  {
+    TRACE;
+    double maxV=-std::numeric_limits<double>::infinity();
+    GraphicObjectList objectList=objects();
+    GraphicObject * obj;
+    foreach(obj, objectList) {
+      double v=obj->printRight();
+      if(v>maxV) {
+        maxV=v;
+      }
+    }
+    return maxV;
+  }
+
+  /*!
+    Returns maximum printBottom() of all objects (excluding margins)
+  */
+  double GraphicSheet::printBottom() const
+  {
+    TRACE;
+    double maxV=-std::numeric_limits<double>::infinity();
+    GraphicObjectList objectList=objects();
+    GraphicObject * obj;
+    foreach(obj, objectList) {
+      double v=obj->printBottom();
+      if(v>maxV) {
+        maxV=v;
+      }
+    }
+    return maxV;
+  }
+
   void GraphicSheet::showOrderIndex(bool isOn)
   {
     TRACE;
@@ -690,7 +822,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
     _selection->update();
   }
 
-  int GraphicSheet::maximumResolution()
+  int GraphicSheet::maximumResolution() const
   {
     TRACE;
     GraphicObjectList objectList=objects();
@@ -710,7 +842,10 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
 
     If \a dpi is different from 0, it override the resolution specified in object properties.
   */
-  void GraphicSheet::exportFile(QString fileName, QString fileFormat, int dpi)
+  void GraphicSheet::exportFile(QString fileName,
+                                QString fileFormat,
+                                const QString& layerName,
+                                int dpi)
   {
     TRACE;
     if(fileFormat.isEmpty()) {
@@ -721,7 +856,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
       fileSave(fileName);
     } else if(fileFormat.toLower()=="layer") {
       selectAll();
-      saveLayers(fileName);
+      saveLayers(fileName, layerName);
     } else {
       exportImage(fileName, fileFormat, dpi);
     }
@@ -746,8 +881,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
     }
     if(!fileName.isEmpty()) {
       if(imageFormat.isEmpty()) {
-        imageFormat=Settings::getFilter("filter-"+QString::number(qHash(GraphicObject::allImageFilter))).
-                      section(' ', 0, 0);
+        imageFormat=Settings::getFilter(Message::filterKey(GraphicObject::allImageFilter)).section(' ', 0, 0);
       }
       if(imageFormat=="PDF") {
         QPrinter printer(QPrinter::HighResolution);
@@ -758,7 +892,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
         }
         printer.setOutputFileName(fileName);
         printer.setOutputFormat(QPrinter::PdfFormat);
-        printer.setPageLayout(_pageSize.pageLayout());
+        printer.setPageLayout(pageLayout());
         QApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
         print(printer);
       } else if(imageFormat=="SVG") {
@@ -879,23 +1013,24 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
 
     if(dpi==0) dpi=maximumResolution();
     double resolution=dpi/2.54;
-    double factor=resolution/SciFigsGlobal::screenResolution();
+    //double factor=resolution/SciFigsGlobal::screenResolution();
     // Find limits of actual sheet
     double x0, y0, x1, y1, mx0, my0, mx1, my1;
     // Scale fonts and eventually adjust size of object for printing
-    FontScales originalFonts;
+    //FontScales originalFonts;
     for(int i=0; i<nObjects; i++) {
       obj=objectList.at(i);
-      obj->scaleFonts(originalFonts, factor);
+      //obj->scaleFonts(originalFonts, factor);
       obj->setPrintSize(resolution);
     }
     printSize(x0, y0, x1, y1, mx0, my0, mx1, my1);
-    int totalw=qRound((mx1 - mx0) * resolution);
-    int totalh=qRound((my1 - my0) * resolution);
+    int totalw=qRound((mx1-mx0)*resolution);
+    int totalh=qRound((my1-my0)*resolution);
     QSvgGenerator gen;
     gen.setFileName(fileName);
     gen.setResolution(dpi);
     gen.setSize(QSize(totalw, totalh));
+    gen.setViewBox(QRect(0, 0, totalw, totalh));
     QPainter p;
     p.begin(&gen);
     if(!_transparentMask) p.eraseRect(0, 0, totalw, totalh);
@@ -910,12 +1045,11 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
       if(progress) progress->setValue(i);
     }
     p.restore();
-    SciFigsGlobal::footprint(p, resolution, totalw, totalh);
     p.end();
     // Restore fonts and eventually screen size of objects
     for(int i=0; i<nObjects; i++) {
       obj=objectList.at(i);
-      obj->restoreScaleFonts(originalFonts);
+      //obj->restoreScaleFonts(originalFonts);
       obj->setPrintSize(SciFigsGlobal::screenResolution());
     }
     if(progress) {
@@ -933,7 +1067,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
     } else {
       printer.setResolution(dpi);
     }
-    printer.setPageLayout(_pageSize.pageLayout());
+    printer.setPageLayout(pageLayout());
     if(Settings::printSetup(&printer)) {
       QApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
       print(printer);
@@ -1105,7 +1239,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
   /*!
     Save layers of selected axiswindows
   */
-  void GraphicSheet::saveLayers(QString fileName)
+  void GraphicSheet::saveLayers(QString fileName, const QString& layerName)
   {
     TRACE;
     QList<AxisWindow *> objectList=selectedObjects<AxisWindow>();
@@ -1115,11 +1249,11 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
     }
     if(fileName.isEmpty()) {
       fileName=Message::getSaveFileName(tr("Save layers as..."),
-                                              tr("Graph layers (*.layer)"));
+                                        tr("Graph layers (*.layer)"));
     }
     if(fileName.length() > 0) {
       if(objectList.count()==1) {
-        objectList.first()->graphContent()->saveLayers(fileName);
+        objectList.first()->graphContents()->saveLayers(fileName, layerName);
       } else {
         QFileInfo fi(fileName);
         QDir d(fi.absolutePath());
@@ -1130,7 +1264,8 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
           baseName=d.absoluteFilePath(fi.fileName() + "_%1");
         }
         for(int i=0; i<objectList.count(); i++) {
-          objectList.at(i)->graphContent()->saveLayers(baseName.arg(i, 4, 10, QChar('0')));
+          objectList.at(i)->graphContents()->saveLayers(baseName.arg(i, 4, 10, QChar('0')),
+                                                       layerName);
         }
       }
     }
@@ -1160,7 +1295,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
       }
       std::sort(fileNames.begin(), fileNames.end());
       for(int i=0; i<n; i++) {
-        objectList.at(i)->graphContent()->appendLayers(fileNames.at(i));
+        objectList.at(i)->graphContents()->appendLayers(fileNames.at(i));
       }
     }
   }
@@ -1742,7 +1877,8 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
   bool GraphicSheet::fileOpen()
   {
     TRACE;
-    QString fileName=Message::getOpenFileName(tr("Open an existing document"), tr("Page file (*.page)"));
+    QString fileName=Message::getOpenFileName(tr("Open an existing document"),
+                                              tr("Page file (*.page);; Layer file (*.layer)"));
     // Opening a file may take some time, refresh quickly after dialog disappeared
     QApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
     if(fileOpen(fileName)) {
@@ -1755,6 +1891,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
 
   /*!
     Load the .page file with a shift of \a dx and \a dy (in cm)
+    .layer file are also accepted if their extension is ".layer"
   */
   bool GraphicSheet::fileOpen(QString fileName, double dx, double dy)
   {
@@ -1769,24 +1906,38 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
       _loadedObjects.clear();
       XMLSciFigs s;
       XMLErrorReport xmler(XMLErrorReport::Read);
-      xmler.setTitle(tr("Open page file"));
-      xmler.setFileName(fileName);
-      if(xmler.exec(s.restoreFile(fileName, this, XMLSciFigs::Page))) {
-        // Move all loaded object by dx and dy
-        if(dx!=0.0 || dy!=0.0) {
-          GraphicObject * obj;
-          foreach (obj, _loadedObjects) {
-            obj->setPrintXAnchor(obj->printXAnchor()+dx);
-            obj->setPrintYAnchor(obj->printYAnchor()+dy);
-            moveObject(obj);
-          }
-        }
-        _loadedObjects.clear();
-        if(_currentFile.isEmpty()) {
-          _currentFile=fileName;
-          emit currentFileChanged(_currentFile);
-        }
+      if(fi.suffix()=="layer") {
+        AxisWindow * w=new AxisWindow;
+        w->setPrintAnchor(currentOrigin() + Point2D(1.0, 1.0));
+        w->setRemovable(true);
+        addObject(w);
+        autoResizeContent();
+        w->graphContents()->appendLayers(fileName);
+        Rect limits=w->graphContents()->boundingRect();
+        limits.enlarge(0.05, LinearScale, LinearScale);
+        w->xAxis()->setRange(limits.x1(), limits.x2());
+        w->yAxis()->setRange(limits.y1(), limits.y2());
         ret=true;
+      } else {
+        xmler.setTitle(tr("Open page file"));
+        xmler.setFileName(fileName);
+        if(xmler.exec(s.restoreFile(fileName, this, XMLSciFigs::Page))) {
+          // Move all loaded object by dx and dy
+          if(dx!=0.0 || dy!=0.0) {
+            GraphicObject * obj;
+            foreach (obj, _loadedObjects) {
+              obj->setPrintXAnchor(obj->printXAnchor()+dx);
+              obj->setPrintYAnchor(obj->printYAnchor()+dy);
+              moveObject(obj);
+            }
+          }
+          _loadedObjects.clear();
+          if(_currentFile.isEmpty()) {
+            _currentFile=fileName;
+            emit currentFileChanged(_currentFile);
+          }
+          ret=true;
+        }
       }
       if(_statusBar) {
         _statusBar->showMessage(QString());
@@ -1921,7 +2072,6 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
   void GraphicSheet::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
   {
     TRACE;
-    _pageSize.xml_save(s, context);
     GraphicObjectList objectList;
     XMLSciFigs * scifigsContext=static_cast<XMLSciFigs *>(context);
     if(scifigsContext->selection()) {
@@ -1942,42 +2092,42 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
   XMLMember GraphicSheet::xml_member(XML_MEMBER_ARGS)
   {
     TRACE;
-    if(tag==PageSize::xmlPageSizeTag) {
-      return XMLMember(&_pageSize);
+    if(tag=="PageSize") {  // kept for compatibility
+      return XMLMember(new XMLGenericItem("PageSize"), true);
     }
     static const QString tmp("objectName");
     XMLSciFigs * scifigsContext=static_cast<XMLSciFigs *>(context);
     XMLRestoreAttributeIterator it=attributes.find(tmp);
     if(it!=attributes.end()) {
       if(scifigsContext->data()) {
-        GraphicObject * obj=GraphicObjectFactory::instance()->create(tag.toString());
+        GraphicObject * obj=GraphicObjectFactory::instance()->create(tag.toStringBuffer());
         if(obj) {
           obj->setRemovable(true);
           addObject(obj, false);
           return XMLMember(obj);
         } else {
-          App::log(tr("Unknown object type %1\n").arg(tag.toString()) );
+          App::log(tr("Unknown object type %1\n").arg(tag.toStringView()) );
           return XMLMember(XMLMember::Unknown);
         }
       } else {
         GraphicObjectList list=objects();
-        GraphicObject * obj=list.findObject(tag.toString(), it.value().toString());
+        GraphicObject * obj=list.findObject(tag.toStringBuffer(), it.value().toStringBuffer());
         if(obj) {
           return XMLMember(obj);
         } else {
-          obj=list.findObject(tag.toString(), nullptr);
+          obj=list.findObject(tag.toStringBuffer(), nullptr);
           if(obj) {
             if(Message::warning(MSG_ID,"Restore",
                                      tr("Cannot find an object of type %1 and named %2,\n"
                                         "but an object of type %3 and named %4 has been found.\n"
                                         "Do you want to restore properties to this object?").
-                                     arg(tag.toString()).arg(it.value().toString()).
-                                     arg(tag.toString()).arg(obj->objectName()),
+                                     arg(tag.toStringView()).arg(it.value().toStringView()).
+                                     arg(tag.toStringView()).arg(obj->objectName()),
                                      Message::yes(),Message::no(), true)==Message::Answer0) {
               return XMLMember(obj);
             } else return XMLMember(XMLMember::Unknown);
           } else {
-            App::log(tr("Cannot find an object of type %1\n").arg(tag.toString()) );
+            App::log(tr("Cannot find an object of type %1\n").arg(tag.toStringView()));
             return XMLMember(XMLMember::Unknown);
           }
         }
@@ -1992,7 +2142,38 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
   {
     TRACE;
     Q_UNUSED(context)
-    if(child->xml_tagName()!=PageSize::xmlPageSizeTag) {
+    if(child->xml_tagName()=="PageSize") {  // Kept for compatibility
+      XMLGenericItem * item=static_cast<XMLGenericItem *>(child);
+      bool ok=true;
+      for(int i=item->childrenCount()-1; i>=0; i--) {
+        XMLGenericItem * value=item->childAt(i);
+        if(value->xml_tagName()=="unit") {
+          _paperUnit=convertUnit(value->value().toString(), ok);
+          if(!ok) {
+            App::log(tr("Bad paper unit '%1'\n").arg(value->value().toString()));
+          }
+        } else if(value->xml_tagName()=="width") {
+          _paperWidth=value->value().toDouble(&ok);
+          if(!ok) {
+            App::log(tr("Bad paper width '%1'\n").arg(value->value().toString()));
+          }
+        } else if(value->xml_tagName()=="height") {
+          _paperHeight=value->value().toDouble(&ok);
+          if(!ok) {
+            App::log(tr("Bad paper height '%1'\n").arg(value->value().toString()));
+          }
+        } else if(value->xml_tagName()=="orientation") {
+          _paperOrientation=convertOrientation(value->value().toString(), ok);
+          if(!ok) {
+            App::log(tr("Bad paper orientation '%1'\n").arg(value->value().toString()));
+          }
+        } else if(value->xml_tagName()=="paperSize") {
+          // ignored
+        } else {
+          App::log(tr("Unknown keyword '%1'\n").arg(value->xml_tagName()));
+        }
+      }
+    } else {
       showObject(static_cast<GraphicObject *>(child));
       _loadedObjects.append(static_cast<GraphicObject *>(child));
     }
@@ -2028,7 +2209,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
   GraphicObject * GraphicSheet::object(QString objectName)
   {
     TRACE;
-    return findChild<GraphicObject *>(objectName);;
+    return findChild<GraphicObject *>(objectName);
   }
 
   GraphicObject * GraphicSheet::object(int index)
@@ -2186,6 +2367,7 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
     AxisWindow * w=new AxisWindow;
     w->setObjectName("graph");
     addObject(w, true);
+    autoResizeContent();
     return w;
   }
 
@@ -2195,7 +2377,113 @@ const QString GraphicSheet::xmlGraphicSheetTag="GraphicSheet";
     TextEdit * te=new TextEdit;
     te->setTextAsData(true);
     addObject(te, true);
+    autoResizeContent();
     return te;
   }
 
+  LegendWidget * GraphicSheet::addLegend()
+  {
+    TRACE;
+    LegendWidget * w=new LegendWidget;
+    w->setObjectName("legend");
+    addObject(w, true);
+    autoResizeContent();
+    return w;
+  }
+
+  ColorMapWidget * GraphicSheet::addColorMap()
+  {
+    TRACE;
+    ColorMapWidget * w=new ColorMapWidget;
+    w->setObjectName("colorMap");
+    addObject(w, true);
+    autoResizeContent();
+    return w;
+  }
+
+  ImageWidget * GraphicSheet::addImage()
+  {
+    TRACE;
+    ImageWidget * w=new ImageWidget;
+    w->setObjectName("image");
+    addObject(w, true);
+    autoResizeContent();
+    return w;
+  }
+
+  void GraphicSheet::moveSelectionFrom(const GraphicSheet * o)
+  {
+    TRACE;
+    GraphicObjectList list=o->selectedObjects();
+    GraphicObject * obj;
+    foreach(obj, list) {
+      obj->setSelectionState(GraphicObject::None);
+      addObject(obj, true);
+    }
+  }
+
+  void GraphicSheet::setPaperUnit(const QString& v)
+  {
+    bool ok=true;
+    QPageSize::Unit u=convertUnit(v, ok);
+    if(ok) {
+      _paperUnit=u;;
+    }
+  }
+
+  QString GraphicSheet::paperUnitString() const
+  {
+    return convertUnit(_paperUnit);
+  }
+
+  void GraphicSheet::setPaperOrientation(const QString& v)
+  {
+    bool ok=true;
+    QPageLayout::Orientation o=convertOrientation(v, ok);
+    if(ok) {
+      _paperOrientation=o;;
+    }
+  }
+
+  QString GraphicSheet::paperOrientationString() const
+  {
+    return convertOrientation(_paperOrientation);
+  }
+
+  void GraphicSheet::setPaperSize(QPageSize::PageSizeId id)
+  {
+    TRACE;
+    if(id!=QPageSize::Custom) {
+      QPageSize ps(id);
+      if(!ps.isValid()) {
+        ps=QPageSize(QPageSize::A4);
+      }
+      _paperUnit=ps.definitionUnits();
+      _paperWidth=ps.definitionSize().width();
+      _paperHeight=ps.definitionSize().height();
+    }
+  }
+
+  QPageLayout GraphicSheet::pageLayout() const
+  {
+    TRACE;
+    QPageLayout l;
+    l.setMode(QPageLayout::FullPageMode);
+    l.setOrientation(_paperOrientation);
+    QPageSize ps(QSizeF(_paperWidth, _paperHeight), _paperUnit,
+                 QString(), QPageSize::ExactMatch);
+    l.setPageSize(ps);
+    return l;
+  }
+
+  ENUM_AS_STRING_BEGIN(GraphicSheet, Unit)
+  ENUM_AS_STRING_DATA_NAMESPACE_6(QPageSize,
+                                  Cicero, Didot, Inch,
+                                  Millimeter, Pica, Point);
+  ENUM_AS_STRING_END
+
+  ENUM_AS_STRING_BEGIN(GraphicSheet, Orientation)
+  ENUM_AS_STRING_DATA_NAMESPACE_2(QPageLayout, Landscape, Portrait);
+  ENUM_AS_STRING_END
+
 } // namespace SciFigs
