@@ -34,14 +34,17 @@
 #include "GraphicObjectList.h"
 #include "GraphicObject.h"
 #include "PageSize.h"
+#include "AxisWindow.h"
+#include "ColorMapWidget.h"
+#include "LegendWidget.h"
+#include "ImageWidget.h"
+#include "TextEdit.h"
 #include "SheetSelectionWidget.h"
 
 namespace SciFigs {
 
   class GraphicObject;
-  class AxisWindow;
-  class GraphContent;
-  class TextEdit;
+  class GraphContents;
   class OrderTip;
   class GraphicSheetProperties;
 
@@ -57,12 +60,16 @@ namespace SciFigs {
     // Use only in scripts
     Q_PROPERTY(int transparency READ transparency WRITE setTransparency)
     Q_PROPERTY(bool transparentMask READ transparentMask WRITE setTransparentMask)
+    Q_PROPERTY(QString paperUnit READ paperUnitString WRITE setPaperUnit)
+    Q_PROPERTY(double paperWidth READ paperWidth WRITE setPaperWidth)
+    Q_PROPERTY(double paperHeight READ paperHeight WRITE setPaperHeight)
+    Q_PROPERTY(QString paperOrientation READ paperOrientationString WRITE setPaperOrientation)
     DUMMY_PROPERTIES
   public:
     GraphicSheet(QWidget *parent=nullptr);
     ~GraphicSheet();
 
-    virtual const QString& xml_tagName() const {return xmlGraphicSheetTag;}
+    const QString& xml_tagName() const {return xmlGraphicSheetTag;}
     static const QString xmlGraphicSheetTag;
 
     void clear(bool force);
@@ -73,8 +80,11 @@ namespace SciFigs {
     int paletteCount();
     bool removeObject(GraphicObject * obj, bool force);
 
-    AxisWindow * addGraph();
-    TextEdit * addText();
+    Q_INVOKABLE AxisWindow * addGraph();
+    Q_INVOKABLE TextEdit * addText();
+    Q_INVOKABLE LegendWidget * addLegend();
+    Q_INVOKABLE ColorMapWidget * addColorMap();
+    Q_INVOKABLE ImageWidget * addImage();
     void addObject(GraphicObject * obj, bool show=true);
     void showObject(GraphicObject * obj);
 
@@ -88,7 +98,7 @@ namespace SciFigs {
     double printBottom();
     double printRight();
     // Find maximum printer resolution in all graphs (!! in dpi !!)
-    int maximumResolution();
+    int maximumResolution() const;
     template <typename T> inline QList<T *> findChildren(Qt::FindChildOptions option) const;
     GraphicObject * activeObject(const char * inherits=0);
     void print(QPrinter& printer);
@@ -105,8 +115,10 @@ namespace SciFigs {
 
     void addProperties(PropertyProxy * pp);
     void removeProperties(PropertyProxy * pp);
-    virtual void properties(PropertyWidget * w) const;
-    virtual void setProperty(uint wid, int pid, QVariant val);
+    void properties(PropertyWidget * w) const;
+    void setProperty(uint wid, int pid, QVariant val);
+    Q_INVOKABLE void setProperty(const QVariant& val, const QMetaProperty& p);
+    void copyProperties(const GraphicSheet& o);
 
     void setTransparency(int val) {_transparency=val;}
     void setTransparentMask(bool val);
@@ -114,10 +126,28 @@ namespace SciFigs {
     int transparency() const {return _transparency;}
     bool transparentMask() const {return _transparentMask;}
 
-    const PageSize& pageSize() const {return _pageSize;}
-    PageSize& pageSize() {return _pageSize;}
+    ENUM_AS_STRING_DECL_NAMESPACE(QPageSize, Unit)
+    ENUM_AS_STRING_DECL_NAMESPACE(QPageLayout, Orientation)
 
-    virtual QSize minimumSizeHind() const {return QSize(100,100);}
+    void setPaperSize(QPageSize::PageSizeId id);
+
+    QPageSize::Unit paperUnit() const {return _paperUnit;}
+    void setPaperUnit(QPageSize::Unit u) {_paperUnit=u;}
+    void setPaperUnit(const QString& v);
+    QString paperUnitString() const;
+
+    double paperWidth() const {return _paperWidth;}
+    void setPaperWidth(double w) {if(w>0.0) _paperWidth=w;}
+
+    double paperHeight() const {return _paperHeight;}
+    void setPaperHeight(double h) {if(h>0.0) _paperHeight=h;}
+
+    QPageLayout::Orientation paperOrientation() const {return _paperOrientation;}
+    void setPaperOrientation(QPageLayout::Orientation o) {_paperOrientation=o;}
+    void setPaperOrientation(const QString& v);
+    QString paperOrientationString() const;
+
+    QSize minimumSizeHint() const {return QSize(100,100);}
 
     bool isMouseTrackingActive() const;
     const QRect& mouseTrackingRect() const {return *_mouseTrackingRect;}
@@ -127,22 +157,30 @@ namespace SciFigs {
     template <typename T> QList<T *> selectedObjects() const;
     GraphicObjectList objects() const {return findChildren<GraphicObject>(Qt::FindDirectChildrenOnly);}
     GraphicObjectList selectedObjects() const {return selectedObjects<GraphicObject>();}
+
+    void moveSelectionFrom(const GraphicSheet * o);
+
+    void printSize(double& x0, double& y0, double& x1, double& y1,
+                   double& mx0, double& my0, double& mx1, double& my1) const;
+    double printRight() const;
+    double printBottom() const;
   protected:
-    virtual void mousePressEvent (QMouseEvent *e);
-    virtual void mouseReleaseEvent (QMouseEvent *e);
-    virtual void mouseMoveEvent(QMouseEvent *e);
-    virtual void resizeEvent(QResizeEvent *e);
+    void mousePressEvent (QMouseEvent *e);
+    void mouseReleaseEvent (QMouseEvent *e);
+    void mouseMoveEvent(QMouseEvent *e);
+    void resizeEvent(QResizeEvent *e);
     void addActions(QMenu * m);
     void addRecentFile(const QString& fileName);
   private:
     void printSvg(const QString& fileName, int dpi);
-    void printSize(double& x0, double& y0, double& x1, double& y1,
-                    double& mx0, double& my0, double& mx1, double& my1);
     void updatePageLimits(QPrinter& p);
+    QPageLayout pageLayout() const;
 
     bool _transparentMask;
     int _transparency;
-    PageSize _pageSize;
+    QPageSize::Unit _paperUnit;
+    double _paperWidth, _paperHeight;
+    QPageLayout::Orientation _paperOrientation;
 
     int _orderIndex;
     // Smartly remember the last loaded file
@@ -192,6 +230,7 @@ namespace SciFigs {
     bool selectAll(QString actionTitle);
     void unselectAll() {selectObjects(nullptr, Qt::NoModifier);}
     void selectObjects(const QRect& r, Qt::KeyboardModifiers m=Qt::NoModifier);
+    void selectObjects(const QStringList& names, Qt::KeyboardModifiers m=Qt::NoModifier);
     void selectObjects(GraphicObject * obj, Qt::KeyboardModifiers m=Qt::NoModifier);
     void select(GraphicObject * obj) {selectObjects(obj, Qt::NoModifier);}
     void addSelect(GraphicObject * obj)  {selectObjects(obj, Qt::ShiftModifier);}
@@ -208,8 +247,13 @@ namespace SciFigs {
     void moveObjects(Point2D delta);
     void resizeObject();
     void startDragging() {selectedObjects().startDragging();}
-    void exportFile(QString fileName=QString(), QString fileFormat=QString(), int dpi=0);
-    void exportImage(QString fileName=QString(), QString imageFormat=QString(), int dpi=0);
+    void exportFile(QString fileName=QString(),
+                    QString fileFormat=QString(),
+                    const QString& layerName=QString(),
+                    int dpi=0);
+    void exportImage(QString fileName=QString(),
+                     QString imageFormat=QString(),
+                     int dpi=0);
     QPixmap image(int dpi=0);
     void print(int dpi=0);
     void print(bool outputToFile, QString name, int dpi);
@@ -217,7 +261,8 @@ namespace SciFigs {
     void pasteMakeUp();
     void saveMakeUp(QString fileName=QString());
     void restoreMakeUp(QString fileName=QString());
-    void saveLayers(QString fileName=QString());
+    void saveLayers(QString fileName=QString(),
+                    const QString& layerName=QString());
     void appendLayers();
     virtual void update();
     virtual void deepUpdate();
@@ -233,17 +278,18 @@ namespace SciFigs {
     void alignGrid();
     void raiseSelection();
     void lowerSelection();
-    void showProperties(uint category=PropertyProxy::invalidId);
+    void showProperties(uint category=PropertyCategory::invalidId);
     void groupObjects();
     void ungroupObjects();
     void enterGroup();
     void exitGroup();
   protected:
-    virtual bool xml_polish(XML_POLISH_ARGS);
-    virtual void xml_polishChild(XML_POLISHCHILD_ARGS);
-    virtual void xml_writeChildren(XML_WRITECHILDREN_ARGS) const;
-    virtual XMLMember xml_member(XML_MEMBER_ARGS);
-    virtual bool xml_setProperty(XML_SETPROPERTY_ARGS) {return qobject_setProperty(this, memberID, tag, attributes, content, context);}
+    void xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const {qobject_writeProperties(this, this, s, context);}
+    void xml_writeChildren(XML_WRITECHILDREN_ARGS) const;
+    XMLMember xml_member(XML_MEMBER_ARGS);
+    bool xml_setProperty(XML_SETPROPERTY_ARGS) {return qobject_setProperty(this, memberID, tag, attributes, content, context);}
+    bool xml_polish(XML_POLISH_ARGS);
+    void xml_polishChild(XML_POLISHCHILD_ARGS);
   };
 
 
