@@ -28,7 +28,7 @@
 
 #include "GraphicSheetMenu.h"
 #include "AxisWindow.h"
-#include "GraphContent.h"
+#include "GraphContents.h"
 #include "TextEdit.h"
 
 namespace SciFigs {
@@ -39,9 +39,9 @@ GraphicSheetMenu::GraphicSheetMenu(QWidget* parent, Qt::WindowFlags f) :
   TRACE;
   _sheet.setObjectName("sheet");
   _childLayout=new QVBoxLayout(this);
-  _childLayout->setMargin(0);
+  _childLayout->setContentsMargins(0, 0, 0, 0);
   _childLayout->setSpacing(0);
-#if !defined(Q_OS_MAC) && !defined(UBUNTU_UNITY)
+#if !defined(Q_OS_DARWIN) && !defined(UBUNTU_UNITY)
   _menuBar=new QMenuBar(this);
   _childLayout->addWidget(_menuBar);
 #endif
@@ -55,7 +55,7 @@ QMenu * GraphicSheetMenu::addMenu(QString title)
   TRACE;
   QMenu * m=new QMenu(this);
   m->setTitle(title);
-#if !defined(Q_OS_MAC) && !defined(UBUNTU_UNITY)
+#if !defined(Q_OS_DARWIN) && !defined(UBUNTU_UNITY)
   _menuBar->addMenu(m);
 #endif
   _sheet.addMenu(m);
