@@ -30,7 +30,7 @@
 #include "GridProperties.h"
 #include "ColorMapProperties.h"
 #include "AxisWindow.h"
-#include "GraphContent.h"
+#include "GraphContents.h"
 #include "IrregularGrid2DDraw.h"
 #include "LayerLocker.h"
 #include "XMLSciFigs.h"
@@ -46,10 +46,10 @@ namespace SciFigs {
 const QString GridPlot::xmlGridPlotTag="GridViewer";
 
 GridPlot::GridPlot(AxisWindow * parent) :
-    GraphContentLayer(parent)
+    GraphContentsLayer(parent)
 {
   TRACE;
-  _colorMap.generateColorScale(20, ColorPalette::Hsv);
+  _colorMap.generate(0, 19);
   _showGrid=false;
   _smooth=true;
 }
@@ -59,8 +59,8 @@ GridPlot::~GridPlot()
   TRACE;
 }
 
-uint GridPlot::_tabColorMap=PropertyProxy::uniqueId();
-uint GridPlot::_tabGrid=PropertyProxy::uniqueId();
+uint GridPlot::_tabColorMap=PropertyTab::uniqueId();
+uint GridPlot::_tabGrid=PropertyTab::uniqueId();
 
 /*!
   Setup property editor
@@ -100,7 +100,7 @@ void GridPlot::properties(PropertyWidget * w) const
     w->setValue(GridProperties::ShowGrid, showGrid());
     w->setValue(GridProperties::Smooth, smooth());
     w->setValue(GridProperties::FillValue, fillValue());
-    w->setValue(GridProperties::FillValueInversed, 1.0/fillValue());
+    w->setValue(GridProperties::FillValueInverse, 1.0/fillValue());
     w->setValue(GridProperties::FillType, GridProperties::area2item(fillType()) );
   }
 }
@@ -121,11 +121,11 @@ void GridPlot::setProperty(uint wid, int pid, QVariant val)
     switch(pid) {
     case GridProperties::ShowGrid:
       setShowGrid(val.toBool());
-      graphContent()->deepUpdate();
+      graphContents()->deepUpdate();
       break;
     case GridProperties::Smooth:
       setSmooth(val.toBool());
-      graphContent()->deepUpdate();
+      graphContents()->deepUpdate();
       break;
     case GridProperties::FillType:
       setFillType(GridProperties::item2area(val.toInt()) );
@@ -133,7 +133,7 @@ void GridPlot::setProperty(uint wid, int pid, QVariant val)
     case GridProperties::FillValue:
       setFillValue(val.toDouble());
       break;
-    case GridProperties::FillValueInversed:
+    case GridProperties::FillValueInverse:
       setFillValue(1.0/val.toDouble());
     default:
       break;
@@ -151,7 +151,7 @@ void GridPlot::setColorMap(const ColorMap& map)
     LayerLocker ll(this);
     _colorMap=map;
     // This layer takes generally time to repaint (useless to repaint only this layer) 
-    graphContent()->deepUpdate();
+    graphContents()->deepUpdate();
     emit colorMapChanged(_colorMap);
   }
 }
@@ -186,7 +186,7 @@ void GridPlot::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
 {
   TRACE;
   _colorMap.xml_save(s, context);
-  GraphContentLayer::xml_writeChildren(s, context);
+  GraphContentsLayer::xml_writeChildren(s, context);
 }
 
 XMLMember GridPlot::xml_member(XML_MEMBER_ARGS)
@@ -196,7 +196,7 @@ XMLMember GridPlot::xml_member(XML_MEMBER_ARGS)
      tag=="ColorPalette") {       // Kept for compatibility
     return XMLMember(&_colorMap);
   }
-  return GraphContentLayer::xml_member(tag, attributes, context);
+  return GraphContentsLayer::xml_member(tag, attributes, context);
 }
 
 void GridPlot::xml_polishChild(XML_POLISHCHILD_ARGS)
@@ -215,11 +215,11 @@ void GridPlot::drawGrid2DBlock(const IrregularGrid2D& grid, ColorMap map,
                                    const LayerPainterRequest& lp, QPainter& p, const IrregularGrid2DDraw& d)
 {
   TRACE;
-  const GraphContentOptions& gc=lp.options();
+  const GraphContentsOptions& gc=lp.options();
   if(grid.nx()==0 || grid.ny()==0) return;
 
   // Draw all visible grid cells, taking care of axis order
-  lp.graphContent()->setProgressMaximum(d.ny);
+  lp.graphContents()->setProgressMaximum(d.ny);
   const double * valx, * valy=grid.valuePointer(d.stopix, d.stopiy);
   int y, dy;
   QColor col;
@@ -227,7 +227,7 @@ void GridPlot::drawGrid2DBlock(const IrregularGrid2D& grid, ColorMap map,
     if(gc.scaleY().isEffectivelyReversed()) {
       for(int iy=d.ny;iy > 0;iy-- ) {
         if(lp.terminated()) return;
-        lp.graphContent()->setProgressValue(d.ny-iy);
+        lp.graphContents()->setProgressValue(d.ny-iy);
         y=d.limy[ iy - 1 ];
         dy=d.limy[ iy ] - y;
         valx=valy;
@@ -242,7 +242,7 @@ void GridPlot::drawGrid2DBlock(const IrregularGrid2D& grid, ColorMap map,
     } else {
       for(int iy=d.ny;iy > 0;iy-- ) {
         if(lp.terminated()) return;
-        lp.graphContent()->setProgressValue(d.ny-iy);
+        lp.graphContents()->setProgressValue(d.ny-iy);
         y=d.limy[ iy ];
         dy=d.limy[ iy - 1 ] - y;
         valx=valy;
@@ -259,7 +259,7 @@ void GridPlot::drawGrid2DBlock(const IrregularGrid2D& grid, ColorMap map,
     if(gc.scaleY().isEffectivelyReversed()) {
       for(int iy=d.ny;iy > 0;iy-- ) {
         if(lp.terminated()) return;
-        lp.graphContent()->setProgressValue(d.ny-iy);
+        lp.graphContents()->setProgressValue(d.ny-iy);
         y=d.limy[ iy - 1 ];
         dy=d.limy[ iy ] - y;
         valx=valy;
@@ -274,7 +274,7 @@ void GridPlot::drawGrid2DBlock(const IrregularGrid2D& grid, ColorMap map,
     } else {
       for(int iy=d.ny;iy > 0;iy-- ) {
         if(lp.terminated()) return;
-        lp.graphContent()->setProgressValue(d.ny-iy);
+        lp.graphContents()->setProgressValue(d.ny-iy);
         y=d.limy[ iy ];
         dy=d.limy[ iy - 1 ] - y;
         valx=valy;
@@ -289,7 +289,7 @@ void GridPlot::drawGrid2DBlock(const IrregularGrid2D& grid, ColorMap map,
     }
   }
   if(lp.terminated()) return;
-  lp.graphContent()->setProgressValue(d.ny);
+  lp.graphContents()->setProgressValue(d.ny);
 }
 
 /*!
@@ -340,7 +340,7 @@ void GridPlot::drawGrid2DSmooth(const IrregularGrid2D& grid, ColorMap map,
                                 const LayerPainterRequest& lp, QPainter & p, IrregularGrid2DDraw& d)
 {
   TRACE;
-  const GraphContentOptions& gc=lp.options();
+  const GraphContentsOptions& gc=lp.options();
   if(grid.nx()==0 || grid.ny()==0) return;
   /*
     Variable description:
@@ -366,7 +366,6 @@ void GridPlot::drawGrid2DSmooth(const IrregularGrid2D& grid, ColorMap map,
   int ysc, ys, yi, nextYi, nextYs, nextYsR, dyi;
   double v1, v2, v3, v4, c13, v13, c24, v24, c;
   int coliY, coliX, nextColYs, nextColXs;
-  uint curCol;
   // Node vectors with global indexes
   int * gnodex, * gnodey;
 
@@ -422,32 +421,42 @@ void GridPlot::drawGrid2DSmooth(const IrregularGrid2D& grid, ColorMap map,
 
   w=imageMaxX-imageMinX+1;
   h=imageMaxY-imageMinY+1;
+#if(QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
+  QImage im(w, h, QImage::Format_RGBA64);
+  quint64 * imPtr=reinterpret_cast<quint64 *>(im.bits());
+  quint64 * imCell;
+  quint64 curCol;
+#else
   QImage im(w, h, QImage::Format_ARGB32);
+  quint32 * imPtr=reinterpret_cast<quint32 *>(im.bits());
+  quint32 * imCell;
+  quint32 curCol;
+#endif
   // Translate node screen coordinates to have them in image coordinates
   for(int xi=d.startix; notEnd(xi, d.stopix, dxi); xi+=dxi) gnodex[ xi ]-=imageMinX;
   for(int yi=d.startiy; notEnd(yi, d.stopiy, dyi); yi+=dyi) gnodey[ yi ]-=imageMinY;
-  uint * imPtr=(uint * ) im.bits();
+  TODO("Check this algorithm: dispersion curve look like shifted when option smooth is on.")
 
-  lp.graphContent()->setProgressMaximum(h);
+  lp.graphContents()->setProgressMaximum(h);
   yi=d.startiy;
   ysc=gnodey[ yi ];
-  while(notEnd( yi, d.stopiy, dyi) && ysc < h) {
+  while(notEnd( yi, d.stopiy, dyi) && ysc<h) {
     if(lp.terminated()) return;
-    lp.graphContent()->setProgressValue(ysc);
+    lp.graphContents()->setProgressValue(ysc);
     xi=d.startix;
-    xsc=gnodex[ xi ];
-    nextYi=yi + dyi;
-    if(nextYi >= grid.ny() || nextYi < 0) break;
-    nextYs=gnodey[ nextYi ];
+    xsc=gnodex[xi];
+    nextYi=yi+dyi;
+    if(nextYi>=grid.ny() || nextYi<0) break;
+    nextYs=gnodey[nextYi];
     v2=grid.value(xi, yi);
     v4=grid.value(xi, nextYi);
     double invDy=1.0/static_cast<double>(nextYs-ysc);
     c24=(v4-v2)*invDy;
-    while(notEnd( xi, d.stopix, dxi) && xsc < w) {
+    while(notEnd(xi, d.stopix, dxi) && xsc<w) {
       nextXi=xi + dxi;
-      if(nextXi >= grid.nx() || nextXi < 0) break;
+      if(nextXi>=grid.nx() || nextXi<0) break;
       xsc=gnodex[ xi ];
-      nextXs=gnodex[ nextXi ];
+      nextXs=gnodex[nextXi];
       v1=v2;
       v2=grid.value(nextXi, yi);
       v3=v4;
@@ -457,7 +466,7 @@ void GridPlot::drawGrid2DSmooth(const IrregularGrid2D& grid, ColorMap map,
       coliY=map.index(v1);
       if(ysc<0) ys=0; else ys=ysc;
       if(nextYs<h) nextYsR=nextYs; else nextYsR=h-1;
-      uint * imCell=imPtr+ys*w;
+      imCell=imPtr+ys*w;
       while(ys<=nextYsR) {
         double nextColYsD;
         if(v1<v3 && coliY<map.count()) {
@@ -479,36 +488,40 @@ void GridPlot::drawGrid2DSmooth(const IrregularGrid2D& grid, ColorMap map,
           v24=v2+c24*dys;
           c=(double)(nextXs-xsc)/(v24-v13);
           coliX=coliY;
-          if(xsc < 0) xs=0; else xs=xsc;
-          if(nextXs < w) nextXsR=nextXs; else nextXsR=w - 1;
-          while(xs <= nextXsR) {
-            curCol=static_cast<uint>(map.color(coliX).rgba());
+          if(xsc<0) xs=0; else xs=xsc;
+          if(nextXs<w) nextXsR=nextXs; else nextXsR=w-1;
+          while(xs<=nextXsR) {
+#if(QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
+            curCol=map.color(coliX).rgba64();
+#else
+            curCol=map.color(coliX).argb32();
+#endif
             double nextColXsD;
             if(v13 < v24 && coliX<map.count()) {
               nextColXsD= xsc+round((map.upperValue(coliX)-v13)*c);
-              if(nextColXsD > nextXsR)
+              if(nextColXsD>nextXsR)
                 nextColXs=nextXsR;
               else
                 nextColXs=(int)  nextColXsD;
-            } else if(v13 > v24 && coliX > 0) {
+            } else if(v13>v24 && coliX>0) {
               nextColXsD=xsc+round((map.lowerValue(coliX)-v13)*c);
               if(nextColXsD > nextXsR)
                 nextColXs=nextXsR;
               else
                 nextColXs=(int) nextColXsD;
             } else nextColXs=nextXsR;
-            while(xs <= nextColXs) {
+            while(xs<=nextColXs) {
               imCell[xs]=curCol;
               xs++;
             }
-            if(v13 < v24) coliX++;
-            else if(v13 > v24) coliX--;
+            if(v13<v24) coliX++;
+            else if(v13>v24) coliX--;
           }
           imCell+=w;
           ys++;
         }
-        if(v1 < v3) coliY++;
-        else if(v1 > v3) coliY--;
+        if(v1<v3) coliY++;
+        else if(v1>v3) coliY--;
       }
       xi=nextXi;
       xsc=nextXs;
@@ -517,7 +530,7 @@ void GridPlot::drawGrid2DSmooth(const IrregularGrid2D& grid, ColorMap map,
     ysc=nextYs;
   }
   if(lp.terminated()) return;
-  lp.graphContent()->setProgressValue(h);
+  lp.graphContents()->setProgressValue(h);
   p.drawImage(imageMinX, imageMinY, im);
 }
 
