@@ -32,16 +32,6 @@ namespace SciFigs {
 
 const QString LegendItem::xmlLegendItemTag="LegendItem";
 
-LegendItem& LegendItem::operator=(const LegendItem& o)
-{
-  TRACE;
-  _text=o._text;
-  _textColor=o._textColor;
-  _pen=o._pen;
-  _symbol=o._symbol;
-  return *this;
-}
-
 bool LegendItem::operator==(const LegendItem& o) const
 {
   TRACE;
@@ -86,10 +76,10 @@ bool LegendItem::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(context)
   switch(memberID) {
   case 0:
-    _text=content.toString();
+    _text=content.toStringBuffer();
     return true;
   case 1: {
-      QColor col(content.toString());
+      QColor col(content.toStringView());
       _textColor=col;
     }
     return true;
