@@ -158,7 +158,7 @@ QVariant LegendTableItem::data(const QModelIndex &index, int role) const
         case LegendTable::ColumnPenWidth:
           return _legend->pen(row).width();
         case LegendTable::ColumnPenStyle:
-          return LegendTable::penItem(_legend->pen(row).style());
+          return LegendTable::penItem(_legend->pen(row).lineStyle());
         case LegendTable::ColumnSymbolType:
           return LegendTable::symbolItem(_legend->symbol(row).type());
         case LegendTable::ColumnSymbolSize:
@@ -168,7 +168,7 @@ QVariant LegendTableItem::data(const QModelIndex &index, int role) const
         case LegendTable::ColumnSymbolPenWidth:
           return _legend->symbol(row).pen().width();
         case LegendTable::ColumnSymbolPenStyle:
-          return LegendTable::penItem(_legend->symbol(row).pen().style());
+          return LegendTable::penItem(_legend->symbol(row).pen().lineStyle());
         case LegendTable::ColumnSymbolBrushColor:
           return _legend->symbol(row).brush().color();
         case LegendTable::ColumnSymbolBrushStyle:
@@ -220,13 +220,13 @@ bool LegendTableItem::setData (const QModelIndex & index, const QVariant & value
       break;
     case LegendTable::ColumnPenStyle: {
         Pen p=_legend->pen(row);
-        p.setStyle(LegendTable::penStyle(value.toInt()) );
+        p.setLineStyle(LegendTable::penStyle(value.toInt()));
         _legend->setPen(row, p);
       }
       break;
     case LegendTable::ColumnSymbolType: {
         Symbol s=_legend->symbol(row);
-        s.setType(LegendTable::symbolType(value.toInt()) );
+        s.setType(LegendTable::symbolType(value.toInt()));
         _legend->setSymbol(row, s);
       }
       break;
@@ -259,7 +259,7 @@ bool LegendTableItem::setData (const QModelIndex & index, const QVariant & value
     case LegendTable::ColumnSymbolPenStyle: {
         Symbol s=_legend->symbol(row);
         Pen p=s.pen();
-        p.setStyle(LegendTable::penStyle(value.toInt()) );
+        p.setLineStyle(LegendTable::penStyle(value.toInt()));
         s.setPen(p);
         _legend->setSymbol(row, s);
       }
@@ -302,7 +302,7 @@ bool LegendTableItem::setData (const QModelIndex & index, const QVariant & value
   }
 }
 
-Qt::ItemFlags LegendTableItem::flags (const QModelIndex & index) const
+Qt::ItemFlags LegendTableItem::flags(const QModelIndex & index) const
 {
   if(index.row()<2) {
     return Qt::ItemIsEnabled;
