@@ -26,8 +26,8 @@
 ***************************************************************************/
 
 #include "LineLayer.h"
-#include "GraphContentLayerFactory.h"
-#include "GraphContent.h"
+#include "GraphContentsLayerFactory.h"
+#include "GraphContents.h"
 #include "GraphicObject.h"
 #include "XMLSciFigs.h"
 #include "LayerMouseTracking.h"
@@ -54,11 +54,12 @@ SYNONYM_GRAPHCONTENTLAYER(DynXYColorLines, "LineLayer")
 SYNONYM_GRAPHCONTENTLAYER(DynLine2DLayer, "LineLayer")
 
 LineLayer::LineLayer(AxisWindow * parent) :
-    GraphContentLayer(parent)
+    GraphContentsLayer(parent)
 {
   TRACE;
   _currentLine=-1;
   _errorBar=VerticalBar;
+  _signThreshold=-1.0;
   _lineEditor=nullptr;
   _referenceLine=nullptr;
   _pointOptions=nullptr;
@@ -137,14 +138,10 @@ void LineLayer::removeLine(int i)
 void LineLayer::removeLine(AbstractLine * l)
 {
   TRACE;
-  delete _lineEditor;
-  _lineEditor=nullptr;
   int i=_lines.indexOf(l);
-  if(i==_currentLine) _currentLine=-1;
-  LayerLocker ll(this);
-  delete l;
-  _lines.removeAt(i);
-  resetLayerProperties();
+  if(i>=0) {
+    removeLine(i);
+  }
 }
 
 void LineLayer::removeEmptyLines()
@@ -218,7 +215,7 @@ Legend LineLayer::legend() const
   return leg;
 }
 
-void LineLayer::setLegend(Legend legend)
+void LineLayer::setLegend(const Legend& legend)
 {
   TRACE;
   LayerLocker ll(this);
@@ -234,36 +231,20 @@ void LineLayer::setLegend(Legend legend)
 Rect LineLayer::boundingRect() const
 {
   TRACE;
-  QList<AbstractLine *>::const_iterator it;
-  // Find the first non null curve with valid points
-  AbstractLine * line=nullptr;
-  int j;
-  SAFE_UNINITIALIZED(j, 0)
-  for(it=begin() ;it!=end();++it) {
-    line=*it;
-    int n=line->count();
-    for(j=0;j < n;j++ ) {
-      if(line->isValid(j)) break;
-    }
-    if(j<n) break;
-  }
-  if(it==end()) {
-    return Rect();
-  }
-  Point p=line->point(j, _pointOptions);
-  Rect r(p.x(), p.y(), p.x(), p.y());
-  for( ;it!=end();++it) {
+  Rect r;
+  for(QList<AbstractLine *>::const_iterator it=begin();it!=end();++it) {
     AbstractLine& line=**it;
     int n=line.count();
-    for(int j=0;j < n;j++ ) {
-      if(line.isValid(j))
+    for(int j=0; j<n; j++) {
+      if(line.isValid(j)) {
         r.add(line.point(j, _pointOptions));
+      }
     }
   }
   return r;
 }
 
-inline void LineLayer::drawVerticalErrorBar(double x, double minY, double maxY, const GraphContentOptions& gc,
+inline void LineLayer::drawVerticalErrorBar(double x, double minY, double maxY, const GraphContentsOptions& gc,
                                             QPainter& p, Rect& r, int tickLength) const
 {
   TRACE;
@@ -283,7 +264,7 @@ inline void LineLayer::drawVerticalErrorBar(double x, double minY, double maxY,
   }
 }
 
-inline void LineLayer::drawHorizontalErrorBar(double y, double minX, double maxX, const GraphContentOptions& gc,
+inline void LineLayer::drawHorizontalErrorBar(double y, double minX, double maxX, const GraphContentsOptions& gc,
                                               QPainter& p, Rect& r, int tickLength) const
 {
   TRACE;
@@ -303,16 +284,16 @@ inline void LineLayer::drawHorizontalErrorBar(double y, double minX, double maxX
   }
 }
 
-void LineLayer::drawCurve(const GraphContentOptions& gc, QPainter& p, double dotpercm, int h,
+void LineLayer::drawCurve(const GraphContentsOptions& gc, QPainter& p, double dotpercm, int h,
                           Rect& r, const AbstractLine& line, int startAt, int endAt) const
 {
   TRACE;
   Point p1=line.point(startAt, _pointOptions);
-  QPoint pscreen1, pscreen2;
-  QPolygon ap(endAt-startAt);
+  QPointF pscreen1, pscreen2;
+  QPointF * polyline=new QPointF[endAt-startAt];
   Pen pen=line.pen();
   int j;
-  if(pen.style()!=Qt::NoPen) {
+  if(pen.lineStyle()!=Pen::NoLine) {
     if(line.isSelected()) { // set selection mark
       pen.setColor(Qt::red);
       double s=pen.width();
@@ -328,33 +309,45 @@ void LineLayer::drawCurve(const GraphContentOptions& gc, QPainter& p, double dot
         continue;
       }
       Point p2=line.point(j, _pointOptions);
-      if(gc.r2s(p1, p2, pscreen1, pscreen2)) {
-        gc.checkOrigin(pscreen1, pscreen2, h);
-        if(subCurveCount==0) {
-          // Still no point on the sub curve? Either very first point of curve or entering back into visible area
-          ap.setPoint(0, pscreen1);
-          subCurveCount=1;
-        } else if(ap.point(subCurveCount-1)!=pscreen1) {
-          // Gap in the curve because it extends out of the plot area
-          p.drawPolyline (ap.data(), subCurveCount);
-          ap.setPoint(0, pscreen1);
-          subCurveCount=1;
+      if(_signThreshold>0.0 &&
+         fabs(p2.y())>_signThreshold &&
+         fabs(p1.y())>_signThreshold &&
+         ((p2.y()>0.0 && p1.y()<0.0) ||
+          (p2.y()<0.0 && p1.y()>0.0))) {
+        if(subCurveCount>1) {
+          p.drawPolyline(polyline, subCurveCount);
         }
-        if(ap.point(subCurveCount-1)!=pscreen2) {
-          // draw a line only if distance between p1 and p2 is not null
-          ap.setPoint(subCurveCount, pscreen2);
-          subCurveCount++;
-        }
-      } else if(subCurveCount>1) {
-        p.drawPolyline (ap.data(), subCurveCount);
         subCurveCount=0;
+      } else {
+        if(gc.r2s(p1, p2, pscreen1, pscreen2)) {
+          gc.checkOrigin(pscreen1, pscreen2, h);
+          if(subCurveCount==0) {
+            // Still no point on the sub curve? Either very first point of curve or entering back into visible area
+            polyline[0]=pscreen1;
+            subCurveCount=1;
+          } else if(polyline[subCurveCount-1]!=pscreen1) {
+            // Gap in the curve because it extends out of the plot area
+            p.drawPolyline(polyline, subCurveCount);
+            polyline[0]=pscreen1;
+            subCurveCount=1;
+          }
+          if(polyline[subCurveCount-1]!=pscreen2) {
+            // draw a line only if distance between p1 and p2 is not null
+            polyline[subCurveCount]=pscreen2;
+            subCurveCount++;
+          }
+        } else if(subCurveCount>1) {
+          p.drawPolyline(polyline, subCurveCount);
+          subCurveCount=0;
+        }
       }
       p1=p2;
     }
     if(subCurveCount>1) {
-      p.drawPolyline (ap.data(), subCurveCount);
+      p.drawPolyline(polyline, subCurveCount);
     }
   }
+  delete [] polyline;
   Symbol sym=line.symbol();
   pen=sym.pen();
   if(line.isSelected()) { // set selection mark
@@ -363,7 +356,7 @@ void LineLayer::drawCurve(const GraphContentOptions& gc, QPainter& p, double dot
     double penWidth=sym.pen().width();
     penWidth=penWidth==0.0 ? 0.2 : penWidth*2.0;
     sym=Symbol(sym.type(), symSize,
-                     Pen(Qt::red, penWidth, sym.pen().style()),
+                     Pen(Qt::red, penWidth, sym.pen().lineStyle()),
                      Brush(Qt::red, sym.brush().style()) );
   }
   if(_errorBar!=NoBar) {
@@ -409,8 +402,9 @@ void LineLayer::drawCurve(const GraphContentOptions& gc, QPainter& p, double dot
 void LineLayer::paintData(const LayerPainterRequest& lp, QPainter & p, double dotpercm) const
 {
   TRACE;
+  p.setRenderHint(QPainter::Antialiasing, true);
   QList<AbstractLine *>::const_iterator it;
-  const GraphContentOptions& gc=lp.options();
+  const GraphContentsOptions& gc=lp.options();
   int h=lp.size().height();
   Rect r(gc.xVisMin(), gc.yVisMin(), gc.xVisMax(), gc.yVisMax());
   for(it=begin() ;it!=end(); ++it) {
@@ -441,6 +435,7 @@ void LineLayer::paintData(const LayerPainterRequest& lp, QPainter & p, double do
       }
     }
   }
+  p.setRenderHint(QPainter::Antialiasing, false);
 }
 
 void LineLayer::toggleTrackingAction(bool checked, int id)
@@ -552,7 +547,7 @@ bool LineLayer::mouseReleaseEvent (QMouseEvent * e, int id)
   TRACE;
   if(e->button()==Qt::LeftButton) {
     switch(id) {
-    case Select:    // This mode uses rectangle, hence directly handled by GraphContent
+    case Select:    // This mode uses rectangle, hence directly handled by GraphContents
       return false;
     case Pick:
       if(_currentLine>-1 && _currentLine<count()) {
@@ -561,8 +556,8 @@ bool LineLayer::mouseReleaseEvent (QMouseEvent * e, int id)
         LayerLocker ll(this);
         emit beginPointAdd(l, i);
         l->append();
-        l->setX(i, graphContent()->options().xs2r(e->pos().x()) );
-        l->setY(i, graphContent()->options().ys2r(e->pos().y()), _pointOptions);
+        l->setX(i, graphContents()->options().xs2r(e->pos().x()) );
+        l->setY(i, graphContents()->options().ys2r(e->pos().y()), _pointOptions);
         emit endPointAdd(l, i);
         deepUpdate();
       }
@@ -570,7 +565,7 @@ bool LineLayer::mouseReleaseEvent (QMouseEvent * e, int id)
     case PickOrdered:
       if(_currentLine>-1 && _currentLine<count()) {
         AbstractLine * l=_lines.at(_currentLine);
-        double x=graphContent()->options().xs2r(e->pos().x());
+        double x=graphContents()->options().xs2r(e->pos().x());
         int i, n=l->count();
         for(i=0; i<n; i++ ) {
           if(l->point(i, _pointOptions).x() > x) break;
@@ -579,7 +574,7 @@ bool LineLayer::mouseReleaseEvent (QMouseEvent * e, int id)
         emit beginPointAdd(l, i);
         l->insert(i);
         l->setX(i, x);
-        l->setY(i, graphContent()->options().ys2r(e->pos().y()), _pointOptions);
+        l->setY(i, graphContents()->options().ys2r(e->pos().y()), _pointOptions);
         emit endPointAdd(l, i);
         deepUpdate();
       }
@@ -644,7 +639,7 @@ bool LineLayer::trackRectangle(int, double rx1, double ry1, double rx2, double r
       line.setSelected(false);
     }
   }
-  graphContent() ->deepUpdate();
+  graphContents()->deepUpdate();
   return true;
 }
 
@@ -661,7 +656,7 @@ void LineLayer::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
     value="reference";
     _referenceLine->xml_save(s, &lineContext, att);
   }
-  for(int i=0; i< n ; i++) {
+  for(int i=0; i<n; i++) {
     if(line(i)->count()>0) {
       value=QString::number(i);
       _lines.at(i)->xml_save(s, &lineContext, att);
@@ -679,14 +674,18 @@ XMLMember LineLayer::xml_member(XML_MEMBER_ARGS)
     if(tag==_referenceLine->xml_tagName()) {
       correctType=true;
     } else { // Recognition of synonyms when comparing to reference type
-      AbstractLine * line=LineFactory::instance()->create(tag.toString());
+      AbstractLine * line=LineFactory::instance()->create(tag.toStringBuffer());
       correctType=line ? (line->xml_tagName()==_referenceLine->xml_tagName()) : false;
       delete line;
     }
     if(correctType) {
       AbstractLine * line;
       XMLRestoreAttributeIterator it=attributes.find(att);
-      if(it!=attributes.end() && it.value().toString()=="reference") {
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+      if(it!=attributes.end() && it.value().toStringView()==QLatin1StringView("reference")) {
+#else
+      if(it!=attributes.end() && it.value().toStringBuffer()=="reference") {
+#endif
         line=_referenceLine;
       } else {
         if(scifigsContext->data()) {
@@ -697,8 +696,9 @@ XMLMember LineLayer::xml_member(XML_MEMBER_ARGS)
             App::log(tr("Make-up for line: index attribute is mising\n") );
             return XMLMember(XMLMember::Skip);
           }
-          int index=it.value().toInt();
-          if(index<0 || index>=_lines.count()) {
+          bool ok=true;
+          int index=it.value().toInt(ok);
+          if(!ok || index<0 || index>=_lines.count()) {
             App::log(tr("Make-up for line: index is out of range\n") );
             return XMLMember(XMLMember::Skip);
           }
@@ -708,10 +708,14 @@ XMLMember LineLayer::xml_member(XML_MEMBER_ARGS)
       return XMLMember(line, false, new LineLayerContext(scifigsContext, _pointOptions));
     }
   } else {
-    AbstractLine * line=LineFactory::instance()->create(tag.toString());
+    AbstractLine * line=LineFactory::instance()->create(tag.toStringBuffer());
     if(line) {
       XMLRestoreAttributeIterator it=attributes.find(att);
-      if(it!=attributes.end() && it.value().toString()=="reference") {
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+      if(it!=attributes.end() && it.value().toStringView()==QLatin1StringView("reference")) {
+#else
+      if(it!=attributes.end() && it.value().toStringBuffer()=="reference") {
+#endif
         setReferenceLine(line);
       } else if(scifigsContext->data()) { // For compatibility if reference line is missing
         setReferenceLine(line);
@@ -721,7 +725,7 @@ XMLMember LineLayer::xml_member(XML_MEMBER_ARGS)
       return XMLMember(line, false, new LineLayerContext(scifigsContext, _pointOptions));
     }
   }
-  return GraphContentLayer::xml_member(tag, attributes, context);
+  return GraphContentsLayer::xml_member(tag, attributes, context);
 }
 
 bool LineLayer::xml_setProperty(XML_SETPROPERTY_ARGS)
@@ -730,142 +734,25 @@ bool LineLayer::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(attributes)
   switch(memberID) {
   case 0: {
-      AbstractLine * line=LineFactory::instance()->create(content.toString());
+      AbstractLine * line=LineFactory::instance()->create(content.toStringBuffer());
       if(line) {
         setReferenceLine(line);
         return true;
       } else {
-        App::log(tr("Unknown line type: %1\n").arg(content.toString()) );
+        App::log(tr("Unknown line type: %1\n").arg(content.toStringView()) );
         return false;
       }
     }
   default:
-    return GraphContentLayer::xml_setProperty(memberID, tag, attributes, content, context);
+    return GraphContentsLayer::xml_setProperty(memberID, tag, attributes, content, context);
   }
 }
 
-void LineLayer::setPenColor(int curveIndex, int red, int green, int blue)
-{
-  TRACE;
-  if(curveIndex<count()) {
-    AbstractLine * l=_lines.at(curveIndex);
-    Pen p=l->pen();
-    p.setColor(QColor(red,green,blue));
-    LayerLocker ll(this);
-    l->setPen(p);
-  }
-}
-
-void LineLayer::setPenStyle(int curveIndex, double width, QString lineStyle,
-                            QString capStyle, QString joinStyle)
-{
-  TRACE;
-  if(curveIndex>=count()) return;
-  AbstractLine * l=_lines.at(curveIndex);
-  Pen p=l->pen();
-  p.setWidth(width);
-  p.setStyle(Pen::styleValue(lineStyle));
-  p.setCapStyle(Pen::capStyleValue(capStyle));
-  p.setJoinStyle(Pen::joinStyleValue(joinStyle));
-  LayerLocker ll(this);
-  l->setPen(p);
-}
-
-void LineLayer::setSymType(int curveIndex, QString type)
-{
-  TRACE;
-  if(curveIndex>=count()) return;
-  AbstractLine * l=_lines.at(curveIndex);
-  Symbol s=l->symbol();
-  s.setType(Symbol::symbolValue(type) );
-  LayerLocker ll(this);
-  l->setSymbol(s);
-}
-
-void LineLayer::setSymSize(int curveIndex, double size)
-{
-  TRACE;
-  if(curveIndex>=count()) return;
-  AbstractLine * l=_lines.at(curveIndex);
-  Symbol s=l->symbol();
-  s.setSize(size);
-  LayerLocker ll(this);
-  l->setSymbol(s);
-}
-
-void LineLayer::setSymPenColor(int curveIndex, int red, int green, int blue)
-{
-  TRACE;
-  if(curveIndex>=count()) return;
-  AbstractLine * l=_lines.at(curveIndex);
-  Symbol s=l->symbol();
-  Pen p=s.pen();
-  p.setColor(QColor(red,green,blue));
-  s.setPen(p);
-  LayerLocker ll(this);
-  l->setSymbol(s);
-}
-
-void LineLayer::setSymPenStyle(int curveIndex, double width,
-                               QString lineStyle, QString capStyle, QString joinStyle)
-{
-  TRACE;
-  if(curveIndex>=count()) return;
-  AbstractLine * l=_lines.at(curveIndex);
-  Symbol s=l->symbol();
-  Pen p=s.pen();
-  p.setWidth(width);
-  p.setStyle(Pen::styleValue(lineStyle));
-  p.setCapStyle(Pen::capStyleValue(capStyle));
-  p.setJoinStyle(Pen::joinStyleValue(joinStyle));
-  s.setPen(p);
-  LayerLocker ll(this);
-  l->setSymbol(s);
-}
-
-void LineLayer::setSymBrushColor(int curveIndex, int red, int green, int blue)
-{
-  TRACE;
-  if(curveIndex>=count()) return;
-  AbstractLine * l=_lines.at(curveIndex);
-  Symbol s=l->symbol();
-  Brush b=s.brush();
-  b.setColor(QColor(red,green,blue));
-  s.setBrush(b);
-  LayerLocker ll(this);
-  l->setSymbol(s);
-}
-
-void LineLayer::setSymBrushStyle(int curveIndex, QString brushStyle)
-{
-  TRACE;
-  if(curveIndex>=count()) return;
-  AbstractLine * l=_lines.at(curveIndex);
-  Symbol s=l->symbol();
-  Brush b=s.brush();
-  b.setStyle(Brush::styleValue(brushStyle) );
-  s.setBrush(b);
-  LayerLocker ll(this);
-  l->setSymbol(s);
-}
-
-void LineLayer::rmStdDev(int curveIndex)
-{
-  TRACE;
-  if(curveIndex>=count()) return;
-  AbstractLine& l=* _lines.at(curveIndex);
-  int n=l.count();
-  LayerLocker ll(this);
-  for(int i =0; i<n; i++) {
-    l.setZ(i, 0.0, _pointOptions);
-  }
-  resetLineProperties();
-}
 
 void LineLayer::setErrorBar(QString b)
 {
   TRACE;
-  if(b.count()>0) {
+  if(b.size()>0) {
     switch(b[0].unicode()) {
     case 'N':
       setErrorBar(NoBar);
@@ -903,22 +790,7 @@ QString LineLayer::errorBarString() const
   }
 }
 
-void LineLayer::attributesHelp()
-{
-  TRACE;
-  qDebug("SYMBOL TYPE: NoSymbol, Cross, Square, Circle, Triangle, "
-         "Losange, Star\n"
-         "PEN STYLE: NoPen, SolidLine, DashLine, DotLine, DashDotLine, "
-         "DashDotDotLine\n"
-         "PEN CAP STYLE: FlatCap, SquareCap, RoundCap\n"
-         "PEN JOIN STYLE: MiterJoin, BevelJoin, RoundJoin\n"
-         "BRUSH STYLES: NoBrush, SolidPattern, Dense1Pattern, Dense2Pattern, "
-         "Dense3Pattern, Dense4Pattern, Dense5Pattern, Dense6Pattern, "
-         "Dense7Pattern, HorPattern, VerPattern, CrossPattern, BDiagPattern, "
-         "FDiagPattern, DiagCrossPattern\n");
-}
-
-uint LineLayer::_tabLineLayer=PropertyProxy::uniqueId();
+uint LineLayer::_tabLineLayer=PropertyTab::uniqueId();
 
 /*!
   Setup property editor
@@ -947,6 +819,35 @@ void LineLayer::removeProperties(PropertyProxy * pp)
   }
 }
 
+void LineLayer::properties(PropertyWidget * w) const
+{
+  TRACE;
+
+  if(w->id()==_tabLineLayer) {
+    w->setValue(LineLayerProperties::SignThreshold, _signThreshold);
+    w->setValue(LineLayerProperties::ErrorBar, LineLayerProperties::errorBar2item(_errorBar));
+  }
+}
+
+/*!
+  Set value \a val to property \a id, after a user action in property editor
+*/
+void LineLayer::setProperty(uint wid, int pid, QVariant val)
+{
+  TRACE;
+  if(wid==_tabLineLayer) {
+    switch(pid) {
+    case LineLayerProperties::SignThreshold:
+      _signThreshold=val.toDouble();
+      break;
+    case LineLayerProperties::ErrorBar:
+      _errorBar=LineLayerProperties::item2errorBar(val.toInt());
+      break;
+    }
+    deepUpdate();
+  }
+}
+
 /*!
   Update the property tab, if active.
   Called automatically by clear(), removeLine(int i), removeLine(AbstractLine * l), removeEmptyLines(),
@@ -980,4 +881,32 @@ void LineLayer::resetLineProperties()
   }
 }
 
+bool LineLayer::canMerge(const GraphContentsLayer * o) const
+{
+  TRACE;
+  const LineLayer * layer=qobject_cast<const LineLayer *>(o);
+  if(!layer) {
+    return false;
+  }
+  int n=layer->count();
+  for(int i=0; i<n; i++) {
+    if(!_referenceLine->canCopy(*layer->line(i))) {
+      return false;
+    }
+  }
+  return true;
+}
+
+void LineLayer::merge(GraphContentsLayer * o)
+{
+  TRACE;
+  LineLayer * layer=qobject_cast<LineLayer *>(o);
+  ASSERT(layer);
+  int n=layer->count();
+  for(int i=0; i<n; i++) {
+    AbstractLine * mergedLine=addLine();
+    *mergedLine=*layer->line(i);
+  }
+}
+
 } // namespace SciFigs
