@@ -37,29 +37,33 @@ class SCIFIGS_EXPORT PlotLine2D : public AbstractLine
 {
   TRANSLATIONS("PlotLine2D")
 public:
-  virtual AbstractLine * clone() const;
-  virtual void operator=(const PlotLine2D& o);
+  PlotLine2D() {}
+  PlotLine2D(const PlotLine2D& o);
 
-  virtual int count() const {return _curve.count();}
-  virtual void clear() {_curve.clear();}
-  virtual void append() {_curve.append(Point2D());}
-  virtual void insert(int index) {_curve.insert(index, Point2D());}
-  virtual void removeLast() {_curve.remove(_curve.count()-1);}
-  virtual bool isSorted() const {return _curve.isSorted();}
-  virtual void checkSort() {_curve.checkSort();}
-  virtual void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
+  AbstractLine * clone() const;
+  void operator=(const AbstractLine& o);
+  bool canCopy(const AbstractLine& o) const;
+
+  int count() const {return _curve.count();}
+  void clear() {_curve.clear();}
+  void append() {_curve.append(Point2D());}
+  void insert(int index) {_curve.insert(index, Point2D());}
+  void removeLast() {_curve.remove(_curve.count()-1);}
+  bool isSorted() const {return _curve.isSorted();}
+  void checkSort() {_curve.checkSort();}
+  void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
     _curve.indexRange(xMin, xMax, indexMin, indexMax);
   }
-  virtual Point point(int index, const CurvePointOptions *) const {return _curve.constAt(index);}
-  virtual void setX(int index, double v) {_curve.setX(index, v);}
-  virtual void setY(int index, double v, const CurvePointOptions *) {_curve.setY(index, v);}
-  virtual void setZ(int, double, const CurvePointOptions *) {}
+  Point point(int index, const CurvePointOptions *) const {return _curve.constAt(index);}
+  void setX(int index, double v) {_curve.setX(index, v);}
+  void setY(int index, double v, const CurvePointOptions *) {_curve.setY(index, v);}
+  void setZ(int, double, const CurvePointOptions *) {}
 
   const Curve<Point2D>& curve() const {return _curve;}
   Curve<Point2D>& curve() {return _curve;}
   void setCurve(const Curve<Point2D>& curve);
   void setCurve(const Curve<Point2D>& curve, const Pen& pen, const Symbol& sym);
-  void setCurve(QVector<double> * dataX, QVector<double> * dataY);
+  void setCurve(VectorList<double> * dataX, VectorList<double> * dataY);
 protected:
   Curve<Point2D> _curve;
 };
