@@ -39,19 +39,34 @@ namespace SciFigs {
 
 const QString RealStatisticalLine::xmlRealStatisticalLineTag="RealStatisticalLine";
 
-REGISTER_LINE(RealStatisticalLine, "RealStatisticalLine" );
-SYNONYM_LINE(StatLine, "RealStatisticalLine" )
+REGISTER_LINE(RealStatisticalLine, "RealStatisticalLine" )
+SYNONYM_LINE(StatLine, "RealStatisticalLine")
+
+RealStatisticalLine::RealStatisticalLine(const RealStatisticalLine& o)
+  : AbstractLine(o)
+{
+  TRACE;
+  _curve=o._curve;
+}
 
 AbstractLine * RealStatisticalLine::clone() const
 {
-  RealStatisticalLine * l=new RealStatisticalLine;
-  *l=*this;
-  return l;
+  TRACE;
+  return new RealStatisticalLine(*this);
+}
+
+bool RealStatisticalLine::canCopy(const AbstractLine& o) const
+{
+  TRACE;
+  return dynamic_cast<const RealStatisticalLine *>(&o);
 }
 
 void RealStatisticalLine::operator=(const RealStatisticalLine& o)
 {
-  _curve=o._curve;
+  TRACE;
+  const RealStatisticalLine * co=dynamic_cast<const RealStatisticalLine *>(&o);
+  ASSERT(co);
+  _curve=co->_curve;
   AbstractLine::operator=(o);
 }
 
