@@ -36,34 +36,38 @@ namespace SciFigs {
 class SCIFIGS_EXPORT RealStatisticalLine : public AbstractLine
 {
 public:
-  virtual AbstractLine * clone() const;
-  virtual void operator=(const RealStatisticalLine& o);
+  RealStatisticalLine() {}
+  RealStatisticalLine(const RealStatisticalLine& o);
 
-  virtual const QString& xml_tagName() const {return xmlRealStatisticalLineTag;}
+  AbstractLine * clone() const;
+  void operator=(const RealStatisticalLine& o);
+  bool canCopy(const AbstractLine& o) const;
+
+  const QString& xml_tagName() const {return xmlRealStatisticalLineTag;}
   static const QString xmlRealStatisticalLineTag;
 
-  virtual int count() const {return _curve.count();}
-  virtual void clear() {_curve.clear();}
-  virtual void append() {_curve.append(RealStatisticalPoint());}
-  virtual void insert(int index) {_curve.insert(index, RealStatisticalPoint());}
-  virtual void removeLast() {_curve.remove(_curve.count()-1);}
-  virtual bool isValid(int index) const {return _curve.isValid(index);}
-  virtual void setValid(int index, bool v) {_curve.setValid(index, v);}
-  virtual bool isSorted() const {return _curve.isSorted();}
-  virtual void checkSort() {_curve.checkSort();}
-  virtual void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
+  int count() const {return _curve.count();}
+  void clear() {_curve.clear();}
+  void append() {_curve.append(RealStatisticalPoint());}
+  void insert(int index) {_curve.insert(index, RealStatisticalPoint());}
+  void removeLast() {_curve.remove(_curve.count()-1);}
+  bool isValid(int index) const {return _curve.isValid(index);}
+  void setValid(int index, bool v) {_curve.setValid(index, v);}
+  bool isSorted() const {return _curve.isSorted();}
+  void checkSort() {_curve.checkSort();}
+  void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
     return _curve.indexRange(xMin, xMax, indexMin, indexMax);
   }
-  virtual Point point(int index, const CurvePointOptions *) const;
-  virtual void setX(int index, double v) {_curve.setX(index, v);}
-  virtual void setY(int index, double v, const CurvePointOptions *) {_curve.constXAt(index).setMean(v);}
-  virtual void setZ(int index, double v, const CurvePointOptions *) {_curve.constXAt(index).setStddev(v);}
+  Point point(int index, const CurvePointOptions *) const;
+  void setX(int index, double v) {_curve.setX(index, v);}
+  void setY(int index, double v, const CurvePointOptions *) {_curve.constXAt(index).setMean(v);}
+  void setZ(int index, double v, const CurvePointOptions *) {_curve.constXAt(index).setStddev(v);}
 
-  const Curve<RealStatisticalPoint>& curve() const {return _curve;}
-  Curve<RealStatisticalPoint>& curve() {return _curve;}
-  void setCurve(const Curve<RealStatisticalPoint>& curve) {_curve=curve;}
+  const RealStatisticalCurve& curve() const {return _curve;}
+  RealStatisticalCurve& curve() {return _curve;}
+  void setCurve(const RealStatisticalCurve& curve) {_curve=curve;}
 protected:
-  Curve<RealStatisticalPoint> _curve;
+  RealStatisticalCurve _curve;
 };
 
 } // namespace SciFigs
