@@ -64,12 +64,13 @@ namespace SciFigs {
     TRACE;
     ASSERT(s!=GraphicObject::None);
 
-    if(s==GraphicObject::Hoover) { // Make sur that there is only one hoovered object
+    if(s==GraphicObject::Hoover) { // Make sure that there is only one hoovered object
       int n=_objects.count();
       for(int i=0; i<n; i++) {
         GraphicObject * obj=_objects.at(i);
         if(obj->selectionState()==GraphicObject::Hoover) {
           _objects.removeAt(i);
+          obj->setSelectionState(GraphicObject::None);
           i--;
           n--;
         }
@@ -78,12 +79,6 @@ namespace SciFigs {
     _objects.append(obj);
     obj->setSelectionState(s);
 
-    /*GraphicObjectList::const_iterator it;
-    qDebug() << "Selected objects:";
-    for(it=_objects.begin(); it!=_objects.end(); it++) {
-      GraphicObject * obj=*it;
-      qDebug() << "  " << obj->objectName();
-    }*/
     update();
   }
 
@@ -144,7 +139,7 @@ namespace SciFigs {
       GraphicObject * obj=_objects.at(i);
       switch (obj->selectionState()) {
       case GraphicObject::None:  // Unselected object should never be in object list
-        _objects.removeAt(i);    // but it may happen with aborted enter/exit events
+        _objects.removeAt(i);    // but it may happen with aborted enter/leave events
         i--;
         n--;
         continue;
