@@ -39,32 +39,14 @@ namespace SciFigs {
 const QString Symbol::xmlSymbolTag="Symbol";
 const Symbol Symbol::null;
 
-Symbol::Symbol(Type type,double size, Pen pen,Brush brush)
+Symbol::Symbol(Type type,double size, Pen pen, Brush brush)
 {
   _type=type;
-  _size=size;
-  if(_size<0) _size=0;
+  _size=size<0 ? 0 : size;
   _pen=pen;
   _brush=brush;
 }
 
-Symbol::Symbol(const Symbol& s) : XMLClass()
-{
-  _type=s._type;
-  _size=s._size;
-  _pen=s._pen;
-  _brush=s._brush;
-}
-
-Symbol& Symbol::operator=(const Symbol& o)
-{
-  _type=o._type;
-  _size=o._size;
-  _pen=o._pen;
-  _brush=o._brush;
-  return *this;
-}
-
 bool Symbol::operator==(const Symbol& o) const
 {
   TRACE;
@@ -74,12 +56,16 @@ bool Symbol::operator==(const Symbol& o) const
       && _brush==o._brush;
 }
 
+ENUM_AS_STRING_BEGIN(Symbol, Type)
+ENUM_AS_STRING_DATA_8(Circle, Cross, Losange, NoSymbol, Square, Star, TriangleDown, TriangleUp);
+ENUM_AS_STRING_END
+
 void Symbol::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
 {
   TRACE;
   Q_UNUSED(context)
-  writeProperty(s, "type",symbolName(_type));
-  writeProperty(s, "size",_size);
+  writeProperty(s, "type", convertType(_type));
+  writeProperty(s, "size", _size);
 }
 
 void Symbol::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
@@ -107,64 +93,19 @@ bool Symbol::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
+  bool ok=true;
   switch(memberID) {
   case 0:
-    _type=symbolValue(content.toString());
-    return true;
+    _type=convertType(content.toStringView(), ok);
+    return ok;
   case 1:
-    _size=content.toDouble();
-    return true;
+    _size=content.toDouble(ok);
+    return ok;
   default:
     return false;
   }
 }
 
-Symbol::Type Symbol::symbolValue(QString s)
-{
-  if(s.count()>=4) {
-    switch(s[2].unicode()) {
-    case 'o':
-      if(s=="Cross") return Cross;
-      break;
-    case 'u':
-      if(s=="Square") return Square;
-      break;
-    case 'i':
-      if(s=="TriangleUp") return TriangleUp;
-      else if(s=="TriangleDown") return TriangleDown;
-      else if(s=="Triangle") return TriangleDown;    // For compatibility
-      break;
-    case 'r':
-      if(s=="Circle") return Circle;
-      break;
-    case 's':
-      if(s=="Losange") return Losange;
-      break;
-    case 'a':
-      if(s=="Star") return Star;
-      break;
-    default:
-      break;
-    }
-  }
-  return NoSymbol;
-}
-
-QString Symbol::symbolName(Type s)
-{
-  TRACE;
-  switch (s) {
-  case Cross: return "Cross";
-  case Square: return "Square";
-  case Circle: return "Circle";
-  case TriangleUp: return "TriangleUp";
-  case TriangleDown: return "TriangleDown";
-  case Losange: return "Losange";
-  case Star: return "Star";
-  default: return "NoSymbol";
-  }
-}
-
 void Symbol::paint(QPainter& p, const QPointF& center, double dotpercm) const
 {
   TRACE;
@@ -177,31 +118,4 @@ void Symbol::paint(QPainter& p, const QPointF& center, double dotpercm) const
   p.restore();
 }
 
-/*QTextStream& operator>>(QTextStream& s, Symbol& sym)
-{
-  bool ok;
-  QString str=s.readLine().trimmed();
-  sym.setType((Type)str.section(" ",0,0).toInt(&ok));
-  if(!ok) goto error;
-  sym.setSize(str.section(" ",1,1).toDouble(&ok));
-  if(!ok) goto error;
-  Pen p;
-  s >> p;
-  sym.setPen(p);
-  str=s.readLine().trimmed();
-  int r=str.section(" ",0,0).toInt(&ok);
-  if(!ok) goto error;
-  int g=str.section(" ",1,1).toInt(&ok);
-  if(!ok) goto error;
-  int b=str.section(" ",2,2).toInt(&ok);
-  if(!ok) goto error;
-  _brush.setColor(QColor(r,g,b));
-  _brush.setStyle((Qt::BrushStyle)str.section(" ",3,3).toInt(&ok));
-  if(!ok) goto error;
-  return s;
-error:
-  Message::wrongTextFormat(s, translate("Symbol", "Restore symbol"));
-  return s;
-} */
-
 } // namespace SciFigs
