@@ -157,8 +157,8 @@ void TextEdit::adjustSize()
   }
 }
 
-uint TextEdit::_category=PropertyProxy::uniqueId();
-uint TextEdit::_tabFormat=PropertyProxy::uniqueId();
+uint TextEdit::_category=PropertyCategory::uniqueId();
+uint TextEdit::_tabFormat=PropertyTab::uniqueId();
 
 /*!
   Setup property editor
@@ -254,21 +254,20 @@ XMLMember TextEdit::xml_member(XML_MEMBER_ARGS)
 */
 bool TextEdit::xml_setProperty(XML_SETPROPERTY_ARGS)
 {
-  // TODO: why not usingg qobject properties? To avoid useless update/resize?
+  bool ok=true;
   switch(memberID) {
   case 0: {
       XMLSciFigs * scifigsContext=static_cast<XMLSciFigs *>(context);
       if(!scifigsContext->restoring() || !_textAsData || scifigsContext->data()) {
-        _text=content.toString();
+        _text=content.toStringBuffer();
       }
     }
     return true;
   case 1:
-    _font.fromString(content.toString());
-    return true;
+    return _font.fromString(content.toStringBuffer());
   case 2:
-    _adjustBox=content.toBool();
-    return true;
+    _adjustBox=content.toBool(ok);
+    return ok;
   default:
     return GraphicObject::xml_setProperty(memberID-3, tag, attributes, content, context);
   }
