@@ -29,7 +29,7 @@
 #include "XMLSciFigs.h"
 #include "XYColorLinesProperties.h"
 #include "AxisWindow.h"
-#include "GraphContentLayerFactory.h"
+#include "GraphContentsLayerFactory.h"
 #include "ColorMapProperties.h"
 #include "LayerPainterRequest.h"
 #include "LayerLocker.h"
@@ -50,7 +50,7 @@ XYValueLines::XYValueLines(AxisWindow * parent, bool autoDelete) :
 {
   TRACE;
   _values=nullptr;
-  _colorMap.generateColorScale(20, ColorPalette::Hsv);
+  _colorMap.generate(0, 19);
 }
 
 XYValueLines::~XYValueLines()
@@ -71,7 +71,7 @@ void XYValueLines::setColorMap(const ColorMap& map)
     LayerLocker ll(this);
     _colorMap=map;
     // This layer takes generally time to repaint (useless to repaint only this layer) 
-    graphContent()->deepUpdate();
+    graphContents()->deepUpdate();
     emit colorMapChanged(map);
   }
 }
@@ -86,7 +86,7 @@ void XYValueLines::setLinearColorMap(double minVal, double maxVal)
   LayerLocker ll(this);
   _colorMap.setValues(minVal, maxVal, SamplingParameters::Linear);
   // This layer takes generally time to repaint (useless to repaint only this layer) 
-  graphContent()->deepUpdate();
+  graphContents()->deepUpdate();
   emit colorMapChanged(colorMap());
 }
 
@@ -108,7 +108,7 @@ void XYValueLines::setValues(double * values)
   Convenience function to set the internal list of values from a dynamic vector of values.
   Returns the internal allocated list of values. Ownership depends upon the constructor of this object.
 */
-double * XYValueLines::setValues(const QVector<double>& values)
+double * XYValueLines::setValues(const VectorList<double>& values)
 {
   TRACE;
   LayerLocker ll(this);
@@ -123,7 +123,7 @@ double * XYValueLines::setValues(const QVector<double>& values)
   return _values;
 }
 
-uint XYValueLines::_tabColorMap=PropertyProxy::uniqueId();
+uint XYValueLines::_tabColorMap=PropertyTab::uniqueId();
 
 /*!
   Setup property editor
@@ -180,18 +180,18 @@ void XYValueLines::paintData(const LayerPainterRequest& lp, QPainter& p, double
   TRACE;
   if( !_curveCount) return ;
   const ColorMap map=_colorMap; // Copy to avoid disturbance during paint.
-  const GraphContentOptions& gc=lp.options();
+  const GraphContentsOptions& gc=lp.options();
   int height=lp.size().height();
   Point2D *p1=_points-1, *p2;
   int lineWeight=qRound(_lineWeight*dotpercm);
   if(lineWeight<1) lineWeight=1;
   QPen currentPen(Qt::black, lineWeight, Qt::SolidLine, Qt::SquareCap, Qt::RoundJoin);
-  lp.graphContent()->setProgressMaximum(_curveCount);
+  lp.graphContents()->setProgressMaximum(_curveCount);
   QColor col;
   if(_signChangeThreshold==0.0) {
     for(int i=0; i<_curveCount; i++) {
       if(lp.terminated()) return;
-      lp.graphContent()->setProgressValue(i);
+      lp.graphContents()->setProgressValue(i);
       int countPoints=_pointCounts[i];
       if(countPoints>0) {
         if(_values) {
@@ -206,7 +206,7 @@ void XYValueLines::paintData(const LayerPainterRequest& lp, QPainter& p, double
   } else {
     for(int i=0; i<_curveCount; i++) {
       if(lp.terminated()) return;
-      lp.graphContent()->setProgressValue(i);
+      lp.graphContents()->setProgressValue(i);
       int countPoints=_pointCounts[i];
       if(countPoints>0) {
         if(_values) {
@@ -219,7 +219,7 @@ void XYValueLines::paintData(const LayerPainterRequest& lp, QPainter& p, double
       }
     }
   }
-  lp.graphContent()->setProgressValue(_curveCount);
+  lp.graphContents()->setProgressValue(_curveCount);
 }
 
 /*!
