@@ -134,10 +134,10 @@ namespace TapePositioningSystem {
     qDeleteAll(quads);
   }
 
-  QVector<int> Triangulator::randomIndex(Random& generator, int n)
+  VectorList<int> Triangulator::randomIndex(Random& generator, int n)
   {
     TRACE;
-    QVector<int> index(n);
+    VectorList<int> index(n);
     for(int i=0; i<n; i++) {
       index[i]=i;
     }
@@ -159,7 +159,7 @@ namespace TapePositioningSystem {
     if(nq<=0) return;
     int trialCount=clusterCount*10;
     while(_clusters.count()<clusterCount && trialCount>0) {
-      QVector<int> quadIndex=randomIndex(generator, nq);
+      VectorList<int> quadIndex=randomIndex(generator, nq);
       ClusterQuads * parent=new ClusterQuads(*quads.at(quadIndex.first()));
       App::log(4, tr("------- NEW CLUSTER starting with %1 -------\n").arg(parent->name()));
       bool somethingAdded;
