@@ -63,7 +63,7 @@ namespace TapePositioningSystem {
     void orderedAggregate(QList<ClusterQuads *> quads);
     bool exhaustiveAggregate(ClusterQuads * parent, QList<ClusterQuads *> quads);
     void randomAggregate(int clusterCount, QList<ClusterQuads *> quads);
-    QVector<int> randomIndex(Random& generator, int n);
+    VectorList<int> randomIndex(Random& generator, int n);
 
     double _maxStddev;
     QMap<QString, Node *> _nodes;
