@@ -316,7 +316,7 @@ void InversionThread::run()
   if(_ns0>0) {
     App::log(tr("Generating %1 models randomly...\n").arg(_ns0));
     _models.setMaximumModelCount(_ns0);
-    _models.start(Thread::idealThreadCount(), Generator::MonteCarlo);
+    _models.start(CoreApplication::instance()->maximumThreadCount(), Generator::MonteCarlo);
     _models.wait();
     App::log(tr("Generated %1 models randomly\n").arg(_ns0));
   }
@@ -325,7 +325,7 @@ void InversionThread::run()
       Application::instance()->setStreamPrefix(QString());
       App::log(tr("Generating %1 models with Neighborhood...\n").arg(_ns));
       _models.setMaximumModelCount(_ns);
-      _models.start(Thread::idealThreadCount(), Generator::Neighborhood);
+      _models.start(CoreApplication::instance()->maximumThreadCount(), Generator::Neighborhood);
       _models.wait();
       _models.printActiveModels();
       App::log(tr("Generated %1 models with Neighborhood\n").arg(_ns));
@@ -338,7 +338,7 @@ void InversionThread::run()
       Application::instance()->setStreamPrefix(QString());
       App::log(tr("Generating %1 models with Borders...\n").arg(_nb));
       _models.setMaximumModelCount(_nb);
-      _models.start(Thread::idealThreadCount(), Generator::Borders);
+      _models.start(CoreApplication::instance()->maximumThreadCount(), Generator::Borders);
       _models.wait();
       _models.printActiveModels();
       App::log(tr("Generated %1 models with Borders\n").arg(_nb));
@@ -434,27 +434,28 @@ XMLMember InversionThread::xml_member(XML_MEMBER_ARGS)
 bool InversionThread::xml_setProperty(XML_SETPROPERTY_ARGS)
 {
   TRACE;
+  bool ok=true;
   switch(memberID) {
   case 0:
-    _itmax=content.toInt(); // Kept for compatibility
-    return true;
+    _itmax=content.toInt(ok); // Kept for compatibility
+    return ok;
   case 1:
-    _ns0=content.toInt();
-    return true;
+    _ns0=content.toInt(ok);
+    return ok;
   case 2:
-    _ns=content.toInt();
-    return true;
+    _ns=content.toInt(ok);
+    return ok;
   case 3:
-    _nr=content.toInt();
-    return true;
+    _nr=content.toInt(ok);
+    return ok;
   case 4:
-    _nw=content.toInt();
-    return true;
+    _nw=content.toInt(ok);
+    return ok;
   case 5:
-    _giveUp=content.toDouble();
-    return true;
+    _giveUp=content.toDouble(ok);
+    return ok;
   case 7: {
-      _reportFileName=content.toString();
+      _reportFileName=content.toStringBuffer();
       QFileInfo fi(_reportFileName);
       QObject::setObjectName(fi.baseName());
       WindowEnvironment::window(this)->logs()->setViewName(this, fi.baseName());
