@@ -53,10 +53,12 @@ MainWindow::MainWindow(QWidget *parent)
   liveUpdate->setName("dinver");
   liveUpdate->setVersion(DINVER_VERSION);
   liveUpdate->setVersionType(DINVER_VERSION_TYPE);
-
-  DinverPluginSettings reg;
-  liveUpdate->addPlugins(reg.pluginList());
+  {
+    DinverPluginSettings reg;
+    liveUpdate->addPlugins(reg.pluginList());
+  }
   statusBar()->addPermanentWidget(liveUpdate, 0);
+  liveUpdate->getLatestVersions();
 
   // Progress and status bar
   _progressBar=new ProgressBar(statusBar());
@@ -68,6 +70,7 @@ MainWindow::MainWindow(QWidget *parent)
   statusBar()->setSizeGripEnabled(true);
   statusBar()->showMessage(tr("Ready"), 2000);
 
+
   _logs=nullptr;
   _runs=nullptr;
   _status=nullptr;
@@ -749,19 +752,6 @@ ThreadList MainWindow::selectedThreads(bool& allOfTheSameType) const
  return _runs->threadTable->selectedThreads(allOfTheSameType);
 }
 
-ThreadList MainWindow::threads(QString t) const
-{
-  TRACE;
-  ThreadList l;
-  QRegExp trexp(t, Qt::CaseSensitive, QRegExp::Wildcard);
-  for(ThreadList::const_iterator it=_threads.begin(); it<_threads.end(); it++ ) {
-    if(trexp.exactMatch((*it)->objectName()) ) {
-      l.append( *it);
-    }
-  }
-  return l;
-}
-
 QStringList MainWindow::selectedReports(const QString& title) const
 {
   TRACE;
