@@ -28,9 +28,7 @@
 #ifndef ModelThreadInfo_H
 #define ModelThreadInfo_H
 
-#include <QList>
-#include <QVector>
-#include <QAbstractItemModel>
+#include <DinverCore.h>
 
 class InversionThread;
 class PSViewer;
@@ -50,7 +48,7 @@ private:
 
 typedef QList<InversionThread *> ThreadList;
 typedef QList<ModelThreadInfo> ModelThreadList;
-typedef QVector<PSViewer*> PSViewerVector;
+typedef VectorList<PSViewer*> PSViewerVector;
 typedef QList<PSViewer*> PSViewerList;
 
 inline ModelThreadInfo::ModelThreadInfo(const InversionThread * t, const SetIndex& index)
