@@ -329,13 +329,14 @@ bool AutocorrTargetWidget::loadMultiColumns(const ColumnTextParser * parser, con
 {
   TRACE;
   ColumnTextIterator it(parser);
-  QRegExp ringExp("from ([0-9\\.\\-+e]+) to ([0-9\\.\\-+e]+)");
+  QRegularExpression ringExp("from ([0-9\\.\\-+e]+) to ([0-9\\.\\-+e]+)");
+  QRegularExpressionMatch match;
   int nCurves=0;
   while(!it.atEnd()) {
     LineLayer * layer;
     QString comments=parser->sectionComments(it.currentSection());
-    if(ringExp.indexIn(comments)>-1) {
-      AutocorrRing ring(ringExp.cap(1).toDouble(), ringExp.cap(2).toDouble());
+    if(comments.indexOf(ringExp, 0, &match)>-1) {
+      AutocorrRing ring(match.captured(1).toDouble(), match.captured(2).toDouble());
       int ringIndex=addRing(ring);
       layer=_ringLayers.at(ringIndex);
     } else {
@@ -413,9 +414,15 @@ void AutocorrTargetWidget::loadCap(QString fileName)
       i--;
     } else {
       c.sort();
+      int firstIndex=0, lastIndex=c.count()-1;
+      c.firstValid(firstIndex);
+      c.lastValid(lastIndex);
       c.addLog(tr("Autocorrelation curves loaded from output CAP file %1.\n"
                    "%2 samples between %3 Hz. to %4 Hz.\n")
-                 .arg(fileName).arg(c.count()).arg(c.firstX()).arg(c.lastX()));
+               .arg(fileName)
+               .arg(c.count())
+               .arg(c.constAt(firstIndex).x())
+               .arg(c.constAt(lastIndex).x()));
     }
   }
   addCurves(newCurves);
@@ -431,6 +438,8 @@ void AutocorrTargetWidget::loadCapError(QTextStream& s)
 void AutocorrTargetWidget::loadNaViewerReport(QString fileName)
 {
   TRACE;
+  Q_UNUSED(fileName);
+  TODO_WARNING;
   /*QFileInfo fInfo(fileName);
   fileName=fInfo.absoluteFilePath();
   qtbError.reset(false);
