@@ -67,8 +67,8 @@ private:
 
   RingBrowser * _rings;
   GraphicSheet * _sheet;
-  QVector<TextEdit *> _ringLabels;
-  QVector<LineLayer *> _ringLayers;
+  VectorList<TextEdit *> _ringLabels;
+  VectorList<LineLayer *> _ringLayers;
 };
 
 #endif // AUTOCORRTARGETWIDGET_H
