@@ -50,6 +50,7 @@ EllipticityCurveTargetWidget::EllipticityCurveTargetWidget(QWidget* parent)
   LineLayer * l=new LineLayer(w);
   initLayer(l);
   setCurrentLayer(l);
+  l->setSignThreshold(45.0);
 }
 
 EllipticityCurveTargetWidget::~EllipticityCurveTargetWidget()
@@ -139,26 +140,26 @@ void EllipticityCurveTargetWidget::loadHVJSesame(QString fileName)
   while(!s.atEnd()) {
     QString str=s.readLine().trimmed().simplified();
     if(str.left(1)!="#") {
-      p.setX(str.section(QRegExp("[ \t]"), 0, 0).toDouble(&ok));
+      p.setX(str.section(QRegularExpression("[ \t]"), 0, 0).toDouble(&ok));
       if(ok) {
         double m, s;
-        m=Angle::radiansToDegrees(std::atan(str.section(QRegExp("[ \t]"), 1, 1).toDouble(&ok)));
+        m=Angle::radiansToDegrees(std::atan(str.section(QRegularExpression("[ \t]"), 1, 1).toDouble(&ok)));
         if(!ok) goto error;
-        s=str.section(QRegExp("[ \t]"), 4, 4).toDouble(&ok);
+        s=str.section(QRegularExpression("[ \t]"), 4, 4).toDouble(&ok);
         if(!ok) s=1.0;
         p.setMean(m);
         p.setStddev(0.5*(m*s-m+m-m/s));
         av.append(p);
-        m=Angle::radiansToDegrees(std::atan(str.section(QRegExp("[ \t]"), 2, 2).toDouble(&ok)));
+        m=Angle::radiansToDegrees(std::atan(str.section(QRegularExpression("[ \t]"), 2, 2).toDouble(&ok)));
         if(!ok) goto error;
-        s=str.section(QRegExp("[ \t]"), 5, 5).toDouble(&ok);
+        s=str.section(QRegularExpression("[ \t]"), 5, 5).toDouble(&ok);
         if(!ok) s=1.0;
         p.setMean(m);
         p.setStddev(0.5*(m*s-m+m-m/s));
         ns.append(p);
-        m=Angle::radiansToDegrees(std::atan(str.section(QRegExp("[ \t]"), 3, 3).toDouble(&ok)));
+        m=Angle::radiansToDegrees(std::atan(str.section(QRegularExpression("[ \t]"), 3, 3).toDouble(&ok)));
         if(!ok) goto error;
-        s=str.section(QRegExp("[ \t]"), 6, 6).toDouble(&ok);
+        s=str.section(QRegularExpression("[ \t]"), 6, 6).toDouble(&ok);
         if(!ok) s=1.0;
         p.setMean(m);
         p.setStddev(0.5*(m*s-m+m-m/s));
@@ -208,14 +209,14 @@ void EllipticityCurveTargetWidget::loadHVGeopsy(QString fileName)
       if(str.section("=", 0, 0).trimmed()=="# Number of windows")
         winCount=str.section( "=", 1, 1).toInt();
     } else {
-      p.setX(str.section(QRegExp( "[ \t]"), 0, 0).toDouble(&ok));
+      p.setX(str.section(QRegularExpression( "[ \t]"), 0, 0).toDouble(&ok));
       if(ok) {
-        mean=str.section(QRegExp("[ \t]"), 1, 1).toDouble(&ok);
+        mean=str.section(QRegularExpression("[ \t]"), 1, 1).toDouble(&ok);
         if(ok) {
           p.setMean(Angle::radiansToDegrees(std::atan(mean)));
-          err1=mean/str.section(QRegExp( "[ \t]"), 2, 2).toDouble(&ok);
+          err1=mean/str.section(QRegularExpression( "[ \t]"), 2, 2).toDouble(&ok);
           if(!ok) err1=0.0;
-          err2=str.section(QRegExp("[ \t]"), 3, 3).toDouble(&ok)/mean;
+          err2=str.section(QRegularExpression("[ \t]"), 3, 3).toDouble(&ok)/mean;
           if(!ok) err2=0.0;
           if(fabs(err1-err2)>1e-4) upDownEqual=false;
           p.setStddev(0.5*(err1+err2));
