@@ -167,9 +167,9 @@ void EllipticityPeakTargetWidget::loadHVGeopsy(QString fileName)
   while( !s.atEnd()) {
     QString str=s.readLine().trimmed().simplified();
     if(str.left(17)=="# f0 from windows" ) {
-      double f0=str.section(QRegExp( "[ \t]" ), 4, 4).toDouble();
+      double f0=str.section(QRegularExpression( "[ \t]" ), 4, 4).toDouble();
       f0Edit->setValue(f0);
-      devF0Edit->setValue(f0-str.section(QRegExp( "[ \t]" ), 5, 5).toDouble());
+      devF0Edit->setValue(f0-str.section(QRegularExpression( "[ \t]" ), 5, 5).toDouble());
     }
   }
 }
