@@ -48,7 +48,7 @@ ParamGroundModelWidget::ParamGroundModelWidget(QWidget *parent, Qt::WindowFlags
   TRACE;
   vboxLayout=new QVBoxLayout(this);
   vboxLayout->setSpacing(6);
-  vboxLayout->setMargin(0);
+  vboxLayout->setContentsMargins(0, 0, 0, 0);
 
   modelSheet=new QScrollArea;
   vboxLayout->addWidget(modelSheet);
@@ -63,12 +63,12 @@ ParamGroundModelWidget::ParamGroundModelWidget(QWidget *parent, Qt::WindowFlags
   QWidget * ccw=new QWidget(this);
   QVBoxLayout * ccLayout=new QVBoxLayout(ccw);
   ccLayout->setSpacing(6);
-  ccLayout->setMargin(0);
+  ccLayout->setContentsMargins(0, 0, 0, 0);
 
   QLabel * label=new QLabel(this);
   QFont font;
   font.setBold(true);
-  font.setWeight(75);
+  font.setWeight(QFont::Bold);
   label->setFont(font);
   label->setTextFormat(Qt::PlainText);
   label->setAlignment(Qt::AlignCenter);
