@@ -70,8 +70,8 @@ bool ExtTarget::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
   switch(memberID) {
-  case 0: _command=content.toString(); return true;
-  case 1: _workingDirectory=content.toString(); return true;
+  case 0: _command=content.toStringBuffer(); return true;
+  case 1: _workingDirectory=content.toStringBuffer(); return true;
   default: return false;
   }
 }
@@ -80,14 +80,18 @@ bool ExtTarget::isOk(int nParams)
 {
   TRACE;
   if(_command.isEmpty()) {
-    App::log(tr("Empty command, computing of misfit disabled. A uniform null misfit will be returned for each model.\n") );
+    App::log(tr("Empty command, computing of misfit disabled. A uniform null misfit will be returned for each model.\n"));
     return true;
   }
   QDir d(_workingDirectory);
+  // Make the command path absolute
+  if(!QDir::cleanPath(_command).startsWith("/")) {
+    _command=QDir::cleanPath(d.absoluteFilePath(_command));
+  }
   // Write fake 'parameter' file
   QFile fp(d.absoluteFilePath("parameters"));
   if(!fp.open(QIODevice::WriteOnly)) {
-    App::log(tr("Cannot write to file %1").arg(d.absoluteFilePath("parameters\n")) );
+    App::log(tr("Cannot write to file %1\n").arg(d.absoluteFilePath("parameters")));
     return false;
   }
   QTextStream s(&fp);
@@ -97,19 +101,25 @@ bool ExtTarget::isOk(int nParams)
   fp.close();
   QProcess p;
   p.setWorkingDirectory(_workingDirectory);
-  p.start(_command);
+  p.start(_command); // To be changed to startCommand in Qt6
   while(!p.waitForStarted (1000) && p.state()==QProcess::Starting) {}
   while(!p.waitForFinished (1000) && p.state()==QProcess::Running) {}
+  bool ret;
   switch(p.error()) {
   case QProcess::FailedToStart:
     App::log(tr("%1 failed to start. Either %1 is missing, or you may have insufficient permissions to invoke it.\n")
               .arg(_command));
-    return false;
+    ret=false;
+    break;
   case QProcess::Crashed:
     App::log(tr("%1 crashed some time after starting successfully.\n").arg(_command));
-    return false;
+    ret=false;
+    break;
   default:
+    ret=true;
     break;
   }
-  return true;
+  d.remove("parameters");
+  d.remove("misfit");
+  return ret;
 }
