@@ -23,7 +23,6 @@
 **
 ***************************************************************************/
 
-#include <signal.h>
 #include <ArrayCore.h>
 
 #include "geopsy-fkVersion.h"
@@ -32,9 +31,6 @@
 PACKAGE_INFO("geopsy-fk", GEOPSY_FK)
 
 ApplicationHelp * help();
-void showProgress(int);
-
-FKTool * tool=nullptr;
 
 bool options(int argc, char ** argv, FKParameters * param)
 {
@@ -45,11 +41,15 @@ bool options(int argc, char ** argv, FKParameters * param)
     if (arg[0]=='-') {
       if(arg=="-param-example") {
         if(CoreApplication::checkOptionArg(i, argc, argv, false)) {
-          if(!param->setProcessType(argv[i])) {
+          bool ok=true;
+          QString p(argv[i]);
+          FKParameters::ProcessType t=FKParameters::convertProcessType(p, ok);
+          if(!ok) {
             App::log(tr("Unrecognized process type '%1'\n").arg(argv[i]));
             return false;
           }
-          param->setDefaultValues(param->processType(), param->inversionMethod());
+          param->setProcessType(t);
+          param->setDefaultValues();
         }
         QTextStream(stdout) << param->AbstractParameters::toString()
                             << param->toString();
@@ -65,7 +65,7 @@ bool options(int argc, char ** argv, FKParameters * param)
             param->addCurveRefine(it->x(), it->y()*(1.0-refineRange), it->y()*(1.0+refineRange));
           }
         } else {
-          App::log(tr("Cannot open file '%1'\n") );
+          App::log(tr("Cannot open file '%1'\n").arg(argv[i]));
           return false;
         }
       } else if(arg=="-refine-range") {
@@ -87,11 +87,6 @@ int main(int argc, char ** argv)
   // No plugins are loaded, TODO: pre-parse options to activate plugins
   GeopsyCoreEngine gp(false);
   skipOpenBlasMultiThreading();
-#ifdef Q_OS_WIN
-  signal(30, showProgress);  // From the list available with 'kill -l'
-#else
-  signal(SIGUSR1, showProgress);
-#endif
   FKParameters * param=new FKParameters;
   CoreToolInterface gti;
   gti.setParameters(param);
@@ -107,40 +102,45 @@ int main(int argc, char ** argv)
   if(!gti.outputBaseName().isEmpty()) {
     param->setOutputBaseName(gti.outputBaseName());
   }
+  gti.showArguments();
   int n=gti.subPoolCount();
   for(int i=0; i<n; i++) {
-    tool=new FKTool;
     SubSignalPool array=gti.subPool(i);
-    if(!tool->setSubPool(&array)) {
-      App::log(tr("Error initializing group '%1'\n").arg(array.name()));
-      return 2;
+    QString outputFileName=param->outputName(gti.groupName(i));
+    if(gti.overwrite(outputFileName)) {
+      FKTool * tool=new FKTool(nullptr);
+      gti.setTool(tool);
+      if(!tool->setSubPool(&array)) {
+        App::log(tr("Error initializing group '%1'\n").arg(array.name()));
+        return 2;
+      }
+      // Set default values according to the available components and processing type
+      param->setDefaultValues(tool->array()->mode());
+      // Force values set by the user
+      param->setValues(*param);
+      *tool->parameters()=*param;
+      if(!tool->setLoop()) {
+        tool->waitFinished(0);
+        // K max solver not properly deleted without a event loop...
+        return 2;
+      }
+      tool->start(0, false);
+      tool->waitFinished(0);
+      tool->saveResults(outputFileName);
+      gti.setTool(nullptr);
+      delete tool;
+      tool=nullptr;
+      gp.cache()->free(); // Avoid to keep all signals from all groups in memory
     }
-    // Set default values according to the available components and processing type
-    param->setDefaultValues(param->processType(), param->inversionMethod());
-    // Force values set by the user
-    param->setValues(*param);
-    if(!tool->setParameters(*param)) {
-      tool->waitFinished();
-      // K max solver not properly deleted without a event loop...
-      return 2;
-    }
-    tool->start();
-    tool->waitFinished();
-    tool->results()->save(param->outputName(gti.groupName(i)), tool->log());
-    delete tool;
-    tool=nullptr;
-    gp.cache()->free(); // Avoid to keep all signals from all groups in memory
   }
+  HRFKRayleighSquared::showProcessingTime();
+  GridSearch1D::showProcessingTime();
+  GridSearch2D::showProcessingTime();
+  GridSearch3D::showProcessingTime();
+  ArrayStationSignals::showProcessingTime();
   return 0;
 }
 
-void showProgress(int)
-{
-  if(tool) {
-    tool->showProgress();
-  }
-}
-
 ApplicationHelp * help()
 {
   TRACE;
