@@ -33,12 +33,10 @@
 PACKAGE_INFO("geopsy-hv", GEOPSY_HV)
 
 ApplicationHelp * help();
-void showProgress(int);
 
 enum Mode {HV, Spectrum, HVRotate, SpectrumRotate};
 Mode mode=HV;
 QStringList timeWindowFiles;
-AbstractHVTool * tool=nullptr;
 
 bool postOptions(int& argc, char ** argv, HVParameters * param)
 {
@@ -88,11 +86,6 @@ int main(int argc, char ** argv)
   // No plugins are loaded, TODO: pre-parse options to activate plugins
   GeopsyCoreEngine gp(false);
   skipOpenBlasMultiThreading();
-#ifdef Q_OS_WIN
-  signal(30, showProgress);  // From the list available with 'kill -l'
-#else
-  signal(SIGUSR1, showProgress);
-#endif
 
   HVParameters * param=new HVParameters;
   CoreToolInterface gti;
@@ -106,33 +99,36 @@ int main(int argc, char ** argv)
   if(!CoreApplication::checkRemainingArgs(argc, argv)) {
     return 2;
   }
-  QDir outputDir(gti.outputBaseName());
+  gti.showArguments();
   int n=gti.subPoolCount();
   for(int i=0; i<n; i++) {
+    AbstractHVTool * tool=nullptr;
     switch(mode) {
     case HV:
-      tool=new HVTool;
+      tool=new HVTool(nullptr);
       break;
     case Spectrum:
-      tool=new SpectrumTool;
+      tool=new SpectrumTool(nullptr);
       break;
     case HVRotate:
-      tool=new HVRotateTool;
+      tool=new HVRotateTool(nullptr);
       break;
     case SpectrumRotate:
-      tool=new SpectrumRotateTool;
+      tool=new SpectrumRotateTool(nullptr);
       break;
     }
     if(!tool) {
       App::log(tr("Unsupported mode\n"));
       return 2;
     }
+    gti.setTool(tool);
     SubSignalPool subPool=gti.subPool(i);
     if(!tool->setSubPool(&subPool)) {
       App::log(tr("Error initializing group '%1'\n").arg(subPool.name()));
       return 2;
     }
-    if(!tool->setParameters(*param)) {
+    *tool->parameters()=*param;
+    if(!tool->setLoop()) {
       return 2;
     }
     if(timeWindowFiles.isEmpty()) {
@@ -142,24 +138,16 @@ int main(int argc, char ** argv)
         return 2;
       }
     }
-    tool->start();
-    tool->waitFinished();
-    App::log(tr("Saving to '%1'...\n").arg(outputDir.absolutePath()));
-    tool->save(outputDir);
+    tool->start(0, false);
+    tool->waitFinished(0);
+    tool->saveResults(gti.outputBaseName());
+    gti.setTool(nullptr);
     delete tool;
-    tool=nullptr;
     gp.cache()->free(); // Avoid to keep all signals from all groups in memory
   }
   return 0;
 }
 
-void showProgress(int)
-{
-  if(tool) {
-    tool->showProgress();
-  }
-}
-
 ApplicationHelp * help()
 {
   TRACE;
