@@ -32,9 +32,6 @@
 PACKAGE_INFO("geopsy-spac", GEOPSY_SPAC)
 
 ApplicationHelp * help();
-void showProgress(int);
-
-SPACTool * tool=nullptr;
 
 bool postOptions(int argc, char ** argv, SPACParameters * param)
 {
@@ -62,11 +59,6 @@ int main(int argc, char ** argv)
   // No plugins are loaded, TODO: pre-parse options to activate plugins
   GeopsyCoreEngine gp(false);
   skipOpenBlasMultiThreading();
-#ifdef Q_OS_WIN
-  signal(30, showProgress);  // From the list available with 'kill -l'
-#else
-  signal(SIGUSR1, showProgress);
-#endif
 
   SPACParameters * param=new SPACParameters;
   CoreToolInterface gti;
@@ -83,38 +75,37 @@ int main(int argc, char ** argv)
   if(!gti.outputBaseName().isEmpty()) {
     param->setOutputBaseName(gti.outputBaseName());
   }
+  gti.showArguments();
   int n=gti.subPoolCount();
   for(int i=0; i<n; i++) {
-    tool=new SPACTool;
-    SubSignalPool array=gti.subPool(i);
-    if(!tool->setSubPool(&array)) {
-      App::log(tr("Error initializing group '%1'\n").arg(array.name()));
-      return 2;
+    QString outputFileName=param->outputName(gti.groupName(i));
+    if(gti.overwrite(outputFileName+".target")) {
+      SPACTool * tool=new SPACTool(nullptr);
+      gti.setTool(tool);
+      SubSignalPool array=gti.subPool(i);
+      if(!tool->setSubPool(&array)) {
+        App::log(tr("Error initializing group '%1'\n").arg(array.name()));
+        return 2;
+      }
+      *tool->parameters()=*param;
+      if(!tool->setLoop()) {
+        tool->waitFinished(0);
+        // K max solver not properly deleted without an event loop...
+        return 2;
+      }
+      tool->start(0, false);
+      tool->waitFinished(0);
+      tool->results()->commitStatistics();
+      tool->results()->reportRejects();
+      tool->saveResults(outputFileName);
+      gti.setTool(nullptr);
+      delete tool;
+      gp.cache()->free(); // Avoid to keep all signals from all groups in memory
     }
-    if(!tool->setParameters(*param)) {
-      tool->waitFinished();
-      // K max solver not properly deleted without an event loop...
-      return 2;
-    }
-    tool->start();
-    tool->waitFinished();
-    tool->results()->commitStatistics();
-    tool->results()->reportRejects();
-    tool->results()->save(param->outputName(gti.groupName(i)), tool->log());
-    delete tool;
-    tool=nullptr;
-    gp.cache()->free(); // Avoid to keep all signals from all groups in memory
   }
   return 0;
 }
 
-void showProgress(int)
-{
-  if(tool) {
-    tool->showProgress();
-  }
-}
-
 ApplicationHelp * help()
 {
   TRACE;
