@@ -53,6 +53,12 @@ FileView::FileView(QWidget* parent)
   connect(sigDnD, SIGNAL(getSelection(SubSignalPool&)),
            this, SLOT(getSelection( SubSignalPool& )));
 
+  _removeAction=nullptr;
+  _copyPathAction=nullptr;
+  _graphicAction=nullptr;
+  _tableAction=nullptr;
+  _mapAction=nullptr;
+  _chronogramAction=nullptr;
   _menu=new QMenu(this);
   setContextMenuPolicy(Qt::DefaultContextMenu);
 
@@ -77,6 +83,11 @@ void FileView::addActions()
   _removeAction->setStatusTip(tr("Remove the selected files from this database (not on the disk for original files!)."));
   connect(_removeAction, SIGNAL(triggered()), this, SLOT(remove()));
 
+  _listReferencesAction=new QAction(this);
+  _listReferencesAction->setText(tr("List references"));
+  _listReferencesAction->setStatusTip(tr("List references to signals of selected files in the current list of groups."));
+  connect(_listReferencesAction, SIGNAL(triggered()), this, SLOT(listReferences()));
+
   _copyPathAction=new QAction(this);
   _copyPathAction->setText(tr("Copy path"));
   _copyPathAction->setStatusTip(tr("Copy the file paths of the selected files to the clipboard."));
@@ -159,8 +170,9 @@ void FileView::contextMenuEvent(QContextMenuEvent * e)
       _menu->addSeparator();
     }
     _menu->addAction(_removeAction);
+    _menu->addAction(_listReferencesAction);
     _menu->addAction(_copyPathAction);
-    _menu->popup(mapToGlobal( e->pos()) );
+    _menu->popup(mapToGlobal(e->pos()));
   }
 }
 
@@ -247,13 +259,49 @@ void FileView::remove()
   model()->remove(fList);
 }
 
+void FileView::listReferences()
+{
+  TRACE;
+  QList<SignalFile *> fList;
+  model()->getSelection(fList, *selectionModel());
+  if(fList.isEmpty()) {
+    App::log(tr("No file selected\n"));
+    return;
+  }
+  int n=0;
+  AbstractSignalGroup * g=Engine::instance()->database(this)->masterGroup();
+  for(QList<SignalFile *>::Iterator itf=fList.begin();itf!=fList.end();++itf) {
+    SignalFile * sf=*itf;
+    SubSignalPool subpool;
+    subpool.addFile(sf);
+    bool ref=false;
+    for(SubSignalPool::iterator its=subpool.begin(); its!=subpool.end(); its++) {
+      Signal * sig=*its;
+      if(g->contains(sig)) {
+        App::log(tr("Signal id %1 from file '%2' referenced in groups.\n")
+                 .arg(sig->id())
+                 .arg(sf->shortName()));
+        ref=true;
+        n++;
+        break;
+      }
+    }
+    if(!ref) {
+      App::log(tr("File '%1' is not referenced in groups\n").arg(sf->shortName()));
+    }
+  }
+  if(fList.count()>1) {
+    App::log(tr("%1/%2 files are referenced in groups\n").arg(n).arg(fList.count()));
+  }
+}
+
 void FileView::copyPath()
 {
   TRACE;
   QList<SignalFile *> fList;
   model()->getSelection(fList, *selectionModel());
   QString fileListStr;
-  int n=fileListStr.count()-1;
+  int n=fileListStr.size()-1;
   if(!fList.isEmpty()) {
     for(int i=0; i<n; i++) {
       fileListStr+=fList.at(i)->name()+"\n";
