@@ -55,12 +55,14 @@ public slots:
   SubPoolWindow * newChronogramWindow();
   void newTool();
   void remove();
+  void listReferences();
   void copyPath();
 protected:
   virtual void contextMenuEvent (QContextMenuEvent * e);
   virtual void mouseDoubleClickEvent (QMouseEvent * e);
 
   QAction * _removeAction;
+  QAction * _listReferencesAction;
   QAction * _copyPathAction;
   QAction * _graphicAction;
   QAction * _tableAction;
