@@ -42,7 +42,7 @@ GraphicWindow::GraphicWindow (QWidget* parent)
   TRACE;
   QVBoxLayout * l=new QVBoxLayout(this);
   l->setSpacing(2);
-  l->setMargin(1);
+  l->setContentsMargins(1, 1, 1, 1);
   setObjectName("graphic");
   AxisWindow * w=new AxisWindow(this);
   l->addWidget(w);
@@ -52,7 +52,7 @@ GraphicWindow::GraphicWindow (QWidget* parent)
 
   _signalLayer=new SignalDisplay(w);
   _signalLayer->setObjectName("graphic");
-  _signalLayer->subPoolUpdate(&subPool());
+  _signalLayer->setSubPoolWindow(this);
   _signalLayer->addTrackingAction(tr("Add gap"), SignalLayer::AddGaps, tr("Add gaps, e.g. to discard non-valid signal."));
   _signalLayer->addTrackingAction(tr("Remove gaps"), SignalLayer::RemoveGaps, tr("Remove gaps."));
   w->xAxis()->setScaleType(Scale::AbsoluteTime);
@@ -62,11 +62,11 @@ GraphicWindow::GraphicWindow (QWidget* parent)
   w->yAxis()->setSizeInfo(10.0);
 
   // Drag and drop to transfert signal selection
-  SigSelectionDnD * sigDnD=new SigSelectionDnD(w->graphContent());
+  SigSelectionDnD * sigDnD=new SigSelectionDnD(w->graphContents());
   connect(sigDnD, SIGNAL(selectionDropped(QWidget *, const SubSignalPool&)), this, SLOT(addSignals(QWidget *, const SubSignalPool&)));
   connect(sigDnD, SIGNAL(getSelection(SubSignalPool&)), this, SLOT(getSelection(SubSignalPool&)));
-  connect(w->graphContent(), SIGNAL(mouseTrackingBegin()), sigDnD, SLOT(disableFilter()));
-  connect(w->graphContent(), SIGNAL(mouseTrackingEnd()), sigDnD, SLOT(enableFilter()));
+  connect(w->graphContents(), SIGNAL(mouseTrackingBegin()), sigDnD, SLOT(disableFilter()));
+  connect(w->graphContents(), SIGNAL(mouseTrackingEnd()), sigDnD, SLOT(enableFilter()));
 
   // Time window layer
   _timeWindowLayer=new TimeWindowLayer(_signalLayer);
@@ -98,7 +98,7 @@ GraphicWindow::GraphicWindow (QWidget* parent)
   QString signalPlotProperties=reg.value("SignalPlot").toString();
   if(!signalPlotProperties.isEmpty()) {
     XMLSciFigs s;
-    s.restoreString(signalPlotProperties, _signalLayer->graphContent(), XMLSciFigs::MakeUp);
+    s.restoreString(signalPlotProperties, _signalLayer->graphContents(), XMLSciFigs::MakeUp);
   }
   // Custom make up
 
@@ -123,7 +123,7 @@ GraphicWindow::~GraphicWindow ()
   // Save as default properties
   QSettings& reg=CoreApplication::instance()->settings();
   XMLSciFigs s;
-  QString signalPlotProperties=s.saveString(_signalLayer->graphContent(), XMLSciFigs::MakeUp);
+  QString signalPlotProperties=s.saveString(_signalLayer->graphContents(), XMLSciFigs::MakeUp);
   reg.setValue("SignalPlot", signalPlotProperties);
 }
 
@@ -325,10 +325,10 @@ void GraphicWindow::showMagnify(bool show, int context, double time, Signal * si
       _magWin=new MagnifierSignal(this);
       _magWin->setContext(context);
       AxisWindow * w=_magWin->_signalLayer->graph();
-      w->graphContent()->setFocus(Qt::OtherFocusReason);
+      w->graphContents()->setFocus(Qt::OtherFocusReason);
       GeopsyGuiEngine::instance()->addSubWindow(this, _magWin);
       PickLayer * pl=pickLayer();
-      w->graphContent()->installEventFilter(pl);
+      w->graphContents()->installEventFilter(pl);
       w->xAxis()->setRange(0, time);
     }
     _magWin->setSignal(&subPool(), sig);
@@ -356,12 +356,17 @@ void GraphicWindow::setMagnifySignal(Signal * sig)
   if(_magWin) {
     _magWin->setSignal(&subPool(), sig);
      AxisWindow * w=_signalLayer->graph();
-    _magWin->setTime(w->graphContent()->options().xs2r(w->xAxis()->lastMousePosition()) );
+    _magWin->setTime(w->graphContents()->options().xs2r(w->xAxis()->lastMousePosition()) );
   }
 }
 
 void GraphicWindow::focusInEvent(QFocusEvent * e)
 {
   TRACE;
-  _signalLayer->graphContent()->setFocus(e->reason());
+  _signalLayer->graphContents()->setFocus(e->reason());
+}
+
+void GraphicWindow::updateEvents()
+{
+  _pickLayer->deepUpdate();
 }
