@@ -384,17 +384,17 @@ void GroupView::emptyGroup()
   }
 }
 
-void GroupView::select(const QRegExp& exp)
+void GroupView::select(const QRegularExpression& exp)
 {
   TRACE;
   selectionModel()->clear();
   select(Engine::instance()->database(this)->masterGroup(), exp);
 }
 
-void GroupView::select(AbstractSignalGroup * parent, const QRegExp& exp)
+void GroupView::select(AbstractSignalGroup * parent, const QRegularExpression& exp)
 {
   TRACE;
-  if(exp.indexIn(parent->name())>=0) {
+  if(parent->name().indexOf(exp)>=0) {
     QItemSelectionModel * sm=selectionModel();
     sm->select(model()->index(parent), QItemSelectionModel::Select);
   }
