@@ -84,7 +84,7 @@ void GroupWidget::on_mode_currentIndexChanged(int index)
 void GroupWidget::on_selectButton_clicked()
 {
   TRACE;
-  QRegExp exp(selectEdit->currentText());
+  QRegularExpression exp(selectEdit->currentText());
   Settings::setHistory("GroupWidgetSelect", exp.pattern());
   selectEdit->clear();
   selectEdit->addItems(Settings::getHistory("GroupWidgetSelect"));
