@@ -87,7 +87,7 @@ public slots:
   void seedlink(QByteArray serverAddress=nullptr, qint16 serverPort=0,
                 QString streamSelection=QString());
   void loadCity();
-  void quit(bool force=false);
+  void quit();
 
   // Edit menu
   void setTableLocked(bool l);
@@ -95,6 +95,7 @@ public slots:
   void setHeader();
   void setReceivers();
   void createNewGroup();
+  void gapsFromNaN();
   // View menu
   void viewSetDataFields();
   void fftTime();
@@ -111,6 +112,7 @@ public slots:
   void increaseProgressValue(int value=1);
   void hideProgressBar();
   void showMessage(QString message);
+  void updateGraphicEvents();
 private slots:
   void directoryMonitorDestroyed();
   void seedlinkDestroyed();
