@@ -28,19 +28,14 @@
 
 #include <QGpGuiTools.h>
 
-class SeismicEventDelegate : public QItemDelegate
+class SeismicEventDelegate : public ItemDelegate
 {
   Q_OBJECT
 public:
-  SeismicEventDelegate(QObject *parent=nullptr) : QItemDelegate(parent) {}
+  SeismicEventDelegate(QObject *parent=nullptr) : ItemDelegate(parent) {}
 
-  QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
+  QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &,
                         const QModelIndex &index) const;
-  void setEditorData(QWidget *editor, const QModelIndex &index) const;
-  void setModelData(QWidget *editor, QAbstractItemModel *model,
-                    const QModelIndex &index) const;
-signals:
-  void dataChanged() const;
 };
 
 #endif // SEISMICEVENTDELEGATE_H
