@@ -59,7 +59,10 @@ const char * ToolSeparator::interfaceVersion() const
   return GEOPSYCORE_VERSION;
 }
 
-ToolFactory::ToolFactory(QObject *parent)
+/*!
+  Parent is used in showTool()
+*/
+ToolFactory::ToolFactory(MainWindow * parent)
   : QObject(parent)
 {
   TRACE;
@@ -184,8 +187,11 @@ void ToolFactory::showTool()
   TRACE;
   QAction * a=qobject_cast<QAction *>(sender());
   if(a) {
-    SubPoolWindow * win=WindowEnvironment::window(a->parentWidget())->currentSubPoolWin();
-    showTool(win, a);
+    MainWindow * mw=qobject_cast<MainWindow *>(parent());
+    if(mw) {
+      SubPoolWindow * win=mw->currentSubPoolWin();
+      showTool(win, a);
+    }
   }
 }
 
@@ -292,6 +298,7 @@ void ToolFactory::showTool(SubPoolWindow * win, GeopsyGuiInterface * info, int s
       win->setTool(tool);
       tool->restoreFields();
     } else {
+      tool->closeChildren();
       delete tool;
     }
   }
