@@ -30,7 +30,7 @@
 #include "GraphicWindow.h"
 #include "WaveformConsole.h"
 #include "SubtractValue.h"
-#include "SubtractSignals.h"
+#include "OperandSignals.h"
 #include "AGC.h"
 #include "Taper.h"
 #include "CutSignal.h"
@@ -57,7 +57,7 @@ WaveformConsole::WaveformConsole(QWidget * parent, Qt::WindowFlags f)
   TRACE;
   setupUi(this);
   // Avoid systematic warning, noticed with Qt-5.14 on Catalina
-#ifdef Q_OS_MAC
+#ifdef Q_OS_DARWIN
   directCommand->setFontFamily("Courier");
   commandHistory->setFontFamily("Courier");
 #else
@@ -176,6 +176,13 @@ void WaveformConsole::addActions(QMenu * m)
   connect(a, SIGNAL(triggered()), this, SLOT(removeTrend()));
   m->addAction(a);
 
+  a=new QAction(tr("Add signals"), this);
+  a->setObjectName("AddSignals");
+  a->setShortcut(tr("Ctrl+Alt+Shift+A"));
+  a->setStatusTip(tr("Add signals to other signals"));
+  connect(a, SIGNAL(triggered()), this, SLOT(addSignals()));
+  m->addAction(a);
+
   a=new QAction(tr("Subtract signals"), this);
   a->setObjectName("S&ubtractSignals");
   a->setShortcut(tr("Ctrl+Alt+Shift+S"));
@@ -267,6 +274,12 @@ void WaveformConsole::addActions(QMenu * m)
   connect(a, SIGNAL(triggered()), this, SLOT(decimateTime()));
   m->addAction(a);
 
+  a=new QAction(tr("Random"), this);
+  a->setObjectName("Random");
+  a->setStatusTip(tr("Generate a random signal"));
+  connect(a, SIGNAL(triggered()), this, SLOT(random()));
+  m->addAction(a);
+
   m->addSeparator();
 
   a=new QAction(tr("Wavelet transf&orm"), this);
@@ -344,11 +357,38 @@ void WaveformConsole::subtractValue()
   delete d;
 }
 
+void WaveformConsole::addSignals()
+{
+  TRACE;
+  if(!_subPoolWin) return;
+  OperandSignals * d=new OperandSignals(this);
+  d->setWindowTitle(tr("Add signals"));
+  Settings::getWidget(d);
+  SubSignalPool& subPool=_subPoolWin->subPool();
+  d->setSubPool(&subPool);
+  if(d->exec()==QDialog::Accepted) {
+    Settings::setWidget(d);
+    if(d->bySignal->isChecked()) {
+      _subPoolWin->signalProcess()->addSignal(d->signalList->currentIndex());
+    } else {
+      AbstractSignalGroup * g=d->group();
+      if(g) {
+        _subPoolWin->signalProcess()->addSignals(g->pathName());
+      } else {
+        Message::warning(MSG_ID, tr("Add signals"), tr("No group was selected, nothing subtracted."));
+      }
+    }
+    processUpdate();
+  }
+  delete d;
+}
+
 void WaveformConsole::subtractSignals()
 {
   TRACE;
   if(!_subPoolWin) return;
-  SubtractSignals * d=new SubtractSignals(this);
+  OperandSignals * d=new OperandSignals(this);
+  d->setWindowTitle(tr("Subtract signals"));
   Settings::getWidget(d);
   SubSignalPool& subPool=_subPoolWin->subPool();
   d->setSubPool(&subPool);
@@ -575,6 +615,25 @@ void WaveformConsole::decimateTime()
   processUpdate();
 }
 
+void WaveformConsole::random()
+{
+  TRACE;
+  if(!_subPoolWin) return ;
+  bool ok;
+  QString text=Settings::getText(QApplication::activeWindow(),
+                                      tr("Generate random signal"),
+                                      tr("Maximum amplitude"),
+                                      QLineEdit::Normal, "2", &ok);
+  if(!ok) return;
+  double maxAmpl=text.toDouble(&ok);
+  if(!ok || maxAmpl<0.0) {
+    Message::warning(MSG_ID, tr("Random"), tr("Maximum amplitude must be positive."));
+    return;
+  }
+  _subPoolWin->signalProcess()->random(maxAmpl);
+  processUpdate();
+}
+
 void WaveformConsole::waveletTransform()
 {
   TRACE;
