@@ -46,7 +46,8 @@ public:
   ActiveFKToolSet * tool() {return static_cast<ActiveFKToolSet *>(_tool);}
   const ActiveFKToolSet * tool() const {return static_cast<const ActiveFKToolSet *>(_tool);}
 public slots:
-  virtual void start();
+  void start(int threadCount=0);
+  void stop();
 private slots:
   void on_processTypeEdit_currentIndexChanged(int index);
   void on_currentSource_currentIndexChanged(int index);
@@ -63,12 +64,11 @@ protected:
   FKParameters::ProcessType processType(int t) const;
   int processType(FKParameters::ProcessType t) const;
 
-  void getParameters(ActiveFKParameters& param) const;
-  void setParameters(const AbstractParameters * param);
-  virtual AbstractParameters * parameters(AbstractParameters * param=nullptr) const;
-  bool checkParameters(ActiveFKParameters * param) const;
+  void parametersToGui();
+  void parametersFromGui();
+  bool checkParameters() const;
 
-  virtual void updateAllFields();
+  void updateAllFields();
 };
 
 #endif
