@@ -46,34 +46,39 @@ public:
 
   bool setParameters(const ArraySelection * array, double frequency, FKParameters * param);
   void setGrid(FKParameters * param);
-  TimeWindowList& timeWindowList() const {return static_cast<TimeWindowList&>(_timeWindows->list());}
+  void setTimeWindows();
 
   const FKCrossSpectrum * crossSpectrum() const {return _crossSpectrum;}
 
   void viewKxCurve();
   void viewKxKyGrid();
+  void viewMatrixGrid();
   void viewKEllGrid();
 
 private slots:
   void setCurrentBlockSet();
 
   void on_showPeaksEdit_toggled(bool checked);
-  void on_kEdit_valueChanged(const QString & );
-  void on_vEdit_valueChanged(const QString & );
+  void on_kEdit_valueChanged(double);
+  void on_vEdit_valueChanged(double);
   void on_plotOption_currentIndexChanged(int index);
   void on_ellipticity_valueChanged(double value);
   void on_direction_valueChanged(double value);
+  void on_brightSpot_clicked();
 
   void currentVelocitySlowness(QPoint mousePos);
   void kxkyChanged();
 private:
+  TimeWindowList& timeWindowList() const {return static_cast<TimeWindowList&>(_timeWindows->list());}
   void highLightWindows(TimeWindowList& winList);
   void setPlotOptions();
   void setPlotOption();
   void setKxKyGridLimits();
+  void setMatrixGridLimits(AbstractFKFunction * fk);
   void setKEllGridLimits();
   void setKxCurveLimits();
   void setPowerLimits();
+  void setMatrixLimits();
   void setPowerConcaveMaskLimits();
   void setPowerGradientLimits();
   void setPowerStepLimits();
@@ -101,7 +106,7 @@ private:
   ColorMap _positiveNegativeMap;
 
   int _currentBlockSet;
-  QVector<QVector<int>> _blockSetList;
+  VectorList<VectorList<int>> _blockSetList;
   static const Color _highLightedColor;
 };
 
