@@ -46,31 +46,34 @@ SPACToolWidget::SPACToolWidget(QWidget * parent) :
   TRACE;
   setupUi(this);
 
-  delete _tool;
-  _tool=new SPACTool;
+  _tool=new SPACTool(this);
   connect(tool(), SIGNAL(finished()), this, SLOT(finish()));
 
   freqSamp->setFrequency();
   winParam->removeFilterOption();
   winParam->setLength(WindowingParameters::FrequencyDependent, 50.0);
 
-  connect(startBut, SIGNAL(clicked()), this, SLOT(start()) );
-  connect(stopBut, SIGNAL(clicked()), this, SLOT(stop()) );
+  connect(startBut, SIGNAL(clicked()), this, SLOT(start()));
+  connect(stopBut, SIGNAL(clicked()), this, SLOT(stop()));
   connect(testBut, SIGNAL(clicked()), this, SLOT(parametersChanged()));
   connect(loadParam, SIGNAL(clicked()), this, SLOT(loadLogParameters()));
   connect(freqSamp, SIGNAL(parametersChanged()), this, SLOT(numFreqChanged()));
 
   connect(timeLimits, SIGNAL(parametersChanged()), this, SLOT(parametersChanged()));
-  connect(selectMinimumDurationEdit, SIGNAL(valueChanged(const QString&)), this, SLOT(parametersChanged()));
+  connect(selectMinimumDurationEdit, SIGNAL(valueChanged(double)), this, SLOT(parametersChanged()));
   connect(winParam, SIGNAL(parametersChanged()), this, SLOT(parametersChanged()));
-  connect(testFrequency, SIGNAL(valueChanged(const QString&)), this, SLOT(parametersChanged()));
+  connect(testFrequency, SIGNAL(valueChanged(double)), this, SLOT(parametersChanged()));
 
   connect(blockAveraging, SIGNAL(parametersChanged()), this, SLOT(parametersChanged()));
 
-  connect(freqBandwidthEdit, SIGNAL(valueChanged(const QString&)), this, SLOT(parametersChanged()));
-  connect(oversamplingEdit, SIGNAL(valueChanged(const QString&)), this, SLOT(parametersChanged()));
+  connect(freqBandwidthEdit, SIGNAL(valueChanged(double)), this, SLOT(parametersChanged()));
+  connect(oversamplingEdit, SIGNAL(valueChanged(double)), this, SLOT(parametersChanged()));
 
   _outputFileChecked=false;
+
+  // Add a menu to start button to adjust the numer of parallel jobs
+  detailedStatus->setButtons(startBut, stopBut);
+  connect(detailedStatus, SIGNAL(startJobs(int)), this, SLOT(start(int)));
 }
 
 SPACToolWidget::~SPACToolWidget()
@@ -119,9 +122,10 @@ void SPACToolWidget::updateAllFields()
   freqSamp->updateAllFields();
   numFreqChanged();
   on_freqScroll_valueChanged(freqScroll->value());
-  if(ringEdit->ringCount()==0) {
+  if(ringEdit->rings().count()==0) {
     ringEdit->autoRings();
   }
+  on_spacMethod_currentIndexChanged(spacMethod->currentIndex());
 }
 
 /*!
@@ -133,8 +137,7 @@ void SPACToolWidget::parametersChanged()
   if(timeWindowLayer() && testBut->isChecked()) {
     SPACTaskManager manager(tool()->array());
     ArraySelection array(tool()->array());
-    ArrayTimeWindows timeWindows(&array, manager.keep(),
-                                 static_cast<SPACParameters *>(parameters()));
+    ArrayTimeWindows timeWindows(&array, manager.keep(), tool()->parameters());
     LayerLocker ll(timeWindowLayer());
     timeWindows.setFrequency(testFrequency->value());
     _winList=timeWindows.list();
@@ -154,9 +157,8 @@ void SPACToolWidget::setArrayMap()
   c.resize(n);
   for(int i=0; i<n; i++) {
     NamedPoint& p=c.at(i);
-    const StationSignals * stat=tool()->array()->at(i);
-    p=stat->coordinates();
-    p.setName(stat->name());
+    p=tool()->array()->position(i);
+    p.setName(tool()->array()->name(i));
   }
   _arrayMap->setLimitsArray();
 }
@@ -165,7 +167,8 @@ void SPACToolWidget::setCoArrayMap()
 {
   TRACE;
   ArraySelection array(tool()->array());
-  SPACCrossSpectrum crossSpectrum(&array, static_cast<SPACParameters *>(parameters()));
+  SPACParameters param;
+  SPACCrossSpectrum crossSpectrum(&array, tool()->parameters());
 
   NameLineLayer * plot=_coArrayMap->mapLayer();
   LayerLocker ll(plot);
@@ -191,7 +194,7 @@ void SPACToolWidget::setTimeWindowLayer(TimeWindowList * winList)
     timeWindowLayer()->clearTimeWindows();
     for(int i=0; i<n; i++) {
       for(int iComp=0; iComp<nComp; iComp++ ) {
-        const SubSignalPool subPool=array.at(i)->originals(iComp);
+        const SubSignalPool subPool=array.stationSignals(i)->originals(iComp);
         for(SubSignalPool::const_iterator itSig=subPool.begin(); itSig!=subPool.end(); itSig++) {
           timeWindowLayer()->addTimeWindows(*itSig, winList);
         }
@@ -202,30 +205,24 @@ void SPACToolWidget::setTimeWindowLayer(TimeWindowList * winList)
 
 /*!
 */
-void SPACToolWidget::start()
+void SPACToolWidget::start(int threadCount)
 {
   TRACE;
   if(subPoolLocked()) {
     return;
   }
-  // Get parameters from dialog box
-  SPACParameters * param=static_cast<SPACParameters *>(parameters());
-  if(!param) {
-    return;
-  }
-  param->setOutputBaseName(outputFileName());
-  if(!param->outputBaseName().isEmpty()) {
+  parametersFromGui();
+  QString fileName=outputFileName();
+  if(!fileName.isEmpty()) {
+    tool()->parameters()->setOutputBaseName(fileName);
     lockSubPool();
-    if(tool()->setParameters(*param)) {
+    if(tool()->setLoop()) {
       detailedStatus->setLoop(tool()->loop());
-      setRunning(true);
-      tool()->start();
+      tool()->start(threadCount, true);
     } else {
       unlockSubPool();
     }
   }
-  delete param;
-
 }
 
 /*!
@@ -234,12 +231,11 @@ void SPACToolWidget::start()
 void SPACToolWidget::finish()
 {
   unlockSubPool();
-  SPACParameters * param=static_cast<SPACParameters *>(parameters());
+  const SPACParameters& param=*tool()->parameters();
   tool()->results()->commitStatistics();
   tool()->results()->reportRejects();
-  tool()->results()->save(param->outputBaseName(), tool()->log());
-  delete param;
-  setRunning(false);
+  tool()->results()->save(param.outputBaseName(), tool()->log());
+  detailedStatus->setRunning(false);
 }
 
 /*!
@@ -251,35 +247,21 @@ void SPACToolWidget::stop()
   tool()->stop();
 }
 
-/*!
-*/
-AbstractParameters * SPACToolWidget::parameters(AbstractParameters * param) const
+void SPACToolWidget::parametersFromGui()
 {
   TRACE;
-  if(!param) {
-    param=new SPACParameters;
-  }
-  getParameters(*static_cast<SPACParameters *>(param));
-  return param;
-}
+  SPACParameters& param=*tool()->parameters();
 
-void SPACToolWidget::setParameters(const AbstractParameters * param)
-{
-  TRACE;
-  setParameters(*static_cast<const SPACParameters *>(param));
-}
-
-void SPACToolWidget::getParameters(SPACParameters& param) const
-{
-  TRACE;
   timeLimits->getParameters(param.timeLimits());
   param.setSelectDurationFactor(0.01*selectMinimumDurationEdit->value());
   winParam->getParameters(param.windowing());
 
-  int nRings=ringEdit->rings->rowCount();
+  const VectorList<PlotSPACRing>& rings=ringEdit->rings();
+  int nRings=rings.count();
+  param.clearRings();
   for(int i=0; i<nRings; i++) {
-    param.addRing(ringEdit->rings->item(i, RingEditor_MinCol)->text().toDouble(),
-                  ringEdit->rings->item(i, RingEditor_MaxCol)->text().toDouble());
+    const SPACRing& r=rings.at(i);
+    param.addRing(r.minRadius(), r.maxRadius());
   }
 
   freqSamp->getParameters(param.frequencySampling());
@@ -288,15 +270,18 @@ void SPACToolWidget::getParameters(SPACParameters& param) const
   param.setfrequencyBandwidth(freqBandwidthEdit->value());
   param.setOversamplingFactor(oversamplingEdit->value());
 
+  param.setMethod(spacMethod->currentIndex()==0 ? SPACParameters::MSPAC : SPACParameters::ESAC);
   param.setMaximumImaginary(maxImaginaryPart->value());
 
   param.setDotMaxOutput(outputMax->isChecked());
   param.setOutputBaseName(outputFileNameEdit->text());
 }
 
-void SPACToolWidget::setParameters(const SPACParameters& param)
+void SPACToolWidget::parametersToGui()
 {
   TRACE;
+  const SPACParameters& param=*tool()->parameters();
+
   timeLimits->setParameters(param.timeLimits());
   selectMinimumDurationEdit->setValue(100.0*param.selectDurationFactor());
   winParam->setParameters(param.windowing());
@@ -313,6 +298,11 @@ void SPACToolWidget::setParameters(const SPACParameters& param)
   freqBandwidthEdit->setValue(param.frequencyBandwidth());
   oversamplingEdit->setValue(param.oversamplingFactor());
 
+  if(param.method()==SPACParameters::MSPAC) {
+    spacMethod->setCurrentIndex(0);
+  } else {
+    spacMethod->setCurrentIndex(1);
+  }
   maxImaginaryPart->setValue(param.maximumImaginary());
 
   outputMax->setChecked(param.dotMaxOutput());
@@ -380,21 +370,8 @@ void SPACToolWidget::on_freqScroll_valueChanged(int)
   testFrequency->setValue(param.value(freqScroll->value()));
 }
 
-/*!
-  Same as in FKToolWidget
-*/
-void SPACToolWidget::setRunning(bool r, const QString& message)
+void SPACToolWidget::on_spacMethod_currentIndexChanged(int index)
 {
   TRACE;
-  startBut->setEnabled(!r);
-  stopBut->setEnabled(r);
-  if(r) {
-    if(message.isEmpty()) {
-      mainStatus->setText(tr("Running..."));
-    } else {
-      mainStatus->setText(message);
-    }
-  } else {
-    mainStatus->setText(tr("Not running"));
-  }
+  tab->widget(2)->setEnabled(index==0);
 }
