@@ -79,20 +79,20 @@ void DampingResults::createObjects(SubSignalPool * subPool)
     Signal * sig=subPool->at(ig);
     w->xAxis()->setTitle("Time (s)");
     w->xAxis()->setNumberPrecision(2);
-    w->xAxis()->setTitleInversedScale("1/Time (1/s)");
-    w->xAxis()->setNumberPrecisionInversedScale(2);
+    w->xAxis()->setTitleInverseScale("1/Time (1/s)");
+    w->xAxis()->setNumberPrecisionInverseScale(2);
     w->yAxis()->setTitle(sig->nameComponent());
     w->yAxis()->setNumberType('e');
     w->yAxis()->setNumberPrecision(1);
-    w->yAxis()->setTitleInversedScale(sig->nameComponent());
-    w->yAxis()->setNumberPrecisionInversedScale(1);
+    w->yAxis()->setTitleInverseScale(sig->nameComponent());
+    w->yAxis()->setNumberPrecisionInverseScale(1);
 
     PlotLine2D * line;
     LineLayer * layer;
 
     layer=new LineLayer(w);
     line=new PlotLine2D;
-    line->setPen(Pen(Qt::black, 0.6, Qt::SolidLine));
+    line->setPen(Pen(Qt::black, 0.6, Pen::SolidLine));
     layer->setReferenceLine(line);
     layer->setObjectName("average");
     _averageCurveLayers[ig]=layer;
@@ -106,7 +106,7 @@ void DampingResults::createObjects(SubSignalPool * subPool)
 
     layer=new LineLayer(w);
     line=new PlotLine2D;
-    line->setPen(Pen(Qt::red, 0.3, Qt::SolidLine));
+    line->setPen(Pen(Qt::red, 0.3, Pen::SolidLine));
     layer->setReferenceLine(line);
     layer->setObjectName("fit");
     _fitCurveLayers[ig]=layer;
@@ -121,7 +121,8 @@ void DampingResults::createObjects(SubSignalPool * subPool)
 bool DampingResults::compute(int ig, const Signal *sig, const Parameters& param)
 {
   TRACE;
-  _log=param.toString();
+  _log=param.AbstractParameters::toString();
+  _log+=param.toString();
   _averageCurveLayers[ig]->clear();
   //_stddevCurveLayers[ig]->clear();
   _fitCurveLayers[ig]->clear();
@@ -308,7 +309,7 @@ bool DampingResults::compute(int ig, const Signal *sig, const Parameters& param)
   //static_cast<PlotLine2D *>(_stddevCurveLayers[ig]->addLine())->setCurve(maxCurve);
   static_cast<PlotLine2D *>(_fitCurveLayers[ig]->addLine())->setCurve(fitCurve);
   // Set limits correctly
-  GraphContent * gc=_averageCurveLayers[ig]->graphContent();
+  GraphContents * gc=_averageCurveLayers[ig]->graphContents();
   AxisWindow * w=gc->graph();
   Rect r=gc->boundingRect();
   w->xAxis()->setRange(r.x1(), r.x2());
@@ -380,7 +381,7 @@ void DampingResults::save(QString fileName)
   QTextStream slog(&flog);
   slog << "### Parameters ###\n"
        << _log
-       << "### End Parameters ###" << endl;
+       << "### End Parameters ###" << Qt::endl;
   // Save a result file with frequency, damping, number of windows
   QFile fres(fileName);
   if( !fres.open(QIODevice::WriteOnly) ) {
@@ -389,11 +390,11 @@ void DampingResults::save(QString fileName)
     return;
   }
   QTextStream sres(&fres);
-  sres << "# Name | Frequency | Damping | Number of windows" << endl;
-  for(QVector<Result>::iterator it=_results.begin();it!=_results.end(); it++) {
+  sres << "# Name | Frequency | Damping | Number of windows" << Qt::endl;
+  for(VectorList<Result>::iterator it=_results.begin();it!=_results.end(); it++) {
     sres << it->name << "\t"
          << QString::number(it->frequency) << "\t"
          << QString::number(it->damping) << "\t"
-         << QString::number(it->nWindows) << endl;
+         << QString::number(it->nWindows) << Qt::endl;
   }
 }
