@@ -86,14 +86,18 @@ void HVToolWidget::frequencyWindowRejection()
 {
   TRACE;
   QList<AbstractStation *> statList=selectedStations();
-  updateParameters();
+  parametersFromGui();
   HVTool * t=static_cast<HVTool *>(tool());
 
   FrequencyWindowRejectionWidget * d=new FrequencyWindowRejectionWidget(this);
   Settings::getWidget(d);
+  FrequencyWindowRejection& param=t->parameters()->frequencyWindowRejection();
+  d->minimumFrequencyEdit->setValue(param.minimumFrequency());
+  d->maximumFrequencyEdit->setValue(param.maximumFrequency());
+  d->stddevFactorEdit->setValue(param.stddevFactor());
+  d->maximumIterationCountEdit->setValue(param.maximumIterationCount());
   if(d->exec()==QDialog::Accepted) {
     Settings::setWidget(d);
-    FrequencyWindowRejection& param=t->parameters()->frequencyWindowRejection();
     param.setMinimumFrequency(d->minimumFrequencyEdit->value());
     param.setMaximumFrequency(d->maximumFrequencyEdit->value());
     param.checkFrequencyRange();
