@@ -40,8 +40,8 @@ public:
 private slots:
   void frequencyWindowRejection();
 protected:
-  virtual AbstractResultSheet * createResultSheet();
-  virtual AbstractSummary * createSummary();
+  AbstractResultSheet * createResultSheet();
+  AbstractSummary * createSummary();
 };
 
 #endif
