@@ -30,9 +30,6 @@
 #include <QGpGuiTools.h>
 #include "ToolRefra.h"
 #include "ToolRefrad.h"
-#include "qtbtoolrefraint.h"
-//#include "qtbrefrareport.h"
-//#include "qtbhodochronedata.h"
 
 ToolRefra::ToolRefra(QWidget * parent) :
   AbstractToolWidget(parent, 0)
@@ -82,16 +79,17 @@ bool ToolRefra::initStations(SubSignalPool * subPool)
       _distances.push_back(-pRef.distanceTo(psrc));
     else
       _distances.push_back(pRef.distanceTo(psrc));
-    double srcAbsc=_distances.back();
-    for(;it!=subPool->end() && (*it)->source()==psrc;++it) {
-      Signal * sig=*it;
+    //double srcAbsc=_distances.back();
+    TODO_WARNING;
+    //for(;it!=subPool->end() && (*it)->source()==psrc;++it) {
+      //Signal * sig=*it;
       /*az=sig->sourceReceiverAzimuth();
       if(az>azimuthMin && az<azimuthMax)
         _distances.push_back(srcAbsc-sig->sourceReceiverDistance());
       else
         _distances.push_back(srcAbsc+sig->sourceReceiverDistance());
         */
-    }
+    //}
   }
   // Set number of available picks
   _d->setPickCount(subPool->maximumTimePickCount());
@@ -131,9 +129,10 @@ void ToolRefra::startInversion()
     _d->on_outputFileBrowse_clicked();
     if(_d->outputFile->text().isEmpty()) return;
   }
-  int pick=_d->averagePick->currentIndex();
-  int dpick=_d->stddevPick->currentIndex()-1;
-  int nNodes=_distances.count();
+  TODO_WARNING;
+  //int pick=_d->averagePick->currentIndex();
+  //int dpick=_d->stddevPick->currentIndex()-1;
+  //int nNodes=_distances.count();
   QString fileName=_d->outputFile->text();
   QFileInfo fi(fileName);
   if(fi.suffix()=="dvt") { // next generation inversion tools
