@@ -55,7 +55,7 @@ void TFAResults::createObjects(const SubSignalPool * subPool)
     AxisWindow * w=sheet()->addGraph();
     Signal * sig=subPool->at(ig);
     w->xAxis()->setTitle( "Time (s)" );
-    w->xAxis()->setTitleInversedScale( "1/Time (1/s)" );
+    w->xAxis()->setTitleInverseScale( "1/Time (1/s)" );
     w->yAxis()->setFrequency();
     _gridLayers[ig]=new IrregularGrid2DPlot(w);
     w->setGeometry(1.0, y, 15.0, 8.0);
@@ -103,7 +103,7 @@ void TFAResults::compute(int ig, Signal *sig, TFAParameters &param)
     Message::warning(MSG_ID, tr("Time Frequency Analysis"),
                      tr("Time range is probably too large for signal %4 (%5=%6 samples). Given the number of signals (%1), "
                         "the number of frequency samples (%2), the maximum number of time samples is %3. "
-                        "That corresponds to a total memory consumption of 512 Mb. Contact the developpers "
+                        "That corresponds to a total memory consumption of 512 Mb. Contact the developers "
                         "if you think that this limit is obsolete according to current computer memories.")
                         .arg(_gridLayers.count())
                         .arg(nFreq)
