@@ -37,11 +37,11 @@ public:
   ~DispersionReader();
 
   bool setOptions(int& argc, char ** argv);
+  bool modelLessAction();
 protected:
   virtual bool parse(QTextStream& s);
 private:
   enum AppMode {CurveMode, GridMode, HalfSpace};
-
   AppMode _mode;
 
   int _nRayleigh, _nLove;
@@ -52,14 +52,13 @@ private:
   int _vNSamples;
   double _vMinRange;
   double _vMaxRange;
+  double _nu;
 
   bool _force;
   bool _oneMode;
   bool _deltaK;
 
-  int _halfSpaceIndex;
-
-  QVector<double> _x;
+  VectorList<double> _x;
 };
 
 #endif // DISPERSIONREADER_H
