@@ -40,11 +40,12 @@ int main(int argc, char ** argv)
 
   // Options
   DispersionReader reader;
-  if(reader.setOptions(argc, argv) && reader.read(argc, argv) ) {
-    return 0;
-  } else {
-    return 2;
+  if(reader.setOptions(argc, argv)) {
+    if(reader.modelLessAction() || reader.read(argc, argv) ) {
+      return 0;
+    }
   }
+  return 2;
 }
 
 ApplicationHelp * help()
@@ -77,7 +78,7 @@ ApplicationHelp * help()
   h->addOption("-vmin <min>","Minimum of range for velocity (only for -grid, default=100)");
   h->addOption("-vmax <max>","Maximum of range for velocity (only for -grid, default=3000)");
   h->addOption("-delta-k","Computes wavenumber gaps between modes. Number of modes must be at least 2.");
-  h->addOption("-half-space <index>", "Take Vp and Vs from layer index and compute the Rayleigh phase slowness for a half-space with these Vp and Vs.");
+  h->addOption("-half-space <NU>", "Computes the relative Rayleigh phase velocity (Vr/Vs) for a half-space with Poisson's ratio NU.");
   h->addExample("gpdc < test.model", "Calculate fundamental Rayleigh dispersion curve from 0.2 Hz to 20 Hz for model 'test.model'.");
   h->addExample("gpdc -L 1 -R 2 < test.model", "Calculate fundamental Love mode and fundamental and first higher mode for Rayleigh.");
   h->addExample("gpdc < test.model | figue -c", "Calculate the same dispersion curve and plot it.");
