@@ -105,7 +105,7 @@ int main(int argc, char ** argv)
   targets->refractionVpTarget().setSelected(false);
   targets->refractionVsTarget().setSelected(false);
   targets->magnetoTelluricTarget().setSelected(false);
-  MisfitType misfitType=L2_Normalized;
+  Misfit::Type misfitType=Misfit::L2_Normalized;
   bool forceMisfitType=false;
 
   // Options
@@ -122,19 +122,19 @@ int main(int argc, char ** argv)
       } else if(arg=="-refra-model") {
         mode=RefractionModel;
       } else if(arg=="-l1") {
-        misfitType=L1_Normalized;
+        misfitType=Misfit::L1_Normalized;
         forceMisfitType=true;
       } else if(arg=="-l2") {
-        misfitType=L2_Normalized;
+        misfitType=Misfit::L2_Normalized;
         forceMisfitType=true;
       } else if(arg=="-akaike") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        misfitType=Akaike;
+        misfitType=Misfit::Akaike;
         akaikeDof=CoreApplication::toInt(i, i-1, argv);
         forceMisfitType=true;
       } else if(arg=="-akaike-few") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        misfitType=AkaikeFewSamples;
+        misfitType=Misfit::AkaikeFewSamples;
         akaikeDof=CoreApplication::toInt(i, i-1, argv);
         forceMisfitType=true;
       } else if(arg=="-o") {
@@ -259,7 +259,7 @@ int main(int argc, char ** argv)
   }
 
   if(outputReport) {
-    QTextStream(stdout) << QString("# Saved %1 misfits in %2").arg(iModel).arg(reportFile) << endl;
+    QTextStream(stdout) << QString("# Saved %1 misfits in %2").arg(iModel).arg(reportFile) << Qt::endl;
   }
 
   delete targets;
@@ -346,7 +346,7 @@ int reportMode()
                 info->addReference();
                 models << info;
               } else {
-                sOut << QString("%1 %2 %3").arg(iReportModel+1).arg(oldMisfit).arg(misfit) << endl;
+                sOut << QString("%1 %2 %3").arg(iReportModel+1).arg(oldMisfit).arg(misfit) << Qt::endl;
                 if(outputReport) {
                   // Save new misfit and the rest of the model entry (param, disp,...)
                   outputReport->addModel(misfit, cs, nParams, params);
@@ -455,7 +455,7 @@ int surfaceModelMode()
       if(ok && totalWeight>0.0) {
         double misfit=totalMisfit/totalWeight;
         if(misfit<maxOutputMisfit) {
-          sOut << misfit << endl;
+          sOut << misfit << Qt::endl;
           if(outputReport) {
             outputReport->addModel(misfit, 0, 0, 0);
             Profile vp=m.vpProfile();
@@ -519,7 +519,7 @@ int refractionModelMode()
       bool ok=true;
       targets->refractionMisfit(totalMisfit, totalWeight, &m, akaikeDof,ok);
       if(ok && totalWeight>0) {
-        s << totalMisfit/totalWeight << endl;
+        s << totalMisfit/totalWeight << Qt::endl;
         m.toStream(s);
       }
     } else {
