@@ -54,7 +54,7 @@ int main(int argc, char ** argv)
   double rhoMax=2000.0;
   bool fixDepths=false;
   double vsLink=-1;
-  QVector<Point> positions;
+  VectorList<Point> positions;
   // Check arguments
   int i, j=1;
   for(i=1; i<argc; i++) {
@@ -195,7 +195,7 @@ int main(int argc, char ** argv)
       QString globalCustomConditions;
       for(int i=0; i<n; i++) {
         gm.setPosition(positions.at(i));
-        QString profilePrefix=QString(65+i)+"_";
+        QString profilePrefix=QString::number(i)+"_";
         if(!fixDepths) {
           gm.setCustomConditions(layerThicknessConditions.arg(profilePrefix));
         }
