@@ -41,7 +41,6 @@
 EllipticityReader::EllipticityReader()
     : ArgumentStdinReader()
 {
-  TRACE;
   _nRayleigh=1;
   _sampling.setScaleType(SamplingParameters::Log);
   _sampling.setRange(0.2, 20.0);
@@ -53,8 +52,15 @@ EllipticityReader::EllipticityReader()
   _angleRad=false;
   _oneMode=false;
   _love=0.0;
-  _halfSpaceIndex=-1;
   _plot=false;
+  _ignoreErrors=false;
+  _vp=0.0;
+  _vs=0.0;
+  _qp=0.0;
+  _qs=0.0;
+  _mode=CurveMode;
+  _signThreshold=0.0;
+  _precision=1e-7; // Multiplied by 1e-3 in Dispersion.h, hence it corresponds to 1e-10
 }
 
 bool EllipticityReader::setOptions(int& argc, char ** argv)
@@ -79,7 +85,12 @@ bool EllipticityReader::setOptions(int& argc, char ** argv)
         _angleRad=true;
         _angleDeg=false;
       } else if(arg=="-plot") {
+        if(CoreApplication::checkOptionArg(i, argc, argv, false)) {
+          _signThreshold=CoreApplication::toDouble(i, i-1, argv);
+        }
         _plot=true;
+      } else if(arg=="-ignore-errors") {
+        _ignoreErrors=true;
       } else if(arg=="-love") {
         CoreApplication::checkOptionArg(i, argc, argv);
         _love=CoreApplication::toDouble(i, i-1, argv);
@@ -89,7 +100,13 @@ bool EllipticityReader::setOptions(int& argc, char ** argv)
         }
       } else if(arg=="-s") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        _sampling.setScaleType(argv[i]);
+        QString s(argv[i]);
+        bool ok=true;
+        _sampling.setScaleType(SamplingParameters::convertScaleType(s, ok));
+        if(!ok) {
+          App::log(tr("gpell: bad option scale type '%1'\n").arg(argv[i]));
+          return false;
+        }
       } else if(arg=="-min") {
         CoreApplication::checkOptionArg(i, argc, argv);
         _sampling.setMinimum(CoreApplication::toDouble(i, i-1, argv));
@@ -113,8 +130,18 @@ bool EllipticityReader::setOptions(int& argc, char ** argv)
         _outputCurves=true;
       } else if(arg=="-half-space") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        _halfSpaceIndex=CoreApplication::toInt(i, i-1, argv);
-        _nRayleigh=0;
+        _vp=CoreApplication::toDouble(i, i-1, argv);
+        CoreApplication::checkOptionArg(i, argc, argv, true, i-1);
+        _vs=CoreApplication::toDouble(i, i-2, argv);
+        if(CoreApplication::checkOptionArg(i, argc, argv, false, i-2)) {
+          _qp=CoreApplication::toDouble(i, i-3, argv);
+          CoreApplication::checkOptionArg(i, argc, argv, true, i-3);
+          _qs=CoreApplication::toDouble(i, i-4, argv);
+        }
+        _mode=HalfSpace;
+      } else if(arg=="-disp-precision") {
+        CoreApplication::checkOptionArg(i, argc, argv);
+        _precision=CoreApplication::toDouble(i, i-1, argv);
       } else {
         App::log(tr("gpell: bad option %1, see -help\n").arg(argv[i]) );
         return false;
@@ -133,9 +160,33 @@ bool EllipticityReader::setOptions(int& argc, char ** argv)
   for(int i=_x.count()-1; i>=0; i--) {
     _x[i]*=2.0*M_PI;
   }
+  if(_signThreshold==0.0) {
+    if(_angleRad) {
+      _signThreshold=0.25*M_PI;
+    } else if(_angleDeg) {
+      _signThreshold=45.0;
+    } else {
+      _signThreshold=2.0;
+    }
+  }
   return true;
 }
 
+bool EllipticityReader::modelLessAction()
+{
+  if(_mode==HalfSpace) {
+    Complex e=Seismic1DModel::halfSpaceEllipticity(_vp, _vs, _qp, _qs);
+    QTextStream(stdout) <<  QString("(%1)+i*(%2) abs=%3 (%4 deg.) phase=%5")
+                            .arg(e.re())
+                            .arg(e.im())
+                            .arg(e.abs())
+                            .arg(Angle::radiansToDegrees(atan(e.abs())))
+                            .arg(Angle::radiansToDegrees(e.phase())) << "\n";
+    return true;
+  }
+  return false;
+}
+
 bool EllipticityReader::parse(QTextStream& s)
 {
   TRACE;
@@ -153,12 +204,11 @@ bool EllipticityReader::parse(QTextStream& s)
       //              The current slowness get corrupted with NaN and the process never stops.
       //              With 1e-12 the solver precision is set to 1e-15, probably entering into
       //              trouble with double number representation.
-      dispersion.setPrecision(1e-10);
+      dispersion.setPrecision(_precision);
       Ellipticity ell(_nRayleigh, &_x);
-      // TODO: take errors into consideration
       if(!dispersion.calculate(&rayleigh, &ell)) {
         App::log(tr("Error computing ellipticity curve (eventually increase verbosity to debug)\n") );
-        return false;
+        return _ignoreErrors;
       }
       QList<double> * peaks=new QList<double>[_nRayleigh];
       if(_calculatePeaks) {
@@ -180,13 +230,7 @@ bool EllipticityReader::parse(QTextStream& s)
       if(_outputCurves) {
         sOut << QString("# %1 Rayleigh ellipticity mode(s)\n").arg(_nRayleigh);
         if(_plot) {
-          double signThreshold=2.0;
-          if(_angleRad) {
-            signThreshold=::atan(signThreshold);
-          } else if(_angleDeg) {
-            signThreshold=Angle::radiansToDegrees(::atan(signThreshold));
-          }
-          ell.toStream(sOut, _oneMode ? _nRayleigh-1 : -1, comments, signThreshold);
+          ell.toStream(sOut, _oneMode ? _nRayleigh-1 : -1, comments, _signThreshold);
         } else {
           ell.toStream(sOut, _oneMode ? _nRayleigh-1 : -1, comments);
         }
@@ -200,19 +244,6 @@ bool EllipticityReader::parse(QTextStream& s)
         }
       }
       delete [] peaks;
-    } else if(_halfSpaceIndex>=0) {
-      if(_halfSpaceIndex<m.layerCount()) {
-        Complex e=m.halfSpaceEllipticity(_halfSpaceIndex);
-        sOut << QString("(%1)+i*(%2) abs=%3 (%5 deg.) phi=%4")
-                .arg(e.re())
-                .arg(e.im())
-                .arg(e.abs())
-                .arg(Angle::radiansToDegrees(e.phase()))
-                .arg(Angle::radiansToDegrees(atan(e.abs()))) << "\n";
-      } else {
-        App::log(tr("gpell: half-space index out of range\n") );
-        return false;
-      }
     }
   }
   return true;
