@@ -41,11 +41,12 @@ int main(int argc, char ** argv)
 
   // Options
   EllipticityReader reader;
-  if(reader.setOptions(argc, argv) && reader.read(argc, argv) ) {
-    return 0;
-  } else {
-    return 2;
+  if(reader.setOptions(argc, argv)) {
+    if(reader.modelLessAction() || reader.read(argc, argv) ) {
+      return 0;
+    }
   }
+  return 2;
 }
 
 ApplicationHelp * help()
@@ -63,11 +64,12 @@ ApplicationHelp * help()
   h->addOption("-n <count>","Number of samples (default=100)");
   h->addOption("-R <n modes>","Number of Rayleigh modes (default=1)");
   h->addOption("-one-mode","Instead of outputting all modes (see option '-R'), output only the highest one.");
+  h->addOption("-ignore-errors","Continue processing even if errors are uncountered.");
   h->addOption("-abs","Output abs(ellipticities).");
   h->addOption("-angle","Output atan(ellipticity) in deg.");
   h->addOption("-angle-deg","Output atan(ellipticity) in deg.");
   h->addOption("-angle-rad","Output atan(ellipticity) in rad.");
-  h->addOption("-plot", "Insert '#' everytime the ellipticity sign changes with a high absolute amplitude. "
+  h->addOption("-plot [T]", "Insert '#' everytime the ellipticity sign changes with a high absolute amplitude (greater than threshold T). "
                         "It is more convenient for plotting.");
   h->addOption("-love <alpha>","Adds a Love contribution, 0<=alpha<1 (default=0)");
   h->addOption("-s <sampling>","Defines the sampling type:\n"
@@ -80,7 +82,8 @@ ApplicationHelp * help()
   h->addOption("-p","Output frequency peaks only");
   h->addOption("-c","Output curves only");
   h->addOption("-pc","Output curves only with peak refinements");
-  h->addOption("-half-space <index>", "Take Vp, Vs, Qp and Qs from layer index and compute the ellipticity for a half-space (from Boore and Toksoz 1969).");
+  h->addOption("-half-space <Vp> <Vs> [<Qp> <Qs>]", "Computes the ellipticity for a half-space (from Boore and Toksoz 1969).");
+  h->addOption("-disp-precision <PREC>", "Set the required precision for the dispersion curve (default=1e-10). Decrease the value in case of high frequency instabilities.");
   h->addExample("gpell < test.model", "Calculate fundamental ellipticity curve from 0.2 Hz to 20 Hz for model 'test.model'.");
   h->addExample("gpell < test.model | figue -c", "Calculate the same ellipticity curve and plot it.");
   h->addExample("gpell < test.model | figue -c -m ell.mkup", "Show the same ellipticity curve on a log-log plot. 'ell.mkup' is a tar.gz file containing an xml description of the graphic format, it can be generated from figue's interface.");
