@@ -43,7 +43,7 @@ SourceParameters::SourceParameters()
   _amplitude=1.0;
   _phase=0.0;
   _velocity=300.0;
-  _ellipticity=1.0;
+  _ellipticity=M_PI/4.0;
   _polarization=Mode::Vertical;
   _color=Qt::black;
 }
@@ -56,19 +56,10 @@ double SourceParameters::azimuth(WaveModel wm) const
   } else {
     a=_sourcePoint.azimuthTo(Point());
   }
-  return Angle::mathToGeographic(a);
+  return a;
 }
 
-double SourceParameters::azimuthMath(WaveModel wm) const
-{
-  if(wm==PlaneWaves) {
-    return _azimuth;
-  } else {
-    return _sourcePoint.azimuthTo(Point());
-  }
-}
-
-double SourceParameters::azimuthMath(WaveModel wm, const Point2D& to) const
+double SourceParameters::azimuth(WaveModel wm, const Point2D& to) const
 {
   if(wm==PlaneWaves) {
     return _azimuth;
@@ -80,10 +71,8 @@ double SourceParameters::azimuthMath(WaveModel wm, const Point2D& to) const
 void SourceParameters::setAzimuth(WaveModel wm, double a)
 {
   if(wm==PlaneWaves) {
-    // DoubleSpinBox::setWrapping does not work with range restriction of  Angle::geographicToMath
-    _azimuth=0.5*M_PI-Angle::degreesToRadians(a);
+    _azimuth=a;
   } else {
-    a=Angle::geographicToMath(a);
     double d=_sourcePoint.distanceTo(Point());
     _sourcePoint.setX(-d*cos(a));
     _sourcePoint.setY(-d*sin(a));
@@ -108,13 +97,13 @@ void SourceParameters::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
   Q_UNUSED(context)
   writeProperty(s, "name", _name);
   writeProperty(s, "sourcePoint", _sourcePoint.toString());
-  writeProperty(s, "polarization", Mode::polarization(_polarization));
-  writeProperty(s, "azimuth", _azimuth);
+  writeProperty(s, "polarization", Mode::convertPolarization(_polarization));
+  writeProperty(s, "azimuth", Angle::radiansToDegrees(_azimuth));
   writeProperty(s, "amplitude", _amplitude);
-  writeProperty(s, "phase", _phase);
+  writeProperty(s, "phase", Angle::radiansToDegrees(_phase));
   writeProperty(s, "velocity", _velocity);
-  writeProperty(s, "ellipticity", _ellipticity);
-  writeProperty(s, "color", _color.name());
+  writeProperty(s, "ellipticity", Angle::radiansToDegrees(_ellipticity));
+  writeProperty(s, "color", _color.toString());
 }
 
 XMLMember SourceParameters::xml_member(XML_MEMBER_ARGS)
@@ -140,34 +129,34 @@ bool SourceParameters::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
+  bool ok=true;
   switch(memberID) {
   case 0:
-    _name=content.toString();
+    _name=content.toStringBuffer();
     return true;
   case 1:
-    _sourcePoint.fromString(content.toString());
-    return true;
+    return _sourcePoint.fromString(content.toStringView());
   case 2:
-    _polarization=Mode::polarization(content.toString());
-    return true;
+    _polarization=Mode::convertPolarization(content.toStringView(), ok);
+    return ok;
   case 3:
-    _azimuth=content.toDouble();
-    return true;
+    _azimuth=Angle::degreesToRadians(content.toDouble(ok));
+    return ok;
   case 4:
-    _amplitude=content.toDouble();
-    return true;
+    _amplitude=content.toDouble(ok);
+    return ok;
   case 5:
-    _phase=content.toDouble();
-    return true;
+    _phase=Angle::degreesToRadians(content.toDouble(ok));
+    return ok;
   case 6:
-    _velocity=content.toDouble();
-    return true;
+    _velocity=content.toDouble(ok);
+    return ok;
   case 7:
-    _ellipticity=content.toDouble();
-    return true;
+    _ellipticity=Angle::degreesToRadians(content.toDouble(ok));
+    return ok;
   case 8:
-    _color.setNamedColor(content.toString());
-    return true;
+    _color.fromString(content.toStringView(), ok);
+    return ok;
   default:
     return false;
   }
