@@ -146,7 +146,7 @@ void GridGenerator::model(RealSpace& ps) const
   double v;
 
   for(int i=0; i<_variableCount; i++) {
-    v=_values[i].interpole(_currentIndex[i]).x();
+    v=_values[i].interpole(_currentIndex[i], LinearScale, LinearScale).x();
     ps.variableParameter(i)->setRealValue(v);
   }
 }
