@@ -35,12 +35,12 @@ public:
   GaussianMixtureOutput(QObject * parent=nullptr);
   ~GaussianMixtureOutput();
 
-  void setHistogramDensities(HistogramDensities * d) {_densities=d;}
-  Densities filter(int index) const;
+  void setHistogramInversion(HistogramInversion * d) {_inversion=d;}
+  GaussianMixtureDistribution filter(int index) const;
 public slots:
   void newValues(int index);
 private:
-  HistogramDensities * _densities;
+  HistogramInversion * _inversion;
 };
 
 #endif // GAUSSIANMIXTUREOUTPUT_H
