@@ -44,6 +44,7 @@ public:
   void setHistogram(Histogram2D * hist);
   void setHistogramComments(QString cmt);
   void exportPlot(const ExportOptions& o);
+  void exportHistogramValues(const ExportOptions& o);
   void setGaussianMixtureParameters(const GaussianMixtureParameters& p);
   void setHeaderLine(const QString& h) {_headerLine=h;}
   bool loadCurves(const QStringList& fileNames, const QString& formatFileName);
@@ -65,6 +66,7 @@ private slots:
   void on_undoAllBut_clicked();
   void on_gridFilter_clicked();
   void adjustCurve();
+
   void addMeanCurve();
   void addMedianCurve();
   void addModeCurve();
@@ -90,6 +92,7 @@ private:
   QString _xUnit, _yUnit;
 
   Histogram2D * _hist;
+  ParallelBands * _currentXLayer;
   IrregularGrid2DPlot * _histogramLayer;
 
   ParallelBands * _densityBandLayer;
@@ -100,8 +103,8 @@ private:
   int _lastX;
 
   QString _headerLine;
-  CurveProperties * _gaussianMixtureCurve;
-  HistogramDensities _gaussianMixtureDensities;
+  CurvePropertiesWidget * _gaussianMixtureCurve;
+  HistogramInversion _gaussianMixtureInversion;
   GaussianMixtureOutput _gaussianMixtureOutput;
 
 };
