@@ -92,7 +92,7 @@ int main(int argc, char ** argv)
   QTextStream sOut(stdout);
   switch (reader.action()) {
   case HistogramReader::Gui: {
-      SciFigsGlobal s;
+      SciFigsGlobal s(true);
       HistogramWidget * w=createWidgets(reader, hist);
       if(!w) {
         return 2;
@@ -110,7 +110,7 @@ int main(int argc, char ** argv)
     }
     break;
   case HistogramReader::Plot: {
-      SciFigsGlobal s;
+      SciFigsGlobal s(true);
       HistogramWidget * w=createWidgets(reader, hist);
       if(!w) {
         return 2;
@@ -121,28 +121,40 @@ int main(int argc, char ** argv)
     }
     break;
   case HistogramReader::Mean: {
+      RealStatisticalCurve c;
+      RealStatisticalProxy p;
+      p.setCurve(&c);
+      hist->meanCurve(&p);
       sOut << "# Mean curve\n"
-           << hist->meanCurve().toString();
+           << c.toString();
       appReturn=0;
     }
     break;
   case HistogramReader::Median: {
+      RealStatisticalCurve c;
+      RealStatisticalProxy p;
+      p.setCurve(&c);
+      hist->medianCurve(&p);
       sOut << "# Median curve\n"
-           << hist->medianCurve().toString();
+           << c.toString();
       appReturn=0;
     }
     break;
   case HistogramReader::Mode: {
+      RealStatisticalCurve c;
+      RealStatisticalProxy p;
+      p.setCurve(&c);
+      hist->modeCurve(&p);
       sOut << "# Mode curve\n"
-           << hist->modeCurve().toString();
+           << c.toString();
       appReturn=0;
     }
     break;
   case HistogramReader::GaussMix: {
       GaussianMixtureOutput gmo;
-      HistogramDensities d;
-      d.setHistogram(hist);
-      gmo.setHistogramDensities(&d);
+      HistogramInversion d(1);
+      d.setHistogram(0, hist);
+      gmo.setHistogramInversion(&d);
       d.setParameters(reader.gaussianMixtureParameters());
       gmo.connect(&d, SIGNAL(histogramFinished(int)), &gmo, SLOT(newValues(int)));
       d.start();
@@ -150,7 +162,7 @@ int main(int argc, char ** argv)
       appReturn=0;
     }
     break;
-  case HistogramReader::Grid: {
+  case HistogramReader::HistogramValues: {
       sOut << "# Grid values\n";
       sOut << *hist;
       appReturn=0;
@@ -164,6 +176,18 @@ int main(int argc, char ** argv)
   case HistogramReader::MinimumVelocity:
     App::log(tr("Unsupported mode\n"));
     break;
+  case HistogramReader::Misfit: {
+      bool ok=true;
+      Curve<Point2D> m=reader.misfit(ok);
+      if(ok) {
+        QTextStream(stdout) << "# misfit\n"
+                            << m.toString();
+        appReturn=0;
+      } else {
+        appReturn=2;
+      }
+    }
+    break;
   }
   delete hist;
   return appReturn;
@@ -205,10 +229,13 @@ ApplicationHelp * help()
   h->addOption("-azimuth", "For .max files, plot azimuth.");
   h->addOption("-ell", "For .max files, plot signed ellipticity.");
   h->addOption("-ell-abs", "For .max files, plot absolute value of ellipticity.");
+  h->addOption("-ell-neg", "For .max files, plot opposite value of ellipticity (for downwards vertical components).");
   h->addOption("-ell-deg", "For .max files, plot ellipticity angle in deg.");
-  h->addOption("-ell-inv-deg", "For .max files, plot ellipticity angle in deg with the opposite sign (for downwards vertical components).");
+  h->addOption("-ell-abs-deg", "For .max files, plot the absolute value of the ellipticity angle in deg.");
+  h->addOption("-ell-neg-deg", "For .max files, plot the ellipticity angle in deg with the opposite sign (for downwards vertical components).");
   h->addOption("-ell-rad", "For .max files, plot ellipticity angle in rad.");
-  h->addOption("-ell-inv-rad", "For .max files, plot ellipticity angle in rad with the opposite sign (for downwards vertical components).");
+  h->addOption("-ell-abs-rad", "For .max files, plot the absolute value of the ellipticity angle in rad.");
+  h->addOption("-ell-neg-rad", "For .max files, plot ellipticity angle in rad with the opposite sign (for downwards vertical components).");
   h->addOption("-noise", "For .max files, plot the ratio of incoherent noise over coherent signal.");
   h->addOption("-s-k", "For .max files, plot slowness versus wave number.");
   h->addOption("-s-l", "For .max files, plot slowness versus wave length.");
@@ -216,8 +243,8 @@ ApplicationHelp * help()
   h->addOption("-k-f", "For .max files, plot wave number versus frequency.");
   h->addOption("-l-f", "For .max files, plot wave length versus frequency.");
   h->addGroup("Gaussian Mixture", "gaussmix");
-  h->addOption("-gm-type <T>", "Inversion type can be: 'Full' or 'MeanOnly' (default).");
-  h->addOption("-gm-count <N>","Adjust histograms with a maximum of N Gaussian densities (default=4).");
+  h->addOption("-gm-count <N>","Adjust histograms with a maximum of N Gaussian densities (default=2).");
+  h->addOption("-gm-mean-spacing <F>","Spacing factor between the mean of the different modes (default=1.05).");
   h->addOption("-gm-relerr <ERR>", "For MeanOnly inversion, use this relative error to compute stddev (default=0.1).");
   h->addOption("-gm-abserr <ERR>", "For MeanOnly inversion, use this absolute error to compute stddev (default=0). "
                                    "If absolute error is 0, relative error is used instead.");
