@@ -106,7 +106,7 @@ bool CurvesThread::setParameters(int& argc, char ** argv)
       if(arg=="-s") {
         CoreApplication::checkOptionArg(i, argc, argv);
         if(strcmp(argv[i],"period")==0) {
-          samplingType=InversedScale;
+          samplingType=InverseScale;
         } else if(strcmp(argv[i],"frequency")==0) {
           samplingType=LinearScale;
         } else {
