@@ -83,7 +83,7 @@ void DispersionGridThread::initResultsGraphs(GraphicSheet * sheet)
 
   w->xAxis()->setFrequency();
   w->yAxis()->setTitle(tr("Slowness (s/m)"));
-  w->yAxis()->setTitleInversedScale(tr("Velocity (m/s)"));
+  w->yAxis()->setTitleInverseScale(tr("Velocity (m/s)"));
 }
 
 bool DispersionGridThread::setParameters(int& argc, char ** argv)
@@ -135,7 +135,7 @@ void DispersionGridThread::start(QList<GeophysicalModel *> models)
     lf->setModel(static_cast<Seismic1DModel *>(models.first()));
     f=lf;
   }
-  _layer->setFunction(f);
+  _layer->setFunction(new FunctionPlot(2, f));
   resultsDeepUpdate();
 }
 
