@@ -76,7 +76,7 @@ void DispersionThread::initResultsGraphs(GraphicSheet * sheet)
   AxisWindow * w=_layer->graph();
   w->xAxis()->setFrequency();
   w->yAxis()->setTitle(tr("Slowness (s/m)"));
-  w->yAxis()->setTitleInversedScale(tr("Velocity (m/s)"));
+  w->yAxis()->setTitleInverseScale(tr("Velocity (m/s)"));
 }
 
 bool DispersionThread::setParameters(int& argc, char ** argv)
