@@ -50,6 +50,7 @@ EllipticityThread::EllipticityThread(QObject * parent)
   _angleDeg=false;
   _angleRad=false;
   _oneMode=false;
+  _precision=1e-7; // Multiplied by 1e-3 in Dispersion.h, hence it corresponds to 1e-10
 }
 
 /*!
@@ -64,6 +65,7 @@ EllipticityThread::EllipticityThread(const EllipticityThread& o)
   _angleDeg=o._angleDeg;
   _angleRad=o._angleRad;
   _oneMode=o._oneMode;
+  _precision=o._precision;
 }
 
 /*!
@@ -81,7 +83,7 @@ void EllipticityThread::initResultsGraphs(GraphicSheet * sheet)
   AxisWindow * w=_layer->graph();
   w->xAxis()->setFrequency();
   w->yAxis()->setTitle(tr("Ellitpticity (H/V)"));
-  w->yAxis()->setTitleInversedScale(tr("Ellitpticity (V/H)"));
+  w->yAxis()->setTitleInverseScale(tr("Ellitpticity (V/H)"));
   if(_abs) {
     if(_angleDeg) {
       w->yAxis()->setRange(0, 90.0);
@@ -126,6 +128,9 @@ bool EllipticityThread::setParameters(int& argc, char ** argv)
       } else if(arg=="-angle-rad") {
         _angleRad=true;
         _angleDeg=false;
+      } else if(arg=="-disp-precision") {
+        CoreApplication::checkOptionArg(i, argc, argv);
+        _precision=CoreApplication::toDouble(i, i-1, argv);
       } else {
         argv[j++]=argv[i];
       }
@@ -145,7 +150,7 @@ void EllipticityThread::run(GeophysicalModel * m)
   if(_nRayleigh>0) {
     Rayleigh rayleigh(static_cast<Seismic1DModel *>(m));
     Dispersion dispersion (_nRayleigh, &_x);
-    dispersion.setPrecision(1e-10); // Highest precision with double
+    dispersion.setPrecision(_precision); // Highest precision with double
     Ellipticity ell(_nRayleigh, &_x);
     if(!dispersion.calculate(&rayleigh, &ell, &_terminated)) {
       return;
