@@ -198,8 +198,8 @@ bool ModelSlider::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
   switch(memberID) {
-  case 0: setTitle(content.toString()); return true;
-  case 1: setCode(content.toString()); return true;
+  case 0: setTitle(content.toStringBuffer()); return true;
+  case 1: setCode(content.toStringBuffer()); return true;
   default: return false;
   }
 }
