@@ -38,7 +38,6 @@
 MagnetoTelluricReader::MagnetoTelluricReader()
     : ArgumentStdinReader()
 {
-  TRACE;
   _samplingType=LogScale;
   _nSamples=10;
   _minRange=1000;
@@ -57,7 +56,7 @@ bool MagnetoTelluricReader::setOptions(int& argc, char ** argv)
       if(arg=="-s") {
         CoreApplication::checkOptionArg(i, argc, argv);
         if(strcmp(argv[i],"period")==0) {
-          _samplingType=InversedScale;
+          _samplingType=InverseScale;
         } else if(strcmp(argv[i],"frequency")==0) {
           _samplingType=LinearScale;
         } else {
