@@ -60,7 +60,7 @@ private:
   int _nDepths;
   int _nProfiles;
 
-  QVector<double> _sampling;
+  VectorList<double> _sampling;
   Curve<Point2D> _vMin, _vMax;
 
   Point _pseudo3DAt;
