@@ -42,7 +42,6 @@
 SignalReader::SignalReader()
     : ArgumentStdinReader()
 {
-  TRACE;
   _nSamples=0;
   _samples=nullptr;
   //_commonFrequency=-1.0;
@@ -55,7 +54,6 @@ SignalReader::SignalReader()
 
 SignalReader::~SignalReader()
 {
-  TRACE;
   delete [] _samples;
   delete _dispersionCurve;
 }
@@ -106,7 +104,7 @@ bool SignalReader::setOptions(int& argc, char ** argv)
           _dispersionCurve=new Curve<Point2D>;
           QTextStream s(&f);
           QString line;
-          QRegExp sep("[ \t]{1,}");
+          QRegularExpression sep("[ \t]{1,}");
           bool okX, okY;
           Point2D p;
           int lineNumber=0;
@@ -159,25 +157,38 @@ bool SignalReader::addWavelet(int posIndex, const Point2D& pos,
   StringSection fields(buf);
   StringSection field;
   const QChar * p=nullptr;
+  bool ok=true;
   field=fields.nextField(p);
   if(!field.isValid()) {
     App::log(tr("gpsignal: error reading amplitude, \n").arg(buf));
     return false;
   }
-  w.amplitude=field.toDouble();
+  w.amplitude=field.toDouble(ok);
+  if(!ok) {
+    App::log(tr("gpsignal: error reading amplitude, \n").arg(buf));
+    return false;
+  }
   field=fields.nextField(p);
   if(!field.isValid()) {
     App::log(tr("gpsignal: error reading frequency, \n").arg(buf));
     return false;
   }
-  w.frequency=field.toDouble();
+  w.frequency=field.toDouble(ok);
+  if(!ok) {
+    App::log(tr("gpsignal: error reading frequency, \n").arg(buf));
+    return false;
+  }
 
   field=fields.nextField(p);
   if(!field.isValid()) {
     App::log(tr("gpsignal: error reading phase, \n").arg(buf));
     return false;
   }
-  double phaseDegrees=field.toDouble();
+  double phaseDegrees=field.toDouble(ok);
+  if(!ok) {
+    App::log(tr("gpsignal: error reading phase, \n").arg(buf));
+    return false;
+  }
   w.phase=Angle::degreesToRadians(phaseDegrees);
 
   field=fields.nextField(p);
@@ -185,14 +196,18 @@ bool SignalReader::addWavelet(int posIndex, const Point2D& pos,
     App::log(tr("gpsignal: error reading azimuth, \n").arg(buf));
     return false;
   }
-  double azimuth=field.toDouble();
+  double azimuth=field.toDouble(ok);
+  if(!ok) {
+    App::log(tr("gpsignal: error reading azimuth, \n").arg(buf));
+    return false;
+  }
   double angle=pos.azimuth();
-  angle-=Angle::geographicToMath(azimuth);
+  angle-=Angle::geographicToMath(Angle::degreesToRadians(azimuth));
 
   double distance=Point2D().distanceTo(pos)*cos(angle);
   double velocity;
   if(_dispersionCurve) {
-    double slowness=_dispersionCurve->interpole(w.frequency).y();
+    double slowness=_dispersionCurve->interpole(w.frequency, LogScale, LogScale).y();
     velocity=1.0/slowness;
     w.phase+=2.0*M_PI*w.frequency*distance*slowness;
   } else {
@@ -201,7 +216,11 @@ bool SignalReader::addWavelet(int posIndex, const Point2D& pos,
       App::log(tr("gpsignal: error reading velocity, \n").arg(buf));
       return false;
     }
-    velocity=field.toDouble();
+    velocity=field.toDouble(ok);
+    if(!ok) {
+      App::log(tr("gpsignal: error reading velocity, \n").arg(buf));
+      return false;
+    }
     w.phase+=2.0*M_PI*w.frequency*distance/velocity;
   }
   _wavelets[posIndex].append(w);
@@ -259,7 +278,7 @@ void SignalReader::exec()
         for(int iy=_grid.ny()-1; iy>=0; iy--) {
           double& v=*_grid.valuePointer(ix, iy);
           v=0.0;
-          const QVector<Wavelet>& ws=_wavelets.at(ix*nx+iy);
+          const VectorList<Wavelet>& ws=_wavelets.at(ix*nx+iy);
           int nWavelets=ws.count();
           for(int iw=0; iw<nWavelets; iw++) {
             const Wavelet& w=ws.at(iw);
@@ -271,7 +290,7 @@ void SignalReader::exec()
       sOut << _grid;
     }
   } else {
-    const QVector<Wavelet>& ws=_wavelets.first();
+    const VectorList<Wavelet>& ws=_wavelets.first();
     int nWavelets=ws.count();
     double t;
     if(_square) {
@@ -303,7 +322,7 @@ void SignalReader::exec()
       sOut << _samples[i] << "\n";
     }
   }
-  sOut << flush;
+  sOut << Qt::flush;
 }
 
 #if 0
