@@ -65,6 +65,18 @@ bool TargetAdd::setOptions(int& argc, char ** argv)
         CoreApplication::checkOptionArg(i, argc, argv);
         _mode.setIndex(CoreApplication::toInt(i, i-1, argv));
         _type=Dispersion;
+      } else if(arg=="-ellipticity") {
+        _mode.setPolarization(Mode::Rayleigh);
+        _mode.setValue(Mode::Signed);
+        CoreApplication::checkOptionArg(i, argc, argv);
+        _mode.setIndex(CoreApplication::toInt(i, i-1, argv));
+        _type=EllipticityCurve;
+      } else if(arg=="-abs-ellipticity") {
+        _mode.setPolarization(Mode::Rayleigh);
+        _mode.setValue(Mode::Absolute);
+        CoreApplication::checkOptionArg(i, argc, argv);
+        _mode.setIndex(CoreApplication::toInt(i, i-1, argv));
+        _type=EllipticityCurve;
       } else if(arg=="-dispersion-love") {
         _mode.setPolarization(Mode::Love);
         CoreApplication::checkOptionArg(i, argc, argv);
@@ -143,6 +155,21 @@ int TargetAdd::execute()
       }
     }
     break;
+  case EllipticityCurve: {
+      QList<ModalCurve> curves=tl.ellipticityCurveTarget().curves();
+      tl.ellipticityCurveTarget().setMisfitWeight(_weight);
+      tl.ellipticityCurveTarget().setMinimumMisfit(_minimumMisfit);
+      QTextStream sIn(stdin);
+      readCurves(curves, sIn);
+      tl.ellipticityCurveTarget().setCurves(curves);
+      XMLVirtualPlugin plugin(&tl, "DispersionCurve");
+      XMLDinverHeader hdr(&plugin);
+      if(hdr.xml_saveFile(fileName())!=XMLClass::NoError) {
+        App::log(tr("gptarget: error writing to file %1\n").arg(fileName()) );
+        return 2;
+      }
+    }
+    break;
   case MagnetoTelluric: {
       QList<MagnetoTelluricCurve> curves=tl.magnetoTelluricTarget().curves();
       tl.magnetoTelluricTarget().setMisfitWeight(_weight);
