@@ -112,7 +112,7 @@ int TargetExtract::execute()
     return 2;
   }
   QTextStream sOut(stdout);
-  sOut << "# position " << tl.position().toString(6) << endl;
+  sOut << "# position " << tl.position().toString('g', 6) << Qt::endl;
   switch(_mode) {
   case Dispersion:
     if(_curveIndex<tl.dispersionTarget().curves().count()) {
