@@ -122,6 +122,14 @@ ApplicationHelp * help()
                                               "mode INDEX (0 is fundamental). Format: frequency(Hz) "
                                               "slowness(s/m) log stddev [weight(0 for invalid)]. "
                                               "Blanks or lines starting with '#' delimit various curves.");
+  h->addOption("-ellipticity <INDEX>","Adds ellipticity curves read from stdin as signed with "
+                                              "mode INDEX (0 is fundamental). Format: frequency(Hz) "
+                                              "Ellipticity(deg) stddev(deg) [weight(0 for invalid)]. "
+                                              "Blanks or lines starting with '#' delimit various curves.");
+  h->addOption("-abs-ellipticity <INDEX>","Adds ellipticity curves read from stdin as absolute values with "
+                                              "mode INDEX (0 is fundamental). Format: frequency(Hz) "
+                                              "Ellipticity(deg) stddev(deg) [weight(0 for invalid)]. "
+                                              "Blanks or lines starting with '#' delimit various curves.");
   h->addOption("-dispersion-love <INDEX>","Adds dispersion curves read from stdin as Love with mode "
                                           "mode INDEX (0 is fundamental). Format: frequency(Hz) "
                                           "slowness(s/m) log stddev [weight(0 for invalid)]. "
