@@ -55,8 +55,8 @@ ApplicationHelp * help()
                   "Operation other than convert are not yet supported." );
   h->addGroup("gptime", "gptime");
   h->addOption("-i, -in-format FORMAT","Defines input time format. Several '-i' options are accepted. "
-                                       "See '-h format' for specification (default=\"yyyy-MM-dd hh:mm:ss.zzz\").");
-  h->addOption("-o, -out-format FORMAT","Defines output time format. See '-h format' for specification (default=\"time_t\").");
+                                       "See '-h format' for specification (default=\"time_t\").");
+  h->addOption("-o, -out-format FORMAT","Defines output time format. See '-h format' for specification (default=\"yyyy-MM-dd hh:mm:ss.zzz\").");
   h->addOption("-p PREC","Output precision for floating point numbers");
   h->addOption("-c COLUMN","Time is in column COLUMN (default=0, means all line). First column starts at index 1.");
   h->addOption("-d DELIMITERS","Column delimiter characters used by option '-c' (default=\" \\t\").");
