@@ -36,43 +36,37 @@
 
 Sample::Sample()
 {
-  _time=0.0;
   _frequency=0.0;
   _slowness=0.0;
   _azimuth=0.0;
   _ellipticity=0.0;
-  _noise=0.0;
+  _verticalNoise=0.0;
+  _horizontalNoise=0.0;
   _power=0.0;
 }
 
-Sample::Sample(const Sample& s)
-{
-  _time=s._time;
-  _frequency=s._frequency;
-  _slowness=s._slowness;
-  _azimuth=s._azimuth;
-  _ellipticity=s._ellipticity;
-  _noise=s._noise;
-  _power=s._power;
-}
-
 /*!
   Read and parse next available not blank and not starting with '#',
   and containing \a pattern. Non-valid samples are ignored.
 */
-bool Sample::read(const QString& line)
+bool Sample::read(const QString& line, int timeColumn, int freqColumn,
+                  int slowColumn, int azimuthColumn, int ellColumn,
+                  int verticalNoiseColumn, int horizontalNoiseColumn,
+                  int powerColumn, int validColumn)
 {
   TRACE;
   bool ok=true;
   LineParser lp(line);
-  _time=lp.toDouble(0, ok);
-  _frequency=lp.toDouble(1, ok);
-  _slowness=lp.toDouble(2, ok);
-  _azimuth=lp.toDouble(3, ok);
-  _ellipticity=Angle::radiansToDegrees(::atan(lp.toDouble(4, ok)));
-  _noise=lp.toDouble(5, ok);
-  _power=lp.toDouble(6, ok);
-  bool valid=(lp.toInt(7, ok)==1);
+  _time=lp.toString(timeColumn, ok);
+  _frequency=lp.toDouble(freqColumn, ok);
+  _slowness=lp.toDouble(slowColumn, ok);
+  _azimuth=lp.toDouble(azimuthColumn, ok);
+  _ellipticity=lp.toDouble(ellColumn, ok);
+  _verticalNoise=lp.toDouble(verticalNoiseColumn, ok);
+  _horizontalNoise=lp.toDouble(horizontalNoiseColumn, ok);
+  _power=lp.toDouble(powerColumn, ok);
+  bool valid=(lp.toInt(validColumn, ok)==1);
+  _line=line;
   if(ok) {
     return valid;
   } else {
@@ -81,16 +75,30 @@ bool Sample::read(const QString& line)
   }
 }
 
-
-void Sample::write(QTextStream& s) const
+void Sample::writeValues(QTextStream& s) const
 {
   TRACE;
-  s <<  _time << " " << _frequency << " " << " "
+  s <<  _time << " " << _frequency << " "
      << _slowness << " "
      << _azimuth << " "
-     << ::tan(Angle::degreesToRadians(_ellipticity)) << " "
-     << _noise << " "
+     << _ellipticity << " "
+     << _verticalNoise << " "
+     << _horizontalNoise << " "
      << _power << " 1\n";
 }
 
+double Sample::xixDeviation() const
+{
+  double xir=Angle::degreesToRadians(_ellipticity);
+  double xix=0.5*atan2(sin(2.0*xir), cos(2.0*xir)+_verticalNoise-_horizontalNoise);
+  return Angle::radiansToDegrees(fabs(xix)-fabs(xir));
+}
+
+double Sample::xisDeviation() const
+{
+  double xir=Angle::degreesToRadians(_ellipticity);
+  double xis=sqrt((sin(xir)+_horizontalNoise)/(cos(xir)+_verticalNoise));
+  return Angle::radiansToDegrees(xis-fabs(xir));
+}
+
 
