@@ -34,14 +34,13 @@ class MatlabVariableName : public MetaString
 public:
   MatlabVariableName() {}
   MatlabVariableName(const QString& n) {setValue(n);}
-  MatlabVariableName(const MatlabVariableName& o) : MetaString(o) {}
 
-  virtual QStringList subNames() const;
-  virtual QString name(int, const QString&) const;
-  virtual QString baseName(int) const;
-  virtual QString title(int, const QString&) const;
+  QStringList subNames() const;
+  QString name(int, const QString&) const;
+  QString baseName(int) const;
+  QString title(int, const QString&) const;
 
-  virtual bool isReadOnly(int) const {return true;}
+  bool isReadOnly(int) const {return true;}
 };
 
 #endif // MATLABVARIABLENAME_H
