@@ -35,9 +35,9 @@ class FreqVelocityFilter : public Dialog, public Ui::FreqVelocityFilter
 {
   Q_OBJECT
 public:
-  FreqVelocityFilter(QWidget *parent=0, Qt::WindowFlags f=0);
+  FreqVelocityFilter(QWidget *parent=0, Qt::WindowFlags f=Qt::WindowFlags());
 
-  void setCurveList(const QList<CurveProperties *>& list);
+  void setCurveList(const QList<CurvePropertiesWidget *>& list);
 public slots:
   void enableWidgets();
 };
