@@ -48,7 +48,7 @@ HistogramWidget::HistogramWidget(MaxEntryList * maxList, QWidget * parent) : QWi
   _gridLayer=new IrregularGrid2DPlot(graph);
   _gridLayer->setObjectName("histograms");
   ColorMap& map=_gridLayer->beginColorMapChange();
-  map.generateColorScale(20, ColorPalette::McNames, true);
+  map.generate(0, 19, ColorPalette::defaultSequential, ColorPalette::Reversed);
   _gridLayer->endColorMapChange();
   LineLayer * curveLayer=new LineLayer(graph);
   curveLayer->setObjectName("curves");
@@ -408,7 +408,7 @@ void HistogramWidget::normalizeGrid(IrregularGrid2D& grid)
   if(logScale) {
     grid.log(YAxis);
   }
-  for(int i=grid.nx() - 1;i >= 0;i-- ) {
+  for(int i=grid.nx()-1; i>=0; i--) {
     grid.normalizeArea(YAxis, i);
   }
   if(logScale) {
@@ -554,7 +554,7 @@ void HistogramWidget::on_closeButton_clicked()
 void HistogramWidget::on_saveButton_clicked()
 {
   TRACE;
-  QString fileName=Message::getSaveFileName(tr("Saving max file"),tr("max file (*.max)"));
+  QString fileName=Message::getSaveFileName(tr("Saving max file"), tr("max file (*.max)"));
   if(!fileName.isEmpty()) {
     _maxList->save(fileName);
   }
@@ -651,12 +651,12 @@ void HistogramWidget::exportPlot(const ExportOptions& o)
   }
   if(!o.appendLayerFiles().isEmpty()) {
     for(QStringList::const_iterator it=o.appendLayerFiles().begin(); it!=o.appendLayerFiles().end(); it++) {
-      w->graphContent()->appendLayers(*it);
+      w->graphContents()->appendLayers(*it);
     }
   }
   if(!o.prependLayerFiles().isEmpty()) {
     for(QStringList::const_iterator it=o.prependLayerFiles().begin(); it!=o.prependLayerFiles().end(); it++) {
-      w->graphContent()->prependLayers(*it);
+      w->graphContents()->prependLayers(*it);
     }
   }
   setLimits();
