@@ -31,7 +31,7 @@
 
 #include "Sample.h"
 
-class Samples : public QVector<Sample>
+class Samples : public VectorList<Sample>
 {
 public:
   //bool save(const QString& fileName, const QString& headerLine, const QString& polarization) const;
