@@ -56,7 +56,7 @@ SpacSelector::SpacSelector(QWidget * parent) :
   _gridLayer=new IrregularGrid2DPlot(graph);
   LineLayer * dispLayer=new LineLayer(graph);
   ModalLine * line=new ModalLine;
-  line->setPen(Pen(QColor(145,145,145), 0.6, Qt::SolidLine) );
+  line->setPen(Pen(QColor(145,145,145), 0.6, Pen::SolidLine) );
   line->setSymbol(Symbol(Symbol::Circle,1.2, Pen(QColor(222,222,222)), Brush(QColor(101,101,101), Qt::SolidPattern) ));
   dispLayer->setReferenceLine(line);
   curves->initLayer(dispLayer);
@@ -64,9 +64,9 @@ SpacSelector::SpacSelector(QWidget * parent) :
   _limitsSolutionsLayer=new LineLayer(graph);
   _limitsSolutionsLayer->setReferenceLine(new PlotLine2D);
   _limitsSolutionsLayer->setObjectName("SPAC Limits & Solutions");
-  _limitsSolutionsLayer->addLine(Pen(Qt::NoPen),Symbol(Symbol::Circle,1.2, Pen(Qt::black), Brush(Qt::black, Qt::SolidPattern)));
-  _limitsSolutionsLayer->addLine(Pen(Qt::black,0.6,Qt::SolidLine),Symbol());
-  _limitsSolutionsLayer->addLine(Pen(Qt::black,0.6,Qt::DotLine),Symbol());
+  _limitsSolutionsLayer->addLine(Pen(Qt::NoPen), Symbol(Symbol::Circle, 1.2, Pen(Qt::black), Brush(Qt::black, Qt::SolidPattern)));
+  _limitsSolutionsLayer->addLine(Pen(Qt::black, 0.6, Pen::SolidLine), Symbol());
+  _limitsSolutionsLayer->addLine(Pen(Qt::black, 0.6, Pen::DotLine), Symbol());
 
   QAction * a=curves->addCurveAction(tr("&Adjust"), tr("Adjust current curve to the closest maximum"), true);
   connect(a, SIGNAL(triggered()), this, SLOT(adjustCurve()) );
@@ -205,7 +205,7 @@ void SpacSelector::radiusScroll_valueChanged()
   if(iRadius>(int)_autocorr->rings()->count()-1) return;
   // Remove marker from last ring plot
   _spacLayers[_lastCurRing]->line(2)->clear();
-  _spacLayers[_lastCurRing]->graphContent()->deepUpdate();
+  _spacLayers[_lastCurRing]->graphContents()->deepUpdate();
   options->radiusMin->setText(QString::number(_autocorr->ring(iRadius).minRadius()));
   options->radiusMax->setText(QString::number(_autocorr->ring(iRadius).maxRadius()));
   _lastCurRing=iRadius;
@@ -244,7 +244,7 @@ void SpacSelector::inverseAt()
     // Inversion itself
     eng.setRing(_autocorr->ring(iRing));
     double omega=2.0*M_PI*autocorrFactory.x()->at(iFreq);
-    QVector<double> solutions=eng.dispersion(omega, p.y(), omega*smin, omega*smax);
+    VectorList<double> solutions=eng.dispersion(omega, p.y(), omega*smin, omega*smax);
     // Plot solutions
     LayerLocker ll(_limitsSolutionsLayer);
     Curve<Point2D>& invRes=limitsSolutionsCurve(0);
@@ -253,8 +253,8 @@ void SpacSelector::inverseAt()
       //printf("sol @ ring %i, %lf Hz %lf\n", iRing, autocorrFactory.x()->at(iFreq), 1/solutions.at(i));
       invRes.append(Point2D(p.x(), solutions.at(i)));
     }
-    _gridLayer->graph()->graphContent()->deepUpdate();
-    w->graphContent()->deepUpdate();
+    _gridLayer->graph()->graphContents()->deepUpdate();
+    w->graphContents()->deepUpdate();
   }
 }
 
@@ -275,7 +275,7 @@ void SpacSelector::setK()
     resol.setY(i, invWLmin/resol.x(i));
     aliasing.setY(i, invWLmax/aliasing.x(i));
   }
-  _gridLayer->graph()->graphContent()->deepUpdate();
+  _gridLayer->graph()->graphContents()->deepUpdate();
 }
 
 void SpacSelector::inverse()
@@ -310,10 +310,10 @@ void SpacSelector::inverse()
     ModalCurve& curve=ringCurves.first();
     for(int iw=0; iw<omegaCount; iw++) {
       double x=autocorrFactory.x()->at(iw);
-      FactoryPoint p=curve.interpole(x);
+      FactoryPoint p=curve.interpole(x, LogScale, LinearScale);
       if(p.isValid() && fabs(p.y())>0.025) {
         double omega=2.0*M_PI*x;
-        QVector<double> solutions=eng.dispersion(omega, p.y(), omega*smin, omega*smax);
+        VectorList<double> solutions=eng.dispersion(omega, p.y(), omega*smin, omega*smax);
         for(int i=0; i<solutions.count() && i<_maxSolutionCount; i++) {
           double s=solutions.at(i);
           //printf("%lf %lf\n", f, s);
@@ -342,7 +342,7 @@ void SpacSelector::setLimits()
   // Ajust palette
   int maxCount=(int)_gridLayer->grid().maximumValue();
   ColorMap pal=_gridLayer->colorMap();
-  pal.generateColorScale(maxCount+2, ColorPalette::Hsv);
+  pal.generate(0, maxCount+1);
   pal.setColor(0, Qt::white);
   pal.setValues(0.5, maxCount+0.5, SamplingParameters::Linear);
   pal.setWhiteTransparent(true);
@@ -398,7 +398,7 @@ void SpacSelector::selectSamples()
   int nCells=options->nCells->value();
   int nCurves=curves->count();
   // Check that only two curve are visible
-  const QVector<double>& freq=*autocorrFactory.x();
+  const VectorList<double>& freq=*autocorrFactory.x();
   ModalCurve limits[2];
   int nLimits=0;
   for(int i=0;i<nCurves;i++) {
@@ -406,12 +406,15 @@ void SpacSelector::selectSamples()
       if(nLimits<2) {
         ModalCurve& f=static_cast<ModalLine *>(curves->currentLayer()->line(i))->curve();
         // Extrapole to cover the whole frequency range
-        if(f.firstX()>freq[0]) {
-          f.append(FactoryPoint(freq[0], f.firstY()));
+        int firstIndex=0, lastIndex=f.count()-1;
+        f.firstValid(firstIndex);
+        f.lastValid(lastIndex);
+        if(f.constAt(firstIndex).x()>freq[0]) {
+          f.append(FactoryPoint(freq[0], f.constAt(firstIndex).y()));
           f.sort();
         }
-        if(f.lastX()<freq.last()) {
-          f.append(FactoryPoint(freq.last(), f.lastY()));
+        if(f.constAt(lastIndex).x()<freq.last()) {
+          f.append(FactoryPoint(freq.last(), f.constAt(lastIndex).y()));
           f.sort();
         }
         limits[nLimits]=f;
@@ -465,7 +468,7 @@ void SpacSelector::selectSamples()
       if(index>-1) {
         const FactoryPoint& p=curve.constAt(index);
         double omega=2*M_PI*autocorrFactory.x()->at(iw);
-        QVector<double> solutions=eng.dispersion(omega, p.y(), omega*smin, omega*smax);
+        VectorList<double> solutions=eng.dispersion(omega, p.y(), omega*smin, omega*smax);
         for(int i=0; i<solutions.count() && i<_maxSolutionCount; i++) {
           double s=solutions.at(i);
           //printf("sol @ ring %i, %lf Hz %lf\n", ir, autocorrFactory.x()->at(iw), 1/s);
@@ -490,7 +493,7 @@ void SpacSelector::selectSamples()
       log+=str.arg(freq[iw]).arg(minS.y(iw)).arg(maxS.y(iw));
     selCurve.addLog(log);
     _selAutocorr->add(selCurve);
-    w->graphContent()->deepUpdate();
+    w->graphContents()->deepUpdate();
   }
 }
 
@@ -553,14 +556,14 @@ void SpacSelector::adjustCurve()
   TRACE;
   int index=curves->currentLine();
   if(index>=0) {
-    CurveProperties * properties=curves->curves().at(index);
+    CurvePropertiesWidget * properties=curves->curves().at(index);
     CurveProxy * proxy=properties->proxy();
     proxy->sort();
     if(proxy->sampleCount()==0) return;
     // Activate dialog
     CurveBrowserCut * d=new CurveBrowserCut(this);
     d->setCurveLimits(proxy->minimumX(), proxy->maximumX() );
-    d->setAxisNames(proxy->xName(), proxy->xInversedName());
+    d->setAxisNames(proxy->xName(), proxy->xInverseName());
     d->setWindowTitle(tr("Adjust"));
     Settings::getWidget(d, "SpacSelector::adjustCurve");
     if(d->exec()==QDialog::Accepted) {
@@ -568,8 +571,8 @@ void SpacSelector::adjustCurve()
       double minimum=d->minimumEdit->text().toDouble();
       double maximum=d->maximumEdit->text().toDouble();
       SamplingOptions options;
-      if(d->inversedBut->isChecked()) {
-        options=InversedScale;
+      if(d->inverseBut->isChecked()) {
+        options=InverseScale;
       } else {
         options=LinearScale;
       }
@@ -579,7 +582,7 @@ void SpacSelector::adjustCurve()
   }
 }
 
-void SpacSelector::adjustCurve(CurveProperties * properties, double min, double max, SamplingOptions options)
+void SpacSelector::adjustCurve(CurvePropertiesWidget * properties, double min, double max, SamplingOptions options)
 {
   TRACE;
   ModalProxy * proxy=static_cast<ModalProxy *>(properties->proxy());
@@ -594,8 +597,8 @@ void SpacSelector::adjustCurve(CurveProperties * properties, double min, double
   adjustCurve(c, min, max, options);
   invalidateRangeK(c);
   QString unit;
-  if(options & InversedScale) {
-    unit=proxy->xInversedUnit();
+  if(options & InverseScale) {
+    unit=proxy->xInverseUnit();
   } else {
     unit=proxy->xUnit();
   }
@@ -607,7 +610,7 @@ void SpacSelector::adjustCurve(ModalCurve& curve, double min, double max, Sampli
 {
   TRACE;
   // Transforms X scale according to options (log and inv)
-  if(options & InversedScale) {
+  if(options & InverseScale) {
     curve.xInverse();
   }
 
@@ -623,7 +626,7 @@ void SpacSelector::adjustCurve(ModalCurve& curve, double min, double max, Sampli
   grid.smooth(YAxis, smoothParam);
   grid.followMaximumX<ModalCurve, FactoryPoint>(curve, min, max);
   // Re-Transforms axis according options (log and inv)
-  if(options & InversedScale) {
+  if(options & InverseScale) {
     curve.xInverse();
   }
 }
@@ -668,12 +671,12 @@ void SpacSelector::exportPlot(const ExportOptions& o)
   }
   if(!o.appendLayerFiles().isEmpty()) {
     for(QStringList::const_iterator it=o.appendLayerFiles().begin(); it!=o.appendLayerFiles().end(); it++) {
-      w->graphContent()->appendLayers(*it);
+      w->graphContents()->appendLayers(*it);
     }
   }
   if(!o.prependLayerFiles().isEmpty()) {
     for(QStringList::const_iterator it=o.prependLayerFiles().begin(); it!=o.prependLayerFiles().end(); it++) {
-      w->graphContent()->prependLayers(*it);
+      w->graphContents()->prependLayers(*it);
     }
   }
   setLimits();
