@@ -49,7 +49,7 @@ static int maxSolutionCount=5, cellCount=-1;
 static ExportOptions exportOptions;
 static AutocorrCurves autocorr;
 static QString dispersionTargetFileName, autocorrTargetFileName;
-Reader maxReader;
+Reader * maxReader=nullptr;
 
 bool saveDispersions(ModalCurve& rayleigh, ModalCurve& love)
 {
@@ -167,7 +167,7 @@ int verticalDispersion()
 
 int verticalGui(const QString& title)
 {
-  SciFigsGlobal s;
+  SciFigsGlobal s(true);
   SpacSelector * w=new SpacSelector;
   w->setMaximumSolutionCount(maxSolutionCount);
   w->setWavenumberRange(kmin, kmax);
@@ -197,7 +197,7 @@ int verticalGui(const QString& title)
 
 int verticalPickCurve()
 {
-  SciFigsGlobal s;
+  SciFigsGlobal s(true);
   SpacSelector * w=new SpacSelector;
   w->setMaximumSolutionCount(maxSolutionCount);
   w->setWavenumberRange(kmin, kmax);
@@ -290,30 +290,30 @@ int allDispersion()
 int maxSpac2Disp(int argc, char ** argv)
 {
   if(vmin>0.0) {
-    maxReader.setMinimumVelocity(vmin);
+    maxReader->setMinimumVelocity(vmin);
   }
   if(vmax>0.0) {
-    maxReader.setMaximumVelocity(vmax);
+    maxReader->setMaximumVelocity(vmax);
   }
-  maxReader.setSamples(new Samples);
-  if(!maxReader.read(argc, argv, maxReader.ignoreStdin())) {
+  maxReader->setSamples(new Samples);
+  if(!maxReader->read(argc, argv, maxReader->ignoreStdin())) {
     return 2;
   }
-  if(maxReader.isEmpty()) {
-    if(!maxReader.read(Message::getOpenFileNames(tr("Open data file"),
-                                                 tr("SPAC Max files (*.max)")))) {
+  if(maxReader->isEmpty()) {
+    if(!maxReader->read(Message::getOpenFileNames(tr("Open data file"),
+                                                  tr("SPAC Max files (*.max)")))) {
       return 2;
     }
   }
-  if(maxReader.strictFrequencyRange()) {
-    if(!maxReader.setFrequencyRange(autocorr)){
+  if(maxReader->strictFrequencyRange()) {
+    if(!maxReader->setFrequencyRange(autocorr)){
       return 2;
     }
   }
-  return maxReader.convert();
+  return maxReader->convert();
 }
 
-int main(int argc, char ** argv)
+int main_helper(int argc, char ** argv)
 {
   Application a(argc, argv, help);
 
@@ -392,7 +392,8 @@ int main(int argc, char ** argv)
   case SelectTarget:
     break;
   case Max:
-    if(!maxReader.setOptions(argc, argv)) {
+    maxReader=new Reader;
+    if(!maxReader->setOptions(argc, argv)) {
       return 2;
     }
     break;
@@ -456,6 +457,13 @@ int main(int argc, char ** argv)
   return appReturn;
 }
 
+int main(int argc, char ** argv)
+{
+  int ret=main_helper(argc, argv);
+  delete maxReader;
+  return ret;
+}
+
 ApplicationHelp * help()
 {
   TRACE;
@@ -467,7 +475,7 @@ ApplicationHelp * help()
   h->addGroup("Spac2disp","spac2disp");
   h->addOption("-V","Vertical autocorrelation validation (default)");
   h->addOption("-VRT","Vertical, Radial and Tranverse component inversion, "
-                      "output '...-dist.target', '...-forward.target' and alpha through stdout.");
+                      "output '...-disp.target', '...-forward.target' and alpha through stdout.");
   h->addOption("-dispersion","Output the dispersion curve for each input autocorrelation curve. "
                              "Only for vertical component.");
   h->addOption("-pick [<FILE>]","Automatically pick or adjust curve loaded from FILE. Curve is sent to stdout."
