@@ -4,6 +4,7 @@
 #ifndef Q_OS_MAC
 #include <QGpCoreTools.h>
 #include <QGpCoreMath.h>
+#include <QGpCoreStat.h>
 #include <QGpCoreWave.h>
 #include <QGpGuiWave.h>
 #include <QGpCompatibility.h>
@@ -12,6 +13,8 @@
 #include <SciFigs.h>
 #include <DinverCore.h>
 #include <DinverGui.h>
+#include <GeopsyCore.h>
+#include <ArrayCore.h>
 #include <DinverDCCore.h>
 #endif // Q_OS_MAC
 #endif // __cplusplus
