@@ -63,8 +63,8 @@ WaranWidget::WaranWidget(QWidget * parent)
   seedlink->removeView();
   seedlink->seedLink()->setBufferType(SeedLinkStream::Rotate);
   setHVWindowLength(); // Just because seedLink rotate buffer is linked to this parameter
-  connect(seedlink->seedLink(), SIGNAL(endSignalChange(Signal *, TimeRange)),
-          this, SLOT(dataChanged(Signal *, TimeRange)), Qt::QueuedConnection);
+  connect(seedlink->seedLink(), SIGNAL(endSignalChange(Signal *, GeopsyCore::TimeRange)),
+          this, SLOT(dataChanged(Signal *, GeoypsCore::TimeRange)), Qt::QueuedConnection);
 
   signalViewer->setSignals(&_signals);
 
@@ -148,7 +148,7 @@ void WaranWidget::initResultGraph(AxisWindow * g, IrregularGrid2DPlot *& gridLay
   g->xAxis()->setFrequency();
   g->yAxis()->setRange(0.0,5.0);
   g->yAxis()->setTitle(tr("Slowness (s/m)"));
-  g->yAxis()->setTitleInversedScale(tr("Velocity (m/s)"));
+  g->yAxis()->setTitleInverseScale(tr("Velocity (m/s)"));
   g->updateExternalGeometry();
   gridLayer=new IrregularGrid2DPlot(g);
   gridLayer->setObjectName("histogram");
@@ -406,12 +406,15 @@ void WaranWidget::on_saveCoordinateButton_clicked()
 void WaranWidget::on_relativePositionButton_clicked()
 {
   TRACE;
-  RelativePositions * d=new RelativePositions(this);
+  Dialog * d=new Dialog(this);
+  d->setWindowTitle(tr("Relative positions"));
+  RelativePositions * relpos=new RelativePositions(d);
   QList<NamedPoint> points=_array.pointList();
-  d->setStationList(&points);
-  Settings::getWidget(d);
+  relpos->setStationList(&points);
+  d->setMainWidget(relpos, Dialog::TitleClose);
+  Settings::getWidget(d, "RelativePositions");
   d->exec();
-  Settings::setWidget(d);
+  Settings::setWidget(d, "RelativePositions");
   delete d;
 }
 
@@ -420,7 +423,7 @@ void WaranWidget::on_relativePositionButton_clicked()
 void WaranWidget::updateArrayResponse()
 {
   TRACE;
-  QVector<Point2D> respArray;
+  VectorList<Point2D> respArray;
   for(int i=_array.count()-1;i>=0;i--) {
     respArray.append(_array.at(i)->coordinates());
   }
@@ -464,9 +467,10 @@ void WaranWidget::updateCoArrayMap()
   // Construct the couple list
   int nStations=_array.count();
   int nCouples=nStations * (nStations - 1)/2;
-  QVector<StationPair> stationCouples(nCouples);
+  VectorList<StationPair> stationCouples(nCouples);
   QList<StationSignals *>::iterator statIt1, statIt2;
-  int iCouple=0;
+  //int iCouple=0;
+  TODO_WARNING;
   for(statIt1=_array.begin();statIt1!=_array.end();++statIt1) {
     statIt2=statIt1;
     //for( ++statIt2;statIt2!=_array.end();++statIt2, iCouple++ )
@@ -478,8 +482,9 @@ void WaranWidget::updateCoArrayMap()
   Curve<NamedPoint>& c=l->curve();
   c.resize(nCouples);
   for(int i=0;i < nCouples;i++ ) {
-    NamedPoint& p=c.at(i);
-    const StationPair& couple=stationCouples[i];
+    //NamedPoint& p=c.at(i);
+    //const StationPair& couple=stationCouples[i];
+    TODO_WARNING;
     /*const Point& p1=couple.station1()->coordinates();
     const Point& p2=couple.station2()->coordinates();
     double dx=p1.x() - p2.x();
