@@ -39,7 +39,7 @@ ApplicationHelp * help();
 int main(int argc, char ** argv)
 {
   Application a(argc, argv, help);
-  SciFigsGlobal s;
+  SciFigsGlobal s(true);
 
 #if 0
   // Options
